---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2016-12-11;232
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20161221&codiceRedaz=16G00242&dataVigenza=20251104
dataGU: 20161221
codiceRedaz: 16G00242
dataVigenza: 20251104
---

# Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019. (16G00242)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

### Sezione I - Misure quantitative per la realizzazione degli obiettivi programmatici

#### Art. 1. - Risultati differenziali. Norme in materia di entrata e di spesa e altre disposizioni. Fondi speciali

1. I livelli massimi del saldo netto da finanziare e del ricorso al mercato finanziario, in termini di competenza e di cassa, di cui all'articolo 21, comma 1-ter, lettera a), della legge 31 dicembre 2009, n. 196, per gli anni 2017, 2018 e 2019, sono indicati nell'allegato n. 1 annesso alla presente legge. I livelli del ricorso al mercato si intendono al netto delle operazioni effettuate al fine di rimborsare prima della scadenza o di ristrutturare passivita' preesistenti con ammortamento a carico dello Stato.

2. Al decreto-legge 4 giugno 2013, n. 63, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 90, sono apportate le seguenti modificazioni:

- a) all'articolo 14, concernente detrazioni fiscali per interventi di efficienza energetica: 1) le parole: «31 dicembre 2016», ovunque ricorrono, salvo quanto previsto dal numero 2) della presente lettera, sono sostituite dalle seguenti: «31 dicembre 2017»; 2) al comma 2, lettera a), le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «31 dicembre 2021»; 3) dopo il comma 2-ter sono inseriti i seguenti: «2-quater. Per le spese sostenute dal 1º gennaio 2017 al 31 dicembre 2021 per interventi di riqualificazione energetica di parti comuni degli edifici condominiali, che interessino l'involucro dell'edificio con un'incidenza superiore al 25 per cento della superficie disperdente lorda dell'edificio medesimo, la detrazione di cui al comma 1 spetta nella misura del 70 per cento. La medesima detrazione spetta, nella misura del 75 per cento, per le spese sostenute per interventi di riqualificazione energetica relativi alle parti comuni di edifici condominiali finalizzati a migliorare la prestazione energetica invernale ed estiva e che conseguano almeno la qualita' media di cui al decreto del Ministro dello sviluppo economico 26 giugno 2015, pubblicato nel supplemento ordinario n. 39 alla Gazzetta Ufficiale n. 162 del 15 luglio 2015. Le detrazioni di cui al presente articolo sono calcolate su un ammontare complessivo delle spese non superiore a euro 40.000 moltiplicato per il numero delle unita' immobiliari che compongono l'edificio. 2-quinquies. La sussistenza delle condizioni di cui al primo e al secondo periodo del comma 2-quater e' asseverata da professionisti abilitati mediante l'attestazione della prestazione energetica degli edifici di cui al citato decreto del Ministro dello sviluppo economico 26 giugno 2015. L'Agenzia nazionale per le nuove tecnologie, l'energia e lo sviluppo economico sostenibile (ENEA) effettua controlli, anche a campione, su tali dichiarazioni. La mancata veridicita' dell'attestazione comporta la decadenza dal beneficio, ferma restando la responsabilita' del professionista ai sensi delle disposizioni vigenti. 2-sexies. Per gli interventi di cui al comma 2-quater, a decorrere dal 1º gennaio 2017, in luogo della detrazione, i soggetti beneficiari possono optare per la cessione del corrispondente credito ai fornitori che hanno effettuato gli interventi ovvero ad altri soggetti privati, con la facolta' di successiva cessione del credito. Rimane esclusa la cessione ad istituti di credito e ad intermediari finanziari. Le modalita' di attuazione del presente comma sono definite con provvedimento del direttore dell'Agenzia delle entrate, da adottare entro sessanta giorni dalla data di entrata in vigore della presente disposizione. 2-septies. Le detrazioni di cui al comma 2-quater sono usufruibili anche dagli istituti autonomi per le case popolari, comunque denominati, per interventi realizzati su immobili di loro proprieta' adibiti ad edilizia residenziale pubblica»;
- b) all'articolo 15, comma 1, le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «31 dicembre 2017»;
- c) all'articolo 16, concernente detrazioni fiscali per interventi di ristrutturazione edilizia e per l'acquisto di mobili: 1) al comma 1, le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «31 dicembre 2017»; 2) il comma 1-bis e' sostituito dal seguente: «1-bis. Per le spese sostenute dal 1º gennaio 2017 al 31 dicembre 2021 per gli interventi di cui all'articolo 16-bis, comma 1, lettera i), del testo unico di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, le cui procedure autorizzatorie sono iniziate dopo la data di entrata in vigore della presente disposizione, su edifici ubicati nelle zone sismiche ad alta pericolosita' (zone 1 e 2) di cui all'ordinanza del Presidente del Consiglio dei ministri n. 3274 del 20 marzo 2003, pubblicata nel supplemento ordinario n. 72 alla Gazzetta Ufficiale n. 105 dell'8 maggio 2003, riferite a costruzioni adibite ad abitazione e ad attivita' produttive, spetta una detrazione dall'imposta lorda nella misura del 50 per cento, fino ad un ammontare complessivo delle stesse spese non superiore a 96.000 euro per unita' immobiliare per ciascun anno. La detrazione e' ripartita in cinque quote annuali di pari importo nell'anno di sostenimento delle spese e in quelli successivi. Nel caso in cui gli interventi di cui al presente comma realizzati in ciascun anno consistano nella mera prosecuzione di interventi iniziati in anni precedenti, ai fini del computo del limite massimo delle spese ammesse a fruire della detrazione si tiene conto anche delle spese sostenute negli stessi anni per le quali si e' gia' fruito della detrazione»; 3) dopo il comma 1-bis, come sostituito dal numero 2) della presente lettera, sono inseriti i seguenti: «1-ter. A decorrere dal 1º gennaio 2017 e fino al 31 dicembre 2021, le disposizioni del comma 1-bis si applicano anche agli edifici ubicati nella zona sismica 3 di cui all'ordinanza del Presidente del Consiglio dei ministri n. 3274 del 20 marzo 2003, pubblicata nel supplemento ordinario n. 72 alla Gazzetta Ufficiale n. 105 dell'8 maggio 2003. 1-quater. Qualora dalla realizzazione degli interventi di cui ai commi 1-bis e 1-ter derivi una riduzione del rischio sismico che determini il passaggio ad una classe di rischio inferiore, la detrazione dall'imposta spetta nella misura del 70 per cento della spesa sostenuta. Ove dall'intervento derivi il passaggio a due classi di rischio inferiori, la detrazione spetta nella misura dell'80 per cento. Con decreto del Ministro delle infrastrutture e dei trasporti, da adottare entro il 28 febbraio 2017, sentito il Consiglio superiore dei lavori pubblici, sono stabilite le linee guida per la classificazione di rischio sismico delle costruzioni nonche' le modalita' per l'attestazione, da parte di professionisti abilitati, dell'efficacia degli interventi effettuati. 1-quinquies. Qualora gli interventi di cui al comma 1-quater siano realizzati sulle parti comuni di edifici condominiali, le detrazioni dall'imposta di cui al primo e al secondo periodo del medesimo comma 1-quater spettano, rispettivamente, nella misura del 75 per cento e dell'85 per cento. Le predette detrazioni si applicano su un ammontare delle spese non superiore a euro 96.000 moltiplicato per il numero delle unita' immobiliari di ciascun edificio. Per tali interventi, a decorrere dal 1º gennaio 2017, in luogo della detrazione i soggetti beneficiari possono optare per la cessione del corrispondente credito ai fornitori che hanno effettuato gli interventi ovvero ad altri soggetti privati, con la facolta' di successiva cessione del credito. Rimane esclusa la cessione ad istituti di credito e ad intermediari finanziari. Le modalita' di attuazione del presente comma sono definite con provvedimento del direttore dell'Agenzia delle entrate, da adottare entro sessanta giorni dalla data di entrata in vigore della presente disposizione. 1-sexies. A decorrere dal 1º gennaio 2017, tra le spese detraibili per la realizzazione degli interventi di cui ai commi 1-ter, 1-quater e 1-quinquies rientrano anche le spese effettuate per la classificazione e verifica sismica degli immobili»; 4) il comma 2 e' sostituito dal seguente: «2. Ai contribuenti che fruiscono della detrazione di cui al comma 1, limitatamente agli interventi di recupero del patrimonio edilizio iniziati a decorrere dal 1º gennaio 2016, e' altresi' riconosciuta una detrazione dall'imposta lorda, fino a concorrenza del suo ammontare, per le ulteriori spese documentate sostenute nell'anno 2017 per l'acquisto di mobili e di grandi elettrodomestici di classe non inferiore ad A+, nonche' A per i forni, per le apparecchiature per le quali sia prevista l'etichetta energetica, finalizzati all'arredo dell'immobile oggetto di ristrutturazione. La detrazione di cui al presente comma, da ripartire tra gli aventi diritto in dieci quote annuali di pari importo, spetta nella misura del 50 per cento delle spese sostenute ed e' calcolata su un ammontare complessivo non superiore a 10.000 euro, considerato, per gli interventi effettuati nell'anno 2016 ovvero per quelli iniziati nel medesimo anno e proseguiti nel 2017, al netto delle spese sostenute nell'anno 2016 per le quali si e' fruito della detrazione. Ai fini della fruizione della detrazione dall'imposta, le spese di cui al presente comma sono computate indipendentemente dall'importo delle spese sostenute per i lavori di ristrutturazione che fruiscono delle detrazioni di cui al comma 1».

3. Le detrazioni di cui all'articolo 16, commi 1-bis, 1-ter, 1-quater, 1-quinquies e 1-sexies, del decreto-legge 4 giugno 2013, n. 63, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 90, come modificato dal comma 2 del presente articolo, non sono cumulabili con agevolazioni gia' spettanti per le medesime finalita' sulla base di norme speciali per interventi in aree colpite da eventi sismici.

4. Il credito d'imposta di cui all'articolo 10 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, e' riconosciuto anche per i periodi d'imposta 2017 e 2018, nella misura del 65 per cento, a condizione che gli interventi abbiano anche le finalita' di cui al comma 2 del presente articolo. Sono comprese tra i beneficiari del credito d'imposta di cui al periodo precedente anche le strutture che svolgono attivita' agrituristica, come definita dalla legge 20 febbraio 2006, n. 96, e dalle pertinenti norme regionali, nonche' le strutture di cui all'articolo 3 della legge 24 ottobre 2000, n. 323, queste ultime anche per la realizzazione di piscine termali e per l'acquisizione di attrezzature e apparecchiature necessarie per lo svolgimento delle attivita' termali.

5. Il credito d'imposta di cui al comma 4, come prorogato e modificato dal medesimo comma, e' ripartito in due quote annuali di pari importo e puo' essere utilizzato a decorrere dal periodo d'imposta successivo a quello in cui gli interventi sono stati realizzati, nel limite massimo di 60 milioni di euro nell'anno 2018, di 120 milioni di euro nell'anno 2019 e di 60 milioni di euro nell'anno 2020.

6. Per quanto non diversamente previsto dai commi 4 e 5 continuano ad applicarsi le disposizioni contenute nell'articolo 10 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106. Entro sessanta giorni dalla data di entrata in vigore della presente legge si provvede all'aggiornamento del decreto di cui all'articolo 10, comma 4, del citato decreto-legge n. 83 del 2014, convertito, con modificazioni, dalla legge n. 106 del 2014.

7. All'articolo 10, comma 7, del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, le parole: «e di 50 milioni di euro per gli anni dal 2016 al 2019» sono sostituite dalle seguenti: «, di 50 milioni di euro per l'anno 2016, di 41,7 milioni di euro per gli anni 2017 e 2018 e di 16,7 milioni di euro per l'anno 2019».

8. Le disposizioni dell'articolo 1, comma 91, della legge 28 dicembre 2015, n. 208, si applicano anche agli investimenti in beni materiali strumentali nuovi, esclusi i veicoli e gli altri mezzi di trasporto di cui all'articolo 164, comma 1, lettere b) e b-bis), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, effettuati entro il 31 dicembre 2017, ovvero entro il 30 giugno 2018 a condizione che entro la data del 31 dicembre 2017 il relativo ordine risulti accettato dal venditore e sia avvenuto il pagamento di acconti in misura almeno pari al 20 per cento del costo di acquisizione.

9. Al fine di favorire processi di trasformazione tecnologica e digitale secondo il modello «Industria 4.0», per gli investimenti in beni materiali strumentali nuovi compresi nell'elenco di cui all'allegato A annesso alla presente legge, il costo di acquisizione e' maggiorato del 150 per cento. La disposizione di cui al presente comma si applica agli investimenti effettuati entro il 31 dicembre 2017, ovvero entro il 30 settembre 2018, a condizione che entro la data del 31 dicembre 2017 il relativo ordine risulti accettato dal venditore e sia avvenuto il pagamento di acconti in misura almeno pari al 20 per cento del costo di acquisizione. (11) (24)

10. Per i soggetti che beneficiano della maggiorazione di cui al comma 9 e che, nel periodo indicato al comma 8, effettuano investimenti in beni immateriali strumentali compresi nell'elenco di cui all'allegato B annesso alla presente legge, il costo di acquisizione di tali beni e' maggiorato del 40 per cento. (11) (24)

11. Per la fruizione dei benefici di cui ai commi 9 e 10, l'impresa e' tenuta a produrre una dichiarazione resa dal legale rappresentante ai sensi del testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa, di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, ovvero, per i beni aventi ciascuno un costo di acquisizione superiore a 500.000 euro, una perizia tecnica giurata rilasciata da un ingegnere o da un perito industriale iscritti nei rispettivi albi professionali ovvero un attestato di conformita' rilasciato da un ente di certificazione accreditato, attestanti che il bene possiede caratteristiche tecniche tali da includerlo negli elenchi di cui all'allegato A o all'allegato B annessi alla presente legge ed e' interconnesso al sistema aziendale di gestione della produzione o alla rete di fornitura.

12. La determinazione degli acconti dovuti per il periodo d'imposta in corso al 31 dicembre 2017 e per quello successivo e' effettuata considerando quale imposta del periodo precedente quella che si sarebbe determinata in assenza delle disposizioni di cui ai commi 8, 9 e 10.

13. Resta ferma l'applicazione delle disposizioni di cui all'articolo 1, commi 93 e 97, della legge 28 dicembre 2015, n. 208.

14. All'articolo 21-quinquies del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, sono apportate le seguenti modificazioni:

- a) al comma 1, le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «31 dicembre 2017»;
- b) al comma 3, le parole: «e del 20 per cento per l'anno 2016» sono sostituite dalle seguenti: «, del 20 per cento per l'anno 2016 e del 15 per cento per l'anno 2017».

15. All'articolo 3 del decreto-legge 23 dicembre 2013, n. 145, convertito, con modificazioni, dalla legge 21 febbraio 2014, n. 9, riguardante il credito d'imposta per attivita' di ricerca e sviluppo, sono apportate le seguenti modificazioni:

- a) al comma 1, le parole: «fino a quello in corso al 31 dicembre 2019» sono sostituite dalle seguenti: «fino a quello in corso al 31 dicembre 2020» e le parole: «nella misura del 25 per cento delle spese» sono sostituite dalle seguenti: «nella misura del 50 per cento delle spese»;
- b) dopo il comma 1 e' inserito il seguente: «1-bis. Il credito d'imposta di cui al comma 1 spetta anche alle imprese residenti o alle stabili organizzazioni nel territorio dello Stato di soggetti non residenti che eseguono le attivita' di ricerca e sviluppo nel caso di contratti stipulati con imprese residenti o localizzate in altri Stati membri dell'Unione europea, negli Stati aderenti all'accordo sullo Spazio economico europeo ovvero in Stati compresi nell'elenco di cui al decreto del Ministro delle finanze 4 settembre 1996, pubblicato nella Gazzetta Ufficiale n. 220 del 19 settembre 1996»;
- c) al comma 3, le parole: «euro 5 milioni» sono sostituite dalle seguenti: «euro 20 milioni»;
- d) al comma 6, la lettera a) e' sostituita dalla seguente: «a) personale impiegato nelle attivita' di ricerca e sviluppo di cui al comma 4»;
- e) il comma 7 e' abrogato;
- f) al comma 8 sono aggiunte, in fine, le seguenti parole: «, a decorrere dal periodo d'imposta successivo a quello in cui sono stati sostenuti i costi di cui al comma 6 del presente articolo».

16. Le disposizioni di cui al comma 15, ad esclusione di quella di cui alla lettera f), hanno efficacia a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2016.

17. All'articolo 66 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, concernente le imprese minori, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Il reddito d'impresa dei soggetti che, secondo le disposizioni del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, applicano il regime di contabilita' semplificata, e' costituito dalla differenza tra l'ammontare dei ricavi di cui all'articolo 85 e degli altri proventi di cui all'articolo 89 percepiti nel periodo d'imposta e quello delle spese sostenute nel periodo stesso nell'esercizio dell'attivita' d'impresa. La differenza e' aumentata dei ricavi di cui all'articolo 57, dei proventi di cui all'articolo 90, comma 1, delle plusvalenze realizzate ai sensi dell'articolo 86 e delle sopravvenienze attive di cui all'articolo 88 e diminuita delle minusvalenze e sopravvenienze passive di cui all'articolo 101»;
- b) al comma 3: 1) al primo periodo, le parole: «109, commi 1, 2, 5, 7 e 9, lettera b)» sono sostituite dalle seguenti: «109, commi 5, 7 e 9, lettera b),»; 2) il terzo e il quarto periodo sono soppressi.

18. Il reddito del periodo d'imposta in cui si applicano le disposizioni dell'articolo 66 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, come modificato dal comma 17 del presente articolo, e' ridotto dell'importo delle rimanenze finali che hanno concorso a formare il reddito dell'esercizio precedente secondo il principio della competenza.

19. Al fine di evitare salti o duplicazioni di imposizione, nel caso di passaggio da un periodo d'imposta soggetto alla determinazione del reddito delle imprese minori ai sensi dell'articolo 66 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, a un periodo d'imposta soggetto a regime ordinario, e viceversa, i ricavi, i compensi e le spese che hanno gia' concorso alla formazione del reddito, in base alle regole del regime di determinazione del reddito d'impresa adottato, non assumono rilevanza nella determinazione del reddito degli anni successivi.

20. All'articolo 5-bis del decreto legislativo 15 dicembre 1997, n. 446, concernente la determinazione del valore della produzione netta delle societa' di persone e delle imprese individuali agli effetti dell'imposta regionale sulle attivita' produttive, dopo il comma 1 e' inserito il seguente: «1-bis. Per i soggetti di cui al comma 1, che determinano il reddito ai sensi dell'articolo 66 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, la base imponibile di cui al comma 1 del presente articolo e' determinata con i criteri previsti dal citato articolo 66».

21. Ai fini della determinazione della base imponibile dell'imposta regionale sulle attivita' produttive per i soggetti di cui al comma 1-bis dell'articolo 5-bis del decreto legislativo 15 dicembre 1997, n. 446, introdotto dal comma 20 del presente articolo, si applicano, in quanto compatibili, le disposizioni di cui ai commi 18 e 19 del presente articolo.

22. L'articolo 18 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e' sostituito dal seguente: «Art. 18 (Contabilita' semplificata per le imprese minori). - 1. Le disposizioni dei precedenti articoli si applicano anche ai soggetti che, a norma del codice civile, non sono obbligati alla tenuta delle scritture contabili di cui allo stesso codice. Tuttavia, i soggetti indicati alle lettere c) e d) del primo comma dell'articolo 13, qualora i ricavi indicati agli articoli 57 e 85 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, percepiti in un anno intero, ovvero conseguiti nell'ultimo anno di applicazione dei criteri previsti dall'articolo 109, comma 2, del medesimo testo unico, non abbiano superato l'ammontare di 400.000 euro per le imprese aventi per oggetto prestazioni di servizi, ovvero di 700.000 euro per le imprese aventi per oggetto altre attivita', sono esonerati per l'anno successivo dalla tenuta delle scritture contabili prescritte dai precedenti articoli, salvi gli obblighi di tenuta delle scritture previste da disposizioni diverse dal presente decreto. Per i contribuenti che esercitano contemporaneamente prestazioni di servizi e altre attivita' si fa riferimento all'ammontare dei ricavi relativi all'attivita' prevalente. In mancanza della distinta annotazione dei ricavi, si considerano prevalenti le attivita' diverse dalle prestazioni di servizi. Con decreto del Ministro dell'economia e delle finanze sono stabiliti i criteri per l'individuazione delle attivita' consistenti nella prestazione di servizi. 2. I soggetti che fruiscono dell'esonero di cui al comma 1 devono annotare cronologicamente in un apposito registro i ricavi percepiti indicando per ciascun incasso: a) il relativo importo; b) le generalita', l'indirizzo e il comune di residenza anagrafica del soggetto che effettua il pagamento; c) gli estremi della fattura o altro documento emesso. Devono essere altresi' annotate cronologicamente, in diverso registro e con riferimento alla data di pagamento, le spese sostenute nell'esercizio. Per ciascuna spesa devono essere fornite le indicazioni di cui alle lettere b) e c) del primo periodo. 3. I componenti positivi e negativi di reddito, diversi da quelli indicati al comma 2, sono annotati nei registri obbligatori di cui al medesimo comma 2 entro il termine di presentazione della dichiarazione dei redditi. 4. I registri tenuti ai fini dell'imposta sul valore aggiunto sostituiscono i registri indicati al comma 2, qualora vi siano iscritte separate annotazioni delle operazioni non soggette a registrazione ai fini della suddetta imposta. In luogo delle singole annotazioni relative a incassi e pagamenti, nell'ipotesi in cui l'incasso o il pagamento non sia avvenuto nell'anno di registrazione, nei registri deve essere riportato l'importo complessivo dei mancati incassi o pagamenti con indicazione delle fatture cui le operazioni si riferiscono. In tal caso, i ricavi percepiti e i costi sostenuti devono essere annotati separatamente nei registri stessi nel periodo d'imposta in cui vengono incassati o pagati, indicando ai sensi del comma 2, lettera c), il documento contabile gia' registrato ai fini dell'imposta sul valore aggiunto. 5. Previa opzione, vincolante per almeno un triennio, i contribuenti possono tenere i registri ai fini dell'imposta sul valore aggiunto senza operare annotazioni relative a incassi e pagamenti, fermo restando l'obbligo della separata annotazione delle operazioni non soggette a registrazione ai fini della suddetta imposta. In tal caso, per finalita' di semplificazione si presume che la data di registrazione dei documenti coincida con quella in cui e' intervenuto il relativo incasso o pagamento. 6. I soggetti esonerati dagli adempimenti relativi all'imposta sul valore aggiunto ai sensi dell'articolo 34 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, non sono tenuti ad osservare le disposizioni dei commi 2, 3 e 4 del presente articolo. 7. Il regime di contabilita' semplificata previsto nel presente articolo si estende di anno in anno qualora non vengano superati gli importi indicati nel comma 1. 8. Il contribuente ha facolta' di optare per il regime ordinario. L'opzione ha effetto dall'inizio del periodo d'imposta nel corso del quale e' esercitata fino a quando non e' revocata e, in ogni caso, per il periodo stesso e per i due successivi. 9. I soggetti che intraprendono l'esercizio di impresa commerciale, qualora ritengano di percepire ricavi per un ammontare, ragguagliato ad un anno, non superiore ai limiti indicati al comma 1, possono, per il primo anno, tenere la contabilita' semplificata di cui al presente articolo. 10. Per i rivenditori, in base a contratti estimatori, di giornali, di libri e di periodici, anche su supporti audiovideomagnetici, e per i distributori di carburante, ai fini del calcolo dei limiti di ammissione ai regimi semplificati di contabilita', i ricavi percepiti si assumono al netto del prezzo corrisposto al fornitore dei predetti beni. Per le cessioni di generi di monopolio, valori bollati e postali, marche assicurative e valori similari, si considerano ricavi gli aggi percepiti spettanti ai rivenditori. 11. Ai fini del presente articolo si assumono come ricavi conseguiti nel periodo d'imposta le somme incassate registrate nel registro di cui al comma 2, primo periodo, ovvero nel registro di cui al comma 4».

23. Le disposizioni di cui ai commi da 17 a 22 si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2016. Con decreto del Ministro dell'economia e delle finanze, entro trenta giorni dalla data di entrata in vigore della presente legge, possono essere adottate disposizioni per l'attuazione dei predetti commi.

24. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, dopo l'articolo 70 e' inserito il seguente titolo: «TITOLO V-bis GRUPPO IVA Art. 70-bis (Requisiti soggettivi per la costituzione di un gruppo IVA). - 1. I soggetti passivi stabiliti nel territorio dello Stato esercenti attivita' d'impresa, arte o professione, per i quali ricorrano congiuntamente i vincoli finanziario, economico e organizzativo di cui all'articolo 70-ter, possono divenire un unico soggetto passivo, di seguito denominato "gruppo IVA". 2. Non possono partecipare a un gruppo IVA: a) le sedi e le stabili organizzazioni situate all'estero; b) i soggetti la cui azienda sia sottoposta a sequestro giudiziario ai sensi dell'articolo 670 del codice di procedura civile; in caso di pluralita' di aziende, la disposizione opera anche se oggetto di sequestro e' una sola di esse; c) i soggetti sottoposti a una procedura concorsuale di cui all'articolo 70-decies, comma 3, terzo periodo; d) i soggetti posti in liquidazione ordinaria. Art. 70-ter (Vincolo finanziario, vincolo economico e vincolo organizzativo). - 1. Si considera sussistente un vincolo finanziario tra soggetti passivi stabiliti nel territorio dello Stato quando, ai sensi dell'articolo 2359, primo comma, numero 1), del codice civile e almeno dal 1º luglio dell'anno solare precedente: a) tra detti soggetti esiste, direttamente o indirettamente, un rapporto di controllo; b) detti soggetti sono controllati, direttamente o indirettamente, dal medesimo soggetto, purche' residente nel territorio dello Stato ovvero in uno Stato con il quale l'Italia ha stipulato un accordo che assicura un effettivo scambio di informazioni. 2. Si considera sussistente un vincolo economico tra soggetti passivi stabiliti nel territorio dello Stato sulla base dell'esistenza di almeno una delle seguenti forme di cooperazione economica: a) svolgimento di un'attivita' principale dello stesso genere; b) svolgimento di attivita' complementari o interdipendenti; c) svolgimento di attivita' che avvantaggiano, pienamente o sostanzialmente, uno o piu' di essi. 3. Si considera sussistente un vincolo organizzativo tra soggetti passivi stabiliti nel territorio dello Stato quando tra detti soggetti esiste un coordinamento, in via di diritto, ai sensi delle disposizioni di cui al libro quinto, titolo V, capo IX, del codice civile, o in via di fatto, tra gli organi decisionali degli stessi, ancorche' tale coordinamento sia svolto da un altro soggetto. 4. Salvo quanto disposto dal comma 5, se tra i soggetti passivi intercorre il vincolo finanziario di cui al comma 1, si presumono sussistenti tra i medesimi anche i vincoli economico e organizzativo di cui ai commi 2 e 3. 5. Per dimostrare l'insussistenza del vincolo economico o di quello organizzativo, e' presentata all'Agenzia delle entrate istanza di interpello ai sensi dell'articolo 11, comma 1, lettera b), della legge 27 luglio 2000, n. 212. 6. Il vincolo economico si considera in ogni caso insussistente per i soggetti per i quali il vincolo finanziario di cui al comma 1 ricorre in dipendenza di partecipazioni acquisite nell'ambito degli interventi finalizzati al recupero di crediti o derivanti dalla conversione in azioni di nuova emissione dei crediti verso imprese in temporanea difficolta' finanziaria, di cui all'articolo 113, comma 1, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917. Per dimostrare la sussistenza del vincolo economico e' presentata all'Agenzia delle entrate istanza di interpello ai sensi dell'articolo 11, comma 1, lettera b), della citata legge n. 212 del 2000. Art. 70-quater (Costituzione del gruppo IVA). - 1. Il gruppo IVA e' costituito a seguito di un'opzione esercitata da tutti i soggetti passivi stabiliti nel territorio dello Stato per i quali ricorrano congiuntamente i vincoli finanziario, economico e organizzativo di cui all'articolo 70-ter. In caso di mancato esercizio dell'opzione da parte di uno o piu' dei soggetti di cui al periodo precedente: a) e' recuperato a carico del gruppo IVA l'effettivo vantaggio fiscale conseguito; b) il gruppo IVA cessa a partire dall'anno successivo rispetto a quello in cui viene accertato il mancato esercizio dell'opzione, a meno che i predetti soggetti non esercitino l'opzione per partecipare al gruppo medesimo. 2. L'opzione di cui al comma 1 e' esercitata mediante la presentazione, in via telematica, da parte del rappresentante del gruppo, della dichiarazione di cui all'articolo 70-duodecies, comma 5, nella quale sono indicati: a) la denominazione del gruppo IVA; b) i dati identificativi del rappresentante del gruppo IVA, di seguito denominato "rappresentante di gruppo", e dei soggetti partecipanti al gruppo medesimo; c) l'attestazione della sussistenza, tra i soggetti partecipanti al gruppo, dei vincoli di cui all'articolo 70-ter; d) l'attivita' o le attivita' che saranno svolte dal gruppo IVA; e) l'elezione di domicilio presso il rappresentante di gruppo da parte di ciascun soggetto partecipante al gruppo medesimo, ai fini della notifica degli atti e dei provvedimenti relativi ai periodi d'imposta per i quali e' esercitata l'opzione; l'elezione di domicilio e' irrevocabile fino al termine del periodo di decadenza dell'azione di accertamento o di irrogazione delle sanzioni relative all'ultimo anno di validita' dell'opzione; f) la sottoscrizione del rappresentante di gruppo, che presenta la dichiarazione, e degli altri soggetti di cui al presente comma. 3. Se la dichiarazione di cui al comma 2 e' presentata dal 1º gennaio al 30 settembre, l'opzione di cui al comma 1 ha effetto a decorrere dall'anno successivo. Se la dichiarazione di cui al comma 2 e' presentata dal 1º ottobre al 31 dicembre, l'opzione di cui al comma 1 ha effetto a decorrere dal secondo anno successivo. 4. Permanendo i vincoli di cui all'articolo 70-ter, l'opzione e' vincolante per un triennio decorrente dall'anno in cui la stessa ha effetto. Trascorso il primo triennio, l'opzione si rinnova automaticamente per ciascun anno successivo, fino a quando non e' esercitata la revoca di cui all'articolo 70-novies. Resta fermo quanto disposto dal comma 1, lettera b). 5. Se negli anni di validita' dell'opzione di cui al comma 1 i vincoli economico e organizzativo di cui all'articolo 70-ter, commi 2 e 3, si instaurano nei riguardi dei soggetti che erano stati esclusi dal gruppo IVA ai sensi del comma 5 del medesimo articolo, ovvero se il vincolo finanziario di cui all'articolo 70-ter, comma 1, si instaura nei riguardi di soggetti passivi stabiliti nel territorio dello Stato relativamente ai quali non sussisteva all'atto dell'esercizio dell'opzione, i predetti soggetti partecipano al gruppo IVA a decorrere dall'anno successivo a quello in cui tali vincoli si sono instaurati. In tal caso, la dichiarazione di cui al comma 2 deve essere presentata entro il novantesimo giorno successivo a quello in cui tali vincoli si sono instaurati. In caso di mancata inclusione di un soggetto di cui al primo periodo nel gruppo IVA, si applicano le disposizioni del secondo periodo del comma 1. Art. 70-quinquies (Operazioni effettuate dal gruppo IVA e nei confronti di esso). - 1. Le cessioni di beni e le prestazioni di servizi effettuate da un soggetto partecipante a un gruppo IVA nei confronti di un altro soggetto partecipante allo stesso gruppo IVA non sono considerate cessioni di beni e prestazioni di servizi agli effetti degli articoli 2 e 3. 2. Le cessioni di beni e le prestazioni di servizi effettuate da un soggetto partecipante a un gruppo IVA nei confronti di un soggetto che non ne fa parte si considerano effettuate dal gruppo IVA. 3. Le cessioni di beni e le prestazioni di servizi effettuate nei confronti di un soggetto partecipante a un gruppo IVA da un soggetto che non ne fa parte si considerano effettuate nei confronti del gruppo IVA. 4. Gli obblighi e i diritti derivanti dall'applicazione delle norme in materia di imposta sul valore aggiunto sono, rispettivamente, a carico e a favore del gruppo IVA. Art. 70-sexies (Eccedenze creditorie antecedenti alla partecipazione al gruppo IVA). - 1. L'eccedenza di imposta detraibile risultante dalla dichiarazione annuale relativa all'anno precedente al primo anno di partecipazione al gruppo IVA non si trasferisce al gruppo medesimo, ma puo' essere chiesta a rimborso, anche in mancanza delle condizioni di cui all'articolo 30 del presente decreto, ovvero compensata a norma dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241. La disposizione di cui al primo periodo non si applica per la parte dell'eccedenza detraibile di ammontare pari ai versamenti dell'imposta sul valore aggiunto effettuati con riferimento a tale precedente anno. Art. 70-septies (Adempimenti). - 1. Il rappresentante di gruppo adempie gli obblighi ed esercita i diritti di cui all'articolo 70-quinquies, comma 4, nei modi ordinari. 2. Il rappresentante di gruppo e' il soggetto che esercita il controllo di cui all'articolo 70-ter, comma 1. Se il predetto soggetto non puo' esercitare l'opzione, e' rappresentante di gruppo il soggetto partecipante con volume d'affari o ammontare di ricavi piu' elevato nel periodo precedente alla costituzione del gruppo medesimo. 3. Se il rappresentante di gruppo cessa di far parte del gruppo IVA senza che vengano meno gli effetti dell'opzione per gli altri partecipanti, subentra quale rappresentante di gruppo un altro soggetto partecipante al gruppo IVA, individuato ai sensi del comma 2, con riferimento all'ultima dichiarazione presentata. La sostituzione ha effetto dal giorno successivo alla cessazione del precedente rappresentante di gruppo ed e' comunicata dal nuovo rappresentante di gruppo con la dichiarazione di cui all'articolo 70-duodecies, comma 5, entro trenta giorni. Art. 70-octies (Responsabilita'). - 1. Il rappresentante di gruppo e' responsabile per l'adempimento degli obblighi connessi all'esercizio dell'opzione. 2. Gli altri soggetti partecipanti al gruppo IVA sono responsabili in solido con il rappresentante di gruppo per le somme che risultano dovute a titolo di imposta, interessi e sanzioni a seguito delle attivita' di liquidazione e controllo. Art. 70-novies (Disposizioni in materia di opzioni e revoche). - 1. La revoca dell'opzione esercitata ai sensi dell'articolo 70-quater e' comunicata dal rappresentante di gruppo con la dichiarazione di cui all'articolo 70-duodecies, comma 5, sottoscritta anche dagli altri soggetti partecipanti al gruppo IVA. 2. La revoca dell'opzione opera nei riguardi di tutti i soggetti partecipanti al gruppo IVA. Se la dichiarazione di cui al comma 1 e' presentata dal 1º gennaio al 30 settembre, la revoca ha effetto a decorrere dall'anno successivo. Se la dichiarazione di cui al comma 1 e' presentata dal 1º ottobre al 31 dicembre, la revoca ha effetto a decorrere dal secondo anno successivo. 3. Alle opzioni e alle revoche previste dal presente titolo non si applicano le disposizioni del regolamento di cui al decreto del Presidente della Repubblica 10 novembre 1997, n. 442. 4. L'esercizio da parte di un soggetto dell'opzione di cui all'articolo 70-quater comporta il venir meno degli effetti delle opzioni in materia di imposta sul valore aggiunto esercitate dallo stesso in precedenza, anche se non e' decorso il periodo minimo di permanenza nel particolare regime prescelto. Art. 70-decies (Esclusione dalla partecipazione al gruppo IVA). - 1. L'opzione di cui all'articolo 70-quater, comma 1, da parte di un soggetto, per il quale non sussistono i requisiti di cui all'articolo 70-bis, e' priva di effetti limitatamente a tale soggetto. 2. Ciascun soggetto partecipante a un gruppo IVA cessa di partecipare al gruppo medesimo se si verifica uno dei seguenti casi: a) viene meno il vincolo finanziario nei riguardi di tale soggetto; b) e' riconosciuto, ai sensi dell'articolo 70-ter, comma 5, il venir meno del vincolo economico od organizzativo nei riguardi di tale soggetto; c) tale soggetto subisce il sequestro giudiziario dell'azienda ai sensi dell'articolo 670 del codice di procedura civile; d) tale soggetto e' sottoposto a una procedura concorsuale; e) tale soggetto e' posto in liquidazione ordinaria. 3. La partecipazione al gruppo IVA cessa a decorrere dalla data in cui si verificano gli eventi previsti nel comma 2, lettere a), c), d) o e), e ha effetto per le operazioni compiute e per gli acquisti e le importazioni annotati a partire da tale data. Nell'ipotesi di cui al comma 2, lettera b), la partecipazione al gruppo IVA cessa a decorrere dall'anno successivo a quello in cui e' riconosciuto il venir meno del vincolo. Per l'individuazione della data in cui si verifica l'evento, nelle ipotesi di cui alle lettere c), d) o e) del comma 2, si fa riferimento alla data di efficacia del provvedimento che dispone il sequestro giudiziario, alla data della sentenza dichiarativa del fallimento, alla data del decreto di ammissione al concordato preventivo, alla data del provvedimento che ordina la liquidazione coatta amministrativa, alla data del decreto che dispone la procedura di amministrazione straordinaria delle grandi imprese in crisi o alla data di assunzione della delibera assembleare della liquidazione ordinaria. 4. Il gruppo IVA cessa quando viene meno la pluralita' dei soggetti partecipanti. In tal caso, l'eccedenza detraibile risultante dalla dichiarazione del gruppo IVA non chiesta a rimborso e' computata in detrazione dal soggetto partecipante che agiva in qualita' di rappresentante di gruppo nelle proprie liquidazioni o nella propria dichiarazione annuale. 5. La cessazione di cui ai commi 2 e 4 e' comunicata dal rappresentante di gruppo entro trenta giorni dalla data in cui si sono verificati gli eventi, con la dichiarazione di cui all'articolo 70-duodecies, comma 5. Art. 70-undecies (Attivita' di controllo). - 1. Per le annualita' di validita' dell'opzione, l'esercizio dei poteri previsti dagli articoli 51 e seguenti nei confronti del gruppo IVA e' demandato alle strutture, gia' esistenti, individuate con il regolamento di amministrazione dell'Agenzia delle entrate, di cui all'articolo 71, comma 3, del decreto legislativo 30 luglio 1999, n. 300, nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente. 2. Alle strutture di cui al comma 1 sono demandate le attivita' di: a) liquidazione prevista dall'articolo 54-bis; b) controllo sostanziale; c) recupero dei crediti inesistenti utilizzati in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241; d) gestione del contenzioso relativo a tutti gli atti di competenza delle strutture stesse; e) rimborso in materia di imposta sul valore aggiunto. 3. Ai fini delle attivita' di controllo, nell'ipotesi di disconoscimento della validita' dell'opzione il recupero dell'imposta avviene nei limiti dell'effettivo vantaggio fiscale conseguito. 4. Con provvedimento del direttore dell'Agenzia delle entrate sono stabiliti specifici adempimenti finalizzati ad assicurare l'efficacia delle attivita' di controllo. Art. 70-duodecies (Disposizioni speciali e di attuazione). - 1. Le modalita' e i termini speciali di emissione, numerazione e registrazione delle fatture nonche' di esecuzione delle liquidazioni e dei versamenti periodici stabiliti dai decreti ministeriali emanati ai sensi degli articoli 22, secondo comma, 73 e 74 si applicano alle operazioni soggette a tali disposizioni effettuate dal gruppo IVA. 2. Se al gruppo IVA partecipano una o piu' banche, alle operazioni riferibili a queste ultime si applicano le disposizioni del regolamento di cui al decreto del Ministro dell'economia e delle finanze 12 febbraio 2004, n. 75. 3. Se al gruppo IVA partecipano una o piu' societa' assicurative, alle operazioni riferibili a queste ultime si applicano le disposizioni di cui al decreto del Ministro delle finanze 30 maggio 1989, pubblicato nella Gazzetta Ufficiale n. 129 del 5 giugno 1989. 4. Le disposizioni di cui all'articolo 8, comma 1, secondo, quarto e quinto periodo, del decreto-legge 25 settembre 2001, n. 351, convertito, con modificazioni, dalla legge 23 novembre 2001, n. 410, si applicano anche nei casi in cui una societa' di gestione di fondi partecipi a un gruppo IVA. 5. Con provvedimento del direttore dell'Agenzia delle entrate sono approvati il modello per la presentazione delle dichiarazioni di cui al presente titolo nonche' le modalita' e le specifiche tecniche per la trasmissione telematica delle stesse. 6. Con decreto del Ministro dell'economia e delle finanze sono stabilite le disposizioni necessarie per l'attuazione del presente titolo».

25. Nella tabella di cui all'allegato B al decreto del Presidente della Repubblica 26 ottobre 1972, n. 642, indicante atti, documenti e registri esenti dall'imposta di bollo in modo assoluto, dopo l'articolo 6 e' inserito il seguente: «Art. 6-bis. Fatture, note, conti, ricevute, quietanze e simili documenti, recanti addebitamenti o accreditamenti relativi a cessioni di beni e prestazioni di servizi tra soggetti partecipanti a un gruppo IVA. La disposizione si applica per le operazioni per le quali, se effettuate nei confronti di un soggetto non partecipante a un gruppo IVA, si applicherebbero le esenzioni di cui agli articoli 6 e 15 della presente tabella e all'articolo 66, comma 5, del decreto-legge 30 agosto 1993, n. 331, convertito, con modificazioni, dalla legge 29 ottobre 1993, n. 427».

26. Al testo unico dell'imposta di registro, di cui al decreto del Presidente della Repubblica 26 aprile 1986, n. 131, sono apportate le seguenti modificazioni:

- a) all'articolo 5, il comma 2 e' sostituito dal seguente: «2. Le scritture private non autenticate sono soggette a registrazione in caso d'uso se tutte le disposizioni in esse contemplate sono relative a operazioni soggette all'imposta sul valore aggiunto. Si considerano soggette all'imposta sul valore aggiunto anche le cessioni e le prestazioni tra soggetti partecipanti a un gruppo IVA, le cessioni e le prestazioni per le quali l'imposta non e' dovuta a norma degli articoli da 7 a 7-septies del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e quelle di cui al comma 6 dell'articolo 21 del medesimo decreto del Presidente della Repubblica n. 633 del 1972. La disposizione del periodo precedente non si applica alle operazioni esenti e imponibili ai sensi dei numeri 8), 8-bis), 8-ter) e 27-quinquies) del primo comma dell'articolo 10 del citato decreto n. 633 del 1972 e alle locazioni di immobili esenti ai sensi del secondo comma del medesimo articolo 10, nonche' alle cessioni di beni e alle prestazioni di servizi tra soggetti partecipanti a un gruppo IVA per le quali, se effettuate nei confronti di un soggetto non partecipante al gruppo IVA, si applicherebbero le suddette disposizioni»;
- b) all'articolo 40: 1) il comma 1 e' sostituito dal seguente: «1. Per gli atti relativi a cessioni di beni e prestazioni di servizi soggetti all'imposta sul valore aggiunto, l'imposta si applica in misura fissa. Si considerano soggette all'imposta sul valore aggiunto anche le cessioni e le prestazioni tra soggetti partecipanti a un gruppo IVA, le cessioni e le prestazioni per le quali l'imposta non e' dovuta a norma degli articoli da 7 a 7-septies del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e quelle di cui al comma 6 dell'articolo 21 del medesimo decreto del Presidente della Repubblica n. 633 del 1972. La disposizione del periodo precedente non si applica alle operazioni esenti ai sensi dei numeri 8), 8-bis) e 27-quinquies) del primo comma dell'articolo 10 del citato decreto n. 633 del 1972 e alle locazioni di immobili esenti ai sensi del secondo comma del medesimo articolo 10, nonche' alle cessioni di beni e alle prestazioni di servizi tra soggetti partecipanti a un gruppo IVA per le quali, se effettuate nei confronti di un soggetto non partecipante al gruppo IVA, si applicherebbero le suddette disposizioni»; 2) il comma 1-bis e' sostituito dal seguente: «1-bis. Sono soggette all'imposta proporzionale di registro le locazioni di immobili strumentali di cui all'articolo 10, primo comma, numero 8), del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, ancorche' siano imponibili agli effetti dell'imposta sul valore aggiunto ovvero intervengano tra soggetti partecipanti a un gruppo IVA».

27. All'articolo 73 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modificazioni:

- a) le parole: «Ministro delle finanze», ovunque ricorrono, sono sostituite dalle seguenti: «Ministro dell'economia e delle finanze»;
- b) il terzo comma e' sostituito dal seguente: «Il Ministro dell'economia e delle finanze puo' disporre con propri decreti, stabilendo le relative modalita', che i versamenti periodici, compreso quello di cui all'articolo 6, comma 2, della legge 29 dicembre 1990, n. 405, e i versamenti dell'imposta dovuta in base alla dichiarazione annuale siano eseguiti per l'ammontare complessivamente dovuto dall'ente o societa' commerciale controllante e dagli enti o societa' commerciali controllati, al netto delle eccedenze detraibili; l'ente o societa' commerciale controllante comunica all'Agenzia delle entrate l'esercizio dell'opzione per la predetta procedura di versamento con la dichiarazione ai fini dell'imposta sul valore aggiunto presentata nell'anno solare a decorrere dal quale intende esercitare l'opzione. Agli effetti dei versamenti di cui al precedente periodo non si tiene conto delle eccedenze detraibili, risultanti dalle dichiarazioni annuali relative al periodo d'imposta precedente, degli enti e societa' diversi da quelli per i quali anche in tale periodo d'imposta l'ente o societa' controllante si e' avvalso della facolta' di cui al presente comma. Alle eccedenze detraibili degli enti e delle societa' per i quali trova applicazione la disposizione di cui al precedente periodo si applicano le disposizioni di cui all'articolo 30. Restano fermi gli altri obblighi e le responsabilita' delle societa' controllate. Si considera controllata la societa' le cui azioni o quote sono possedute per oltre la meta' dall'altra, almeno dal 1º luglio dell'anno solare precedente a quello di esercizio dell'opzione».

28. Il Ministro dell'economia e delle finanze, con proprio decreto, adegua le vigenti disposizioni ministeriali alle modificazioni introdotte dal comma 27, lettera b).

29. Il regolamento di amministrazione dell'Agenzia delle entrate, di cui all'articolo 71, comma 3, del decreto legislativo 30 luglio 1999, n. 300, puo' attribuire alle medesime strutture, gia' esistenti, di cui al comma 1 dell'articolo 70-undecies del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, introdotto dal comma 24 del presente articolo, nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, i poteri previsti dagli articoli 31 e seguenti del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, nei confronti dei soggetti che aderiscono al gruppo IVA.

30. Le disposizioni di cui ai commi 27 e 28 si applicano dal 1º gennaio 2017; le altre disposizioni di cui ai commi 24, 25, 26 e 29 si applicano dal 1º gennaio 2018.

31. Per le disposizioni di cui al comma 24 il Ministero dell'economia e delle finanze procede alla consultazione del Comitato consultivo dell'imposta sul valore aggiunto, ai sensi dell'articolo 11 della direttiva 2006/112/CE del Consiglio, del 28 novembre 2006.

32. All'articolo 16 del decreto-legge 14 febbraio 2016, n. 18, convertito, con modificazioni, dalla legge 8 aprile 2016, n. 49, sono apportate le seguenti modificazioni:

- a) al comma 1, le parole: «due anni» sono sostituite dalle seguenti: «cinque anni»;
- b) al comma 2, la parola: «biennio» e' sostituita dalla seguente: «quinquennio»;
- c) al comma 3, le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «30 giugno 2017».

33. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modificazioni:

- a) all'articolo 10, comma 1, numero 14), le parole: «o altri mezzi di trasporto abilitati ad eseguire servizi di trasporto marittimo, lacuale, fluviale e lagunare» sono soppresse;
- b) alla tabella A, parte II-bis, dopo il numero 1-bis) e' aggiunto il seguente: «1-ter) prestazioni di trasporto urbano di persone effettuate mediante mezzi di trasporto abilitati ad eseguire servizi di trasporto marittimo, lacuale, fluviale e lagunare»;
- c) alla tabella A, parte III, numero 127-novies), dopo la parola: «escluse» sono inserite le seguenti: «quelle di cui alla tabella A, parte II-bis, numero 1-ter), e».

34. La tariffa amministrata per i servizi di trasporto marittimo, lacuale, fluviale e lagunare e' comunque comprensiva dell'imposta sul valore aggiunto.

35. Le disposizioni di cui ai commi 33 e 34 si applicano alle operazioni effettuate a decorrere dal 1º gennaio 2017.

36. Dopo il comma 2 dell'articolo 25-ter del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, introdotto dall'articolo 1, comma 43, della legge 27 dicembre 2006, n. 296, sono aggiunti i seguenti: «2-bis. Il versamento della ritenuta di cui al comma 1 e' effettuato dal condominio quale sostituto d'imposta quando l'ammontare delle ritenute operate raggiunga l'importo di euro 500. Il condominio e' comunque tenuto all'obbligo di versamento entro il 30 giugno e il 20 dicembre di ogni anno anche qualora non sia stato raggiunto l'importo stabilito al primo periodo. 2-ter. Il pagamento dei corrispettivi di cui al comma 1 deve essere eseguito dai condomini tramite conti correnti bancari o postali a loro intestati ovvero secondo altre modalita' idonee a consentire all'amministrazione finanziaria lo svolgimento di efficaci controlli, che possono essere stabilite con decreto del Ministro dell'economia e delle finanze da emanare ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400. L'inosservanza della presente disposizione comporta l'applicazione delle sanzioni previste dal comma 1 dell'articolo 11 del decreto legislativo 18 dicembre 1997, n. 471».

37. All'articolo 164, comma 1, lettera b), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, l'ultimo periodo e' sostituito dal seguente: «I predetti limiti di 35 milioni di lire e di 7 milioni di lire sono elevati rispettivamente a euro 25.822,84 e a euro 5.164,57 per gli autoveicoli utilizzati da agenti o rappresentanti di commercio».

38. Al fine di semplificare e razionalizzare il sistema delle tasse automobilistiche, senza nuovi o maggiori oneri per la finanza pubblica, la facolta' di pagamento cumulativo ai sensi dell'articolo 7, comma 1, della legge 23 luglio 2009, n. 99, e' estesa alle aziende con flotte di auto e camion delle quali siano proprietarie, usufruttuarie, acquirenti con patto di riservato dominio ovvero utilizzatrici a titolo di locazione finanziaria.

39. I versamenti cumulativi di cui al comma 38 del presente articolo e all'articolo 7 della legge 23 luglio 2009, n. 99, devono in ogni caso essere eseguiti in favore della regione o provincia autonoma competente in relazione rispettivamente al luogo di immatricolazione del veicolo o, in caso di locazione finanziaria, al luogo di residenza dell'utilizzatore del veicolo medesimo.

40. A decorrere dall'anno 2017, la misura del canone di abbonamento alla televisione per uso privato di cui al regio decreto-legge 21 febbraio 1938, n. 246, convertito dalla legge 4 giugno 1938, n. 880, e' pari complessivamente all'importo di euro 90 annui.(61)

41. All'articolo 3, numero 1), della legge 17 luglio 1942, n. 907, dopo le parole: «La concessione» sono inserite le seguenti: «, ad eccezione di quella relativa all'estrazione del sale dai giacimenti,».

42. All'articolo 1 della legge 28 dicembre 2015, n. 208, sono apportate le seguenti modificazioni:

- a) al comma 26, le parole: «per l'anno 2016» sono sostituite dalle seguenti: «per gli anni 2016 e 2017»;
- b) al comma 28, e' aggiunto, in fine, il seguente periodo: «Per l'anno 2017, i comuni che hanno deliberato ai sensi del periodo precedente possono continuare a mantenere con espressa deliberazione del consiglio comunale la stessa maggiorazione confermata per l'anno 2016».

43. All'articolo 2, comma 3-bis, del decreto-legge 28 gennaio 2014, n. 4, convertito, con modificazioni, dalla legge 28 marzo 2014, n. 50, le parole: «31 dicembre 2016» sono sostituite dalle seguenti: «31 dicembre 2017».

44. Per gli anni 2017, 2018, 2019, 2020, 2021, 2022 e 2023, i redditi dominicali e agrari non concorrono alla formazione della base imponibile ai fini dell'imposta sul reddito delle persone fisiche dei coltivatori diretti e degli imprenditori agricoli professionali di cui all'articolo 1 del decreto legislativo 29 marzo 2004, n. 99, iscritti nella previdenza agricola. PERIODO SOPPRESSO DALLA L. 30 DICEMBRE 2020, N. 178. Per gli anni 2024 e 2025 i redditi dominicali e agrari dei coltivatori diretti e degli imprenditori agricoli professionali di cui al predetto articolo 1 del decreto legislativo n. 99 del 2004 iscritti nella previdenza agricola, diversi dalle societa' che hanno esercitato l'opzione di cui all'articolo 1, comma 1093, della legge 27 dicembre 2006, n. 296, concorrono, considerati congiuntamente, alla formazione del reddito complessivo nelle seguenti percentuali:

- a) fino a 10.000 euro, 0 per cento;
- b) oltre 10.000 euro e fino a 15.000 euro, 50 per cento;
- c) oltre 15.000 euro, 100 per cento.

45. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro delle politiche agricole alimentari e forestali, da adottare entro il 31 gennaio 2017, ai sensi dell'articolo 34, comma 1, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, le percentuali di compensazione applicabili agli animali vivi delle specie bovina e suina sono innalzate, per l'anno 2017, rispettivamente in misura non superiore al 7,7 per cento e all'8 per cento. L'attuazione delle disposizioni di cui al precedente periodo non puo' comportare minori entrate superiori a 20 milioni di euro.

46. Il comma 3 dell'articolo 66 della legge 27 dicembre 2002, n. 289, e' abrogato. Le risorse residue disponibili del Fondo di investimento nel capitale di rischio previsto dal decreto del Ministro delle politiche agricole e forestali 22 giugno 2004, n. 182, per gli interventi di cui al citato comma 3 dell'articolo 66 della legge n. 289 del 2002, entro trenta giorni dalla data di entrata in vigore della presente legge, sono versate dall'ISMEA all'entrata del bilancio dello Stato, nel limite di 9 milioni di euro per l'anno 2017.

47. All'articolo 10, comma 4, del decreto legislativo 14 marzo 2011, n. 23, sono aggiunte, in fine, le seguenti parole: «, e delle disposizioni di cui all'articolo 9, secondo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 601».

48. A decorrere dal 1º gennaio 2017 l'aliquota di accisa sulla birra di cui all'allegato I annesso al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi e relative sanzioni penali e amministrative, di cui al decreto legislativo 26 ottobre 1995, n. 504, e' rideterminata in euro 3,02 per ettolitro e per grado-Plato.

49. All'articolo 1 della legge 28 dicembre 2015, n. 208, sono apportate le seguenti modificazioni:

- a) al comma 65, dopo le parole: «di cui al decreto legislativo 27 gennaio 1992, n. 87,» sono inserite le seguenti: «escluse le societa' di gestione dei fondi comuni d'investimento di cui al testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58,»;
- b) il comma 67 e' sostituito dal seguente: «67. All'articolo 96, comma 5-bis, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, il primo periodo e' sostituito dal seguente: "Gli interessi passivi sostenuti dalle imprese di assicurazione e dalle societa' capogruppo di gruppi assicurativi e dalle societa' di gestione dei fondi comuni d'investimento di cui al testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, sono deducibili nel limite del 96 per cento del loro ammontare"».

50. All'articolo 90, comma 2, della legge 27 dicembre 2002, n. 289, e' aggiunto, in fine, il seguente periodo: «A decorrere dal periodo di imposta in corso alla data del 1º gennaio 2017, l'importo e' elevato a 400.000 euro».

51. Dopo l'articolo 111 del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1º settembre 1993, n. 385, e' inserito il seguente: «Art. 111-bis (Finanza etica e sostenibile). - 1. Sono operatori bancari di finanza etica e sostenibile le banche che conformano la propria attivita' ai seguenti principi: a) valutano i finanziamenti erogati a persone giuridiche secondo standard di rating etico internazionalmente riconosciuti, con particolare attenzione all'impatto sociale e ambientale; b) danno evidenza pubblica, almeno annualmente, anche via web, dei finanziamenti erogati di cui alla lettera a), tenuto conto delle vigenti normative a tutela della riservatezza dei dati personali; c) devolvono almeno il 20 per cento del proprio portafoglio di crediti a organizzazioni senza scopo di lucro o a imprese sociali con personalita' giuridica, come definite dalla normativa vigente; d) non distribuiscono profitti e li reinvestono nella propria attivita'; e) adottano un sistema di governance e un modello organizzativo a forte orientamento democratico e partecipativo, caratterizzato da un azionariato diffuso; f) adottano politiche retributive tese a contenere al massimo la differenza tra la remunerazione maggiore e quella media della banca, il cui rapporto comunque non puo' superare il valore di 5. 2. Non concorre a formare il reddito imponibile ai sensi dell'articolo 81 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, degli operatori bancari di finanza etica e sostenibile una quota pari al 75 per cento delle somme destinate a incremento del capitale proprio. 3. Il Ministro dell'economia e delle finanze, sentita la Banca d'Italia, stabilisce, con proprio decreto, le norme di attuazione delle disposizioni del presente articolo, dalle quali non possono derivare oneri a carico della finanza pubblica superiori a 1 milione di euro in ragione annua a decorrere dall'anno 2017. 4. L'agevolazione di cui al presente articolo e' riconosciuta nel rispetto dei limiti di cui al regolamento (UE) n. 1407/2013 della Commissione, del 18 dicembre 2013, relativo all'applicazione degli articoli 107 e 108 del Trattato sul funzionamento dell'Unione europea agli aiuti "de minimis"».

52. Il termine per la concessione dei finanziamenti per l'acquisto di nuovi macchinari, impianti e attrezzature da parte delle piccole e medie imprese di cui all'articolo 2, comma 2, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, e' prorogato al 31 dicembre 2018. (11)

53. Per fare fronte agli oneri derivanti dalla concessione dei contributi previsti dall'articolo 2, comma 4, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, e dai commi da 52 a 57 del presente articolo, e' autorizzata la spesa di 28 milioni di euro per l'anno 2017, di 84 milioni di euro per l'anno 2018, di 112 milioni di euro per ciascuno degli anni dal 2019 al 2021, di 84 milioni di euro per l'anno 2022 e di 28 milioni di euro per l'anno 2023.

54. Una quota pari al 20 per cento delle risorse di cui al comma 53 e' riservata alla concessione dei contributi di cui al comma 56. Le risorse che, alla data del 30 giugno 2018, non risultano utilizzate per la predetta riserva rientrano nella disponibilita' della misura.

55. Al fine di favorire la transizione del sistema produttivo nazionale verso la manifattura digitale e di incrementare l'innovazione e l'efficienza del sistema imprenditoriale, anche tramite l'innovazione di processo o di prodotto, le imprese di micro, piccola e media dimensione possono accedere ai finanziamenti e ai contributi di cui all'articolo 2 del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, per l'acquisto di macchinari, impianti e attrezzature nuovi di fabbrica aventi come finalita' la realizzazione di investimenti in tecnologie, compresi gli investimenti in big data, cloud computing, banda ultralarga, cybersecurity, robotica avanzata e meccatronica, realta' aumentata, manifattura 4D, Radio frequency identification (RFID) e sistemi di tracciamento e pesatura dei rifiuti.

56. A fronte della realizzazione di investimenti aventi le finalita' di cui al comma 55 del presente articolo, il contributo di cui all'articolo 2, comma 4, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, e' concesso secondo le modalita' di cui alle disposizioni attuative, adottate ai sensi del medesimo articolo 2, comma 5, del citato decreto-legge n. 69 del 2013, con una maggiorazione pari al 30 per cento della misura massima ivi stabilita, fermo restando il rispetto delle intensita' massime di aiuto previste dalla normativa dell'Unione europea applicabile in materia di aiuti di Stato. (32)

57. L'importo massimo dei finanziamenti di cui all'articolo 2, comma 8, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, puo' essere incrementato, in funzione delle richieste di finanziamento a valere sul plafond di provvista costituito presso la gestione separata della Cassa depositi e prestiti Spa e, comunque, fino a un massimo di ulteriori 7 miliardi di euro.

58. Per il potenziamento delle azioni di promozione all'estero e l'internazionalizzazione delle imprese italiane, l'importo di cui all'articolo 1, comma 202, quinto periodo, della legge 23 dicembre 2014, n. 190, e' incrementato di 1 milione di euro per l'anno 2017. Il Ministro dello sviluppo economico presenta alle Camere una relazione annuale nella quale rende conto in modo analitico dell'utilizzazione di tali somme.

59. Ai soggetti di cui all'articolo 1, comma 1, della legge 25 giugno 2003, n. 155, come sostituito dall'articolo 13, comma 1, della legge 19 agosto 2016, n. 166, che acquistano in Italia, anche in locazione finanziaria, beni mobili strumentali utilizzati direttamente ed esclusivamente per le finalita' di cui alla medesima legge n. 155 del 2003, e' riconosciuto un contributo fino al 15 per cento del prezzo di acquisto, per un massimo di 3.500 euro annui, nel limite delle risorse di cui al comma 63 del presente articolo per gli anni 2017 e 2018.

60. Il contributo e' corrisposto dal venditore mediante compensazione con il prezzo di acquisto.

61. Le imprese costruttrici o importatrici dei beni mobili di cui al comma 59 rimborsano al venditore l'importo del contributo e recuperano tale importo quale credito d'imposta per il versamento delle ritenute dell'imposta sul reddito delle persone fisiche operate in qualita' di sostituto d'imposta sui redditi da lavoro dipendente, dell'imposta sul reddito delle persone fisiche, dell'imposta sul reddito delle societa' e dell'imposta sul valore aggiunto dovute, anche in acconto, per l'esercizio in cui e' effettuato l'acquisto.

62. Fino al 31 dicembre del quinto anno successivo a quello in cui e' stata emessa la fattura di vendita, le imprese costruttrici o importatrici conservano la copia della fattura di vendita e dell'atto di acquisto che deve essere ad esse trasmessa dal venditore.

63. Per provvedere all'erogazione del credito d'imposta previsto dai commi da 59 a 64 e' autorizzata la spesa di 10 milioni di euro per ciascuno degli anni 2017 e 2018.

64. Con decreto di natura non regolamentare del Ministro dello sviluppo economico, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, di concerto con il Ministro dell'economia e delle finanze, sono stabilite le modalita' per la preventiva autorizzazione all'erogazione dei contributi previsti e le condizioni per la loro fruizione. Con il medesimo decreto sono definite modalita' di monitoraggio e di controllo per garantire il rispetto dei limiti di spesa di cui al comma 63.

65. All'articolo 4, comma 10-bis, del decreto-legge 24 gennaio 2015, n. 3, convertito, con modificazioni, dalla legge 24 marzo 2015, n. 33, le parole: «dall'articolo 24» sono sostituite dalle seguenti: «dagli articoli 24 e 25».

66. All'articolo 29 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, sono apportate le seguenti modificazioni:

- a) dopo il comma 3 e' inserito il seguente: «3-bis. A decorrere dall'anno 2017, l'investimento massimo detraibile di cui al comma 3 e' aumentato a euro 1.000.000»;
- b) ai commi 3 e 5, le parole: «due anni» sono sostituite dalle seguenti: «tre anni»;
- c) dopo il comma 7 e' inserito il seguente: «7-bis. A decorrere dall'anno 2017, le aliquote di cui ai commi 1, 4 e 7 sono aumentate al 30 per cento»;
- d) dopo il comma 8 e' inserito il seguente: «8-bis. Per l'attuazione delle disposizioni di cui ai commi 3-bis e 7-bis, si applicano, in quanto compatibili, le disposizioni del decreto del Ministro dell'economia e delle finanze 25 febbraio 2016, pubblicato nella Gazzetta Ufficiale n. 84 dell'11 aprile 2016».

67. L'efficacia delle disposizioni di cui al comma 66, lettere a) e c), del presente articolo, e' subordinata, ai sensi dell'articolo 108, paragrafo 3, del Trattato sul funzionamento dell'Unione europea, all'autorizzazione della Commissione europea, richiesta a cura del Ministero dello sviluppo economico.

68. All'articolo 4 del decreto-legge 24 gennaio 2015, n. 3, convertito, con modificazioni, dalla legge 24 marzo 2015, n. 33, sono apportate le seguenti modificazioni:

- a) al comma 9, le parole da: «che operano» fino alla fine del comma sono sostituite dalle seguenti: «nel rispetto delle condizioni e dei limiti previsti dagli Orientamenti sugli aiuti di Stato destinati a promuovere gli investimenti per il finanziamento del rischio, di cui alla comunicazione 2014/C 19/04 della Commissione, del 22 gennaio 2014»;
- b) il comma 9-bis e' abrogato;
- c) al comma 12, le parole: «dai commi 9 e 9-bis» sono sostituite dalle seguenti: «dal comma 9»;
- d) al comma 12-bis, le parole da: «e i requisiti» fino alla fine del comma sono sostituite dalle seguenti: «di cui al comma 9»;
- e) al comma 12-ter, le parole: «comma 9-bis» sono sostituite dalle seguenti: «comma 9».

69. All'articolo 26, comma 8, del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, e' aggiunto, in fine, il seguente periodo: «L'atto costitutivo della start-up innovativa, costituita ai sensi dell'articolo 4, comma 10-bis, del decreto-legge 24 gennaio 2015, n. 3, convertito, con modificazioni, dalla legge 24 marzo 2015, n. 33, nonche' di quella costituita con atto pubblico, in caso di contestuale iscrizione nella citata sezione speciale di cui all'articolo 25, comma 8, e' esente dal pagamento delle imposte di bollo e dei diritti di segreteria».

70. Al testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, sono apportate le seguenti modificazioni:

- a) il comma 5-novies dell'articolo 1 e' sostituito dal seguente: «5-novies. Per "portale per la raccolta di capitali per le PMI" si intende una piattaforma on line che abbia come finalita' esclusiva la facilitazione della raccolta di capitale di rischio da parte delle PMI come definite dalla disciplina dell'Unione europea e degli organismi di investimento collettivo del risparmio o altre societa' che investono prevalentemente in PMI»;
- b) all'articolo 50-quinquies, le parole: «per le start-up innovative, per le PMI innovative» sono sostituite, ovunque ricorrono, dalle seguenti: «per le PMI», le parole: «in start-up innovative e in PMI innovative» sono sostituite, ovunque ricorrono, dalle seguenti: «in PMI» e, alla rubrica, le parole: «per start-up innovative e PMI innovative» sono sostituite dalle seguenti: «per le PMI»;
- c) alla rubrica del capo III-quater del titolo III della parte II, le parole: «per le start-up innovative e le PMI innovative» sono sostituite dalle seguenti: «per le PMI».

71. Per il finanziamento delle iniziative di cui al titolo I, capo 0I, del decreto legislativo 21 aprile 2000, n. 185, e' autorizzata la spesa di 47,5 milioni di euro per l'anno 2017 e di 47,5 milioni di euro per l'anno 2018. Le predette risorse sono iscritte nello stato di previsione del Ministero dello sviluppo economico per essere successivamente accreditate su un conto corrente infruttifero, intestato all'Agenzia nazionale per l'attrazione degli investimenti e lo sviluppo d'impresa Spa-INVITALIA, aperto presso la tesoreria centrale dello Stato e dedicato al citato titolo I, capo 0I, del decreto legislativo n. 185 del 2000. Sul medesimo conto corrente sono, altresi', accreditate le disponibilita' finanziarie presenti nel fondo rotativo depositato sul conto corrente di tesoreria n. 22048, istituito ai sensi dell'articolo 4 del decreto del Ministro dell'economia e delle finanze 30 novembre 2004, pubblicato nella Gazzetta Ufficiale n. 14 del 19 gennaio 2005, nella misura di un terzo delle risorse complessive, nonche' i rientri dei finanziamenti erogati dalla citata Agenzia ai sensi delle disposizioni del titolo I del citato decreto legislativo n. 185 del 2000.

72. La dotazione del Fondo per la crescita sostenibile, di cui all'articolo 23, comma 2, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' incrementata di 47,5 milioni di euro per l'anno 2017 e di 47,5 milioni di euro per l'anno 2018, da destinare all'erogazione dei finanziamenti agevolati per gli interventi di cui al decreto del Ministro dello sviluppo economico 24 settembre 2014, pubblicato nella Gazzetta Ufficiale n. 264 del 13 novembre 2014, per il sostegno alla nascita e allo sviluppo di imprese start-up innovative.

73. Il Ministero dello sviluppo economico e le regioni possono destinare, nell'anno 2017, alle misure di cui ai commi 71 e 72 risorse a valere sul programma operativo nazionale imprese e competitivita', sui programmi operativi regionali e sulla connessa programmazione nazionale 2014-2020, fino a complessivi 120 milioni di euro, di cui 70 milioni di euro per gli interventi di cui al comma 71 e 50 milioni di euro per gli interventi di cui al comma 72. Al fine di coordinare e ottimizzare la predetta destinazione di risorse, il Ministero dello sviluppo economico promuove specifici accordi con le regioni.

74. Al fine di garantire la continuita' del sostegno alla promozione e allo sviluppo di nuove imprese e la conseguente crescita dei livelli di occupazione, di cui al decreto del Ministro dello sviluppo economico 4 dicembre 2014, pubblicato nella Gazzetta Ufficiale n. 2 del 3 gennaio 2015, al Fondo per la crescita sostenibile, di cui all'articolo 23 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, sono assegnati 5 milioni di euro per l'anno 2017 e 5 milioni di euro per l'anno 2018, destinati all'erogazione di finanziamenti agevolati a societa' cooperative costituite da lavoratori di aziende in crisi, di cooperative sociali e di cooperative che gestiscono aziende confiscate alla criminalita' organizzata, nonche' allo sviluppo e al consolidamento di societa' cooperative ubicate nelle regioni del Mezzogiorno.

75. Al fine di ampliare gli strumenti finanziari di intervento e favorire la capitalizzazione dell'impresa da parte di lavoratori, all'articolo 17 della legge 27 febbraio 1985, n. 49, sono apportate le seguenti modificazioni:

- a) il comma 5 e' sostituito dal seguente: «5. Con le risorse apportate ai sensi del comma 2, le societa' finanziarie possono assumere partecipazioni temporanee di minoranza nelle cooperative, anche in piu' soluzioni, con priorita' per quelle costituite da lavoratori provenienti da aziende in crisi, e concedere alle cooperative stesse finanziamenti e agevolazioni finanziarie in conformita' alla disciplina dell'Unione europea in materia, per la realizzazione di progetti di impresa»;
- b) dopo il comma 5 e' inserito il seguente: «5-bis. Le societa' finanziarie possono, altresi', sottoscrivere, anche successivamente all'assunzione delle partecipazioni, prestiti subordinati, prestiti partecipativi e gli strumenti finanziari di cui all'articolo 2526 del codice civile, nonche' svolgere attivita' di servizi e di promozione ed essere destinatarie di fondi pubblici. In deroga a quanto previsto dall'articolo 2522 del codice civile, le societa' finanziarie possono intervenire nelle societa' cooperative costituite da meno di nove soci».

76. Per le societa' fra le quali intercorre un rapporto di partecipazione che preveda una percentuale del diritto di voto esercitabile nell'assemblea ordinaria e di partecipazione agli utili non inferiore al 20 per cento e' ammessa la possibilita' di cedere le perdite fiscali di cui all'articolo 84 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, con le stesse modalita' previste per la cessione dei crediti d'imposta di cui all'articolo 43-bis del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, a condizione che le azioni della societa' cessionaria, o della societa' che controlla direttamente o indirettamente la societa' cessionaria, siano negoziate in un mercato regolamentato o in un sistema multilaterale di negoziazione di uno degli Stati membri dell'Unione europea e degli Stati aderenti all'Accordo sullo Spazio economico europeo con il quale l'Italia abbia stipulato un accordo che assicuri un effettivo scambio di informazioni e che la societa' cedente non svolga in via prevalente attivita' immobiliare. La cessione deve riguardare l'intero ammontare delle perdite fiscali.

77. Le perdite fiscali trasferibili sono solo quelle realizzate nei primi tre esercizi della societa' cedente, subordinatamente al verificarsi delle seguenti ulteriori condizioni:

- a) sussistenza di identita' dell'esercizio sociale della societa' cedente e della societa' cessionaria;
- b) sussistenza del requisito partecipativo del 20 per cento al termine del periodo d'imposta relativamente al quale le societa' si avvalgono della possibilita' di cui al comma 76;
- c) perfezionamento della cessione entro il termine di presentazione della dichiarazione dei redditi.

78. Le perdite di cui al comma 76 relative a un periodo d'imposta sono computate dalla societa' cessionaria in diminuzione del reddito complessivo dello stesso periodo d'imposta e, per la differenza, nei successivi entro il limite del reddito imponibile di ciascuno di essi e per l'intero importo che trova capienza nel reddito imponibile di ciascuno di essi a condizione che le suddette perdite si riferiscano a una nuova attivita' produttiva ai sensi dell'articolo 84, comma 2, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

79. La societa' cessionaria e' obbligata a remunerare la societa' cedente del vantaggio fiscale ricevuto, determinato, in ogni caso, mediante applicazione, all'ammontare delle perdite acquisite, dell'aliquota dell'imposta sul reddito delle societa' di cui all'articolo 77 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, relativa al periodo d'imposta in cui le perdite sono state conseguite dalla societa' cedente, entro trenta giorni dal termine per il versamento del saldo relativo allo stesso periodo d'imposta. Non concorrono alla formazione del reddito imponibile, in quanto escluse, le somme percepite o versate tra le societa' di cui al comma 76 del presente articolo in contropartita dei vantaggi fiscali ricevuti o attribuiti.

80. La societa' cedente non puo' optare per i regimi di cui agli articoli 115, 117 e 130 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, in relazione ai periodi d'imposta nei quali ha conseguito le perdite fiscali cedute ai sensi dei commi da 76 a 79 del presente articolo.

81. L'articolo 182-ter del regio decreto 16 marzo 1942, n. 267, e' sostituito dal seguente: «Art. 182-ter (Trattamento dei crediti tributari e contributivi). - 1. Con il piano di cui all'articolo 160 il debitore, esclusivamente mediante proposta presentata ai sensi del presente articolo, puo' proporre il pagamento, parziale o anche dilazionato, dei tributi e dei relativi accessori amministrati dalle agenzie fiscali, nonche' dei contributi amministrati dagli enti gestori di forme di previdenza e assistenza obbligatorie e dei relativi accessori, se il piano ne prevede la soddisfazione in misura non inferiore a quella realizzabile, in ragione della collocazione preferenziale, sul ricavato in caso di liquidazione, avuto riguardo al valore di mercato attribuibile ai beni o ai diritti sui quali sussiste la causa di prelazione, indicato nella relazione di un professionista in possesso dei requisiti di cui all'articolo 67, terzo comma, lettera d). Se il credito tributario o contributivo e' assistito da privilegio, la percentuale, i tempi di pagamento e le eventuali garanzie non possono essere inferiori o meno vantaggiosi rispetto a quelli offerti ai creditori che hanno un grado di privilegio inferiore o a quelli che hanno una posizione giuridica e interessi economici omogenei a quelli delle agenzie e degli enti gestori di forme di previdenza e assistenza obbligatorie; se il credito tributario o contributivo ha natura chirografaria, il trattamento non puo' essere differenziato rispetto a quello degli altri creditori chirografari ovvero, nel caso di suddivisione in classi, dei creditori rispetto ai quali e' previsto un trattamento piu' favorevole. Nel caso in cui sia proposto il pagamento parziale di un credito tributario o contributivo privilegiato, la quota di credito degradata al chirografo deve essere inserita in un'apposita classe. 2. Ai fini della proposta di accordo sui crediti di natura fiscale, copia della domanda e della relativa documentazione, contestualmente al deposito presso il tribunale, deve essere presentata al competente agente della riscossione e all'ufficio competente sulla base dell'ultimo domicilio fiscale del debitore, unitamente alla copia delle dichiarazioni fiscali per le quali non e' pervenuto l'esito dei controlli automatici nonche' delle dichiarazioni integrative relative al periodo fino alla data di presentazione della domanda. L'agente della riscossione, non oltre trenta giorni dalla data della presentazione, deve trasmettere al debitore una certificazione attestante l'entita' del debito iscritto a ruolo scaduto o sospeso. L'ufficio, nello stesso termine, deve procedere alla liquidazione dei tributi risultanti dalle dichiarazioni e alla notifica dei relativi avvisi di irregolarita', unitamente a una certificazione attestante l'entita' del debito derivante da atti di accertamento, ancorche' non definitivi, per la parte non iscritta a ruolo, nonche' dai ruoli vistati, ma non ancora consegnati all'agente della riscossione. Dopo l'emissione del decreto di cui all'articolo 163, copia dell'avviso di irregolarita' e delle certificazioni deve essere trasmessa al commissario giudiziale per gli adempimenti previsti dagli articoli 171, primo comma, e 172. In particolare, per i tributi amministrati dall'Agenzia delle dogane e dei monopoli, l'ufficio competente a ricevere copia della domanda con la relativa documentazione prevista al primo periodo, nonche' a rilasciare la certificazione di cui al terzo periodo, si identifica con l'ufficio che ha notificato al debitore gli atti di accertamento. 3. Relativamente al credito tributario complessivo, il voto sulla proposta concordataria e' espresso dall'ufficio, previo parere conforme della competente direzione regionale, in sede di adunanza dei creditori, ovvero nei modi previsti dall'articolo 178, quarto comma. 4. Il voto e' espresso dall'agente della riscossione limitatamente agli oneri di riscossione di cui all'articolo 17 del decreto legislativo 13 aprile 1999, n. 112. 5. Il debitore puo' effettuare la proposta di cui al comma 1 anche nell'ambito delle trattative che precedono la stipulazione dell'accordo di ristrutturazione di cui all'articolo 182-bis. In tali casi l'attestazione di cui al citato articolo 182-bis, primo comma, relativamente ai crediti fiscali deve inerire anche alla convenienza del trattamento proposto rispetto alle alternative concretamente praticabili; tale punto costituisce oggetto di specifica valutazione da parte del tribunale. La proposta di transazione fiscale, unitamente alla documentazione di cui all'articolo 161, e' depositata presso gli uffici indicati al comma 2 del presente articolo. Alla proposta di transazione deve altresi' essere allegata la dichiarazione sostitutiva, resa dal debitore o dal suo legale rappresentante ai sensi dell'articolo 47 del testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa, di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, che la documentazione di cui al periodo precedente rappresenta fedelmente e integralmente la situazione dell'impresa, con particolare riguardo alle poste attive del patrimonio. L'adesione alla proposta e' espressa, su parere conforme della competente direzione regionale, con la sottoscrizione dell'atto negoziale da parte del direttore dell'ufficio. L'atto e' sottoscritto anche dall'agente della riscossione in ordine al trattamento degli oneri di riscossione di cui all'articolo 17 del decreto legislativo 13 aprile 1999, n. 112. L'assenso cosi' espresso equivale a sottoscrizione dell'accordo di ristrutturazione. 6. La transazione fiscale conclusa nell'ambito dell'accordo di ristrutturazione di cui all'articolo 182-bis e' risolta di diritto se il debitore non esegue integralmente, entro novanta giorni dalle scadenze previste, i pagamenti dovuti alle Agenzie fiscali e agli enti gestori di forme di previdenza e assistenza obbligatorie».

82. Per le proprie finalita', l'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL), previa adozione di un apposito regolamento di disciplina, da sottoporre all'approvazione del Ministero del lavoro e delle politiche sociali e del Ministero dell'economia e delle finanze, puo' sottoscrivere quote di fondi comuni di investimento di tipo chiuso dedicati all'attivazione di start-up innovative, di cui al decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, ovvero costituire e partecipare a start-up di tipo societario finalizzate all'utilizzazione industriale dei risultati della ricerca, anche con soggetti pubblici e privati, italiani e stranieri, operanti nei settori funzionali al raggiungimento del proprio scopo, aventi quale oggetto sociale esclusivo o prevalente lo sviluppo, la produzione e la commercializzazione di prodotti o servizi innovativi di alto valore tecnologico, anche rivolte alla realizzazione di progetti in settori tecnologici altamente strategici, previa autorizzazione del Ministero del lavoro e delle politiche sociali, d'intesa con il Ministero dell'economia e delle finanze.

83. Per lo svolgimento delle attivita' di cui al comma 82, l'INAIL opera nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente.

84. Al fine di favorire l'efficiente utilizzo delle risorse previste dal comma 3 dell'articolo 33 del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, le percentuali destinate alla sottoscrizione delle quote dei fondi di cui ai commi 1, 8-ter e 8-quater del citato articolo 33, fermo restando il complessivo limite del 40 per cento, possono essere rimodulate, tenuto conto delle esigenze di finanziamento dei diversi fondi, su proposta della societa' di gestione del risparmio ivi prevista.

85. L'INAIL, nell'ambito degli investimenti immobiliari previsti dal piano di impiego dei fondi disponibili di cui all'articolo 65 della legge 30 aprile 1969, n. 153, destina 100 milioni di euro per la realizzazione di nuove strutture scolastiche. Le regioni dichiarano la propria disponibilita' ad aderire all'operazione per la costruzione di nuove strutture scolastiche, facendosi carico del canone di locazione, comunicandola formalmente alla Presidenza del Consiglio dei ministri - Struttura di missione per il coordinamento e impulso nell'attuazione di interventi di riqualificazione dell'edilizia scolastica, entro il termine perentorio del 20 gennaio 2017, secondo modalita' individuate e pubblicate nel sito internet istituzionale della medesima Struttura. Successivamente alla ricezione delle dichiarazioni di disponibilita' delle regioni, con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro del lavoro e delle politiche sociali, con il Ministro dell'istruzione, dell'universita' e della ricerca e con il Ministro dell'economia e delle finanze, sono individuate le regioni ammesse alla ripartizione, sono assegnate le risorse disponibili e sono stabiliti i criteri di selezione dei progetti. (13)

85-bis. Per gli interventi gia' individuati alla data di entrata in vigore della presente disposizione sulla base del decreto di cui al terzo periodo del comma 85, l'intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, ai sensi dell'articolo 3 del decreto legislativo 28 agosto 1997, n. 281, puo' essere raggiunta successivamente all'adozione dello stesso decreto, purche' anteriormente all'avvio delle procedure di affidamento degli interventi stessi.

86. All'articolo 1, comma 312, della legge 28 dicembre 2015, n. 208, dopo le parole: «legge 26 luglio 1975, n. 354,» sono inserite le seguenti: «dei soggetti impegnati in lavori di pubblica utilita' ai sensi dell'articolo 186, comma 9-bis, e dell'articolo 187, comma 8-bis, del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285, dell'articolo 73, comma 5-bis, del testo unico di cui al decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, e dell'articolo 168-bis del codice penale».

87. Per le finalita' di cui al comma 86 del presente articolo, il Fondo di cui all'articolo 1, comma 312, della legge 28 dicembre 2015, n. 208, e' integrato di euro 3 milioni per gli anni 2017, 2018 e 2019.

88. Gli enti di previdenza obbligatoria di cui al decreto legislativo 30 giugno 1994, n. 509, e al decreto legislativo 10 febbraio 1996, n. 103, possono destinare somme, fino al 10 per cento dell'attivo patrimoniale risultante dal rendiconto dell'esercizio precedente, agli investimenti qualificati indicati al comma 89 del presente articolo nonche' ai piani di risparmio a lungo termine di cui al comma 100 del presente articolo. Agli enti di cui al presente comma non si applica il comma 112, primo periodo.

89. Le somme indicate al comma 88 devono essere investite in:

- a) azioni o quote di imprese residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo con stabile organizzazione nel territorio medesimo;
- b) in quote o azioni di organismi di investimento collettivo del risparmio residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo, che investono prevalentemente negli strumenti finanziari di cui alla lettera a).
- b-bis) quote di prestiti, di fondi di credito cartolarizzati erogati od originati per il tramite di piattaforme di prestiti per soggetti finanziatori non professionali, gestite da societa' iscritte nell'albo degli intermediari finanziari tenuto dalla Banca d'Italia di cui all'articolo 106 del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1° settembre 1993, n. 385, da istituti di pagamento rientranti nel campo di applicazione dell'articolo 114 del medesimo testo unico di cui al decreto legislativo n. 385 del 1993 o da soggetti vigilati operanti nel territorio italiano in quanto autorizzati in altri Stati dell'Unione europea.
- b-ter) quote o azioni di Fondi per il Venture Capital residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo. L'importo totale delle risorse e' investito dai soggetti indicati nei commi 88 e 92, per il tramite dei Fondi per il Venture Capital (FVC), in ciascuna piccola e media impresa (PMI), entro la durata del FVC. Ciascuna PMI rispetta i requisiti, alternativi tra loro, previsti dall'articolo 21, paragrafo 3, lettere a), b) e
- c) del regolamento (UE) n. 651/2014 della Commissione, del 17 giugno 2014.

90. I redditi, diversi da quelli relativi a partecipazioni qualificate di cui all'articolo 67, comma 1, lettera c), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, generati dagli investimenti qualificati indicati al comma 89 del presente articolo, sono esenti ai fini dell'imposta sul reddito purche' gli investimenti qualificati in quote o azioni di Fondi per il Venture Capital di cui al comma 89, lettera b-ter), ((a far data dal 1° gennaio 2025, siano almeno pari al 3 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente, per l'anno 2026)) siano almeno pari al 5 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente ((e, a partire dall'anno 2027)), almeno pari al 10 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente. ((70))

91. Gli strumenti finanziari oggetto di investimento qualificato ai sensi del comma 88 devono essere detenuti per almeno cinque anni. In caso di cessione degli strumenti finanziari oggetto di investimento agevolato prima dei cinque anni, i redditi realizzati attraverso la cessione e quelli percepiti durante il periodo minimo di investimento sono soggetti ad imposta sostitutiva in misura corrispondente a quella prevista dalle norme ordinarie, unitamente agli interessi, senza applicazione di sanzioni, e il relativo versamento deve essere effettuato dai soggetti di cui al comma 88 entro il giorno 16 del secondo mese successivo alla cessione. In caso di rimborso o di scadenza dei titoli oggetto di investimento prima dei cinque anni, le somme conseguite devono essere reinvestite negli strumenti finanziari di cui al comma 89 entro novanta giorni.

92. Le forme di previdenza complementare di cui al decreto legislativo 5 dicembre 2005, n. 252, possono destinare somme, fino al 10 per cento dell'attivo patrimoniale risultante dal rendiconto dell'esercizio precedente, agli investimenti qualificati indicati al comma 89 del presente articolo nonche' ai piani di risparmio a lungo termine di cui al comma 100 del presente articolo. Agli enti gestori delle forme di previdenza di cui al presente comma non si applica il comma 112, primo periodo.

93. Gli strumenti finanziari oggetto di investimento qualificato ai sensi del comma 92 devono essere detenuti per almeno cinque anni.

94. I redditi, diversi da quelli relativi a partecipazioni qualificate di cui all'articolo 67, comma 1, lettera c), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, derivanti dagli investimenti di cui al comma 92 del presente articolo sono esenti ai fini dell'imposta sul reddito e pertanto non concorrono alla formazione della base imponibile dell'imposta prevista dall'articolo 17 del decreto legislativo 5 dicembre 2005, n. 252, purche' gli investimenti qualificati in quote o azioni di Fondi per il Venture Capital di cui al comma 89, lettera b-ter), ((a far data dal 1° gennaio 2025, siano almeno pari al 3 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente, per l'anno 2026)) siano almeno pari al 5 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente ((e, a partire dall'anno 2027)), almeno pari al 10 per cento del paniere degli investimenti qualificati risultanti dal rendiconto dell'esercizio precedente. Ai fini della formazione delle prestazioni pensionistiche erogate dalle forme di previdenza complementare i redditi derivanti dagli investimenti di cui al comma 92 del presente articolo incrementano la parte corrispondente ai redditi gia' assoggettati ad imposta. In caso di cessione degli strumenti finanziari oggetto di investimento prima dei cinque anni, i redditi realizzati attraverso la cessione e quelli che non hanno concorso alla formazione della predetta base imponibile ai sensi del primo periodo durante il periodo minimo di investimento, sono soggetti a imposta sostitutiva delle imposte sui redditi con aliquota pari a quella di cui al citato articolo 17 del decreto legislativo n. 252 del 2005, senza applicazione di sanzioni, e il relativo versamento, unitamente agli interessi, deve essere effettuato dai soggetti di cui al comma 8 del medesimo articolo 17 entro il giorno 16 del secondo mese successivo alla cessione. In caso di rimborso o di scadenza degli strumenti finanziari oggetto di investimento prima del quinquennio, il controvalore conseguito deve essere reinvestito negli strumenti finanziari di cui al comma 89 del presente articolo entro novanta giorni dal rimborso. (6) ((70))

94-bis. Le disposizioni di cui ai commi da 92 a 94 e da 95-bis a 95-quater si applicano ai sottoconti italiani di prodotti pensionistici individuali paneuropei (PEPP) di cui al regolamento (UE) 2019/1238.

95. La ritenuta di cui all'articolo 27 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e l'imposta sostitutiva di cui all'articolo 27-ter del medesimo decreto non si applicano agli utili corrisposti ai soggetti indicati al secondo periodo del comma 3 del citato articolo 27 derivanti dagli investimenti qualificati di cui al comma 89 del presente articolo fino al 10 per cento dell'attivo patrimoniale risultante dal rendiconto dell'esercizio precedente nel rispetto della condizione di cui al comma 93 del presente articolo. Ai fini dell'applicazione delle disposizioni di cui al primo periodo, il soggetto non residente beneficiario effettivo degli utili deve produrre una dichiarazione dalla quale risultino i dati identificativi del soggetto medesimo e la sussistenza di tutte le condizioni alle quali e' subordinata l'agevolazione di cui ai commi da 88 a 114 del presente articolo, nonche' l'impegno a detenere gli strumenti finanziari oggetto dell'investimento qualificato per il periodo di tempo richiesto dalla legge. Il predetto soggetto non residente deve fornire, altresi', copia dei prospetti contabili che consentano di verificare l'osservanza delle predette condizioni. I soggetti indicati agli articoli 27 e 27-ter del citato decreto del Presidente della Repubblica n. 600 del 1973 che corrispondono utili ai soggetti non residenti di cui al medesimo articolo 27, comma 3, secondo periodo, sono obbligati a comunicare annualmente all'amministrazione finanziaria i dati relativi alle operazioni compiute nell'anno precedente.

95-bis. Ai fini dell'applicazione delle disposizioni di cui ai commi da 88 a 95, il soggetto percettore deve produrre una dichiarazione dalla quale risulti la sussistenza delle condizioni previste dai commi 88 e 92, nonche' l'impegno a detenere gli strumenti finanziari oggetto dell'investimento qualificato per almeno 5 anni. Il percettore deve altresi' dichiarare che i redditi generati dagli investimenti qualificati non sono relativi a partecipazioni qualificate.

95-ter. I soggetti indicati nei commi 88, 92 e 95 devono tenere separata evidenza delle somme destinate agli investimenti qualificati di cui al comma 89.

95-quater. Le minusvalenze e le perdite realizzate mediante cessione a titolo oneroso ovvero rimborso degli strumenti finanziari oggetto degli investimenti qualificati di cui al comma 89 sono deducibili dalle plusvalenze o proventi realizzati nelle successive operazioni nello stesso periodo di imposta e nei successivi ma non oltre il quarto, ovvero possono essere portate in deduzione ai sensi del comma 5 dell'articolo 68 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917. Per le forme di previdenza complementare di cui al decreto legislativo 5 dicembre 2005, n. 252, le minusvalenze e le perdite maturate o realizzate relativamente agli strumenti finanziari oggetto degli investimenti qualificati di cui al comma 89 concorrono a formare la base imponibile dell'imposta prevista dall'articolo 17 del medesimo decreto legislativo.

96. All'articolo 1 della legge 23 dicembre 2014, n. 190, i commi da 91 a 94 sono abrogati.

97. All'articolo 2, comma 4, del decreto legislativo 30 giugno 1994, n. 509, e' aggiunto, in fine, il seguente periodo: «Ai fini dei provvedimenti di cui ai periodi precedenti la Commissione parlamentare di controllo sull'attivita' degli enti gestori di forme obbligatorie di previdenza e assistenza sociale segnala ai Ministeri vigilanti le situazioni di disavanzo economico-finanziario di cui e' venuta a conoscenza nell'esercizio delle proprie funzioni di controllo dei bilanci di tali enti ai sensi dell'articolo 56 della legge 9 marzo 1989, n. 88».

98. All'articolo 6, comma 1, lettera c), del decreto legislativo 10 febbraio 1996, n. 103, dopo le parole: «per ogni frazione inferiore a mille» sono inserite le seguenti: «e nel massimo di cinquanta unita'».

99. All'articolo 17 del decreto legislativo 5 dicembre 2005, n. 252, dopo il comma 9 e' aggiunto il seguente: «9-bis. Le operazioni di costituzione, trasformazione, scorporo e concentrazione tra fondi pensione sono soggette alle imposte di registro, ipotecaria e catastale nella misura fissa di 200 euro per ciascuna di esse».

100. Non sono soggetti a imposizione i redditi di capitale di cui all'articolo 44 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, diversi da quelli relativi a partecipazioni qualificate e i redditi diversi di cui all'articolo 67, comma 1, lettere c-bis), c-ter), c-quater) e c-quinquies), del medesimo testo unico, conseguiti, al di fuori dell'esercizio di impresa commerciale, da persone fisiche residenti nel territorio dello Stato, derivanti dagli investimenti nei piani di risparmio a lungo termine, con l'esclusione di quelli che concorrono alla formazione del reddito complessivo imponibile. Ai fini del presente comma e dei commi da 101 a 113 del presente articolo si considerano qualificati le partecipazioni e i diritti o titoli di cui alla lettera c) del comma 1 dell'articolo 67 del citato testo unico, tenendo conto anche delle percentuali di partecipazione o di diritti di voto possedute dai familiari della persona fisica di cui al comma 5 dell'articolo 5 del medesimo testo unico e delle societa' o enti da loro direttamente o indirettamente controllati ai sensi dei numeri 1) e 2) del primo comma dell'articolo 2359 del codice civile.

101. Il piano di risparmio a lungo termine si costituisce con la destinazione di somme o valori per un importo non superiore, in ciascun anno solare, a 40.000 euro ed entro un limite complessivo non superiore a 200.000 euro, agli investimenti qualificati indicati al comma 102 del presente articolo, attraverso l'apertura di un rapporto di custodia o amministrazione o di gestione di portafogli o altro stabile rapporto con esercizio dell'opzione per l'applicazione del regime del risparmio amministrato di cui all'articolo 6 del decreto legislativo 21 novembre 1997, n. 461, o di un contratto di assicurazione sulla vita o di capitalizzazione, avvalendosi di intermediari abilitati o imprese di assicurazione residenti, ovvero non residenti operanti nel territorio dello Stato tramite stabile organizzazione o in regime di libera prestazione di servizi con nomina di un rappresentante fiscale in Italia scelto tra i predetti soggetti. Il rappresentante fiscale adempie negli stessi termini e con le stesse modalita' previsti per i suindicati soggetti residenti. Il conferimento di valori nel piano di risparmio si considera cessione a titolo oneroso e l'intermediario applica l'imposta secondo le disposizioni del citato articolo 6 del decreto legislativo n. 461 del 1997. Per i piani di risparmio a lungo termine di cui all'articolo 13-bis, comma 2-bis, del decreto-legge 26 ottobre 2019, n. 124, convertito, con modificazioni, dalla legge 19 dicembre 2019, n. 157, gli investitori possono destinare somme o valori per un importo non superiore a 300.000 euro all'anno e a 1.500.000 euro complessivi. Ai soggetti di cui ai commi 88 e 92 non si applicano i limiti di cui al presente comma. (38)

102. In ciascun anno solare di durata del piano, per almeno i due terzi dell'anno stesso, le somme o i valori destinati nel piano di risparmio a lungo termine devono essere investiti per almeno il 70 per cento del valore complessivo in strumenti finanziari, anche non negoziati nei mercati regolamentati o nei sistemi multilaterali di negoziazione, emessi o stipulati con imprese residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo con stabili organizzazioni nel territorio medesimo; la predetta quota del 70 per cento deve essere investita per almeno il 30 per cento del valore complessivo in strumenti finanziari di imprese diverse da quelle inserite nell'indice FTSE MIB della Borsa italiana o in indici equivalenti di altri mercati regolamentati. PERIODO SOPPRESSO DALLA L. 27 DICEMBRE 2017, N. 205. PERIODO SOPPRESSO DALLA L. 27 DICEMBRE 2017, N. 205.

103. Le somme o i valori destinati nel piano non possono essere investiti per una quota superiore al 10 per cento del totale in strumenti finanziari di uno stesso emittente o stipulati con la stessa controparte o con altra societa' appartenente al medesimo gruppo dell'emittente o della controparte o in depositi e conti correnti. (35)

104. Sono considerati investimenti qualificati anche le quote o azioni di organismi di investimento collettivo del risparmio residenti nel territorio dello Stato, ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo, che investono per almeno il 70 per cento dell'attivo in strumenti finanziari indicati al comma 102 del presente articolo nel rispetto delle condizioni di cui al comma 103.

105. Le somme o valori destinati nel piano non possono essere investiti in strumenti finanziari emessi o stipulati con soggetti residenti in Stati o territori diversi da quelli che consentono un adeguato scambio di informazioni.

106. Gli strumenti finanziari in cui e' investito il piano devono essere detenuti per almeno cinque anni. In caso di cessione degli strumenti finanziari oggetto di investimento prima dei cinque anni, i redditi realizzati attraverso la cessione e quelli percepiti durante il periodo minimo di investimento del piano sono soggetti a imposizione secondo le regole ordinarie, unitamente agli interessi, senza applicazione di sanzioni, e il relativo versamento deve essere effettuato dai soggetti di cui al comma 101 entro il giorno 16 del secondo mese successivo alla cessione. I soggetti di cui al comma 101 recuperano le imposte dovute attraverso adeguati disinvestimenti o chiedendone la provvista al titolare. In caso di rimborso degli strumenti finanziari oggetto di investimento prima del quinquennio, il controvalore conseguito deve essere reinvestito in strumenti finanziari indicati ai commi 102 e 104 entro novanta giorni dal rimborso.

107. Il venire meno delle condizioni di cui ai commi 102, 103 e 104 comporta la decadenza dal beneficio fiscale relativamente ai redditi degli strumenti finanziari detenuti nel piano stesso, diversi da quelli investiti nel medesimo piano nel rispetto delle suddette condizioni per il periodo di tempo indicato al comma 106, e l'obbligo di corrispondere le imposte non pagate, unitamente agli interessi, senza applicazione di sanzioni, secondo quanto previsto al comma 106.

108. Le ritenute alla fonte e le imposte sostitutive eventualmente applicate e non dovute fanno sorgere in capo al titolare del piano il diritto a ricevere una somma corrispondente. I soggetti di cui al comma 101 presso i quali e' costituito il piano provvedono al pagamento della predetta somma, computandola in diminuzione dal versamento delle ritenute e delle imposte dovute dai medesimi soggetti. Ai fini del predetto computo non si applicano i limiti di cui all'articolo 1, comma 53, della legge 24 dicembre 2007, n. 244, e di cui all'articolo 34 della legge 23 dicembre 2000, n. 388.

109. Le minusvalenze, le perdite e i differenziali negativi realizzati mediante cessione a titolo oneroso ovvero rimborso degli strumenti finanziari nei quali e' investito il piano sono deducibili dalle plusvalenze, differenziali positivi o proventi realizzati nelle successive operazioni poste in essere nell'ambito del medesimo piano e sottoposti a tassazione ai sensi dei commi 106 e 107 nello stesso periodo d'imposta e nei successivi ma non oltre il quarto. Alla chiusura del piano le minusvalenze, perdite o differenziali negativi possono essere portati in deduzione non oltre il quarto periodo d'imposta successivo a quello del realizzo dalle plusvalenze, proventi e differenziali positivi realizzati nell'ambito di altro rapporto con esercizio dell'opzione ai sensi dell'articolo 6 del decreto legislativo 21 novembre 1997, n. 461, intestato allo stesso titolare del piano, ovvero portati in deduzione ai sensi del comma 5 dell'articolo 68 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

110. In caso di strumenti finanziari appartenenti alla medesima categoria omogenea, si considerano ceduti per primi i titoli acquistati per primi e si considera come costo quello medio ponderato dell'anno di acquisto.

111. Il trasferimento del piano di risparmio a lungo termine dall'intermediario o dall'impresa di assicurazione presso il quale e' stato costituito ad altro soggetto di cui al comma 101 non rileva ai fini del computo dei cinque anni di detenzione degli strumenti finanziari.

112. Ciascuna persona fisica di cui al comma 100 non puo' essere titolare di piu' piani di risparmio costituiti ai sensi del comma 101, salvi i casi di piani costituiti presso lo stesso intermediario o la medesima impresa di assicurazione, fermi restando i limiti di investimento annuale e complessivo di cui al medesimo comma 101. Ciascuna persona fisica di cui al comma 100 puo' essere titolare di piu' piani di risparmio costituiti ai sensi del comma 2-bis dell'articolo 13-bis del decreto-legge 26 ottobre 2019, n. 124, convertito, con modificazioni, dalla legge 19 dicembre 2019, n. 157, fermi restando i limiti di investimento annuale e complessivo di cui al comma 101. Ciascun piano di risparmio a lungo termine non puo' avere piu' di un titolare. L'intermediario o l'impresa di assicurazione presso il quale sono costituiti i piani, all'atto dell'incarico, acquisisce dal titolare un'autocertificazione con la quale lo stesso dichiara di non essere titolare di un altro piano di risparmio a lungo termine costituito ai sensi del comma 101 presso un altro intermediario o un'altra impresa di assicurazione.

113. L'intermediario o l'impresa di assicurazioni presso il quale e' costituito il piano di risparmio a lungo termine tiene separata evidenza delle somme destinate nel piano in anni differenti, nonche' degli investimenti qualificati effettuati.

114. Il trasferimento a causa di morte degli strumenti finanziari detenuti nel piano non e' soggetto all'imposta sulle successioni e donazioni di cui al testo unico delle disposizioni concernenti l'imposta sulle successioni e donazioni, di cui al decreto legislativo 31 ottobre 1990, n. 346.

115. Con decreto del Ministero dello sviluppo economico, di concerto con il Ministero dell'economia e delle finanze, da adottare entro centoventi giorni dalla data di entrata in vigore della presente legge, sono definite le modalita' di costituzione e le forme di finanziamento, nel limite di 20 milioni di euro per il 2017 e di 10 milioni di euro per il 2018, di centri di competenza ad alta specializzazione, nella forma del partenariato pubblico-privato, aventi lo scopo di promuovere e realizzare progetti di ricerca applicata, di trasferimento tecnologico e di formazione su tecnologie avanzate, nel quadro degli interventi connessi al Piano nazionale Industria 4.0.

116. Al fine di incrementare gli investimenti pubblici e privati nei settori della ricerca finalizzata alla prevenzione e alla salute, coerentemente con il Programma nazionale per la ricerca (PNR), e' istituita la Fondazione per la creazione di un'infrastruttura scientifica e di ricerca, di interesse nazionale, multidisciplinare e integrata nei settori della salute, della genomica, dell'alimentazione e della scienza dei dati e delle decisioni, e per la realizzazione del progetto scientifico e di ricerca Human technopole di cui all'articolo 5 del decreto-legge 25 novembre 2015, n. 185, convertito, con modificazioni, dalla legge 22 gennaio 2016, n. 9, e al relativo decreto del Presidente del Consiglio dei ministri 16 settembre 2016 di approvazione del progetto esecutivo, di seguito denominata «Fondazione». Per il raggiungimento dei propri scopi la Fondazione instaura rapporti con omologhi enti e organismi in Italia e all'estero.

117. Sono membri fondatori il Ministero dell'economia e delle finanze, il Ministero della salute e il Ministero dell'istruzione, dell'universita' e della ricerca, ai quali viene attribuita la vigilanza sulla Fondazione.

118. Il comitato di coordinamento di cui al decreto del Presidente del Consiglio dei ministri 16 settembre 2016 predispone lo schema di statuto della Fondazione che e' approvato con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca e con il Ministro della salute. Lo statuto stabilisce la denominazione della Fondazione e disciplina, tra l'altro, la partecipazione alla Fondazione di altri enti pubblici e privati, nonche' le modalita' con cui tali soggetti possono partecipare finanziariamente al progetto scientifico Human technopole.

119. Il patrimonio della Fondazione e' costituito da apporti dei Ministeri fondatori e incrementato da ulteriori apporti dello Stato, nonche' dalle risorse provenienti da soggetti pubblici e privati. Le attivita', oltre che dai mezzi propri, possono essere finanziate da contributi di enti pubblici e di privati. Alla Fondazione possono essere concessi in comodato beni immobili facenti parte del demanio e del patrimonio disponibile e indisponibile dello Stato. L'affidamento in comodato di beni di particolare valore artistico e storico alla Fondazione e' effettuato dall'amministrazione competente, d'intesa con il Ministro dei beni e delle attivita' culturali e del turismo, fermo restando il relativo regime giuridico dei beni demaniali affidati, previsto dagli articoli 823 e 829, primo comma, del codice civile.

120. Per lo svolgimento dei propri compiti la Fondazione puo' avvalersi di personale, anche di livello dirigenziale, all'uopo messo a disposizione su richiesta della stessa, secondo le norme previste dai rispettivi ordinamenti, da enti e da altri soggetti individuati ai sensi dell'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196. La Fondazione puo' avvalersi, inoltre, della collaborazione di esperti e di societa' di consulenza nazionali ed estere, ovvero di universita' e di istituti universitari e di ricerca.

121. Per la costituzione della Fondazione e per la realizzazione del progetto Human technopole di cui al comma 116 e' autorizzata la spesa di 10 milioni di euro per il 2017, di 114,3 milioni di euro per il 2018, di 136,5 milioni di euro per il 2019, di 112,1 milioni di euro per il 2020, di 122,1 milioni di euro per il 2021, di 133,6 milioni di euro per il 2022 e di 140,3 milioni di euro a decorrere dal 2023. Il contributo e' erogato sulla base dello stato di avanzamento del progetto Human technopole di cui al comma 116. Gli apporti al fondo di dotazione e al fondo di gestione della Fondazione a carico del bilancio dello Stato sono accreditati su un conto infruttifero aperto presso la Tesoreria dello Stato, intestato alla Fondazione.

122. Tutti gli atti connessi alle operazioni di costituzione della Fondazione e di conferimento e devoluzione alla stessa sono esclusi da ogni tributo e diritto e vengono effettuati in regime di neutralita' fiscale.

123. I criteri e le modalita' di attuazione dei commi da 116 a 122 del presente articolo, compresa la disciplina dei rapporti con l'Istituto italiano di tecnologia in ordine al progetto Human technopole di cui al medesimo comma 116, e il trasferimento alla Fondazione delle risorse residue di cui all'articolo 5, comma 2, del decreto-legge 25 novembre 2015, n. 185, convertito, con modificazioni, dalla legge 22 gennaio 2016, n. 9, sono stabiliti con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca e con il Ministro della salute.

124. La gestione dell'infrastruttura di ricerca FERMI rientra nell'esercizio dei compiti istituzionali di cui all'articolo 10, comma 4, lettera d), della legge 19 ottobre 1999, n. 370, e non ha natura commerciale. Ad essa si applicano le disposizioni di cui al medesimo articolo 10, comma 4, della legge n. 370 del 1999 e il suo valore non e' soggetto ad ammortamento.

125. Alla societa' di cui all'articolo 10, comma 4, della legge 19 ottobre 1999, n. 370, e alle amministrazioni pubbliche che vi partecipano non si applicano, limitatamente alla predetta partecipazione, le disposizioni del testo unico in materia di societa' a partecipazione pubblica, di cui al decreto legislativo 19 agosto 2016, n. 175.

126. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, e' nominato il Commissario straordinario per la liquidazione della societa' EXPO 2015 Spa in liquidazione.

127. Gli organi sociali della societa' EXPO 2015 Spa in liquidazione decadono alla data di entrata in vigore del decreto del Presidente del Consiglio dei ministri di cui al comma 126.

128. I poteri attribuiti al collegio dei liquidatori ai sensi dell'articolo 2489, primo comma, del codice civile sono assunti dal Commissario straordinario per la liquidazione della societa' EXPO 2015 Spa in liquidazione. Al fine di limitare l'assunzione di ulteriori oneri a carico della procedura liquidatoria della societa' EXPO 2015 Spa in liquidazione, contenendone gli effetti sulle pubbliche finanze, per lo svolgimento dei compiti di cui ai commi da 126 a 139 del presente articolo, il Commissario straordinario si avvale del personale e delle strutture di cui all'articolo 2, comma 3, del decreto del Presidente del Consiglio dei ministri 6 maggio 2013, pubblicato nella Gazzetta Ufficiale n. 123 del 28 maggio 2013.

129. Il contributo economico-patrimoniale a carico dei soci della societa' EXPO 2015 Spa in liquidazione, come individuato nel progetto di liquidazione adottato dal collegio dei liquidatori, non puo', in nessun caso, essere complessivamente superiore a 23.690.000 euro.

130. Il Ministero dell'economia e delle finanze, la regione Lombardia, il comune di Milano, la citta' metropolitana di Milano e la camera di commercio, industria, artigianato e agricoltura di Milano assicurano, ciascuno in proporzione alla partecipazione al capitale della societa', le risorse necessarie all'integrale copertura del fondo di liquidazione, nella misura massima di cui al comma 129.

131. Il contributo economico-patrimoniale a carico dello stato di previsione della spesa del Ministero dell'economia e delle finanze e' individuato in misura non superiore a 9.460.000 euro. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

132. In deroga a quanto previsto all'articolo 2490, primo comma, del codice civile, le risorse di competenza del Ministero dell'economia e delle finanze, fissate nella misura massima di cui al comma 131, primo periodo, destinate alla copertura del Fondo di liquidazione della societa' EXPO 2015 Spa in liquidazione sono riconosciute, per ciascuna delle annualita' comprese tra il 1º gennaio 2017 e il 31 dicembre 2021, in via anticipata, nella misura massima, rispettivamente, di 4.810.000 euro per il 2017, di 1.480.000 euro per il 2018, di 1.230.000 euro per il 2019, di 1.060.000 euro per il 2020 e di 880.000 euro per il 2021. Il Commissario straordinario presenta, con cadenza annuale, al Dipartimento del Tesoro del Ministero dell'economia e delle finanze il rendiconto delle attivita' di liquidazione, che dovranno concludersi entro il 2021. Fermo restando quanto previsto ai commi 129 e 131, il riconoscimento, entro il loro limite massimo, delle somme relative alle annualita' successive al 2017 e' posto a conguaglio con la differenza tra quanto gia' corrisposto in via anticipata nell'annualita' precedente e gli oneri effettivamente sostenuti dal Commissario straordinario nello stesso periodo di riferimento.

132-bis. Al fine di accelerare la chiusura della procedura di liquidazione della societa' di cui al comma 126 del presente articolo, agevolando in tal modo il versamento all'entrata del bilancio dello Stato e dei bilanci delle altre amministrazioni socie il relativo avanzo di liquidazione, il Commissario straordinario per la liquidazione della societa' di cui all'articolo 14, comma 2, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, trasmette alle amministrazioni socie, entro il 31 gennaio 2022, il rendiconto finale delle attivita' liquidatorie alla data del 31 dicembre 2021, unitamente a un prospetto concernente l'individuazione dei rapporti giuridici attivi e passivi, anche di natura contenziosa e processuale, sorti in capo alla societa', ancora pendenti alla data del 31 dicembre 2021. Il Commissario straordinario per la liquidazione della societa' di cui al citato articolo 14, comma 2, del decreto-legge n. 112 del 2008, convertito, con modificazioni, dalla legge n. 133 del 2008, entro il 28 febbraio 2022, versa all'entrata del bilancio dello Stato e dei bilanci delle altre amministrazioni socie l'avanzo di liquidazione derivante dalla chiusura della liquidazione della stessa societa', con esclusione dei rapporti giuridici attivi e passivi, anche di natura contenziosa e processuale, di cui al precedente periodo, pendenti alla data del 31 dicembre 2021. I rapporti giuridici attivi e passivi, anche di natura contenziosa e processuale, di cui al primo periodo del presente comma, pendenti alla data del 31 dicembre 2021, sorti in capo alla societa' di cui al medesimo articolo 14, comma 2, del decreto-legge n. 112 del 2008, convertito, con modificazioni, dalla legge n. 133 del 2008, sono trasferiti alla societa' Fintecna Spa o a diversa societa' da questa interamente partecipata entro il 30 aprile 2022. Gli atti e le operazioni posti in essere per il trasferimento dei rapporti giuridici di cui al terzo periodo sono esenti da imposizione fiscale diretta e indiretta e dall'applicazione di tasse. La societa' trasferitaria procede alla liquidazione delle posizioni derivanti dai rapporti giuridici attivi e passivi oggetto di trasferimento ai sensi del terzo periodo, subentrando altresi' nei contenziosi pendenti alla data del 31 dicembre 2021. I rapporti giuridici attivi e passivi trasferiti ai sensi del terzo periodo alla societa' Fintecna Spa o a diversa societa' da questa interamente partecipata costituiscono un unico patrimonio separato rispetto sia al patrimonio della societa' trasferitaria, sia ai patrimoni separati ad essa trasferiti in virtu' di specifiche disposizioni legislative. La societa' trasferitaria non risponde in alcun modo con il proprio patrimonio dei debiti e degli oneri sorti in forza dei rapporti giuridici attivi e passivi, anche di natura contenziosa e processuale, trasferiti al patrimonio separato di cui al sesto periodo, ivi compresi quelli da sostenersi per la liquidazione di tale patrimonio. Agli oneri derivanti dal compenso da riconoscere alla societa' Fintecna Spa o alla diversa societa' da questa interamente partecipata per la liquidazione dei rapporti giuridici trasferiti ai sensi del terzo periodo, da determinare con decreto del Ministro dell'economia e delle finanze, in misura comunque complessivamente non superiore a 500.000 euro, si provvede a valere sulle risorse affluite al patrimonio separato. Alla cessazione dei rapporti attivi, passivi, contenziosi e processuali trasferiti al patrimonio separato, la societa' trasferitaria procede al versamento delle eventuali somme attive al Ministero dell'economia e delle finanze, alla regione Lombardia, al comune di Milano, alla citta' metropolitana di Milano e alla camera di commercio di Milano Monza Brianza Lodi, per ciascuno in proporzione alla partecipazione al capitale della societa' di cui al primo periodo del presente comma. Dall'attuazione delle disposizioni di cui al presente comma non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

132-ter. All'articolo 1, comma 58, lettera e), della legge 23 dicembre 2014, n. 190, il terzo periodo e' soppresso. All'articolo 7-sexies del decreto-legge 22 ottobre 2016, n. 193, convertito, con modificazioni, dalla legge 1° dicembre 2016, n. 225, il comma 2 e' abrogato.

133. Agli oneri di cui al comma 132 si provvede mediante corrispondente riduzione del Fondo per interventi strutturali di politica economica, di cui all'articolo 10, comma 5, del decreto-legge 29 novembre 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307.

134. Al fine di dare compiuta attuazione al progetto di valorizzazione dell'area utilizzata per l'EXPO 2015 di cui all'articolo 5 del decreto-legge 25 novembre 2015, n. 185, convertito, con modificazioni, dalla legge 22 gennaio 2016, n. 9, e' autorizzata la spesa di 8 milioni di euro per il 2017 per l'avvio delle attivita' di progettazione propedeutiche alla realizzazione delle strutture per il trasferimento dei dipartimenti scientifici dell'Universita' degli studi di Milano.

135. Agli oneri di cui al comma 134 si provvede, per l'importo di 3 milioni di euro, mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 10, comma 1, lettera d), della legge 19 ottobre 1999, n. 370, e, per l'importo di 5 milioni di euro, mediante corrispondente riduzione del Fondo per gli investimenti nella ricerca scientifica e tecnologica di cui all'articolo 1, comma 870, della legge 27 dicembre 2006, n. 296.

136. La societa' AREXPO Spa puo' avvalersi, sulla base di convenzioni, della collaborazione degli uffici tecnici e amministrativi dei propri soci pubblici, nonche' delle rispettive societa' in house.

137. All'articolo 1 della legge 7 aprile 2014, n. 56, sono apportate le seguenti modificazioni:

- a) al comma 49, l'ultimo periodo e' soppresso;
- b) al comma 49-bis, il quinto periodo e' soppresso;
- c) al comma 49-ter, il quarto e quinto periodo sono soppressi.

138. Il comma 775 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' abrogato.

139. Gli enti pubblici non economici strumentali degli enti locali e regionali soci della societa' EXPO 2015 Spa per le attivita' strettamente funzionali alla manutenzione degli investimenti di compensazione ambientale e per il paesaggio rurale realizzati per l'esposizione universale, fermo restando il rispetto degli obiettivi di finanza pubblica, possono procedere, anche in deroga agli specifici vincoli assunzionali e finanziari previsti dalla legislazione in materia di personale, ad assunzione di personale a tempo determinato con durata fino al 31 dicembre 2019.

140. Nello stato di previsione del Ministero dell'economia e delle finanze e' istituito un apposito fondo da ripartire, con una dotazione di 1.900 milioni di euro per l'anno 2017, di 3.150 milioni di euro per l'anno 2018, di 3.500 milioni di euro per l'anno 2019 e di 3.000 milioni di euro per ciascuno degli anni dal 2020 al 2032, per assicurare il finanziamento degli investimenti e lo sviluppo infrastrutturale del Paese, anche al fine di pervenire alla soluzione delle questioni oggetto di procedure di infrazione da parte dell'Unione europea, nei settori di spesa relativi a:

- a) trasporti, viabilita', mobilita' sostenibile, sicurezza stradale, riqualificazione e accessibilita' delle stazioni ferroviarie;
- b) infrastrutture, anche relative alla rete idrica e alle opere di collettamento, fognatura e depurazione;
- c) ricerca;
- d) difesa del suolo, dissesto idrogeologico, risanamento ambientale e bonifiche;
- e) edilizia pubblica, compresa quella scolastica;
- f) attivita' industriali ad alta tecnologia e sostegno alle esportazioni;
- g) informatizzazione dell'amministrazione giudiziaria;
- h) prevenzione del rischio sismico;
- i) investimenti per la riqualificazione urbana e per la sicurezza delle periferie delle citta' metropolitane e dei comuni capoluogo di provincia;
- l) eliminazione delle barriere architettoniche. L'utilizzo del fondo di cui al primo periodo e' disposto con uno o piu' decreti del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, di concerto con i Ministri interessati, in relazione ai programmi presentati dalle amministrazioni centrali dello Stato. Gli schemi dei decreti sono trasmessi alle Commissioni parlamentari competenti per materia, le quali esprimono il proprio parere entro trenta giorni dalla data dell'assegnazione; decorso tale termine, i decreti possono essere adottati anche in mancanza del predetto parere. Con i medesimi decreti sono individuati gli interventi da finanziare e i relativi importi, indicando, ove necessario, le modalita' di utilizzo dei contributi, sulla base di criteri di economicita' e di contenimento della spesa, anche attraverso operazioni finanziarie con oneri di ammortamento a carico del bilancio dello Stato, con la Banca europea per gli investimenti, con la Banca di sviluppo del Consiglio d'Europa, con la Cassa depositi e prestiti Spa e con i soggetti autorizzati all'esercizio dell'attivita' bancaria ai sensi del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1º settembre 1993, n. 385, compatibilmente con gli obiettivi programmati di finanza pubblica. Fermo restando che i decreti di cui al periodo precedente, nella parte in cui individuano interventi rientranti nelle materie di competenza regionale o delle province autonome, e limitatamente agli stessi, sono adottati previa intesa con gli enti territoriali interessati, ovvero in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le Province autonome di Trento e di Bolzano, per gli interventi rientranti nelle suddette materie individuati con i decreti adottati anteriormente alla data del 18 aprile 2018 l'intesa puo' essere raggiunta anche successivamente all'adozione degli stessi decreti. Restano in ogni caso fermi i procedimenti di spesa in corso alla data di entrata in vigore della legge di conversione del presente decreto nei termini indicati dalla sentenza della Corte costituzionale n. 74 del 13 aprile 2018. (11) (14) (24) (38) (67)

140-bis. Per l'anno 2017 una quota del Fondo di cui al comma 140, per un importo pari a 400 milioni di euro, e' attribuita alle Regioni a statuto ordinario per le medesime finalita' ed e' ripartita secondo gli importi indicati nella tabella di seguito riportata. Le Regioni a statuto ordinario sono tenute ad effettuare investimenti nuovi e aggiuntivi per un importo almeno pari a 132.421.052,63 euro nell'anno 2017. A tal fine, entro il 31 luglio 2017, le medesime Regioni a statuto ordinario adottano gli atti finalizzati all'impiego delle risorse, assicurando l'esigibilita' degli impegni nel medesimo anno 2017 per la quota di competenza di ciascuna Regione. Gli investimenti che le singole Regioni sono chiamate a realizzare, secondo quanto stabilito al periodo precedente, sono considerati nuovi o aggiuntivi qualora sia rispettata una delle seguenti condizioni:

- a) le Regioni procedono a variare il bilancio di previsione 2017 - 2019 incrementando gli stanziamenti riguardanti gli investimenti diretti e indiretti per la quota di rispettiva competenza, come indicata nella tabella di seguito riportata;
- b) gli investimenti per l'anno 2017 devono essere superiori, per un importo pari ai valori indicati nella tabella di seguito riportata, rispetto agli impegni per investimenti diretti e indiretti effettuati nell'esercizio 2016 a valere su risorse regionali, escluse le risorse del Fondo pluriennale vincolato. Le Regioni certificano l'avvenuta realizzazione degli investimenti di cui alla tabella di seguito riportata, entro il 31 marzo 2018, mediante apposita comunicazione al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. In caso di mancata o parziale realizzazione degli investimenti, rispetto agli obiettivi indicati per ciascuna Regione nella tabella di seguito riportata qualora la Regione non abbia conseguito, per la differenza, un valore positivo del saldo di cui al comma 466, si applicano le sanzioni di cui commi 475 e 476. SNF IN Regioni Percentuale Riparto quota fondo investimenti Quote investimenti nuovi e aggiuntivi Abruzzo 3,16% 12.650.315,79 4.187.920,33 Basilicata 2,50% 9.994.315,79 3.308.644,54 Calabria 4,46% 17.842.315,79 5.906.745,60 Campania 10,54% 42.159.368,42 13.956.969,86 Emilia-Romagna 8,51% 34.026.315,79 11.264.501,39 Lazio 11,70% 46.813.263,16 15.497.653,96 Liguria 3,10% 12.403.157,89 4.106.098,06 Lombardia 17,48% 69.930.105,26 23.150.545,37 Marche 3,48% 13.929.473,68 4.611.388,92 Molise 0,96% 3.828.842,11 1.267.548,25 Piemonte 8,23% 32.908.842,11 10.894.558,78 Puglia 8,15% 32.610.736,84 10.795.870,25 Toscana 7,82% 31.269.263,16 10.351.771,86 Umbria 1,96% 7.848.210,53 2.598.170,75 Veneto 7,95% 31.785.473,68 10.522.664,71 TOTALE 100,00% 400.000.000,00 132.421.052,63

140-ter. Una quota del Fondo di cui al comma 140, per un importo pari a 64 milioni di euro per l'anno 2017, 118 milioni di euro per l'anno 2018 80 milioni di euro per l'anno 2019 e 44,1 milioni di euro per l'anno 2020, e' attribuita dal Ministero dell'istruzione, dell'universita' e della ricerca alle province e alle citta' metropolitane per il finanziamento degli interventi in materia di edilizia scolastica coerenti con la Programmazione triennale. Tali risorse possono essere destinate anche all'attuazione degli interventi di adeguamento alla normativa in materia di sicurezza antincendio. E' corrispondentemente ridotta l'autorizzazione di spesa di cui al predetto comma 140. Le province e le citta' metropolitane certificano l'avvenuta realizzazione degli investimenti di cui al presente comma entro il 31 marzo successivo all'anno di riferimento, mediante apposita comunicazione al Ministero dell'istruzione, dell'universita' e della ricerca e al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. In caso di mancata o parziale realizzazione degli investimenti, le corrispondenti risorse assegnate alle singole province o citta' metropolitane sono versate all'entrata del bilancio dello Stato per essere riassegnate al fondo di cui al comma 140.

141. Al fine di garantire il completo finanziamento dei progetti selezionati nell'ambito del Programma straordinario di intervento per la riqualificazione urbana e la sicurezza delle periferie delle citta' metropolitane e dei comuni capoluogo di provincia, di cui all'articolo 1, commi da 974 a 978, della legge 28 dicembre 2015, n. 208, a integrazione delle risorse stanziate sull'apposito capitolo di spesa e di quelle assegnate ai sensi del comma 140 del presente articolo, con delibera del Comitato interministeriale per la programmazione economica (CIPE) sono destinate ulteriori risorse a valere sulle risorse disponibili del Fondo per lo sviluppo e la coesione per il periodo di programmazione 2014-2020.

142. Gli interventi di cui ai commi 140, 140-bis e 140-ter e 141 del presente articolo sono monitorati ai sensi del decreto legislativo 29 dicembre 2011, n. 229.

143. Presso il Ministero dell'ambiente e della tutela del territorio e del mare e' istituito un fondo per la realizzazione degli investimenti per la conservazione della fauna e della flora e per la salvaguardia della biodiversita' e dell'ecosistema marino con una dotazione finanziaria di 3 milioni di euro per ciascuno degli anni dal 2017 al 2021.

144. Per lo sviluppo del sistema nazionale di ciclovie turistiche di cui all'articolo 1, comma 640, primo periodo, della legge 28 dicembre 2015, n. 208, e' autorizzata l'ulteriore spesa di 13 milioni di euro per l'anno 2017, di 30 milioni di euro per l'anno 2018 e di 40 milioni di euro per ciascuno degli anni dal 2019 al 2024.

145. Le risorse di cui al comma 144 sono destinate alla realizzazione di progetti individuati con decreto del Ministro delle infrastrutture e dei trasporti.

146. All'articolo 11, comma 3, della legge 7 luglio 2016, n. 122, sono aggiunte, in fine, le seguenti parole: «e, in particolare, ai figli della vittima in caso di omicidio commesso dal coniuge, anche separato o divorziato, o da persona che e' o e' stata legata da relazione affettiva alla persona offesa».

147. Dopo il comma 3 dell'articolo 15 del decreto-legge 25 novembre 2015, n. 185, convertito, con modificazioni, dalla legge 22 gennaio 2016, n. 9, e' inserito il seguente: «3-bis. Nel caso in cui il progetto ammesso sia gia' stato finanziato con altre risorse pubbliche diverse da quelle stanziate dal presente articolo, il relativo intervento e' escluso dal piano pluriennale degli interventi. Resta salva la possibilita' che, in sede di rimodulazione annuale del piano, le risorse equivalenti siano destinate, su richiesta del proponente, previa valutazione da parte del CONI dei requisiti necessari e previo accordo con l'ente proprietario, al finanziamento di altri interventi relativi a proposte presentate dallo stesso soggetto proponente, negli stessi modi e termini gia' previsti dal CONI, che abbiano analogo o inferiore importo e che posseggano i requisiti previsti».

148. Al testo unico delle disposizioni concernenti la disciplina dell'immigrazione e norme sulla condizione dello straniero, di cui al decreto legislativo 25 luglio 1998, n. 286, dopo l'articolo 26 e' inserito il seguente: «Art. 26-bis (Ingresso e soggiorno per investitori). - 1. L'ingresso e il soggiorno per periodi superiori a tre mesi sono consentiti, al di fuori delle quote di cui all'articolo 3, comma 4, agli stranieri che intendono effettuare: a) un investimento di almeno euro 2.000.000 in titoli emessi dal Governo italiano e che vengano mantenuti per almeno due anni; b) un investimento di almeno euro 1.000.000 in strumenti rappresentativi del capitale di una societa' costituita e operante in Italia mantenuto per almeno due anni ovvero di almeno euro 500.000 nel caso tale societa' sia una start-up innovativa iscritta nella sezione speciale del registro delle imprese di cui all'articolo 25, comma 8, del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221; c) una donazione a carattere filantropico di almeno euro 1.000.000 a sostegno di un progetto di pubblico interesse, nei settori della cultura, istruzione, gestione dell'immigrazione, ricerca scientifica, recupero di beni culturali e paesaggistici e che: 1) dimostrano di essere titolari e beneficiari effettivi di un importo almeno pari a euro 2.000.000, nel caso di cui alla lettera a), o euro 1.000.000, nei casi di cui alla lettera b) e alla presente lettera, importo che deve essere in ciascun caso disponibile e trasferibile in Italia; 2) presentano una dichiarazione scritta in cui si impegnano a utilizzare i fondi di cui al numero 1) per effettuare un investimento o una donazione filantropica che rispettino i criteri di cui alle lettere a) e b) e alla presente lettera, entro tre mesi dalla data di ingresso in Italia; 3) dimostrano di avere risorse sufficienti, in aggiunta rispetto ai fondi di cui al numero 1) e in misura almeno superiore al livello minimo previsto dalla legge per l'esenzione dalla partecipazione alla spesa sanitaria, per il proprio mantenimento durante il soggiorno in Italia. 2. Per l'accertamento dei requisiti previsti dal comma 1, lo straniero richiedente deve presentare mediante procedura da definire con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'interno e con il Ministro degli affari esteri e della cooperazione internazionale, da emanare entro novanta giorni dalla data di entrata in vigore della presente disposizione, i seguenti documenti: a) copia del documento di viaggio in corso di validita' con scadenza superiore di almeno tre mesi a quella del visto richiesto; b) documentazione comprovante la disponibilita' della somma minima prevista al comma 1, lettera c), numero 1), e che tale somma puo' essere trasferita in Italia; c) certificazione della provenienza lecita dei fondi di cui al comma 1, lettera c), numero 1); d) dichiarazione scritta di cui al comma 1, lettera c), numero 2), contenente una descrizione dettagliata delle caratteristiche e dei destinatari dell'investimento o della donazione. 3. L'autorita' amministrativa individuata con il decreto di cui al comma 2, all'esito di una valutazione positiva della documentazione ricevuta, trasmette il nulla osta alla rappresentanza diplomatica o consolare competente per territorio che, compiuti gli accertamenti di rito, rilascia il visto di ingresso per investitori con l'espressa indicazione "visto investitori". 4. Ferma restando l'applicazione del decreto legislativo 21 novembre 2007, n. 231, ai fini della preliminare verifica sulla sussistenza delle condizioni per il rilascio del nulla osta di cui al comma 3, l'autorita' amministrativa individuata con il decreto di cui al comma 2 del presente articolo trasmette tempestivamente all'Unita' di informazione finanziaria le comunicazioni che attestano la provenienza lecita dei fondi unitamente ad ogni altra informazione, documento o atto disponibile sul soggetto che intende avvalersi della procedura di cui al medesimo comma 2, che siano ritenuti utili ai fini della verifica. Con il decreto di cui al comma 2 sono altresi' disciplinate le forme e le modalita' di attuazione delle predette verifiche preliminari, da concludere entro quindici giorni dalla trasmissione della documentazione di cui al primo periodo, del relativo scambio di informazioni e della partecipazione richiesta agli organi di cui all'articolo 8, comma 2, del medesimo decreto legislativo n. 231 del 2007. 5. Al titolare del visto per investitori e' rilasciato, in conformita' alle disposizioni del presente testo unico, un permesso di soggiorno biennale recante la dicitura "per investitori", revocabile anche prima della scadenza quando l'autorita' amministrativa individuata con il decreto di cui al comma 2 comunica alla questura che lo straniero non ha effettuato l'investimento o la donazione di cui al comma 1 entro tre mesi dalla data di ingresso in Italia o ha dismesso l'investimento prima della scadenza del termine di due anni di cui al comma 1, lettere a) e b). 6. Il permesso di soggiorno per investitori e' rinnovabile per periodi ulteriori di tre anni, previa valutazione positiva, da parte dell'autorita' amministrativa individuata con il decreto di cui al comma 2, della documentazione comprovante che la somma di cui al comma 1 e' stata interamente impiegata entro tre mesi dalla data di ingresso in Italia e che risulta ancora investita negli strumenti finanziari di cui al comma 1. 7. Ai fini del rinnovo del permesso di soggiorno, l'autorita' amministrativa individuata con il decreto di cui al comma 2, all'esito di una valutazione positiva della documentazione ricevuta, trasmette il nulla osta alla questura della provincia in cui il richiedente dimora, che provvede al rinnovo del permesso di soggiorno. 8. Ai sensi dell'articolo 29, comma 4, e' consentito l'ingresso, al seguito dello straniero detentore del visto per investitori, dei familiari con i quali e' consentito il ricongiungimento ai sensi dello stesso articolo 29. Ai familiari e' rilasciato un visto per motivi familiari ai sensi dell'articolo 30. 9. Chiunque, nell'ambito della procedura di cui al presente articolo, esibisce o trasmette atti o documenti falsi, in tutto o in parte, ovvero fornisce dati e notizie non rispondenti al vero e' punito con la reclusione da un anno e sei mesi a sei anni. In relazione alla certificazione di cui al comma 2, lettera c), del presente articolo, resta ferma l'applicabilita' degli articoli 648-bis, 648-ter e 648-ter.1 del codice penale e dell'articolo 12-quinquies del decreto-legge 8 giugno 1992, n. 306, convertito, con modificazioni, dalla legge 7 agosto 1992, n. 356».

149. All'articolo 44, comma 1, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, le parole: «dalla data di entrata in vigore del presente decreto ed entro i sette anni solari successivi» sono soppresse.

150. All'articolo 16 del decreto legislativo 14 settembre 2015, n. 147, sono apportate le seguenti modificazioni:

- a) al comma 1, alinea: 1) le parole: «Il reddito di lavoro dipendente prodotto» sono sostituite dalle seguenti: «I redditi di lavoro dipendente e di lavoro autonomo prodotti»; 2) le parole: «settanta per cento» sono sostituite dalle seguenti: «cinquanta per cento»;
- b) dopo il comma 1 e' inserito il seguente: «1-bis. Le condizioni di cui al comma 1, lettere b) e d), non si applicano ai lavoratori autonomi»;
- c) al comma 2 e' aggiunto, in fine, il seguente periodo: «Il criterio di determinazione del reddito di cui al comma 1 si applica anche ai cittadini di Stati diversi da quelli appartenenti all'Unione europea, con i quali sia in vigore una convenzione per evitare le doppie imposizioni in materia di imposte sul reddito ovvero un accordo sullo scambio di informazioni in materia fiscale, in possesso di un diploma di laurea, che hanno svolto continuativamente un'attivita' di lavoro dipendente, di lavoro autonomo o di impresa fuori dall'Italia negli ultimi ventiquattro mesi ovvero che hanno svolto continuativamente un'attivita' di studio fuori dall'Italia negli ultimi ventiquattro mesi o piu', conseguendo un diploma di laurea o una specializzazione post lauream».

151. Le disposizioni di cui al comma 150, lettera a), numero 2), e lettera c), si applicano a decorrere dal periodo d'imposta in corso al 1º gennaio 2017. Le medesime disposizioni di cui al comma 150, lettera a), numero 2), si applicano, per i periodi d'imposta dal 2017 al 2020, anche ai lavoratori dipendenti che nell'anno 2016 hanno trasferito la residenza nel territorio dello Stato ai sensi dell'articolo 2 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e ai soggetti che nel medesimo anno 2016 hanno esercitato l'opzione ai sensi del comma 4 dell'articolo 16 del decreto legislativo 14 settembre 2015, n. 147.

152. Al capo I del titolo I del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' aggiunto, in fine, il seguente articolo: «Art. 24-bis (Opzione per l'imposta sostitutiva sui redditi prodotti all'estero realizzati da persone fisiche che trasferiscono la propria residenza fiscale in Italia). - 1. Le persone fisiche che trasferiscono la propria residenza in Italia ai sensi dell'articolo 2, comma 2, possono optare per l'assoggettamento all'imposta sostitutiva, di cui al comma 2 del presente articolo, dei redditi prodotti all'estero individuati secondo i criteri di cui all'articolo 165, comma 2, a condizione che non siano state fiscalmente residenti in Italia, ai sensi dell'articolo 2, comma 2, per un tempo almeno pari a nove periodi d'imposta nel corso dei dieci precedenti l'inizio del periodo di validita' dell'opzione. L'imposta sostitutiva non si applica ai redditi di cui all'articolo 67, comma 1, lettera c), realizzati nei primi cinque periodi d'imposta di validita' dell'opzione, che rimangono soggetti al regime ordinario di imposizione di cui all'articolo 68, comma 3. 2. Per effetto dell'esercizio dell'opzione di cui al comma 1, relativamente ai redditi prodotti all'estero di cui al comma 1 e' dovuta un'imposta sostitutiva dell'imposta sui redditi delle persone fisiche calcolata in via forfetaria, a prescindere dall'importo dei redditi percepiti, nella misura di euro 100.000 per ciascun periodo d'imposta in cui e' valida la predetta opzione. Tale importo e' ridotto a euro 25.000 per ciascun periodo d'imposta per ciascuno dei familiari di cui al comma 6. L'imposta e' versata in un'unica soluzione entro la data prevista per il versamento del saldo delle imposte sui redditi. Per l'accertamento, la riscossione, il contenzioso e le sanzioni si applicano, in quanto compatibili, le disposizioni previste per l'imposta sul reddito delle persone fisiche. L'imposta non e' deducibile da nessun'altra imposta o contributo. 3. L'opzione di cui al comma 1 deve essere esercitata dopo aver ottenuto risposta favorevole a specifica istanza di interpello presentata all'Agenzia delle entrate, ai sensi dell'articolo 11, comma 1, lettera b), della legge 27 luglio 2000, n. 212, entro il termine per la presentazione della dichiarazione relativa al periodo d'imposta in cui viene trasferita la residenza in Italia ai sensi del comma 1 del presente articolo ed e' efficace a decorrere da tale periodo d'imposta. Le persone fisiche di cui al comma 1 indicano nell'opzione la giurisdizione o le giurisdizioni in cui hanno avuto l'ultima residenza fiscale prima dell'esercizio di validita' dell'opzione. L'Agenzia delle entrate trasmette tali informazioni, attraverso gli idonei strumenti di cooperazione amministrativa, alle autorita' fiscali delle giurisdizioni indicate come luogo di ultima residenza fiscale prima dell'esercizio di validita' dell'opzione. 4. L'opzione di cui al comma 1 e' revocabile e comunque cessa di produrre effetti decorsi quindici anni dal primo periodo d'imposta di validita' dell'opzione. Gli effetti dell'opzione cessano in ogni caso in ipotesi di omesso o parziale versamento, in tutto o in parte, dell'imposta sostitutiva di cui al comma 2 nella misura e nei termini previsti dalle vigenti disposizioni di legge. Sono fatti salvi gli effetti prodotti nei periodi d'imposta precedenti. La revoca o la decadenza dal regime precludono l'esercizio di una nuova opzione. 5. Le persone fisiche di cui al comma 1, per se' o per uno o piu' dei familiari di cui al comma 6, possono manifestare la facolta' di non avvalersi dell'applicazione dell'imposta sostitutiva con riferimento ai redditi prodotti in uno o piu' Stati o territori esteri, dandone specifica indicazione in sede di esercizio dell'opzione ovvero con successiva modifica della stessa. Soltanto in tal caso, per i redditi prodotti nei suddetti Stati o territori esteri si applica il regime ordinario e compete il credito d'imposta per i redditi prodotti all'estero. Ai fini dell'individuazione dello Stato o territorio estero in cui sono prodotti i redditi si applicano i medesimi criteri di cui all'articolo 23. 6. Su richiesta del soggetto che esercita l'opzione di cui al comma 1, l'opzione ivi prevista puo' essere estesa nel corso di tutto il periodo dell'opzione a uno o piu' dei familiari di cui all'articolo 433 del codice civile, purche' soddisfino le condizioni di cui al comma 1. In tal caso, il soggetto che esercita l'opzione indica la giurisdizione o le giurisdizioni in cui i familiari a cui si estende il regime avevano l'ultima residenza prima dell'esercizio di validita' dell'opzione. L'estensione dell'opzione puo' essere revocata in relazione a uno o piu' familiari di cui al periodo precedente. La revoca dall'opzione o la decadenza dal regime del soggetto che esercita l'opzione si estendono anche ai familiari. La decadenza dal regime di uno o piu' dei familiari per omesso o parziale versamento dell'imposta sostitutiva loro riferita non comporta decadenza dal regime per le persone fisiche di cui al comma 1».

153. I soggetti che esercitano l'opzione di cui all'articolo 24-bis del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, introdotto dal comma 152 del presente articolo, per i periodi d'imposta di validita' dell'opzione ivi prevista, non sono tenuti agli obblighi di dichiarazione di cui all'articolo 4 del decreto-legge 28 giugno 1990, n. 167, convertito, con modificazioni, dalla legge 4 agosto 1990, n. 227, e sono esenti dalle imposte previste dall'articolo 19, commi 13 e 18, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214. La presente disposizione si applica anche ai familiari di cui al comma 6 del citato articolo 24-bis del testo unico di cui al decreto del Presidente della Repubblica n. 917 del 1986.

154. Gli effetti dell'opzione di cui all'articolo 24-bis del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, introdotto dal comma 152 del presente articolo, non sono cumulabili con quelli previsti dall'articolo 44 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e dall'articolo 16 del decreto legislativo 14 settembre 2015, n. 147.

155. Al fine di favorire l'ingresso di significativi investimenti in Italia, anche preordinati ad accrescere i livelli occupazionali, con decreto del Ministro degli affari esteri e della cooperazione internazionale, di concerto con il Ministro dell'interno, sono individuate forme di agevolazione nella trattazione delle domande di visto di ingresso e di permesso di soggiorno applicabili a chi trasferisce la propria residenza fiscale in Italia ai sensi dell'articolo 24-bis del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, introdotto dal comma 152 del presente articolo.

156. Con decreto del Ministro degli affari esteri e della cooperazione internazionale, di concerto con il Ministro dell'interno, sono individuate, nel rispetto della normativa vigente nazionale ed europea, forme di agevolazione nella trattazione delle domande di visto di ingresso e di permesso di soggiorno connesse con start-up innovative, con iniziative d'investimento, di formazione avanzata, di ricerca o di mecenatismo, da realizzare anche in partenariato con imprese, universita', enti di ricerca e altri soggetti pubblici o privati italiani.

157. Le modalita' applicative per l'esercizio, la modifica o la revoca dell'opzione di cui al comma 1 dell'articolo 24-bis del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, introdotto dal comma 152 del presente articolo, e per il versamento dell'imposta sostitutiva di cui al comma 2 del medesimo articolo 24-bis sono individuate con provvedimento del direttore dell'Agenzia delle entrate, da adottare entro novanta giorni dalla data di entrata in vigore della presente legge.

158. Per le successioni aperte e le donazioni effettuate nei periodi d'imposta di validita' dell'opzione esercitata dal dante causa, ai sensi dell'articolo 24-bis del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, introdotto dal comma 152 del presente articolo, l'imposta sulle successioni e donazioni di cui al testo unico delle disposizioni concernenti l'imposta sulle successioni e donazioni, di cui al decreto legislativo 31 ottobre 1990, n. 346, e' dovuta limitatamente ai beni e ai diritti esistenti nello Stato al momento della successione o della donazione.

159. Le disposizioni di cui ai commi da 148 a 158 si applicano per la prima volta con riferimento alle dichiarazioni dei redditi relative al periodo d'imposta in corso alla data di entrata in vigore della presente legge.

160. All'articolo 1 della legge 28 dicembre 2015, n. 208, sono apportate le seguenti modificazioni:

- a) al comma 182, le parole: «2.000 euro» sono sostituite dalle seguenti: «3.000 euro»;
- b) al comma 184 e' aggiunto, in fine, il seguente periodo: «Le somme e i valori di cui al comma 4 del medesimo articolo 51 concorrono a formare il reddito di lavoro dipendente secondo le regole ivi previste e non sono soggetti all'imposta sostitutiva disciplinata dai commi da 182 a 191 del presente articolo, anche nell'eventualita' in cui gli stessi siano fruiti, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182»;
- c) dopo il comma 184 e' inserito il seguente: «184-bis. Ai fini dell'applicazione del comma 184, non concorrono a formare il reddito di lavoro dipendente, ne' sono soggetti all'imposta sostitutiva disciplinata dai commi da 182 a 191: a) i contributi alle forme pensionistiche complementari di cui al decreto legislativo 5 dicembre 2005, n. 252, versati, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182 del presente articolo, anche se eccedenti i limiti indicati all'articolo 8, commi 4 e 6, del medesimo decreto legislativo n. 252 del 2005. Tali contributi non concorrono a formare la parte imponibile delle prestazioni pensionistiche complementari ai fini dell'applicazione delle previsioni di cui all'articolo 11, comma 6, del medesimo decreto legislativo n. 252 del 2005; b) i contributi di assistenza sanitaria di cui all'articolo 51, comma 2, lettera a), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, versati per scelta del lavoratore in sostituzione, in tutto o in parte, delle somme di cui al comma 182 del presente articolo, anche se eccedenti i limiti indicati nel medesimo articolo 51, comma 2, lettera a); c) il valore delle azioni di cui all'articolo 51, comma 2, lettera g), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, ricevute, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182 del presente articolo, anche se eccedente il limite indicato nel medesimo articolo 51, comma 2, lettera g), e indipendentemente dalle condizioni dallo stesso stabilite»;
- d) al comma 186, le parole: «euro 50.000» sono sostituite dalle seguenti: «euro 80.000»;
- e) al comma 189, le parole: «2.500 euro» sono sostituite dalle seguenti: «4.000 euro».

161. All'articolo 51, comma 2, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, dopo la lettera f-ter) e' inserita la seguente: «f-quater) i contributi e i premi versati dal datore di lavoro a favore della generalita' dei dipendenti o di categorie di dipendenti per prestazioni, anche in forma assicurativa, aventi per oggetto il rischio di non autosufficienza nel compimento degli atti della vita quotidiana, le cui caratteristiche sono definite dall'articolo 2, comma 2, lettera d), numeri 1) e 2), del decreto del Ministro del lavoro, della salute e delle politiche sociali 27 ottobre 2009, pubblicato nella Gazzetta Ufficiale n. 12 del 16 gennaio 2010, o aventi per oggetto il rischio di gravi patologie».

162. Le disposizioni di cui all'articolo 51, comma 2, lettera f), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, come da ultimo modificate dalla legge 28 dicembre 2015, n. 208, si interpretano nel senso che le stesse si applicano anche alle opere e servizi riconosciuti dal datore di lavoro, del settore privato o pubblico, in conformita' a disposizioni di contratto collettivo nazionale di lavoro, di accordo interconfederale o di contratto collettivo territoriale.

163. Per consentire il completamento delle procedure di cui all'articolo 1, comma 207, terzo periodo, della legge 27 dicembre 2013, n. 147, da concludere inderogabilmente entro il 31 dicembre 2017, e' autorizzata la spesa di 50 milioni di euro per l'anno 2017, a titolo di compartecipazione dello Stato. La regione Calabria dispone con propria legge regionale la copertura finanziaria a carico del bilancio della regione medesima degli ulteriori oneri necessari derivanti da quanto previsto dal primo periodo e assicura la compatibilita' dell'intervento con il raggiungimento dei propri obiettivi di finanza pubblica. (11)

164. All'articolo 2, comma 34, della legge 28 giugno 2012, n. 92, le parole: «Per il periodo 2013-2016» sono sostituite dalle seguenti: «A decorrere dal 1º gennaio 2013».

165. A decorrere dall'anno 2017, per i lavoratori autonomi, titolari di posizione fiscale ai fini dell'imposta sul valore aggiunto, iscritti alla Gestione separata di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, che non risultano iscritti ad altre gestioni di previdenza obbligatoria ne' pensionati, l'aliquota contributiva di cui all'articolo 1, comma 79, della legge 24 dicembre 2007, n. 247, e' stabilita in misura pari al 25 per cento.

166. A decorrere dal 1º maggio 2017, in via sperimentale fino al 31 dicembre 2019, e' istituito l'anticipo finanziario a garanzia pensionistica (APE). L'APE e' un prestito corrisposto a quote mensili per dodici mensilita' a un soggetto in possesso dei requisiti di cui al comma 167 del presente articolo fino alla maturazione del diritto alla pensione di vecchiaia di cui all'articolo 24, commi 6 e 7, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214. La restituzione del prestito avviene a partire dalla maturazione del diritto alla pensione di vecchiaia, con rate di ammortamento mensili per una durata di venti anni. Il prestito e' coperto da una polizza assicurativa obbligatoria per il rischio di premorienza.

167. L'APE puo' essere richiesto dagli iscritti all'assicurazione generale obbligatoria, alle forme sostitutive ed esclusive della medesima e alla Gestione separata di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, che, al momento della richiesta di APE, hanno un'eta' anagrafica minima di 63 anni e che maturano il diritto a una pensione di vecchiaia entro 3 anni e 7 mesi, purche' siano in possesso del requisito contributivo minimo di venti anni e la loro pensione, al netto della rata di ammortamento corrispondente all'APE richiesta, sia pari o superiore, al momento dell'accesso alla prestazione, a 1,4 volte il trattamento minimo previsto nell'assicurazione generale obbligatoria. Non possono ottenere l'APE coloro che sono gia' titolari di un trattamento pensionistico diretto.

168. Il soggetto richiedente, direttamente o tramite un intermediario autorizzato ai sensi della legge 30 marzo 2001, n. 152, presenta all'Istituto nazionale della previdenza sociale (INPS), tramite il suo portale, domanda di certificazione del diritto all'APE. L'INPS, verificato il possesso dei requisiti di cui al comma 167 del presente articolo, certifica il diritto e comunica al soggetto richiedente l'importo minimo e l'importo massimo dell'APE ottenibile.

169. Il soggetto in possesso della certificazione di cui al comma 168 del presente articolo, direttamente o tramite un intermediario autorizzato ai sensi della legge 30 marzo 2001, n. 152, presenta, attraverso l'uso dell'identita' digitale SPID di secondo livello, di cui al decreto del Presidente del Consiglio dei ministri 24 ottobre 2014, pubblicato nella Gazzetta Ufficiale n. 285 del 9 dicembre 2014, e con i modelli da approvare con il decreto del Presidente del Consiglio dei ministri di cui al comma 175 del presente articolo, domanda di APE e domanda di pensione di vecchiaia da liquidare al raggiungimento dei requisiti di legge. La domanda di APE e di pensione di cui al periodo precedente non sono revocabili, salvo in caso di esercizio del diritto di recesso di cui agli articoli 125-ter del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1º settembre 1993, n. 385, e 67-duodecies del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206. In deroga all'articolo 67-duodecies, comma 2, del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206, il termine per recedere dal contratto di assicurazione di cui ai commi da 166 a 186 del presente articolo e' di quattordici giorni. La facolta' di estinzione anticipata dell'APE e' regolata dal decreto del Presidente del Consiglio dei ministri di cui al comma 175 del presente articolo. Nella domanda il soggetto richiedente indica il finanziatore cui richiedere l'APE, nonche' l'impresa assicurativa alla quale richiedere la copertura del rischio di premorienza. Le informazioni precontrattuali e contrattuali previste ai sensi di legge sono fornite, in formato elettronico e su supporto durevole, al soggetto richiedente dall'INPS, per conto del finanziatore e dell'impresa assicurativa; il finanziatore e l'impresa assicurativa forniscono all'INPS, in tempo utile, la documentazione necessaria. I finanziatori e le imprese assicurative sono scelti tra quelli che aderiscono agli accordi-quadro da stipulare, a seguito dell'entrata in vigore del decreto del Presidente del Consiglio dei ministri di cui al comma 175 del presente articolo, tra il Ministro dell'economia e delle finanze e il Ministro del lavoro e delle politiche sociali e, rispettivamente, l'Associazione bancaria italiana e l'Associazione nazionale fra le imprese assicuratrici e altre imprese assicurative primarie. L'attivita' svolta dall'INPS ai sensi dei commi da 166 a 186 del presente articolo non costituisce esercizio di agenzia in attivita' finanziaria, ne' di mediazione creditizia, ne' di intermediazione assicurativa.

170. La durata minima dell'APE e' di sei mesi. L'entita' minima e l'entita' massima di APE richiedibile sono stabilite dal decreto del Presidente del Consiglio dei ministri di cui al comma 175 del presente articolo. Ai fini dell'applicazione delle disposizioni del titolo VI del testo unico di cui al decreto legislativo 1º settembre 1993, n. 385, il prestito costituisce credito ai consumatori. Per le finalita' di cui al decreto legislativo 21 novembre 2007, n. 231, l'operazione di finanziamento e' sottoposta a obblighi semplificati di adeguata verifica della clientela. Con decreto del Ministro dell'economia e delle finanze, sentito il Comitato di sicurezza finanziaria, sono definite le modalita' semplificate di adempimento dei predetti obblighi, tenuto conto della natura del prodotto e di ogni altra circostanza riferibile al profilo di rischio connesso all'operazione di finanziamento. Il decreto del Presidente del Consiglio dei ministri di cui al comma 175 del presente articolo disciplina le comunicazioni periodiche al soggetto finanziato e assicurato, anche in deroga a quanto previsto dalla legge.

171. L'istituto finanziatore trasmette all'INPS e al soggetto richiedente il contratto di prestito, ovvero l'eventuale comunicazione di reiezione dello stesso. L'identificazione del soggetto richiedente e' effettuata dall'INPS con il sistema SPID anche ai sensi dell'articolo 30, comma 8, del decreto legislativo 21 novembre 2007, n. 231, per il perfezionamento del contratto di finanziamento e della polizza assicurativa del rischio di premorienza. In caso di concessione del prestito, dalla data del perfezionamento decorre il termine di cui agli articoli 125-ter del testo unico di cui al decreto legislativo 1º settembre 1993, n. 385, e 67-duodecies del codice di cui al decreto legislativo 6 settembre 2005, n. 206, se il soggetto richiedente ha ricevuto dall'INPS tutte le informazioni precontrattuali e contrattuali previste ai sensi di legge. In caso di reiezione della richiesta, ovvero di recesso da parte del soggetto richiedente, la domanda di pensione e' priva di effetti. L'erogazione del prestito ha inizio entro trenta giorni lavorativi dalla data del predetto perfezionamento. L'INPS trattiene a partire dalla prima pensione mensile l'importo della rata per il rimborso del finanziamento e lo riversa al finanziatore tempestivamente e comunque non oltre centottanta giorni dalla data di scadenza della medesima rata.

172. I datori di lavoro del settore privato del richiedente, gli enti bilaterali o i fondi di solidarieta' di cui agli articoli 26 e 27 del decreto legislativo 14 settembre 2015, n. 148, possono, previo accordo individuale con il lavoratore, incrementare il montante contributivo individuale maturato da quest'ultimo, versando all'INPS in un'unica soluzione, alla scadenza prevista per il pagamento dei contributi del mese di erogazione della prima mensilita' dell'APE, un contributo non inferiore, per ciascun anno o frazione di anno di anticipo rispetto alla maturazione del diritto alla pensione di vecchiaia, all'importo determinato ai sensi dell'articolo 7 del decreto legislativo 30 aprile 1997, n. 184. Al contributo di cui al periodo precedente si applicano le disposizioni sanzionatorie e di riscossione previste dall'articolo 116, comma 8, lettera a), della legge 23 dicembre 2000, n. 388, nel caso di mancato o ritardato pagamento dei contributi previdenziali obbligatori.

173. E' istituito nello stato di previsione del Ministero dell'economia e delle finanze un Fondo di garanzia per l'accesso all'APE, con una dotazione iniziale pari a 70 milioni di euro per l'anno 2017. Le disponibilita' del Fondo di cui all'articolo 1, comma 32, della legge 23 dicembre 2014, n. 190, sono versate all'entrata del bilancio dello Stato per il corrispondente importo di 70 milioni di euro nell'anno 2017. Per le finalita' del presente comma e' autorizzata l'istituzione di un apposito conto corrente presso la tesoreria dello Stato. Il Fondo di garanzia per l'accesso all'APE e' ulteriormente alimentato con le commissioni di accesso al Fondo stesso, che a tal fine sono versate all'entrata del bilancio dello Stato per la successiva riassegnazione al Fondo. Tali somme sono versate sul conto corrente presso la tesoreria dello Stato istituito ai sensi del terzo periodo del presente comma. La garanzia del Fondo copre l'80 per cento del finanziamento di cui al comma 166 del presente articolo e dei relativi interessi. La garanzia del Fondo e' a prima richiesta, esplicita, incondizionata, irrevocabile e onerosa. Gli interventi del Fondo sono assistiti dalla garanzia dello Stato, avente le medesime caratteristiche di quella del Fondo, quale garanzia di ultima istanza. Il finanziamento e' altresi' assistito automaticamente dal privilegio di cui all'articolo 2751-bis, numero 1), del codice civile. La garanzia dello Stato e' elencata nell'allegato allo stato di previsione del Ministero dell'economia e delle finanze, di cui all'articolo 31 della legge 31 dicembre 2009, n. 196. Il Fondo e' surrogato di diritto alla banca, per l'importo pagato, nel privilegio di cui al citato articolo 2751-bis, numero 1), del codice civile. Tale finanziamento e le formalita' a esso connesse nell'intero svolgimento del rapporto sono esenti dall'imposta di registro, dall'imposta di bollo e da ogni altra imposta indiretta, nonche' da ogni altro tributo o diritto. I finanziamenti garantiti dal Fondo possono essere ceduti, in tutto o in parte, all'interno del gruppo del soggetto finanziatore o a istituzioni finanziarie nazionali, comunitarie e internazionali, anche ai sensi della legge 30 aprile 1999, n. 130, senza le formalita' e i consensi previsti dalla disciplina che regola la cessione del credito e conservano le medesime garanzie e le coperture assicurative che assistono il finanziamento.

174. All'APE si applica il tasso di interesse e la misura del premio assicurativo relativa all'assicurazione di copertura del rischio di premorienza indicati negli accordi-quadro di cui al comma 169.

175. Le modalita' di attuazione delle disposizioni di cui ai commi da 165 a 174 e gli ulteriori criteri, condizioni e adempimenti per l'accesso al finanziamento, nonche' i criteri, le condizioni e le modalita' di funzionamento del Fondo di garanzia di cui al comma 173 e della garanzia di ultima istanza dello Stato sono disciplinati con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'economia e delle finanze e con il Ministro del lavoro e delle politiche sociali, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge.

176. La gestione del Fondo di garanzia di cui al comma 173 e' affidata all'INPS sulla base di un'apposita convenzione da stipulare tra lo stesso Istituto e il Ministro dell'economia e delle finanze e il Ministro del lavoro e delle politiche sociali.

177. Le somme erogate in quote mensili di cui al comma 166 del presente articolo non concorrono a formare il reddito ai fini dell'imposta sul reddito delle persone fisiche. A fronte degli interessi sul finanziamento e dei premi assicurativi per la copertura del rischio di premorienza corrisposti al soggetto erogatore e' riconosciuto, alle condizioni di cui al presente comma, un credito d'imposta annuo nella misura massima del 50 per cento dell'importo pari a un ventesimo degli interessi e dei premi assicurativi complessivamente pattuiti nei relativi contratti. Tale credito d'imposta non concorre alla formazione del reddito ai fini delle imposte sui redditi ed e' riconosciuto dall'INPS per l'intero importo rapportato a mese a partire dal primo pagamento del trattamento di pensione. L'INPS recupera il credito rivalendosi sulle ritenute da versare mensilmente all'erario nella sua qualita' di sostituto d'imposta. All'APE si applicano gli articoli da 15 a 22 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601.

178. Gli effetti della trattenuta di cui al sesto periodo del comma 171 non rilevano ai fini del riconoscimento di prestazioni assistenziali e previdenziali sottoposte alla prova dei mezzi.

179. In via sperimentale, dal 1º maggio 2017 e fino al 31 dicembre 2023, agli iscritti all'assicurazione generale obbligatoria, alle forme sostitutive ed esclusive della medesima e alla Gestione separata di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, che si trovano in una delle condizioni di cui alle lettere da

- a) a d) del presente comma, al compimento del requisito anagrafico dei 63 anni, e' riconosciuta, alle condizioni di cui ai commi 185 e 186 del presente articolo, un'indennita' per una durata non superiore al periodo intercorrente tra la data di accesso al beneficio e il conseguimento dell'eta' anagrafica prevista per l'accesso al trattamento pensionistico di vecchiaia di cui all'articolo 24, comma 6, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214: a) si trovano in stato di disoccupazione a seguito di cessazione del rapporto di lavoro per licenziamento, anche collettivo, dimissioni per giusta causa o risoluzione consensuale nell'ambito della procedura di cui all'articolo 7 della legge 15 luglio 1966, n. 604, ovvero per scadenza del termine del rapporto di lavoro a tempo determinato a condizione che abbiano avuto, nei trentasei mesi precedenti la cessazione del rapporto, periodi di lavoro dipendente per almeno diciotto mesi hanno concluso integralmente la prestazione per la disoccupazione loro spettante e sono in possesso di un'anzianita' contributiva di almeno 30 anni;
- b) assistono, al momento della richiesta e da almeno sei mesi, il coniuge o un parente di primo grado convivente con handicap in situazione di gravita' ai sensi dell'articolo 3, comma 3, della legge 5 febbraio 1992, n. 104, ovvero un parente o un affine di secondo grado convivente qualora i genitori o il coniuge della persona con handicap in situazione di gravita' abbiano compiuto i settanta anni di eta' oppure siano anch'essi affetti da patologie invalidanti o siano deceduti o mancanti, e sono in possesso di un'anzianita' contributiva di almeno 30 anni;
- c) hanno una riduzione della capacita' lavorativa, accertata dalle competenti commissioni per il riconoscimento dell'invalidita' civile, superiore o uguale al 74 per cento e sono in possesso di un'anzianita' contributiva di almeno 30 anni;
- d) sono lavoratori dipendenti, al momento della decorrenza dell'indennita' di cui al comma 181, all'interno delle professioni indicate nell'allegato C annesso alla presente legge che svolgono da almeno sette anni negli ultimi dieci ovvero almeno sei anni negli ultimi sette attivita' lavorative per le quali e' richiesto un impegno tale da rendere particolarmente difficoltoso e rischioso il loro svolgimento in modo continuativo e sono in possesso di un'anzianita' contributiva di almeno 36 anni. (6) (50) (61) (67)

179-bis. Ai fini del riconoscimento dell'indennita' di cui al comma 179, i requisiti contributivi richiesti alle lettere da

- a) a d) del medesimo comma sono ridotti, per le donne, di dodici mesi per ogni figlio, nel limite massimo di due anni.(61) (67)

180. La concessione dell'indennita' di cui al comma 179 e' subordinata alla cessazione dell'attivita' lavorativa e non spetta a coloro che sono gia' titolari di un trattamento pensionistico diretto.(61) (67)

181. L'indennita' di cui al comma 179 e' erogata mensilmente su dodici mensilita' nell'anno ed e' pari all'importo della rata mensile della pensione calcolata al momento dell'accesso alla prestazione. L'importo dell'indennita' non puo' in ogni caso superare l'importo massimo mensile di 1.500 euro e non e' soggetto a rivalutazione.(61) (67)

182. L'indennita' di cui al comma 179 del presente articolo non e' compatibile con i trattamenti di sostegno al reddito connessi allo stato di disoccupazione involontaria, con il trattamento di cui all'articolo 16 del decreto legislativo 4 marzo 2015, n. 22, nonche' con l'indennizzo previsto dall'articolo 1 del decreto legislativo 28 marzo 1996, n. 207.(61) (67)

183. Il beneficiario decade dal diritto all'indennita' nel caso di raggiungimento dei requisiti per il pensionamento anticipato. L'indennita' e' compatibile con la percezione dei redditi da lavoro dipendente o parasubordinato nel limite di 8.000 euro annui e dei redditi derivanti da attivita' di lavoro autonomo nel limite di 4.800 euro annui.(61) (67)

184. Per i lavoratori di cui agli articoli 1, comma 2, e 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, nonche' per il personale degli enti pubblici di ricerca, che cessano l'attivita' lavorativa e richiedono l'indennita' di cui al comma 179 del presente articolo i termini di pagamento delle indennita' di fine servizio comunque denominate di cui all'articolo 3 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, iniziano a decorrere al compimento dell'eta' di cui all'articolo 24, comma 6, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e sulla base della disciplina vigente in materia di corresponsione del trattamento di fine servizio comunque denominato.(61) (67)

185. Le modalita' di attuazione delle disposizioni di cui ai commi da 179 a 184, nel rispetto dei limiti di spesa annuali di cui al comma 186, sono disciplinate con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, avuto particolare riguardo a:

- a) la determinazione delle caratteristiche specifiche delle attivita' lavorative di cui al comma 179, lettera d);
- b) le procedure per l'accertamento delle condizioni per l'accesso al beneficio di cui ai commi da 179 a 186 e la relativa documentazione da presentare a tali fini;
- c) le disposizioni attuative di quanto previsto dai commi da 179 a 186, con particolare riferimento: 1) all'attivita' di monitoraggio e alla procedura di cui al comma 186 del presente articolo, da effettuare con il procedimento di cui all'articolo 14 della legge 7 agosto 1990, n. 241; 2) alla disciplina del procedimento di accertamento anche in relazione alla documentazione da presentare per accedere al beneficio; 3) alle comunicazioni che l'ente previdenziale erogatore dell'indennita' di cui al comma 179 fornisce all'interessato in esito alla presentazione della domanda di accesso al beneficio; 4) alla predisposizione dei criteri da seguire nell'espletamento dell'attivita' di verifica ispettiva da parte del personale ispettivo del Ministero del lavoro e delle politiche sociali nonche' degli enti che gestiscono forme di assicurazione obbligatoria; 5) alle modalita' di utilizzo da parte dell'ente previdenziale delle informazioni relative alla dimensione, all'assetto organizzativo dell'azienda e alle tipologie di lavorazioni aziendali, anche come risultanti dall'analisi dei dati amministrativi in possesso degli enti previdenziali, ivi compresi quelli assicuratori nei confronti degli infortuni sul lavoro; 6) all'individuazione dei criteri di priorita' di cui al comma 186; 7) alle forme e modalita' di collaborazione tra enti che gestiscono forme di assicurazione obbligatoria, con particolare riferimento allo scambio di dati ed elementi conoscitivi in ordine alle tipologie di lavoratori interessati.(61) (67)

186. Il beneficio dell'indennita' disciplinata ai sensi dei commi da 179 a 185 e' riconosciuto a domanda nel limite di 300 milioni di euro per l'anno 2017, di 630 milioni di euro per l'anno 2018, di 666,5 milioni di euro per l'anno 2019, di 530,7 milioni di euro per l'anno 2020, di 411,1 milioni di euro per l'anno 2021, di 285,1 milioni di euro per l'anno 2022, di 169,3 milioni di euro per l'anno 2023, di 119,9 milioni di euro per l'anno 2024, di 71,5 milioni di euro per l'anno 2025 e di 8,9 milioni di euro per l'anno 2026. Qualora dal monitoraggio delle domande presentate e accolte emerga il verificarsi di scostamenti, anche in via prospettica, del numero di domande rispetto alle risorse finanziarie di cui al primo periodo del presente comma, la decorrenza dell'indennita' e' differita, con criteri di priorita' in ragione della maturazione dei requisiti di cui al comma 180, individuati con il decreto del Presidente del Consiglio dei ministri di cui al comma 185, e, a parita' degli stessi, in ragione della data di presentazione della domanda, al fine di garantire un numero di accessi all'indennita' non superiore al numero programmato in relazione alle predette risorse finanziarie. (25) (32) (50) (58) (61) (64) (67) ((70))

187. Al decreto-legge 2 luglio 2007, n. 81, convertito, con modificazioni, dalla legge 3 agosto 2007, n. 127, sono apportate le seguenti modificazioni:

- a) la tabella A e' sostituita dalla tabella A di cui all'allegato D annesso alla presente legge;
- b) all'articolo 5, comma 1, quarto periodo, le parole: «e spetta a condizione che il soggetto non possieda un reddito complessivo individuale relativo all'anno stesso superiore a una volta e mezza il trattamento minimo annuo del Fondo pensioni lavoratori dipendenti» sono sostituite dalle seguenti: «e spetta: nella misura prevista al punto 1) della predetta tabella A a condizione che il soggetto possieda un reddito complessivo individuale relativo all'anno stesso non superiore a una volta e mezza il trattamento minimo annuo del Fondo pensioni lavoratori dipendenti; fermo restando quanto stabilito dal comma 2, nella misura prevista al punto 2) della predetta tabella A a condizione che il soggetto possieda un reddito complessivo individuale relativo all'anno stesso compreso tra una volta e mezza e due volte il trattamento minimo annuo del Fondo pensioni lavoratori dipendenti»;
- c) il comma 2 dell'articolo 5 e' sostituito dal seguente: «2. Nei confronti dei soggetti che soddisfano le condizioni di cui al comma 1 e per i quali l'importo complessivo del reddito individuale annuo, al netto dei trattamenti di famiglia, risulti superiore a una volta e mezza il trattamento minimo e inferiore a tale limite incrementato dell'importo della somma aggiuntiva spettante, l'importo e' comunque attribuito fino a concorrenza del predetto limite maggiorato. Nei confronti dei soggetti che soddisfano le condizioni di cui al comma 1 e per i quali l'importo complessivo del reddito individuale annuo, al netto dei trattamenti di famiglia, risulti superiore a due volte il trattamento minimo e inferiore a tale limite incrementato dell'importo della somma aggiuntiva spettante, l'importo e' attribuito fino a concorrenza del predetto limite maggiorato».

188. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

189. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

190. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

191. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

192. Per i lavoratori di cui agli articoli 1, comma 2, e 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, nonche' per il personale degli enti pubblici di ricerca, che accedono a RITA di cui all'articolo 11, comma 4, del decreto legislativo 5 dicembre 2005, n. 252 e cessano dal rapporto di lavoro, il trattamento di fine rapporto e di fine servizio sono corrisposti al momento in cui il soggetto avrebbe maturato il diritto alla corresponsione degli stessi secondo le disposizioni dell'articolo 24, comma 6, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e la disciplina vigente in materia di corresponsione del trattamento di fine servizio comunque denominato.

193. Il Governo trasmette alle Camere entro il 10 settembre 2018 una relazione nella quale da' conto dei risultati delle sperimentazioni relative alle misure di cui ai commi da 166 a 186 e da 188 a 192 e formula proposte in ordine alla loro eventuale prosecuzione.

194. Con effetto sui trattamenti pensionistici decorrenti dal 1º gennaio 2018, le disposizioni di cui all'articolo 24, comma 10, terzo e quarto periodo, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, in materia di riduzione percentuale dei trattamenti pensionistici, non trovano applicazione.

195. All'articolo 1, comma 239, della legge 24 dicembre 2012, n. 228, sono apportate le seguenti modificazioni:

- a) al primo periodo, dopo le parole: «e alle forme sostitutive ed esclusive della medesima,» sono inserite le seguenti: «nonche' agli enti di previdenza di cui al decreto legislativo 30 giugno 1994, n. 509, e al decreto legislativo 10 febbraio 1996, n. 103,» e le parole: «, qualora non siano in possesso dei requisiti per il diritto al trattamento pensionistico» sono soppresse;
- b) il secondo periodo e' sostituito dal seguente: «La predetta facolta' puo' essere esercitata per la liquidazione del trattamento pensionistico a condizione che il soggetto interessato abbia i requisiti anagrafici previsti dal comma 6 dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e il requisito contributivo di cui al comma 7 del medesimo articolo 24, ovvero, indipendentemente dal possesso dei requisiti anagrafici, abbia maturato l'anzianita' contributiva prevista dal comma 10 del medesimo articolo 24, adeguata agli incrementi della speranza di vita ai sensi dell'articolo 12 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, nonche' per la liquidazione dei trattamenti per inabilita' e ai superstiti di assicurato deceduto».

196. Per i lavoratori di cui agli articoli 1, comma 2, e 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, nonche' per il personale degli enti pubblici di ricerca, che si avvalgono della facolta' di cui all'articolo 1, comma 239, della legge 24 dicembre 2012, n. 228, come modificato dal comma 195 del presente articolo, i termini di pagamento delle indennita' di fine servizio comunque denominate di cui all'articolo 3 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, iniziano a decorrere al compimento dell'eta' di cui all'articolo 24, comma 6, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214.

197. Per i casi di esercizio della facolta' di ricongiunzione di cui agli articoli 1 e 2 della legge 7 febbraio 1979, n. 29, da parte dei soggetti, titolari di piu' periodi assicurativi che consentono l'accesso al trattamento pensionistico a seguito di quanto previsto all'articolo 1, comma 239, della legge 24 dicembre 2012, n. 228, per effetto delle modifiche introdotte dal comma 195 del presente articolo, sono consentiti, su richiesta degli interessati, il recesso e la restituzione di quanto gia' versato, solo nei casi in cui non si sia perfezionato il pagamento integrale dell'importo dovuto. La restituzione di quanto versato e' effettuata a decorrere dal dodicesimo mese dalla data della richiesta di rimborso in quattro rate annuali, non maggiorate di interessi. Il recesso di cui al presente comma non puo', comunque, essere esercitato oltre il termine di un anno dalla data di entrata in vigore della presente legge e nei casi in cui abbia gia' dato titolo alla liquidazione del trattamento pensionistico.

198. I soggetti, titolari di piu' periodi assicurativi che consentono l'accesso al trattamento pensionistico previsto all'articolo 1, comma 239, della legge 24 dicembre 2012, n. 228, a seguito delle modifiche introdotte dal comma 195 del presente articolo, che hanno presentato domanda di pensione in totalizzazione ai sensi del decreto legislativo 2 febbraio 2006, n. 42, anteriormente alla data di entrata in vigore della presente legge e per i quali il relativo procedimento amministrativo non sia ancora concluso, possono, previa rinuncia alla domanda di pensione in totalizzazione, accedere al trattamento pensionistico previsto al medesimo articolo 1, comma 239, come modificato dal comma 195 del presente articolo.

199. A decorrere dal 1º maggio 2017, il requisito contributivo di cui all'articolo 24, comma 10, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, come rideterminato ai sensi del comma 12 del medesimo articolo 24 per effetto degli adeguamenti applicati con decorrenza 2013 e 2016, e' ridotto a 41 anni per i lavoratori di cui all'articolo 1, commi 12 e 13, della legge 8 agosto 1995, n. 335, che hanno almeno 12 mesi di contribuzione per periodi di lavoro effettivo precedenti il raggiungimento del diciannovesimo anno di eta' e che si trovano in una delle seguenti condizioni di cui alle lettere da

- a) a d) del presente comma, come ulteriormente specificate ai sensi del comma 202 del presente articolo: a) sono in stato di disoccupazione a seguito di cessazione del rapporto di lavoro per licenziamento, anche collettivo, dimissioni per giusta causa o risoluzione consensuale nell'ambito della procedura di cui all'articolo 7 della legge 15 luglio 1966, n. 604, e hanno concluso integralmente la prestazione per la disoccupazione loro spettante da almeno tre mesi;
- b) assistono, al momento della richiesta e da almeno sei mesi, il coniuge o un parente di primo grado convivente con handicap in situazione di gravita' ai sensi dell'articolo 3, comma 3, della legge 5 febbraio 1992, n. 104, ovvero un parente o un affine di secondo grado convivente qualora i genitori o il coniuge della persona con handicap in situazione di gravita' abbiano compiuto i settanta anni di eta' oppure siano anch'essi affetti da patologie invalidanti o siano deceduti o mancanti;
- c) hanno una riduzione della capacita' lavorativa, accertata dalle competenti commissioni per il riconoscimento dell'invalidita' civile, superiore o uguale al 74 per cento;
- d) sono lavoratori dipendenti di cui alle professioni indicate all'allegato E annesso alla presente legge che svolgono, al momento del pensionamento, da almeno sette anni negli ultimi dieci ovvero almeno sei anni negli ultimi sette attivita' lavorative per le quali e' richiesto un impegno tale da rendere particolarmente difficoltoso e rischioso il loro svolgimento in modo continuativo ovvero sono lavoratori che soddisfano le condizioni di cui all'articolo 1, commi 1, 2 e 3, del decreto legislativo 21 aprile 2011, n. 67. (6)

200. Al requisito contributivo ridotto di cui al comma 199 del presente articolo continuano ad applicarsi gli adeguamenti alla speranza di vita di cui all'articolo 12 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122. (25)

201. Per i lavoratori di cui agli articoli 1, comma 2, e 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, nonche' per il personale degli enti pubblici di ricerca, che soddisfano i requisiti di cui al comma 199 del presente articolo, le indennita' di fine servizio comunque denominate di cui all'articolo 3 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, sono corrisposte al momento in cui il soggetto avrebbe maturato il diritto alla corresponsione delle stesse secondo le disposizioni dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e sulla base della disciplina vigente in materia di corresponsione del trattamento di fine servizio comunque denominato.

202. Le modalita' di attuazione delle disposizioni dei commi da 199 a 205 del presente articolo, nel rispetto dei limiti di spesa annuali di cui al comma 203, sono disciplinate con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, avuto particolare riguardo:

- a) alla determinazione delle caratteristiche specifiche delle attivita' lavorative di cui al comma 199, lettera d);
- b) alle procedure per l'accertamento delle condizioni per l'accesso al beneficio di cui ai commi da 199 a 205 e alla relativa documentazione da presentare a tali fini;
- c) all'attivita' di monitoraggio e alla procedura di cui al comma 203 del presente articolo, da effettuare con il procedimento di cui all'articolo 14 della legge 7 agosto 1990, n. 241;
- d) alle comunicazioni che l'ente previdenziale erogatore del trattamento pensionistico fornisce all'interessato in esito alla presentazione della domanda di accesso al beneficio;
- e) alla predisposizione dei criteri da seguire nello svolgimento dell'attivita' di verifica ispettiva da parte del personale ispettivo del Ministero del lavoro e delle politiche sociali nonche' degli enti che gestiscono forme di assicurazione obbligatoria;
- f) alle modalita' di utilizzo da parte dell'ente previdenziale delle informazioni relative alla dimensione, all'assetto organizzativo dell'azienda e alle tipologie di lavorazioni aziendali, anche come risultanti dall'analisi dei dati amministrativi in possesso degli enti previdenziali, ivi compresi quelli assicuratori nei confronti degli infortuni sul lavoro;
- g) all'individuazione dei criteri di priorita' di cui al comma 203;
- h) alle forme e modalita' di collaborazione tra enti che gestiscono forme di assicurazione obbligatoria, con particolare riferimento allo scambio di dati ed elementi conoscitivi in ordine alle tipologie di lavoratori interessati.

203. Il beneficio dell'anticipo del pensionamento ai sensi dei commi da 199 a 202 e' riconosciuto a domanda nel limite di 360 milioni di euro per l'anno 2017, di 564,4 milioni di euro per l'anno 2018, di 631,7 milioni di euro per l'anno 2019, di 594,3 milioni di euro per l'anno 2020, di 592,7 milioni di euro per l'anno 2021, di 589,1 milioni di euro per l'anno 2022 e di 587,6 milioni di euro annui a decorrere dall'anno 2023. Qualora dal monitoraggio delle domande presentate ed accolte emerga il verificarsi di scostamenti, anche in via prospettica, del numero di domande rispetto alle risorse finanziarie di cui al primo periodo del presente comma, la decorrenza dei trattamenti e' differita, con criteri di priorita' in ragione della maturazione dei requisiti agevolati di cui al comma 199, individuati con il decreto del Presidente del Consiglio dei ministri di cui al comma 202, e, a parita' degli stessi, in ragione della data di presentazione della domanda, al fine di garantire un numero di accessi al pensionamento, sulla base dei predetti requisiti agevolati, non superiore al numero di pensionamenti programmato in relazione alle predette risorse finanziarie. (25) (58) (61) (67)

204. A far data dalla sua decorrenza il trattamento pensionistico di cui al comma 199 del presente articolo non e' cumulabile con redditi da lavoro, subordinato o autonomo, per un periodo di tempo corrispondente alla differenza tra l'anzianita' contributiva di cui all'articolo 24, commi 10 e 12, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e l'anzianita' contributiva al momento del pensionamento.

205. Il beneficio di cui ai commi da 199 a 204 non e' cumulabile con altre maggiorazioni previste per le attivita' di lavoro di cui al comma 199 del presente articolo, fermo restando quanto previsto all'articolo 80, comma 3, della legge 23 dicembre 2000, n. 388.

206. Con effetto dalla data di entrata in vigore della presente legge:

- a) l'articolo 24, comma 17-bis, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e' abrogato;
- b) all'articolo 1, comma 2, del decreto legislativo 21 aprile 2011, n. 67, sono apportate le seguenti modificazioni: 1) alla lettera a), le parole: «, compreso l'anno di maturazione dei requisiti,» sono soppresse e le parole: «per le pensioni aventi decorrenza entro il 31 dicembre 2017;» sono sostituite dalla seguente: «ovvero»; 2) alla lettera b), le parole: «, per le pensioni aventi decorrenza dal 1º gennaio 2018» sono soppresse;
- c) all'articolo 1, comma 4, del decreto legislativo 21 aprile 2011, n. 67, e' aggiunto, in fine, il seguente periodo: «In via transitoria, con riferimento ai requisiti di cui al presente comma non trovano applicazione gli adeguamenti alla speranza di vita di cui al citato articolo 12 del decreto-legge n. 78 del 2010, convertito, con modificazioni, dalla legge n. 122 del 2010, previsti per gli anni 2019, 2021, 2023 e 2025 ai sensi dell'articolo 24, comma 13, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214»;
- d) all'articolo 2, comma 1, del decreto legislativo 21 aprile 2011, n. 67, sono apportate le seguenti modificazioni: 1) alla lettera b), le parole: «a decorrere dal 1º gennaio 2012» sono sostituite dalle seguenti: «entro il 31 dicembre 2016»; 2) dopo la lettera b) sono aggiunte le seguenti: «b-bis) entro il 1º marzo dell'anno di maturazione dei requisiti agevolati qualora tali requisiti siano maturati nel corso dell'anno 2017; b-ter) entro il 1º maggio dell'anno precedente a quello di maturazione dei requisiti agevolati qualora tali requisiti siano maturati a decorrere dal 1º gennaio 2018».

207. Per effetto di quanto stabilito dal comma 206 del presente articolo il Fondo di cui all'articolo 1, comma 3, lettera f), della legge 24 dicembre 2007, n. 247, e' incrementato di 84,5 milioni di euro per l'anno 2017, di 86,3 milioni di euro per l'anno 2018, di 124,5 milioni di euro per l'anno 2019, di 126,6 milioni di euro per l'anno 2020, di 123,8 milioni di euro per l'anno 2021, di 144,4 milioni di euro per l'anno 2022, di 145,2 milioni di euro per l'anno 2023, di 151,8 milioni di euro per l'anno 2024, di 155,4 milioni di euro per l'anno 2025 e di 170,5 milioni di euro annui a decorrere dall'anno 2026, con conseguente corrispondente incremento degli importi di cui all'articolo 7, comma 1, del decreto legislativo 21 aprile 2011, n. 67.

208. Ai fini della corretta attuazione dei commi 206 e 207, entro sessanta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono apportate le necessarie modificazioni al decreto del Ministro del lavoro e delle politiche sociali 20 settembre 2011, pubblicato nella Gazzetta Ufficiale n. 276 del 26 novembre 2011, anche introducendo eventuali semplificazioni nella documentazione necessaria per la richiesta di accesso al beneficio, fermi restando i contenuti informativi previsti per la certificazione del beneficio medesimo ai sensi del decreto legislativo 21 aprile 2011, n. 67.

209. Con effetto dalla data di entrata in vigore della presente legge, all'articolo 9, comma 2, della legge 29 marzo 1985, n. 113, le parole: «In attesa della legge di riforma generale del sistema pensionistico,» sono soppresse e sono aggiunte, in fine, le seguenti parole: «nonche' all'incremento dell'eta' anagrafica a cui applicare il coefficiente di trasformazione per il calcolo della quota di pensione nel sistema contributivo come previsto dall'articolo 1, comma 6, della legge 8 agosto 1995, n. 335».

210. I commi 3 e 4 dell'articolo 13 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 29 dicembre 1986, n. 917, sono sostituiti dal seguente: «3. Se alla formazione del reddito complessivo concorrono uno o piu' redditi di pensione di cui all'articolo 49, comma 2, lettera a), spetta una detrazione dall'imposta lorda, non cumulabile con quella prevista al comma 1 del presente articolo, rapportata al periodo di pensione nell'anno, pari a: a) 1.880 euro, se il reddito complessivo non supera 8.000 euro. L'ammontare della detrazione effettivamente spettante non puo' essere inferiore a 713 euro; b) 1.297 euro, aumentata del prodotto fra 583 euro e l'importo corrispondente al rapporto fra 15.000 euro, diminuito del reddito complessivo, e 7.000 euro, se l'ammontare del reddito complessivo e' superiore a 8.000 euro ma non a 15.000 euro; c) 1.297 euro, se il reddito complessivo e' superiore a 15.000 euro ma non a 55.000 euro. La detrazione spetta per la parte corrispondente al rapporto tra l'importo di 55.000 euro, diminuito del reddito complessivo, e l'importo di 40.000 euro».

211. A decorrere dalla data di entrata in vigore della presente legge, ai trattamenti pensionistici spettanti alle vittime del dovere e ai loro familiari superstiti, di cui alla legge 13 agosto 1980, n. 466, alla legge 20 ottobre 1990, n. 302, e all'articolo 1, commi 563 e 564, della legge 23 dicembre 2005, n. 266, si applicano i benefici fiscali di cui all'articolo 2, commi 5 e 6, della legge 23 novembre 1998, n. 407, e dell'articolo 3, comma 2, della legge 3 agosto 2004, n. 206, in materia di esenzione dall'imposta sui redditi.

212. A seguito dell'attivita' di monitoraggio e verifica relativa alle misure di salvaguardia previste dall'articolo 24, comma 14, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, dall'articolo 22 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dall'articolo 1, commi da 231 a 234, della legge 24 dicembre 2012, n. 228, dagli articoli 11 e 11-bis del decreto-legge 31 agosto 2013, n. 102, convertito, con modificazioni, dalla legge 28 ottobre 2013, n. 124, dall'articolo 1, commi da 194 a 198, della legge 27 dicembre 2013, n. 147, dall'articolo 2 della legge 10 ottobre 2014, n. 147, e dai relativi decreti attuativi del Ministro del lavoro e delle politiche sociali 1º giugno 2012, 8 ottobre 2012, 22 aprile 2013 e 14 febbraio 2014, pubblicati, rispettivamente, nella Gazzetta Ufficiale n. 171 del 24 luglio 2012, n. 17 del 21 gennaio 2013, n. 123 del 28 maggio 2013 e n. 89 del 16 aprile 2014, nonche' dall'articolo 1, commi da 265 a 276, della legge 28 dicembre 2015, n. 208, resa possibile in relazione alle misure per le quali la certificazione del diritto al beneficio e' da ritenere conclusa nonche' a quanto stabilito dal comma 213 del presente articolo, i complessivi importi indicati al quarto periodo del comma 235 dell'articolo 1 della legge n. 228 del 2012 sono rideterminati in 243,4 milioni di euro per l'anno 2013, 908,9 milioni di euro per l'anno 2014, 1.618,5 milioni di euro per l'anno 2015, 2.000,4 milioni di euro per l'anno 2016, 1.796,2 milioni di euro per l'anno 2017, 1.270,6 milioni di euro per l'anno 2018, 734,8 milioni di euro per l'anno 2019, 388,1 milioni di euro per l'anno 2020, 194,8 milioni di euro per l'anno 2021, 103,5 milioni di euro per l'anno 2022 e 9,9 milioni di euro per l'anno 2023, cui corrisponde la rideterminazione del limite numerico massimo in 137.095 soggetti. La ripartizione dei complessivi limiti di spesa e numerici di cui al primo periodo del presente comma e' effettuata ai sensi dell'articolo 1, comma 193, della legge n. 147 del 2013. Ai sensi di quanto stabilito dall'articolo 1, comma 235, della legge n. 228 del 2012, l'autorizzazione di spesa di cui al primo periodo del predetto comma 235 e' incrementata di 641,85 milioni di euro per l'anno 2017, di 405,7 milioni di euro per l'anno 2018, di 106,54 milioni di euro per l'anno 2019, di 76,97 milioni di euro per l'anno 2020, di 50,22 milioni di euro per l'anno 2021, di 10,48 milioni di euro per l'anno 2022 e di 2 milioni di euro per l'anno 2023.

213. In considerazione del limitato utilizzo, come anche accertato ai sensi dell'articolo 1, comma 263, della legge 28 dicembre 2015, n. 208, ai fini dell'accesso al pensionamento secondo i requisiti e le decorrenze vigenti prima della data di entrata in vigore dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, della salvaguardia di cui all'articolo 22, comma 1, lettera a), del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, nonche' della circostanza che risultano trascorsi i termini decadenziali di comunicazione degli elenchi nominativi di cui all'articolo 3 del decreto del Ministro del lavoro e delle politiche sociali 8 ottobre 2012, pubblicato nella Gazzetta Ufficiale n. 17 del 21 gennaio 2013, all'articolo 22, comma 1, alinea, del citato decreto-legge n. 95 del 2012, convertito, con modificazioni, dalla legge n. 135 del 2012, le parole: «ulteriori 35.000 soggetti» sono sostituite dalle seguenti: «ulteriori 19.741 soggetti».

214. Le disposizioni in materia di requisiti di accesso e di regime delle decorrenze vigenti prima della data di entrata in vigore dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, ferme restando, nei limiti definiti ai sensi del comma 212 del presente articolo, le salvaguardie ivi indicate, continuano ad applicarsi ai seguenti soggetti che maturano i requisiti per il pensionamento successivamente al 31 dicembre 2011:

- a) nel limite di 11.000 soggetti, ai lavoratori collocati in mobilita' o in trattamento speciale edile ai sensi degli articoli 4, 11 e 24 della legge 23 luglio 1991, n. 223, o ai sensi dell'articolo 3 del decreto-legge 16 maggio 1994, n. 299, convertito, con modificazioni, dalla legge 19 luglio 1994, n. 451, a seguito di accordi governativi o non governativi, stipulati entro il 31 dicembre 2011, ovvero da aziende cessate o interessate dall'attivazione, precedente alla data di licenziamento, delle vigenti procedure concorsuali quali il fallimento, il concordato preventivo, la liquidazione coatta amministrativa, l'amministrazione straordinaria o l'amministrazione straordinaria speciale, previa esibizione della documentazione attestante la data di avvio della procedura concorsuale, anche in mancanza dei predetti accordi, cessati dall'attivita' lavorativa entro il 31 dicembre 2014 e che perfezionano, anche mediante il versamento di contributi volontari, entro trentasei mesi dalla fine del periodo di fruizione dell'indennita' di mobilita' o del trattamento speciale edile, i requisiti vigenti prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214. Il versamento volontario di cui alla presente lettera, anche in deroga alle disposizioni dell'articolo 6, comma 1, del decreto legislativo 30 aprile 1997, n. 184, puo' riguardare anche periodi eccedenti i sei mesi precedenti la domanda di autorizzazione stessa e puo' comunque essere effettuato solo con riferimento ai trentasei mesi successivi al termine di fruizione dell'indennita' di mobilita' o del trattamento speciale edile indicato dalla presente lettera. Eventuali periodi di sospensione dell'indennita' di mobilita', ai sensi dell'articolo 8, commi 6 e 7, della legge n. 223 del 1991 e dell'articolo 3 del decreto-legge n. 299 del 1994, convertito, con modificazioni, dalla legge n. 451 del 1994, intervenuti entro la data di entrata in vigore della presente legge per svolgere attivita' di lavoro subordinato, a tempo parziale, a tempo determinato, ovvero di lavoro parasubordinato mantenendo l'iscrizione nella lista, si considerano rilevanti ai fini del prolungamento del periodo di fruizione dell'indennita' stessa e non comportano l'esclusione dall'accesso alle salvaguardie di cui al presente comma;
- b) nel limite di 9.200 soggetti, ai lavoratori di cui all'articolo 1, comma 194, lettera a), della legge 27 dicembre 2013, n. 147, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, entro l'ottantaquattresimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- c) nel limite di 1.200 soggetti, ai lavoratori di cui all'articolo 1, comma 194, lettera f), della legge 27 dicembre 2013, n. 147, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, entro il settantaduesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- d) nel limite di 7.800 soggetti, ai lavoratori di cui all'articolo 1, comma 194, lettere b), c) e d), della legge 27 dicembre 2013, n. 147, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, entro l'ottantaquattresimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- e) nel limite di 700 soggetti, ai lavoratori di cui all'articolo 24, comma 14, lettera e-ter), del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, limitatamente ai lavoratori in congedo per assistere figli con disabilita' grave ai sensi dell'articolo 42, comma 5, del testo unico delle disposizioni legislative in materia di tutela e sostegno della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del decreto-legge n. 201 del 2011, entro l'ottantaquattresimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- f) nel limite di 800 soggetti, con esclusione del settore agricolo e dei lavoratori con qualifica di stagionali, ai lavoratori con contratto di lavoro a tempo determinato e ai lavoratori in somministrazione con contratto a tempo determinato, cessati dal lavoro tra il 1º gennaio 2007 e il 31 dicembre 2011, non rioccupati a tempo indeterminato, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, entro il settantaduesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011.

215. Per i lavoratori di cui al comma 214, lettera a), che siano gia' stati autorizzati ai versamenti volontari in data antecedente a quella di entrata in vigore della presente legge e per i quali siano decorsi i termini di pagamento, sono riaperti a domanda i termini dei versamenti relativi ai trentasei mesi successivi alla fine del periodo di fruizione dell'indennita' di mobilita' o del trattamento speciale edile come specificato nel medesimo comma 214.

216. Ai fini della presentazione delle istanze da parte dei lavoratori, da effettuare entro il termine di decadenza di sessanta giorni dalla data di entrata in vigore della presente legge, si applicano per ciascuna categoria di lavoratori salvaguardati le specifiche procedure previste nei precedenti provvedimenti in materia di salvaguardia dei requisiti di accesso e di regime delle decorrenze vigenti prima della data di entrata in vigore dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, da ultimo stabilite con decreto del Ministro del lavoro e delle politiche sociali 14 febbraio 2014, pubblicato nella Gazzetta Ufficiale n. 89 del 16 aprile 2014. L'INPS provvede al monitoraggio delle domande di pensionamento inoltrate dai lavoratori di cui al comma 214 del presente articolo che intendono avvalersi dei requisiti di accesso e del regime delle decorrenze vigenti prima della data di entrata in vigore del medesimo decreto-legge n. 201 del 2011, convertito, con modificazioni, dalla legge n. 214 del 2011, sulla base della data di cessazione del rapporto di lavoro, e provvede a pubblicare nel proprio sito internet, in forma aggregata al fine di rispettare le vigenti disposizioni in materia di tutela dei dati personali, i dati raccolti a seguito dell'attivita' di monitoraggio, avendo cura di evidenziare le domande accolte, quelle respinte e le relative motivazioni. Qualora dal monitoraggio risulti il raggiungimento del limite numerico delle domande di pensione e dei limiti di spesa, anche in via prospettica, determinati ai sensi dei commi 214 e 218, primo periodo, del presente articolo, l'INPS non prende in esame ulteriori domande di pensionamento finalizzate ad usufruire dei benefici previsti dai commi da 214 a 218 del presente articolo.

217. I dati rilevati nell'ambito del monitoraggio svolto dall'INPS ai sensi del comma 216 del presente articolo sono utilizzati ai fini della predisposizione della relazione di cui all'articolo 2, comma 5, della legge 10 ottobre 2014, n. 147.

218. I benefici di cui al comma 214 sono riconosciuti nel limite di 30.700 soggetti e nel limite massimo di 137 milioni di euro per l'anno 2017, di 305 milioni di euro per l'anno 2018, di 368 milioni di euro per l'anno 2019, di 333 milioni di euro per l'anno 2020, di 261 milioni di euro per l'anno 2021, di 171 milioni di euro per l'anno 2022, di 72 milioni di euro per l'anno 2023, di 21 milioni di euro per l'anno 2024, di 9 milioni di euro per l'anno 2025 e di 3 milioni di euro per l'anno 2026. Conseguentemente, all'articolo 1, comma 235, della legge 24 dicembre 2012, n. 228, gli importi indicati al quarto periodo, come modificati ai sensi del comma 212 del presente articolo, sono corrispondentemente incrementati degli importi di cui al precedente periodo, per una rideterminazione pari a 243,4 milioni di euro per l'anno 2013, 908,9 milioni di euro per l'anno 2014, 1.618,5 milioni di euro per l'anno 2015, 2.000,4 milioni di euro per l'anno 2016, 1.933,2 milioni di euro per l'anno 2017, 1.575,6 milioni di euro per l'anno 2018, 1.102,8 milioni di euro per l'anno 2019, 721,1 milioni di euro per l'anno 2020, 455,8 milioni di euro per l'anno 2021, 274,5 milioni di euro per l'anno 2022, 81,9 milioni di euro per l'anno 2023, 21 milioni di euro per l'anno 2024, 9 milioni di euro per l'anno 2025 e 3 milioni di euro per l'anno 2026, cui corrisponde la rideterminazione del limite numerico massimo in 167.795 soggetti. (9)

219. Al fine del concorso alla copertura degli oneri derivanti dai commi da 214 a 218 del presente articolo, l'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, come rifinanziata anche ai sensi del comma 212 del presente articolo, e' ridotta di 134 milioni di euro per l'anno 2017, di 295 milioni di euro per l'anno 2018, di 106,54 milioni di euro per l'anno 2019, di 76,97 milioni di euro per l'anno 2020, di 50,22 milioni di euro per l'anno 2021, di 57,10 milioni di euro per l'anno 2022 e di 54 milioni di euro per l'anno 2023.

220. Al fine del concorso alla copertura degli oneri derivanti dai commi da 214 a 218 del presente articolo si provvede altresi' mediante corrispondente riduzione dell'autorizzazione di spesa relativa al Fondo per interventi strutturali di politica economica, di cui all'articolo 10, comma 5, del decreto-legge 29 novembre 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307, per 3 milioni di euro per l'anno 2017, per 10 milioni di euro per l'anno 2018, per 22 milioni di euro per l'anno 2019, per 30 milioni di euro per l'anno 2020, per 31 milioni di euro per l'anno 2021, per 28 milioni di euro per l'anno 2022, per 18 milioni di euro per l'anno 2023, per 10 milioni di euro per l'anno 2024, per 6 milioni di euro per l'anno 2025 e per 3 milioni di euro per l'anno 2026.

221. Le risorse residue dell'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, come conseguenti dai commi da 212 a 219 del presente articolo, concorrono alla copertura dei maggiori oneri derivanti dalle misure in materia pensionistica previste dalla presente legge, e, conseguentemente, all'articolo 1, comma 235, della legge 24 dicembre 2012, n. 228, sono soppressi i primi tre periodi e gli ultimi due periodi. Qualora dall'attivita' di monitoraggio di cui al comma 216 del presente articolo dovessero venire accertate, anche in via prospettica, economie rispetto ai limiti di spesa di cui al comma 218, primo periodo, del presente articolo, le stesse confluiscono nel Fondo sociale per occupazione e formazione, di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2.

222. Al fine di portare a conclusione la sperimentazione di cui all'articolo 1, comma 9, della legge 23 agosto 2004, n. 243, a decorrere dalla data di entrata in vigore della presente legge, la facolta' prevista dal medesimo articolo 1, comma 9, e' estesa alle lavoratrici che non hanno maturato entro il 31 dicembre 2015 i requisiti previsti dalla stessa disposizione per effetto degli incrementi della speranza di vita di cui all'articolo 12 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122.

223. Per le lavoratrici di cui al comma 222 del presente articolo restano fermi, ai fini dell'accesso al trattamento pensionistico, il regime degli incrementi della speranza di vita di cui all'articolo 12 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, il regime delle decorrenze, nonche' il sistema di calcolo delle prestazioni applicati al pensionamento di anzianita' di cui all'articolo 1, comma 9, della legge 23 agosto 2004, n. 243.

224. Gli oneri derivanti dai commi 222 e 223 sono valutati in 18,3 milioni di euro per l'anno 2017, in 47,2 milioni di euro per l'anno 2018, in 87,5 milioni di euro per l'anno 2019, in 68,6 milioni di euro per l'anno 2020, in 34,1 milioni di euro per l'anno 2021 e in 1,7 milioni di euro per l'anno 2022.

225. A quota parte degli oneri di cui al comma 224 si provvede:

- a) quanto a 4,5 milioni di euro per l'anno 2019, a 2,5 milioni di euro per l'anno 2020, a 0,9 milioni di euro per l'anno 2021 e a 0,2 milioni di euro per l'anno 2022, mediante le maggiori entrate derivanti dalle misure di cui ai commi 222 e 223;
- b) quanto a 22,2 milioni di euro per l'anno 2018, a 52,5 milioni di euro per l'anno 2019 e a 33,6 milioni di euro per l'anno 2020, mediante il versamento all'entrata del bilancio dello Stato da parte dell'INPS, in deroga a quanto previsto dall'articolo 5 del decreto legislativo 14 settembre 2015, n. 150, di una quota pari a 22,2 milioni di euro per l'anno 2018, a 52,5 milioni di euro per l'anno 2019 e a 33,6 milioni di euro per l'anno 2020 delle entrate derivanti dall'aumento contributivo di cui all'articolo 25 della legge 21 dicembre 1978, n. 845, con esclusione delle somme destinate al finanziamento dei fondi paritetici interprofessionali nazionali per la formazione continua di cui all'articolo 118 della legge 23 dicembre 2000, n. 388;
- c) quanto a 25 milioni di euro per l'anno 2018, a 30,5 milioni di euro per l'anno 2019, a 32,5 milioni di euro per l'anno 2020, a 33,2 milioni di euro per l'anno 2021 e a 1,5 milioni di euro per l'anno 2022, mediante corrispondente riduzione dell'autorizzazione di spesa relativa al Fondo per interventi strutturali di politica economica, di cui all'articolo 10, comma 5, del decreto-legge 29 novembre 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307.

226. Nelle more dell'esercizio della delega di cui all'articolo 2, comma 4, della legge 26 ottobre 2016, n. 198, per il sostegno degli oneri derivanti dalle prestazioni di vecchiaia anticipata per i giornalisti dipendenti da aziende in ristrutturazione o riorganizzazione per crisi aziendale, di cui all'articolo 37 della legge 5 agosto 1981, n. 416, e' autorizzata la spesa di 5,5 milioni di euro per ciascuno degli anni 2017, 2018 e 2019, di 5 milioni di euro per l'anno 2020 e di 1,5 milioni di euro per l'anno 2021, in aggiunta a quanto previsto dall'articolo 1-bis del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114. Sono conseguentemente aumentati i limiti di spesa di cui all'articolo 41-bis, comma 7, del decreto-legge 30 dicembre 2008, n. 207, convertito, con modificazioni, dalla legge 27 febbraio 2009, n. 14.

227. I trattamenti di vecchiaia anticipata di cui ai commi da 226 a 232 del presente articolo sono erogati ai giornalisti interessati dai piani di ristrutturazione o riorganizzazione presentati al Ministero del lavoro e delle politiche sociali prima della data di entrata in vigore della presente legge, ancorche' ne siano esauriti i termini di durata. In tal caso, non si tiene conto, ai fini della decorrenza dei trattamenti ovvero della decadenza del termine di sessanta giorni previsto dall'alinea del comma 1 dell'articolo 37 della legge 5 agosto 1981, n. 416, del periodo intercorrente tra la data di scadenza del piano di ristrutturazione o riorganizzazione e quella di entrata in vigore della presente legge, dalla quale inizia a decorrere nuovamente il predetto termine. L'Istituto nazionale di previdenza dei giornalisti italiani prende in considerazione le domande di pensionamento secondo l'ordine cronologico di presentazione dei piani, nel rispetto dei limiti di spesa di cui al comma 226 del presente articolo e delle condizioni di cui all'articolo 1-bis, comma 2, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114.

228. Agli oneri derivanti dalle prestazioni di vecchiaia anticipata finanziate ai sensi dei commi da 226 a 232 del presente articolo concorre il contributo aggiuntivo a carico dei datori di lavoro di cui all'articolo 41-bis, comma 7, secondo periodo, del decreto-legge 30 dicembre 2008, n. 207, convertito, con modificazioni, dalla legge 27 febbraio 2009, n. 14.

229. L'instaurazione di rapporti di lavoro dipendente o autonomo di cui agli articoli 2222 e seguenti del codice civile, anche in forma di collaborazione coordinata e continuativa, ovvero la sottoscrizione di contratti per la cessione del diritto d'autore, con i giornalisti che abbiano optato per i trattamenti di vecchiaia anticipata finanziati ai sensi dei commi da 226 a 232 del presente articolo comporta la revoca del finanziamento concesso, anche nel caso in cui il rapporto di lavoro sia instaurato con un'azienda diversa facente capo al medesimo gruppo editoriale.

230. All'onere derivante dall'attuazione del comma 226 si provvede:

- a) quanto a 5,5 milioni di euro per l'anno 2017, mediante corrispondente riduzione della quota del Fondo per il pluralismo e l'innovazione dell'informazione destinata per l'anno 2017 agli interventi di competenza della Presidenza del Consiglio dei ministri ai sensi dell'articolo 1, comma 4, della legge 26 ottobre 2016, n. 198;
- b) quanto a 5,5 milioni di euro per l'anno 2018, a 5,5 milioni di euro per l'anno 2019, a 5 milioni di euro per l'anno 2020 e a 1,5 milioni di euro per l'anno 2021, mediante corrispondente versamento all'entrata del bilancio dello Stato, per pari importo e per i medesimi anni, delle risorse disponibili su apposita contabilita' speciale, su cui affluiscono 17,5 milioni di euro della quota del Fondo per il pluralismo e l'innovazione dell'informazione destinata per l'anno 2017 agli interventi di competenza della Presidenza del Consiglio dei ministri ai sensi dell'articolo 1, comma 4, della legge 26 ottobre 2016, n. 198.

231. Alla compensazione dei conseguenti effetti finanziari sui saldi di finanza pubblica recati dal comma 230 del presente articolo si provvede mediante corrispondente utilizzo del Fondo di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, pari a 5,5 milioni di euro per l'anno 2018, a 5,5 milioni di euro per l'anno 2019, a 5 milioni di euro per l'anno 2020 e a 1,5 milioni di euro per l'anno 2021.

232. Il Fondo di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e' incrementato di 17,5 milioni di euro per l'anno 2017.

233. L'autorizzazione di spesa di cui all'articolo 1, comma 284, quinto periodo, della legge 28 dicembre 2015, n. 208, e' ridotta di 100 milioni di euro per l'anno 2017 e di 50 milioni di euro per l'anno 2018 e, conseguentemente, le somme versate in entrata al bilancio dello Stato ai sensi dell'undicesimo periodo del medesimo comma 284, in misura pari a 120 milioni di euro per l'anno 2017 e a 60 milioni di euro per l'anno 2018, sono trasferite all'INPS a copertura dei maggiori oneri derivanti dallo stesso comma 284 nella misura di 20 milioni di euro per l'anno 2017 e di 10 milioni di euro per l'anno 2018 e rimangono acquisite al bilancio dello Stato per l'importo di 100 milioni di euro per l'anno 2017 e di 50 milioni di euro per l'anno 2018.

234. All'articolo 12, comma 1, primo periodo, del decreto-legge 3 maggio 2016, n. 59, convertito, con modificazioni, dalla legge 30 giugno 2016, n. 119, le parole: «2016 e 2017» sono sostituite dalle seguenti: «2016, 2017, 2018 e 2019». Le disposizioni di cui al primo periodo del presente comma sono estese anche al Fondo di solidarieta' per il sostegno dell'occupabilita', dell'occupazione e del reddito del personale del credito cooperativo. L'operativita' delle disposizioni di cui ai primi due periodi del presente comma e' subordinata all'emanazione dei regolamenti di adeguamento della disciplina dei Fondi ai sensi dell'articolo 26, comma 3, del decreto legislativo 14 settembre 2015, n. 148, da adottare con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, entro trenta giorni dalla data di entrata in vigore della presente legge. Dall'attuazione di quanto previsto dal presente comma non devono derivare nuovi o maggiori oneri per la finanza pubblica.

235. Fino al 31 dicembre 2019, con riferimento alle imprese o gruppi di imprese coinvolti in processi di ristrutturazione o fusione, rientranti nei settori destinatari dei Fondi di solidarieta' di cui all'articolo 26 del decreto legislativo 14 settembre 2015, n. 148, e interessati da provvedimenti legislativi relativi a processi di adeguamento o riforma per aumentarne la stabilita' e rafforzarne la patrimonializzazione, il contributo straordinario a carico del datore di lavoro previsto dall'articolo 33, comma 3, del predetto decreto legislativo n. 148 del 2015 per l'assegno straordinario per il sostegno al reddito di cui all'articolo 26, comma 9, lettera b), del medesimo decreto legislativo n. 148 del 2015, e' ridotto, a domanda da presentare dallo stesso datore di lavoro e nei limiti e alle condizioni di cui al comma 236 del presente articolo, di un importo pari all'85 per cento dell'importo equivalente alla somma della prestazione di cui all'articolo 1 del decreto legislativo 4 marzo 2015, n. 22, e della contribuzione figurativa di cui all'articolo 12 del medesimo decreto legislativo n. 22 del 2015, per i nuovi accessi all'assegno straordinario nel 2017, e pari al 50 per cento dell'importo equivalente alla medesima somma, per i nuovi accessi all'assegno straordinario negli anni 2018 e 2019, con riferimento a un limite massimo complessivo di 25.000 accessi nel triennio 2017-2019. Detto importo e' calcolato, per ciascun lavoratore coinvolto nei processi di agevolazione all'esodo, ai sensi degli articoli 4 e 5 del decreto legislativo n. 22 del 2015, e in ogni caso relativamente a un periodo non superiore alla durata dell'assegno straordinario. All'integrazione del finanziamento degli assegni straordinari necessaria per effetto della riduzione del contributo straordinario di cui al primo periodo del presente comma provvede la Gestione degli interventi assistenziali e di sostegno alle gestioni previdenziali, istituita presso l'INPS ai sensi dell'articolo 37 della legge 9 marzo 1989, n. 88.

236. Il beneficio di cui al comma 235 e' riconosciuto ai datori di lavoro nel limite di 174 milioni di euro per l'anno 2017, di 224 milioni di euro per l'anno 2018, di 139 milioni di euro per l'anno 2019, di 87 milioni di euro per l'anno 2020 e di 24 milioni di euro per l'anno 2021. L'INPS provvede al monitoraggio delle domande presentate ai sensi del comma 235 ai fini del rispetto dei limiti di spesa annuali di cui al primo periodo del presente comma e del limite numerico complessivo di cui al comma 235. Fermo restando il limite numerico complessivo di cui al comma 235, qualora dal monitoraggio risulti il raggiungimento, anche in via prospettica, dei limiti di spesa annuali di cui al primo periodo del presente comma, l'INPS non prende in esame ulteriori domande finalizzate a usufruire del beneficio di cui al comma 235. Alle attivita' previste l'INPS provvede con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica.

237. Per il triennio 2017-2019, i Fondi di solidarieta' di cui al comma 234 provvedono, a loro carico e previo il versamento agli stessi Fondi della relativa provvista finanziaria da parte dei datori di lavoro ai sensi del secondo periodo del presente comma, nei confronti dei lavoratori che raggiungano i requisiti previsti per il pensionamento di vecchiaia o anticipato nei successivi sette anni, anche al versamento della contribuzione correlata a periodi, utili per il conseguimento del diritto alla pensione anticipata o di vecchiaia, riscattabili o ricongiungibili precedenti all'accesso ai Fondi di solidarieta'. Gli oneri di finanziamento sono versati ai Fondi dal datore di lavoro e costituiscono specifica fonte di finanziamento con destinazione riservata alle finalita' di cui al primo periodo del presente comma. L'operativita' della disposizione di cui ai primi due periodi del presente comma e' subordinata all'emanazione dei regolamenti di adeguamento della disciplina dei Fondi di cui al comma 234, da adottare con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, entro trenta giorni dalla data di entrata in vigore della presente legge. Dall'attuazione di quanto previsto dal presente comma non devono derivare nuovi o maggiori oneri per la finanza pubblica.

238. Lo stanziamento del Fondo per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 1, comma 386, della legge 28 dicembre 2015, n. 208, e' incrementato di 150 milioni di euro annui a decorrere dall'anno 2017. L'autorizzazione di spesa di cui all'articolo 16, comma 7, del decreto legislativo 4 marzo 2015, n. 22, come rifinanziata dall'articolo 43, comma 5, del decreto legislativo 14 settembre 2015, n. 148, e' ridotta di 150 milioni di euro annui a decorrere dall'anno 2017.

239. Nelle more dell'attuazione dei provvedimenti legislativi di cui all'articolo 1, comma 388, della legge 28 dicembre 2015, n. 208, con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, per l'anno 2017 sono definiti, nei limiti delle risorse disponibili nel Fondo per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 1, comma 386, della citata legge n. 208 del 2015, nuovi criteri di accesso alla misura di contrasto alla poverta' di cui all'articolo 1, comma 387, lettera a), della medesima legge n. 208 del 2015, anche al fine di ampliare la platea nel rispetto delle priorita' previste dalla legislazione vigente. Con il medesimo decreto sono stabilite le modalita' di prosecuzione della sperimentazione dell'assegno di disoccupazione (ASDI), di cui all'articolo 16 del decreto legislativo 4 marzo 2015, n. 22, anche mediante eventuale utilizzo di quota parte delle risorse disponibili nel predetto Fondo per la lotta alla poverta' e all'esclusione sociale.

240. A valere sulle risorse del Fondo sociale per occupazione e formazione di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, si provvede, nei limiti degli importi rispettivamente indicati:

- a) alla restituzione dell'anticipazione effettuata dalla Presidenza del Consiglio dei ministri per interventi di pubblica utilita' e socialmente utili nei territori di Genova Cornigliano, pari a 5 milioni di euro per l'anno 2017;
- b) all'estensione degli incentivi di cui all'articolo 32, comma 1, del decreto legislativo 14 settembre 2015, n. 150, alle assunzioni effettuate fino al 31 dicembre 2017; a tal fine e' autorizzata la spesa di 2,6 milioni di euro per l'anno 2017, di 5,6 milioni di euro per l'anno 2018 e di 3 milioni di euro per l'anno 2019; conseguentemente, all'articolo 32, comma 3, primo periodo, dello stesso decreto legislativo n. 150 del 2015, le parole: «2015 e 2016» sono sostituite dalle seguenti: «2015, 2016 e 2017» e le parole: «sono incrementate di 27 milioni di euro per l'anno 2015 e di 27 milioni di euro per l'anno 2016» sono sostituite dalle seguenti: «sono incrementate di 27 milioni di euro per l'anno 2015, di 27 milioni di euro per l'anno 2016 e di 27 milioni di euro per l'anno 2017»;
- c) all'incremento di 15 milioni di euro annui del finanziamento della misura di cui all'articolo 6, comma 4-bis, del decreto-legge 1º ottobre 1996, n. 510, convertito, con modificazioni, dalla legge 28 novembre 1996, n. 608, introdotto dall'articolo 5, comma 1, del decreto-legge 20 marzo 2014, n. 34, convertito, con modificazioni, dalla legge 16 maggio 2014, n. 78; conseguentemente, al comma 4-bis dell'articolo 6 del citato decreto-legge n. 510 del 1996, le parole: «euro 15 milioni annui» sono sostituite dalle seguenti: «euro 30 milioni annui»;
- d) al finanziamento delle misure di sostegno al reddito per i lavoratori dipendenti dalle imprese del settore del call-center, previste dall'articolo 44, comma 7, del decreto legislativo 14 settembre 2015, n. 148, nella misura di 30 milioni di euro per l'anno 2017.

241. Il diritto all'astensione dal lavoro di cui all'articolo 24, comma 1, del decreto legislativo 15 giugno 2015, n. 80, e' riconosciuto alle lavoratrici autonome nella misura massima di tre mesi.

242. Durante il periodo di congedo di cui al comma 241, la lavoratrice autonoma ha diritto a percepire un'indennita' giornaliera pari all'80 per cento del salario minimo giornaliero stabilito dall'articolo 1 del decreto-legge 29 luglio 1981, n. 402, convertito, con modificazioni, dalla legge 26 settembre 1981, n. 537, nella misura risultante, per la qualifica di impiegato, dalla tabella A allegata al medesimo decreto e dai decreti ministeriali di cui al secondo comma del medesimo articolo 1.

243. L'articolo 24-bis del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' sostituito dal seguente: «Art. 24-bis (Misure a sostegno della tutela dei dati personali, della sicurezza nazionale, della concorrenza e dell'occupazione nelle attivita' svolte da call center). - 1. Le misure del presente articolo si applicano alle attivita' svolte da call center indipendentemente dal numero di dipendenti occupati. 2. Qualora un operatore economico decida di localizzare, anche mediante affidamento a terzi, l'attivita' di call center fuori dal territorio nazionale in un Paese che non e' membro dell'Unione europea, deve darne comunicazione, almeno trenta giorni prima del trasferimento: a) al Ministero del lavoro e delle politiche sociali, nonche' all'Ispettorato nazionale del lavoro a decorrere dalla data della sua effettiva operativita' a seguito dell'adozione dei decreti di cui all'articolo 5 del decreto legislativo 14 settembre 2015, n. 149, indicando i lavoratori coinvolti; la predetta comunicazione e' effettuata dal soggetto che svolge il servizio di call center; b) al Ministero dello sviluppo economico, indicando le numerazioni telefoniche messe a disposizione del pubblico e utilizzate per i servizi delocalizzati; c) al Garante per la protezione dei dati personali, indicando le misure adottate per garantire il rispetto della legislazione nazionale, e in particolare delle disposizioni del codice in materia di protezione dei dati personali, di cui al decreto legislativo 30 giugno 2003, n. 196, nonche' delle disposizioni concernenti il registro pubblico delle opposizioni, istituito ai sensi del regolamento di cui al decreto del Presidente della Repubblica 7 settembre 2010, n. 178. 3. Gli operatori economici che, antecedentemente alla data di entrata in vigore della presente disposizione, hanno localizzato, anche mediante affidamento a terzi, l'attivita' di call center fuori dal territorio nazionale in un Paese che non e' membro dell'Unione europea, devono darne comunicazione ai soggetti di cui al comma 2 entro sessanta giorni dalla medesima data di entrata in vigore, indicando le numerazioni telefoniche messe a disposizione del pubblico e utilizzate per i servizi delocalizzati. In caso di omessa o tardiva comunicazione si applica la sanzione amministrativa pecuniaria pari a 10.000 euro per ciascun giorno di ritardo. 4. In attesa di procedere alla ridefinizione del sistema degli incentivi all'occupazione nel settore dei call center, nessun beneficio, anche fiscale o previdenziale, previsto per tale tipologia di attivita' puo' essere erogato a operatori economici che, dopo la data di entrata in vigore della presente disposizione, delocalizzano l'attivita' di call center in un Paese che non e' membro dell'Unione europea. 5. Quando un soggetto effettua una chiamata a un call center deve essere informato preliminarmente sul Paese in cui l'operatore con cui parla e' fisicamente collocato nonche', a decorrere dal novantesimo giorno successivo alla data di entrata in vigore della presente disposizione, nell'ipotesi di localizzazione dell'operatore in un Paese che non e' membro dell'Unione europea, della possibilita' di richiedere che il servizio sia reso tramite un operatore collocato nel territorio nazionale o di un Paese membro dell'Unione europea, di cui deve essere garantita l'immediata disponibilita' nell'ambito della medesima chiamata. 6. Le disposizioni del presente articolo si applicano anche quando un cittadino e' destinatario di una chiamata proveniente da un call center. 7. In caso di omessa o tardiva comunicazione di cui al comma 2 si applica la sanzione amministrativa pecuniaria pari a 150.000 euro per ciascuna comunicazione omessa o tardiva. Nei casi di cui al comma 2, lettera a), la sanzione e' irrogata dal Ministero del lavoro e delle politiche sociali ovvero, dalla data della sua effettiva operativita', dall'Ispettorato nazionale del lavoro. Nei casi di cui al comma 2, lettere b) e c), la sanzione e' irrogata, rispettivamente, dal Ministero dello sviluppo economico e dal Garante per la protezione dei dati personali. Il mancato rispetto delle disposizioni dei commi 5 e 6 comporta la sanzione amministrativa pecuniaria pari a 50.000 euro per ogni giornata di violazione; all'accertamento delle violazioni delle disposizioni dei commi 5 e 6 e all'irrogazione delle relative sanzioni provvede il Ministero dello sviluppo economico. Resta fermo quanto previsto dall'articolo 161 del codice di cui al decreto legislativo 30 giugno 2003, n. 196, ove la mancata informazione di cui ai commi 5 e 6 del presente articolo integri, altresi', la violazione di cui all'articolo 13 del medesimo codice di cui al decreto legislativo n. 196 del 2003. Al fine di consentire l'applicazione delle predette disposizioni, il Ministero dello sviluppo economico comunica al Garante per la protezione dei dati personali l'accertamento dell'avvenuta violazione. 8. Ai fini dell'applicazione del presente articolo, nonche' di quanto previsto dall'articolo 130 del codice di cui al decreto legislativo 30 giugno 2003, n. 196, anche il soggetto che ha affidato lo svolgimento di propri servizi a un call center esterno e' considerato titolare del trattamento ai sensi degli articoli 4, comma 1, lettera f), e 28 del medesimo codice di cui al decreto legislativo n. 196 del 2003 ed e' conseguentemente responsabile in solido con il soggetto gestore. La constatazione della violazione puo' essere notificata all'affidatario estero per il tramite del committente. 9. Qualunque operatore economico che svolge o si avvale di servizi di call center e' tenuto a comunicare, su richiesta del Ministero del lavoro e delle politiche sociali, del Ministero dello sviluppo economico o del Garante per la protezione dei dati personali, entro dieci giorni dalla richiesta, la localizzazione del call center destinatario della chiamata o dal quale origina la stessa. Il mancato rispetto delle disposizioni del presente comma comporta la sanzione amministrativa pecuniaria pari a 50.000 euro per ogni violazione. 10. Per le amministrazioni aggiudicatrici e gli enti aggiudicatori che procedono ad affidamenti di servizi a operatori di call center l'offerta migliore e' determinata al netto delle spese relative al costo del personale, determinato ai sensi dell'articolo 23, comma 16, del decreto legislativo 18 aprile 2016, n. 50, ovvero sulla base di accordi con le organizzazioni sindacali maggiormente rappresentative. 11. Tutti gli operatori economici che svolgono attivita' di call center su numerazioni nazionali devono, entro sessanta giorni dalla data di entrata in vigore della presente disposizione, iscriversi al Registro degli operatori di comunicazione di cui alla delibera dell'Autorita' per le garanzie nelle comunicazioni n. 666/08/CONS del 26 novembre 2008, comunicando, altresi', tutte le numerazioni telefoniche messe a disposizione del pubblico e utilizzate per i servizi di call center. L'obbligo di iscrizione sussiste anche a carico dei soggetti terzi affidatari dei servizi di call center e deve essere contemplato nel contratto di affidamento del servizio. 12. L'inosservanza dell'obbligo di cui al comma 11 comporta l'applicazione di una sanzione pecuniaria amministrativa pari a 50.000 euro».

244. Al fine di garantire la continuita' del reddito degli operatori del settore della pesca, con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delle politiche agricole alimentari e forestali, da adottare entro sessanta giorni dalla data di sottoscrizione di accordi e contratti collettivi da parte delle organizzazioni sindacali e imprenditoriali del settore comparativamente piu' rappresentative a livello nazionale, ai sensi dell'articolo 26 del decreto legislativo 14 settembre 2015, n. 148, e comunque entro il 31 marzo 2017, presso l'INPS e' istituito il Fondo di solidarieta' per il settore della pesca (FOSPE).

245. Il FOSPE e' costituito da una dotazione iniziale pari a 1 milione di euro a carico del bilancio dello Stato per l'anno 2017 e da contribuzione ordinaria, ripartita tra datori di lavoro e lavoratori nella misura, rispettivamente, di due terzi e di un terzo, in misura tale da garantire un flusso costante di risorse sufficiente all'avvio dell'attivita' e alla gestione del Fondo a regime, da individuare anche in relazione all'importo stimato delle prestazioni da erogare, alle compatibilita' finanziarie e agli obblighi di equilibrio di bilancio di cui all'articolo 35 del decreto legislativo 14 settembre 2015, n. 148, nonche' ai livelli retributivi stabiliti dalla contrattazione collettiva nazionale delle organizzazioni sindacali e imprenditoriali comparativamente piu' rappresentative, nel limite massimo pari a due terzi dell'aliquota prevista dall'articolo 20 della legge 8 agosto 1972, n. 457.

246. Il FOSPE eroga prestazioni e relative coperture figurative ai dipendenti e comunque a tutti gli imbarcati delle imprese di pesca nonche' a quelli delle cooperative di pesca, compresi i soci lavoratori e i soci delle cooperative della piccola pesca di cui alla legge 13 marzo 1958, n. 250, nel caso di arresto temporaneo obbligatorio deciso dalle autorita' pubbliche competenti e nel caso di sospensioni temporanee dell'attivita' di pesca per condizioni meteorologiche avverse o per ogni altra causa, organizzativa o ambientale, non imputabile al datore di lavoro, prevista dagli accordi e contratti collettivi sottoscritti dalle organizzazioni sindacali e imprenditoriali del settore comparativamente piu' rappresentative a livello nazionale.

247. Il Ministro del lavoro e delle politiche sociali effettua un monitoraggio sul tasso di adesione al FOSPE da parte dei soggetti di cui al comma 246 e presenta alle Camere, entro il 31 ottobre 2017, una relazione sullo stato di attuazione del Fondo, sul suo funzionamento e sul tasso di adesione rilevato.

248. Per quanto non espressamente previsto dai commi da 244 a 247 del presente articolo si applicano al FOSPE le disposizioni del titolo II del decreto legislativo 14 settembre 2015, n. 148.

249. Le pensioni a favore dei superstiti di assicurato e pensionato, nell'ambito del regime dell'assicurazione generale obbligatoria e delle forme esclusive o sostitutive di tale regime, nonche' della Gestione separata di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, limitatamente a quelle percepite dagli orfani, concorrono alla formazione del reddito complessivo di cui all'articolo 8 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, per l'importo eccedente euro 1.000.

250. A decorrere dalla data di entrata in vigore della presente legge e nei limiti previsti dagli ultimi tre periodi del presente comma, il lavoratore iscritto all'assicurazione generale obbligatoria o alle forme esclusive e sostitutive della medesima affetto da mesotelioma pleurico (c45.0), mesotelioma pericardico (c45.2), mesotelioma peritoneale (c45.1), mesotelioma della tunica vaginale del testicolo (c45.7), carcinoma polmonare (c34) e asbestosi (c61), riconosciuti di origine professionale, ovvero quale causa di servizio, ha diritto al conseguimento di una pensione di inabilita', ancorche' non si trovi nell'assoluta e permanente impossibilita' di svolgere qualsiasi attivita' lavorativa. Ai fini del conseguimento del diritto alla pensione di inabilita' di cui al primo periodo, il requisito contributivo si intende perfezionato quando risultino versati a favore dell'assicurato almeno cinque anni nell'intera vita lavorativa. Il beneficio pensionistico di cui ai primi due periodi, che non e' cumulabile con altri benefici pensionistici previsti dalla normativa vigente, e' riconosciuto, a domanda, nel limite di 20 milioni di euro per l'anno 2017 e di 30 milioni di euro annui a decorrere dal 2018. Qualora dal monitoraggio delle domande presentate e accolte, emerga il verificarsi di scostamenti, anche in via prospettica, del numero di domande rispetto alle risorse finanziarie di cui al terzo periodo il riconoscimento del trattamento pensionistico e' differito, con criteri di priorita' in ragione dell'eta' anagrafica, dell'anzianita' contributiva e, infine, della data di presentazione della domanda, allo scopo di garantire un numero di accessi al pensionamento non superiore al numero di pensionamenti programmato in relazione alle predette risorse finanziarie. Per i lavoratori di cui all'articolo 1, comma 2, e all'articolo 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, nonche' per il personale degli enti pubblici di ricerca, che rientrano nelle fattispecie di cui ai primi due periodi del presente comma, le indennita' di fine servizio comunque denominate di cui all'articolo 3 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, sono corrisposte al momento in cui il soggetto avrebbe maturato il diritto alla corresponsione delle stesse secondo le disposizioni dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e sulla base della disciplina vigente in materia di corresponsione del trattamento di fine servizio comunque denominato. Entro sessanta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono emanate le disposizioni necessarie per l'attuazione del presente comma.

250-bis. Con effetto dalla data di entrata in vigore della presente disposizione, le disposizioni del comma 250 del presente articolo si applicano ai lavoratori in servizio o cessati dall'attivita' alla medesima data che risultano affetti da patologia asbesto-correlata accertata e riconosciuta ai sensi dell'articolo 13, comma 7, della legge 27 marzo 1992, n. 257. Sono compresi nell'ambito di applicazione della presente disposizione anche i soggetti di cui al primo periodo che:

- a) in seguito alla cessazione del rapporto di lavoro siano transitati in una gestione di previdenza diversa da quella dell'INPS, compresi coloro che, per effetto della ricongiunzione contributiva effettuata ai sensi dell'articolo 2 della legge 7 febbraio 1979, n. 29, non possano far valere contribuzione nell'assicurazione generale obbligatoria;
- b) siano titolari del sussidio per l'accompagnamento alla pensione entro l'anno 2020, riconosciuto ai sensi dell'articolo 1, comma 276, della legge 28 dicembre 2015, n. 208, secondo i criteri e le modalita' indicate nel decreto del Ministro del lavoro e delle politiche sociali 29 aprile 2016, pubblicato nella Gazzetta Ufficiale n. 134 del 10 giugno 2016, che optino per la pensione di inabilita' di cui al comma 250 del presente articolo.

250-ter. Entro sessanta giorni dalla data di entrata in vigore della presente disposizione, con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono emanate le disposizioni per l'applicazione del comma 250-bis. Il beneficio pensionistico di cui al comma 250-bis e' riconosciuto a domanda nel limite di spesa di 7,7 milioni di euro per l'anno 2019, di 13,1 milioni di euro per l'anno 2020, di 12,6 milioni di euro per l'anno 2021, di 12,3 milioni di euro per l'anno 2022, di 11,7 milioni di euro per l'anno 2023, di 11,1 milioni di euro per l'anno 2024, di 10 milioni di euro per l'anno 2025, di 9,2 milioni di euro per l'anno 2026, di 8,5 milioni di euro per l'anno 2027 e di 7,5 milioni di euro annui a decorrere dall'anno 2028. Agli oneri derivanti dal comma 250-bis e dal presente comma si provvede:

- a) quanto a 7,7 milioni di euro per l'anno 2019 e a 1,1 milioni di euro per l'anno 2020, mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 12, comma 6, del decreto-legge 28 gennaio 2019, n. 4, convertito, con modificazioni, dalla legge 28 marzo 2019, n. 26;
- b) quanto a 12 milioni di euro per l'anno 2020, a 12,6 milioni di euro per l'anno 2021, a 12,3 milioni di euro per l'anno 2022, a 11,7 milioni di euro per l'anno 2023, a 11,1 milioni di euro per l'anno 2024, a 10 milioni di euro per l'anno 2025, a 9,2 milioni di euro per l'anno 2026, a 8,5 milioni di euro per l'anno 2027 e a 7,5 milioni di euro annui a decorrere dall'anno 2028, mediante corrispondente riduzione del Fondo di cui all'articolo 1, comma 255, della legge 30 dicembre 2018, n. 145;
- c) quanto a 3.734.500 euro per l'anno 2019 e a 533.500 euro per l'anno 2020, mediante corrispondente riduzione del Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, ai fini della compensazione degli effetti finanziari in termini di fabbisogno e di indebitamento netto.

251. Le risorse del Fondo per il diritto al lavoro dei disabili, di cui all'articolo 13, comma 4, della legge 12 marzo 1999, n. 68, gia' trasferite alle regioni e alle province autonome di Trento e di Bolzano ed eventualmente non impegnate in favore dei beneficiari, sono riattribuite ai Fondi regionali per l'occupazione dei disabili, di cui all'articolo 14, comma 1, della medesima legge n. 68 del 1999 e sono prioritariamente utilizzate allo scopo di finanziare gli incentivi alle assunzioni delle persone con disabilita' successive al 1º gennaio 2015 non coperte dal predetto Fondo di cui all'articolo 13, comma 4, della legge n. 68 del 1999.

252. Gli studenti dei corsi di laurea e di laurea magistrale delle universita' statali contribuiscono alla copertura dei costi dei servizi didattici, scientifici e amministrativi mediante un contributo onnicomprensivo annuale, anche differenziato tra i diversi corsi di laurea e di laurea magistrale, da versare all'universita' alla quale sono iscritti. Restano ferme le norme in materia di imposta di bollo, le norme in materia di esonero e di graduazione dei contributi, di cui all'articolo 9 del decreto legislativo 29 marzo 2012, n. 68, nonche' le norme sulla tassa regionale per il diritto allo studio, di cui all'articolo 3, commi da 20 a 23, della legge 28 dicembre 1995, n. 549. Sono comunque ricompresi, all'interno del contributo onnicomprensivo annuale, i contributi per attivita' sportive.

253. L'importo del contributo onnicomprensivo annuale e' stabilito da ciascuna universita' statale con il regolamento di cui al comma 254 del presente articolo. Tutti gli studenti, ad eccezione di coloro che ne sono esonerati ai sensi dell'articolo 3, comma 22, della legge 28 dicembre 1995, n. 549, sono tenuti al pagamento della tassa regionale per il diritto allo studio.

254. Ciascuna universita' statale, nell'esercizio della propria autonomia normativa, approva il regolamento in materia di contribuzione studentesca, nel rispetto dei criteri di equita', gradualita' e progressivita', nonche' delle disposizioni dei commi da 252 a 267. In sede di prima applicazione, ciascuna universita' statale approva il proprio regolamento in materia di contribuzione studentesca entro il 31 marzo 2017. Il regolamento si applica a decorrere dall'anno accademico 2017/2018. In caso di mancata approvazione del regolamento entro il 31 marzo 2017, trovano comunque applicazione le disposizioni dei commi da 255 a 258.

255. Sono esonerati dal pagamento del contributo onnicomprensivo annuale gli studenti che soddisfano congiuntamente i seguenti requisiti:

- a) appartengono a un nucleo familiare il cui Indicatore della situazione economica equivalente (ISEE), calcolato secondo le modalita' previste dall'articolo 8 del regolamento di cui al decreto del Presidente del Consiglio dei ministri 5 dicembre 2013, n. 159, nonche' dall'articolo 2-sexies del decreto-legge 29 marzo 2016, n. 42, convertito, con modificazioni, dalla legge 26 maggio 2016, n. 89, e' inferiore o eguale a 13.000 euro;
- b) sono iscritti all'universita' di appartenenza da un numero di anni accademici inferiore o uguale alla durata normale del corso di studio, aumentata di uno;
- c) nel caso di iscrizione al secondo anno accademico abbiano conseguito, entro la data del 10 agosto del primo anno, almeno 10 crediti formativi universitari; nel caso di iscrizione ad anni accademici successivi al secondo abbiano conseguito, nei dodici mesi antecedenti la data del 10 agosto precedente la relativa iscrizione, almeno 25 crediti formativi.

256. Nel caso di iscrizione al primo anno accademico, l'unico requisito da soddisfare e' quello di cui al comma 255, lettera a).

257. Per gli studenti che appartengono a un nucleo familiare il cui ISEE sia compreso tra 13.001 euro e 30.000 euro e che soddisfano entrambi i requisiti di cui alle lettere b) e c) del comma 255, il contributo onnicomprensivo annuale non puo' superare il 7 per cento della quota di ISEE eccedente 13.000 euro.

258. Per gli studenti che appartengono a un nucleo familiare il cui ISEE sia inferiore a 30.000 euro e che soddisfano il requisito di cui alla lettera c) del comma 255, ma non quello di cui alla lettera b) del medesimo comma 255, il contributo onnicomprensivo annuale non puo' superare quello determinato ai sensi dei commi 255 e 257, aumentato del 50 per cento, con un valore minimo di 200 euro.

259. Il regolamento di cui al comma 254 stabilisce, nel rispetto di quanto previsto dai commi da 255 a 258 e del principio di equilibrio di bilancio di ciascuna universita' statale:

- a) eventuali ulteriori casi di esonero, o graduazione, del contributo onnicomprensivo annuale, per specifiche categorie di studenti, individuate in relazione alla carriera universitaria individuale o alla particolare situazione personale;
- b) le modalita' di versamento del contributo onnicomprensivo annuale, in una o piu' rate, unitamente alle maggiorazioni dovute in caso di ritardo nel versamento.

260. Oltre al contributo onnicomprensivo annuale di cui comma 252, le universita' statali non possono istituire ulteriori tasse o contributi a carico degli studenti, fino al rilascio del titolo finale di studio, fatti salvi i contributi per i servizi prestati su richiesta dello studente per esigenze individuali e le imposte erariali.

261. Nel caso di studenti aventi la cittadinanza di Stati non appartenenti all'Unione europea, e non residenti in Italia, per i quali risulti inapplicabile il calcolo dell'ISEE del nucleo familiare di appartenenza ai sensi dell'articolo 8, comma 5, del regolamento di cui al decreto del Presidente del Consiglio dei ministri 5 dicembre 2013, n. 159, l'importo del contributo onnicomprensivo annuale e' stabilito dalle singole universita' statali, anche in deroga ai criteri individuati nei commi da 255 a 258 del presente articolo.

262. Gli studenti dei corsi di dottorato di ricerca che non sono beneficiari di borsa di studio sono esonerati dal pagamento delle tasse o contributi a favore dell'universita'. Il regolamento di cui al comma 254 stabilisce il contributo annuale dovuto dagli iscritti ai corsi o scuole di specializzazione.

263. Gli articoli 2 e 3 del regolamento di cui al decreto del Presidente della Repubblica 25 luglio 1997, n. 306, sono abrogati.

264. A decorrere dall'anno accademico 2020/2021, i limiti di importo ISEE di cui ai commi 255, 257 e 258 sono aggiornati ogni tre anni, con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, a seguito del monitoraggio dell'attuazione e dell'efficacia delle norme dei commi da 252 a 267 del presente articolo.

265. Il Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537, e' incrementato di 55 milioni di euro per l'anno 2017 e di 105 milioni di euro a decorrere dall'anno 2018. Le somme di cui al primo periodo sono ripartite tra le universita' statali, a decorrere dall'anno 2017, con riferimento all'anno accademico 2016/2017, e conseguentemente per gli anni successivi, in proporzione al numero degli studenti esonerati dal pagamento di ogni contribuzione ai sensi dell'articolo 9 del decreto legislativo 29 marzo 2012, n. 68, cui si aggiunge, a decorrere dall'anno 2018, il numero degli studenti esonerati dal pagamento del contributo onnicomprensivo annuale ai sensi del comma 255 del presente articolo, moltiplicati per il costo standard di ateneo per studente in corso.

266. Le disposizioni dei commi da 252 a 267 del presente articolo non si applicano alle universita' non statali, alle universita' telematiche e alle istituzioni universitarie ad ordinamento speciale, nonche' all'universita' degli studi di Trento.

267. Le istituzioni statali dell'alta formazione artistica, musicale e coreutica, entro il 31 marzo 2017, adeguano i propri regolamenti in materia di contribuzione studentesca alle disposizioni dei commi da 252 a 266. In caso di mancato adeguamento entro il 31 marzo 2017, trovano comunque applicazione le disposizioni dei commi da 255 a 258. Il Ministero dell'istruzione, dell'universita' e della ricerca, nella ripartizione del fondo annuale di dotazione tra le istituzioni di cui al presente comma, tiene conto degli studenti esonerati dal pagamento di ogni contribuzione e di quelli esonerati dal pagamento del contributo onnicomprensivo annuale.

268. Al fine di sostenere l'accesso dei giovani all'universita', e in particolare dei giovani provenienti da famiglie meno abbienti, il fondo integrativo statale per la concessione di borse di studio, di cui all'articolo 18, comma 1, lettera a), del decreto legislativo 29 marzo 2012, n. 68, iscritto nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca, e' incrementato di 50 milioni di euro a decorrere dall'anno 2017.

269. Ai fini della gestione delle risorse del fondo di cui all'articolo 18 del decreto legislativo 29 marzo 2012, n. 68, ciascuna regione razionalizza l'organizzazione degli enti erogatori dei servizi per il diritto allo studio mediante l'istituzione, entro sei mesi dalla data di entrata in vigore della presente legge, di un unico ente erogatore dei medesimi servizi, prevedendo comunque una rappresentanza degli studenti nei relativi organi direttivi. Sono comunque fatti salvi i modelli sperimentali di gestione degli interventi di cui all'articolo 12 del decreto legislativo 29 marzo 2012, n. 68. (16)

270. La norma del comma 269 costituisce principio fondamentale di coordinamento della finanza pubblica. (16)

271. Nelle more dell'emanazione del decreto di cui all'articolo 7, comma 7, del decreto legislativo 29 marzo 2012, n. 68, e allo scopo di consentire che l'assegnazione delle risorse del fondo di cui al comma 268 del presente articolo avvenga, in attuazione dell'articolo 18, commi 1, lettera a), e 3, del medesimo decreto legislativo n. 68 del 2012, in misura proporzionale al fabbisogno finanziario delle regioni, il Ministro dell'istruzione, dell'universita' e della ricerca, con decreto emanato entro tre mesi dalla data di entrata in vigore della presente legge, di concerto con il Ministro dell'economia e delle finanze, previo parere della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, che si esprime entro sessanta giorni dalla data di trasmissione, decorso il quale il decreto puo' essere comunque adottato, determina i fabbisogni finanziari regionali. (16)

272. Le risorse del fondo di cui all'articolo 18, comma 1, lettera a), del decreto legislativo 29 marzo 2012, n. 68, sono direttamente attribuite al bilancio dell'ente regionale erogatore dei servizi per il diritto allo studio, a norma del comma 269 del presente articolo, entro il 30 settembre di ciascun anno. Nelle more della razionalizzazione di cui al medesimo comma 269, tali risorse sono comunque trasferite direttamente agli enti regionali erogatori, previa indicazione da parte di ciascuna regione della quota da trasferire a ciascuno di essi. (16)

273. A decorrere dal 1º gennaio 2017, la Fondazione per il Merito, di cui all'articolo 9, comma 3, del decreto-legge 13 maggio 2011, n. 70, convertito, con modificazioni, dalla legge 12 luglio 2011, n. 106, assume la denominazione di «Fondazione Articolo 34». La nuova denominazione sostituisce la precedente, ovunque presente, nel medesimo decreto-legge n. 70 del 2011, convertito, con modificazioni, dalla legge n. 106 del 2011, e in ogni altro provvedimento legislativo o regolamentare.

274. All'articolo 9 del decreto-legge 13 maggio 2011, n. 70, convertito, con modificazioni, dalla legge 12 luglio 2011, n. 106, sono apportate le seguenti modificazioni:

- a) al comma 4 e' aggiunto, in fine, il seguente periodo: «I componenti dell'organo di amministrazione della Fondazione e il suo presidente sono nominati con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'istruzione, dell'universita' e della ricerca e del Ministro dell'economia e delle finanze»;
- b) al comma 6 e' aggiunta, in fine, la seguente lettera: «e-bis) i criteri e le metodologie per l'assegnazione delle borse di studio nazionali per il merito e la mobilita'».

275. Entro il 30 aprile di ogni anno, la «Fondazione Articolo 34», sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, bandisce almeno 400 borse di studio nazionali, ciascuna del valore di 15.000 euro annuali, destinate a studenti capaci, meritevoli e privi di mezzi, al fine di favorirne l'immatricolazione e la frequenza a corsi di laurea o di laurea magistrale a ciclo unico, nelle universita' statali, o a corsi di diploma accademico di I livello, nelle istituzioni statali dell'alta formazione artistica, musicale e coreutica, aventi sedi anche differenti dalla residenza anagrafica del nucleo familiare dello studente. (16)

276. Sono ammessi a partecipare al bando di cui al comma 275 gli studenti iscritti all'ultimo anno della scuola secondaria di secondo grado che soddisfano congiuntamente i seguenti requisiti:

- a) l'ISEE, alla data di emanazione del bando, calcolato ai sensi dell'articolo 8 del regolamento di cui al decreto del Presidente del Consiglio dei ministri 5 dicembre 2013, n. 159, nonche' dell'articolo 2-sexies del decreto-legge 29 marzo 2016, n. 42, convertito, con modificazioni, dalla legge 26 maggio 2016, n. 89, e' inferiore o eguale a 20.000 euro;
- b) le medie dei voti ottenuti in tutte le materie, negli scrutini finali del penultimo e del terzultimo anno della scuola secondaria di secondo grado, nonche' negli scrutini intermedi dell'ultimo anno, purche' comunque effettuati entro la data di scadenza del bando, sono tutte eguali o superiori a 8/10;
- c) i punteggi riportati nelle prove dell'Istituto nazionale per la valutazione del sistema educativo di istruzione e di formazione (INVALSI), relative alle materie di italiano e matematica, ricadono nel primo quartile dei risultati INVALSI della regione ove ha sede la scuola di appartenenza.

277. Il limite di importo dell'ISEE di cui al comma 276, lettera a), puo' essere aggiornato con cadenza triennale con decreto del Ministro dell'istruzione, dell'universita' e della ricerca a seguito del monitoraggio dell'attuazione e dell'efficacia delle norme dei commi da 273 a 289.

278. Sono altresi' ammessi a partecipare al bando di cui al comma 275, in numero non superiore a due per ciascuna istituzione scolastica, gli studenti che soddisfano le condizioni di cui al comma 276, lettere a) e c), e che, pur non soddisfacendo la condizione di cui al comma 276, lettera b), sono motivatamente qualificati come eccezionalmente meritevoli dal dirigente scolastico della scuola secondaria di secondo grado di appartenenza, su proposta del collegio dei docenti.

279. I candidati ammessi a partecipare al bando ai sensi dei commi 276 e 278 sono inclusi in un'unica graduatoria nazionale di merito. Il punteggio assegnato a ciascun candidato e' calcolato sulla base dei criteri di valutazione stabiliti nel bando e fondati sui valori di cui al comma 276, lettere a), b) e c), nonche' sulla motivazione del giudizio di merito eccezionale di cui al comma 278. Nella fissazione dei predetti criteri, i valori delle medie di cui al comma 276, lettera b), sono rapportati ai valori delle medesime medie nelle scuole della provincia di appartenenza, come calcolati dall'INVALSI.

280. Le borse di studio di cui ai commi da 273 a 289 sono assegnate, nell'ordine della graduatoria nazionale di merito, entro il 31 agosto di ogni anno e sono corrisposte allo studente in rate semestrali anticipate, previa verifica del rispetto delle condizioni di cui ai commi 281 e 282.

281. La prima rata e' versata allo studente al momento della comunicazione dell'avvenuta immatricolazione a un corso di laurea o di laurea magistrale a ciclo unico o a un diploma accademico di I livello, scelto liberamente dallo studente, fermo restando il superamento delle prove di ammissione, ove previste. La seconda rata e' versata allo studente entro il 31 marzo dell'anno successivo.

282. Le borse di studio di cui ai commi da 273 a 289 sono confermate, negli anni accademici successivi al primo, per tutta la durata normale del relativo corso di laurea o corso di laurea magistrale a ciclo unico, o corso di diploma accademico di I livello, e sono versate in due rate semestrali annuali, entro il 30 settembre dell'anno di riferimento ed entro il 31 marzo dell'anno successivo, a condizione che lo studente, al 10 agosto di ogni anno accademico, abbia conseguito:

- a) tutti i crediti formativi degli anni accademici precedenti;
- b) almeno 40 crediti formativi dell'anno accademico in corso, con una media dei voti riportati in tutti gli esami sostenuti non inferiore a 28/30 e nessun voto inferiore a 24/30.

283. Gli studenti beneficiari delle borse di studio di cui ai commi da 273 a 289 del presente articolo sono esonerati dal pagamento della tassa regionale per il diritto allo studio di cui all'articolo 3, commi 20, 21, 22 e 23, della legge 28 dicembre 1995, n. 549, nonche' delle tasse e dei contributi previsti dagli ordinamenti delle universita' statali o delle istituzioni statali dell'alta formazione artistica, musicale e coreutica di appartenenza, ferma restando la disciplina dell'imposta di bollo.

284. Le borse di studio di cui ai commi da 273 a 289 sono incompatibili con ogni altra borsa di studio, ad eccezione di quelle destinate a sostenere finanziariamente lo studente per soggiorni di studio all'estero, con tutti gli strumenti e i servizi del diritto allo studio di cui al decreto legislativo 29 marzo 2012, n. 68, nonche' con l'ammissione alle istituzioni universitarie ad ordinamento speciale o ad altre consimili strutture universitarie che offrano gratuitamente agli studenti vitto e alloggio. Lo studente puo' comunque chiedere di usufruire dei servizi offerti dagli enti regionali per il diritto allo studio, al costo stabilito dai medesimi enti.

285. Alle borse di studio di cui ai commi da 273 a 289 del presente articolo si applicano, in materia fiscale, le disposizioni dell'articolo 4 della legge 13 agosto 1984, n. 476.

286. Per il finanziamento delle borse di studio di cui ai commi da 273 a 289 del presente articolo, sono attribuiti alla «Fondazione Articolo 34» 6 milioni di euro per l'anno 2017, 13 milioni di euro per l'anno 2018 e 20 milioni di euro a decorrere dall'anno 2019.

287. Al finanziamento dell'organizzazione e delle attivita' ordinarie della «Fondazione Articolo 34» sono attribuiti 2 milioni di euro per l'anno 2017 e 1 milione di euro a decorrere dall'anno 2018.

288. Nelle more del raggiungimento della piena operativita' della «Fondazione Articolo 34» e della nomina dei relativi organi di amministrazione, al fine di attuare tempestivamente le finalita' dei commi da 273 a 289 con decreto del Presidente del Consiglio dei ministri e' istituita, presso la Presidenza del Consiglio dei ministri, una cabina di regia, composta da tre membri designati, rispettivamente, dal Presidente del Consiglio dei ministri, dal Ministro dell'economia e delle finanze e dal Ministro dell'istruzione, dell'universita' e della ricerca, incaricata di attivare le procedure relative all'emanazione del bando di cui al comma 275, ai fini dell'assegnazione e del versamento delle borse di studio agli studenti vincitori. Con il medesimo decreto del Presidente del Consiglio dei ministri sono definiti le modalita' operative e organizzative della cabina di regia e il supporto amministrativo e tecnico alle attivita' della stessa, nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente presso la Presidenza del Consiglio dei ministri. Al raggiungimento della piena operativita' della Fondazione e alla nomina dei relativi organi di amministrazione, la cabina di regia decade automaticamente dalle sue funzioni.

289. La quota parte delle risorse di cui al comma 286 eventualmente non utilizzate per le finalita' di cui ai commi da 273 a 288, da accertare entro il 15 settembre di ogni anno con decreto del Ministero dell'istruzione, dell'universita' e della ricerca, confluisce, nel medesimo esercizio finanziario, nel Fondo di intervento integrativo per la concessione dei prestiti d'onore e delle borse di studio iscritto nello stato di previsione del medesimo Ministero. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

290. In attuazione dell'articolo 6, comma 1, lettera a), della legge 19 novembre 1990, n. 341, nonche' dell'articolo 3 del decreto legislativo 14 gennaio 2008, n. 21, sulla base degli obiettivi indicati dal comma 1 del medesimo articolo 3, le universita' e le istituzioni dell'alta formazione artistica, musicale e coreutica organizzano specifici corsi di orientamento pre-universitario o pre-accademico destinati agli studenti, da svolgere, in collaborazione con le scuole e senza interferenze con l'attivita' scolastica ordinaria, durante gli ultimi due anni di corso della scuola secondaria di secondo grado o nel periodo intercorrente tra il conseguimento del diploma e l'immatricolazione.

291. All'articolo 11, comma 1, del decreto legislativo 29 marzo 2012, n. 68, dopo le parole: «connesse ai servizi» sono inserite le seguenti: «e al tutorato di cui all'articolo 13 della legge 19 novembre 1990, n. 341».

292. In attuazione dell'articolo 13 della legge 19 novembre 1990, n. 341, e ai fini di cui al comma 2 del medesimo articolo 13, le universita' organizzano specifiche attivita' di tutorato riservate a studenti iscritti al primo o al secondo anno di un corso di laurea o di laurea magistrale a ciclo unico che abbiano riscontrato ostacoli formativi iniziali, anche con collaborazioni a tempo parziale di studenti dei corsi di studio o degli anni superiori assegnate ai sensi e con le modalita' di cui all'articolo 11 del decreto legislativo 29 marzo 2012, n. 68, come modificato dal comma 291 del presente articolo.

293. Per le finalita' dei commi da 290 a 292 del presente articolo, il Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537, e' incrementato di 5 milioni di euro a decorrere dall'anno 2017. Tale importo e' ripartito annualmente tra le universita' tenendo conto delle attivita' organizzate dalle stesse per attuare piani pluriennali di interventi integrati di orientamento pre-universitario, di sostegno didattico e di tutorato adottati ai sensi dell'articolo 2, comma 2, del decreto legislativo 14 gennaio 2008, n. 21, e dei commi da 290 a 292 del presente articolo, nonche' dei risultati raggiunti.

294. Al testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, sono apportate le seguenti modificazioni:

- a) all'articolo 15, comma 1, lettera i-octies), dopo le parole: «nonche' a favore» sono inserite le seguenti: «degli istituti tecnici superiori di cui al decreto del Presidente del Consiglio dei ministri 25 gennaio 2008, pubblicato nella Gazzetta Ufficiale n. 86 dell'11 aprile 2008,»;
- b) all'articolo 100, comma 2, lettera o-bis), dopo le parole: «e successive modificazioni,» sono inserite le seguenti: «nonche' a favore degli istituti tecnici superiori di cui al decreto del Presidente del Consiglio dei ministri 25 gennaio 2008, pubblicato nella Gazzetta Ufficiale n. 86 dell'11 aprile 2008,».

295. Al fine di incentivare l'attivita' base di ricerca dei docenti delle universita' statali, nel Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537, iscritto nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca, e' istituita una apposita sezione denominata «Fondo per il finanziamento delle attivita' base di ricerca», con uno stanziamento di 45 milioni di euro per l'anno 2017, di 30 milioni di euro per l'anno 2018, di 18 milioni di euro per l'anno 2019 e di 18 milioni di euro a decorrere dall'anno 2020.

296. Il Fondo di cui al comma 295 e' destinato al finanziamento annuale delle attivita' base di ricerca dei ricercatori e dei professori di seconda fascia in servizio nelle universita' statali.

297. Sono esclusi dal finanziamento annuale i ricercatori e i professori di seconda fascia che, alla data di presentazione della domanda di cui al comma 301 del presente articolo, sono in regime di impegno a tempo definito, sono collocati in aspettativa o sono risultati vincitori delle procedure di cui all'articolo 1, commi da 207 a 212, della legge 28 dicembre 2015, n. 208, ovvero usufruiscono di finanziamenti provenienti dallo European Research Council (ERC), da progetti di ricerca di interesse nazionale (PRIN) o da ulteriori finanziamenti pubblici, nazionali, europei o internazionali, comunque denominati.

298. L'importo individuale del finanziamento annuale e' pari a 3.000 euro, per un totale di 15.000 finanziamenti individuali nel 2017. A decorrere dal 2018 il numero dei finanziamenti individuali e' determinato in proporzione all'importo complessivamente disponibile di cui al comma 295, fermo restando l'importo individuale di 3.000 euro. L'assegnazione del finanziamento deve tenere conto dell'ordine di elenchi di cui al comma 300, lettere b) e c), in modo che le domande di cui al comma 301 siano soddisfatte nella misura del 75 per cento di quelle presentate dai ricercatori e del 25 per cento di quelle presentate dai professori associati.

299. Entro il 31 luglio di ogni anno, l'Agenzia nazionale di valutazione del sistema universitario e della ricerca (ANVUR), con riferimento a ciascun settore scientifico-disciplinare, predispone gli elenchi dei ricercatori e dei professori di seconda fascia che possono richiedere il finanziamento annuale individuale delle attivita' base di ricerca.

300. Nel limite delle disponibilita' finanziarie di cui al comma 295 e fermo restando l'importo del finanziamento individuale di cui al comma 298, l'ANVUR predispone gli elenchi di cui al comma 299 sulla base dei seguenti criteri:

- a) la verifica della sussistenza, per ognuno dei ricercatori e dei professori di seconda fascia, delle condizioni di cui al comma 297;
- b) l'inclusione, nell'elenco dei ricercatori appartenenti a ciascun settore scientifico-disciplinare, di tutti i ricercatori la cui produzione scientifica individuale, relativa agli ultimi cinque anni, e' pari o superiore a un apposito indicatore della produzione scientifica dei ricercatori appartenenti a ciascun settore scientifico-disciplinare, calcolato dall'ANVUR sulla base dei dati disponibili per l'ultimo triennio;
- c) l'inclusione, nell'elenco dei professori di seconda fascia appartenenti a ciascun settore scientifico-disciplinare, di tutti i professori di seconda fascia la cui produzione scientifica individuale, relativa agli ultimi cinque anni, e' pari o superiore a un apposito indicatore della produzione scientifica dei professori di seconda fascia appartenenti a ciascun settore scientifico-disciplinare, calcolato dall'ANVUR sulla base dei dati disponibili per l'ultimo triennio.

301. Entro il 30 settembre di ogni anno ciascun ricercatore e professore di seconda fascia incluso negli elenchi predisposti ai sensi dei commi 299 e 300, esclusivamente tramite l'apposita procedura telematica accessibile dal sito internet istituzionale dell'ANVUR, puo' presentare la domanda diretta a ottenere il finanziamento annuale individuale delle attivita' base di ricerca.

302. Entro il 30 novembre di ogni anno, il Ministero dell'istruzione, dell'universita' e della ricerca trasferisce a ciascuna universita' le risorse per il finanziamento annuale delle attivita' base di ricerca spettante ai ricercatori e ai professori di seconda fascia.

303. Al fine di favorire lo sviluppo delle attivita' di ricerca nelle universita' statali e di valorizzare le attivita' di supporto allo svolgimento delle stesse senza maggiori oneri per lo Stato, a decorrere dall'anno 2017:

- a) gli atti e i contratti di cui all'articolo 7, comma 6, del decreto legislativo 30 marzo 2001, n. 165, stipulati dalle universita' statali non sono soggetti al controllo previsto dall'articolo 3, comma 1, lettera f-bis), della legge 14 gennaio 1994, n. 20;
- b) all'articolo 6 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, al comma 12, quarto periodo, le parole: «dalle universita' e» sono sostituite dalle seguenti: «dalle universita' nonche' a quella effettuata» e, al comma 13, quarto periodo, sono aggiunte, in fine, le seguenti parole: «, nonche' dalle universita'». Al fine di assicurare il rispetto di quanto previsto dall'articolo 6, comma 21, del decreto-legge n. 78 del 2010, convertito, con modificazioni, dalla legge n. 122 del 2010, in termini di minori entrate per lo Stato con riferimento a quanto previsto dal periodo precedente, lo stanziamento del Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537, e' ridotto di 12 milioni di euro;
- c) all'articolo 1, comma 1, lettere a) e b), del decreto del Presidente del Consiglio dei ministri 31 dicembre 2014, pubblicato nella Gazzetta Ufficiale n. 66 del 20 marzo 2015, le parole: «30 per cento» sono sostituite dalle seguenti: «50 per cento».

304. Le somme destinate, a qualsiasi titolo, dal Ministero dell'istruzione, dell'universita' e della ricerca al finanziamento delle attivita' di ricerca non sono soggette ad esecuzione forzata. Gli atti di sequestro e di pignoramento afferenti ai fondi di cui ai commi da 295 a 305 sono nulli e la nullita' e' rilevabile d'ufficio.

305. La dotazione finanziaria del Fondo ordinario per gli enti e le istituzioni di ricerca, di cui all'articolo 7 del decreto legislativo 5 giugno 1998, n. 204, e' incrementata di 25 milioni di euro a decorrere dall'anno 2018, da destinare al sostegno specifico delle «Attivita' di ricerca a valenza internazionale».

306. Al fine di consentire il regolare svolgimento dei compiti attribuiti all'ANVUR, e' autorizzata l'assunzione, a decorrere dall'anno 2017, di ulteriori 15 unita' appartenenti all'area terza del contratto collettivo nazionale di lavoro (CCNL) - comparto Ministeri, di cui 13 funzionari valutatori tecnici e 2 funzionari amministrativi, e di ulteriori 2 unita' appartenenti all'area seconda del medesimo CCNL - comparto Ministeri, mediante scorrimento delle graduatorie concorsuali vigenti presso l'Agenzia e, per l'eventuale quota non coperta, mediante avvio di nuove procedure concorsuali, previo espletamento delle procedure di mobilita' di cui all'articolo 30 del decreto legislativo 30 marzo 2001, n. 165.

307. Al fine di contribuire al funzionamento dell'Istituto nazionale di genetica molecolare (INGM) di cui all'articolo 1, comma 1, lettera b), del decreto-legge 29 marzo 2004, n. 81, convertito, con modificazioni, dalla legge 26 maggio 2004, n. 138, e' autorizzata a decorrere dall'anno 2017 una spesa ulteriore di 1 milione di euro annui.

308. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205. (11)

309. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205. (11)

310. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205. (11)

311. Il secondo periodo del comma 39 dell'articolo 1 della legge 13 luglio 2015, n. 107, e' sostituito dal seguente: «Le risorse sono ripartite tra le istituzioni scolastiche del sistema nazionale di istruzione».

312. All'articolo 1 della legge 27 dicembre 2006, n. 296, dopo il comma 616-bis e' inserito il seguente: «616-ter. Il Ministero dell'istruzione, dell'universita' e della ricerca, relativamente al programma operativo nazionale "Per la scuola - competenze e ambienti per l'apprendimento" riferito al periodo di programmazione 2014/2020, puo' condurre le verifiche di cui all'articolo 125, paragrafo 5, del regolamento (UE) n. 1303/2013 del Parlamento europeo e del Consiglio, del 17 dicembre 2013, avvalendosi dei revisori dei conti di cui al comma 616 del presente articolo, rispettando il principio della separazione delle funzioni previsto dalla normativa dell'Unione europea che disciplina l'intervento dei Fondi strutturali».

313. Nel programma operativo nazionale «Per la scuola - competenze e ambienti per l'apprendimento», riferito al periodo di programmazione 2014/2020, di cui alla decisione della Commissione europea C(2014) 9952 del 17 dicembre 2014, per «istituzioni scolastiche» si intendono tutte le istituzioni scolastiche che costituiscono il sistema nazionale di istruzione, ai sensi dell'articolo 1, comma 1, della legge 10 marzo 2000, n. 62.

314. Al fine di incentivare l'attivita' dei dipartimenti delle universita' statali che si caratterizzano per l'eccellenza nella qualita' della ricerca e nella progettualita' scientifica, organizzativa e didattica, nonche' con riferimento alle finalita' di ricerca di «Industria 4.0», nel Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537, iscritto nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca, e' istituita un'apposita sezione denominata «Fondo per il finanziamento dei dipartimenti universitari di eccellenza», con uno stanziamento di 271 milioni di euro a decorrere dall'anno 2018.

315. Il Fondo di cui al comma 314 e' destinato al finanziamento quinquennale dei dipartimenti di eccellenza delle universita' statali, come individuati e selezionati ai sensi e per gli effetti dei commi da 318 a 331.

316. La quota parte delle risorse di cui al comma 314, eventualmente non utilizzata per le finalita' di cui ai commi da 318 a 339 del presente articolo, confluisce, nel medesimo esercizio finanziario, nel Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5 della legge 24 dicembre 1993, n. 537.

317. Per le istituzioni universitarie statali ad ordinamento speciale, ai fini dell'applicazione dei commi da 318 a 339, il riferimento ai dipartimenti si intende sostituito dal riferimento alle classi.

318. Entro il 31 dicembre del quarto anno di erogazione del finanziamento di cui ai commi da 314 a 317, con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, e' nominata una commissione deputata allo svolgimento delle attivita' di cui ai commi da 325 a 328. La commissione e' composta da sette membri, di cui:

- a) due designati dal Ministro dell'istruzione, dell'universita' e della ricerca, di cui uno con funzioni di presidente;
- b) quattro designati dal Ministro dell'istruzione, dell'universita' e della ricerca nell'ambito di due rose di tre membri ciascuna, indicate rispettivamente dall'ANVUR e dal Comitato nazionale dei garanti della ricerca, di cui all'articolo 21 della legge 30 dicembre 2010, n. 240;
- c) uno indicato dal Presidente del Consiglio dei ministri.

319. Entro la medesima data di cui al comma 318, il Ministero dell'istruzione, dell'universita' e della ricerca richiede all'ANVUR, sulla base dei risultati ottenuti, all'esito dell'ultima valutazione della qualita' della ricerca (VQR), dai docenti appartenenti a ciascun dipartimento delle universita' statali:

- a) la definizione del calcolo di un apposito «Indicatore standardizzato della performance dipartimentale» (ISPD), che tenga conto della posizione dei dipartimenti nella distribuzione nazionale della VQR, nei rispettivi settori scientifico-disciplinari;
- b) l'attribuzione a ognuno dei dipartimenti delle universita' statali del relativo ISPD.

320. All'esito delle procedure di cui al comma 319, il Ministero dell'istruzione, dell'universita' e della ricerca redige e rende pubblica, nel proprio sito internet istituzionale, la graduatoria dei dipartimenti delle universita' statali, in ordine decrescente rispetto all'ISPD attribuito al singolo dipartimento.

321. Dal 1º maggio al 31 luglio del quinto anno di erogazione del finanziamento di cui ai commi da 314 a 317, esclusivamente tramite l'apposita procedura telematica accessibile dal sito internet istituzionale del Ministero dell'istruzione, dell'universita' e della ricerca, le universita' statali di appartenenza dei dipartimenti collocati nelle prime 350 posizioni della graduatoria di cui al comma 320, come aggiornata agli esiti dei pareri negativi di cui al comma 337, terzo periodo, possono presentare la domanda diretta a ottenere, per ognuno dei medesimi dipartimenti, il finanziamento di cui ai commi da 314 a 317.

322. Il numero massimo di domande ammissibili, per i dipartimenti appartenenti alla stessa universita' statale, e' pari a 15. Nel caso in cui i dipartimenti per i quali l'universita' statale puo' presentare la domanda di cui al comma 321 siano superiori a 15, l'universita' stessa procede a una selezione delle proprie domande dipartimentali, nel numero massimo di 15, motivando la scelta in ragione dell'ISPD attribuito al singolo dipartimento, nonche' di ulteriori criteri demandati all'autonoma valutazione del singolo ateneo.

323. La domanda di cui ai commi 321 e 322:

- a) e' presentata, per ciascun dipartimento, con riferimento a una sola delle quattordici aree disciplinari del Consiglio universitario nazionale (CUN);
- b) contiene un progetto dipartimentale di sviluppo, avente durata quinquennale, e relativo: agli obiettivi di carattere scientifico; all'utilizzo del finanziamento per il reclutamento, ai sensi degli articoli 18 e 24 della legge 30 dicembre 2010, n. 240, e dell'articolo 1, comma 9, della legge 4 novembre 2005, n. 230, del personale docente, ovvero per il reclutamento di personale tecnico e amministrativo; alla premialita', ai sensi dell'articolo 9 della legge n. 240 del 2010; all'investimento in infrastrutture per la ricerca; allo svolgimento di attivita' didattiche di elevata qualificazione; alla presenza di eventuali cofinanziamenti attribuiti al progetto dipartimentale;
- c) qualora, al medesimo dipartimento, afferissero docenti appartenenti a piu' aree disciplinari, il progetto di cui alla lettera b) deve dare preminenza alle aree disciplinari che hanno ottenuto, all'esito dell'ultima VQR, i migliori risultati.

324. Il numero complessivo dei dipartimenti che possono ottenere il finanziamento di cui ai commi da 314 a 317 e' pari a 180. Il numero dei dipartimenti finanziati, con riferimento a ciascuna delle 14 aree disciplinari del CUN, non puo' essere inferiore a 5 ne' superiore a 20. La suddivisione del numero dei dipartimenti finanziati, con riferimento a ciascuna delle 14 aree disciplinari del CUN, e' stabilita, nel limite delle risorse economiche di cui ai commi da 314 a 317, con il decreto di cui al comma 318, e tenuto conto:

- a) della numerosita' della singola area disciplinare, in termini di dipartimenti ad essa riferibili;
- b) di criteri informati ad obiettivi di crescita e miglioramento di particolari aree della ricerca scientifica e tecnologica italiana.

325. La valutazione delle domande presentate ai sensi dei commi 321, 322 e 323 per la selezione dei dipartimenti di cui al comma 324 e' affidata alla commissione di cui al comma 318 e si svolge mediante due fasi successive.

326. Nella prima fase, la commissione procede a valutare le domande presentate da ciascuna universita' statale in relazione al solo dipartimento che ha ottenuto la migliore collocazione nelle prime 350 posizioni della graduatoria di cui al comma 320. La valutazione della domanda ha ad oggetto il progetto dipartimentale di sviluppo di cui al comma 323, lettere b) e c). Esclusivamente in caso di esito positivo della valutazione, il dipartimento consegue il finanziamento di cui ai commi da 314 a 317, nei limiti massimi delle risorse finanziarie assegnate a ciascuna delle 14 aree disciplinari del CUN ai sensi del comma 324.

327. Nella seconda fase, tenuto conto del numero dei dipartimenti ammessi e di quelli esclusi dal finanziamento ai sensi del comma 326, la commissione valuta le rimanenti domande assegnando a ognuna di esse un punteggio da 1 a 100, di cui 70 punti sono attribuiti in base all'ISPD del singolo dipartimento e 30 punti sono attribuiti in base al progetto dipartimentale di sviluppo di cui al comma 323, lettere b) e c), in relazione alla coerenza e alla fattibilita' dei contenuti del medesimo progetto. La graduatoria risultante all'esito di questa seconda fase suddivide i dipartimenti in base alla relativa area disciplinare di appartenenza e assegna il finanziamento di cui ai commi da 314 a 317 ai dipartimenti che, nei limiti del numero complessivo di cui al comma 324, sono utilmente posizionati.

328. Entro il 31 dicembre del quinto anno di erogazione del finanziamento di cui ai commi da 314 a 317, la commissione pubblica, nel sito internet istituzionale dell'ANVUR, l'elenco dei dipartimenti che sono risultati assegnatari del finanziamento di cui ai commi da 314 a 317. Entro il 31 marzo di ognuno dei cinque anni successivi alla predetta pubblicazione, il Ministero dell'istruzione, dell'universita' e della ricerca trasferisce alle universita' statali cui appartengono i dipartimenti il relativo finanziamento. L'universita' e' vincolata all'utilizzo di queste risorse a favore dei dipartimenti finanziati.

329. Il quarto periodo del comma 1 dell'articolo 9 della legge 30 dicembre 2010, n. 240, e' sostituito dal seguente: «In tal caso, le universita' possono prevedere, con appositi regolamenti, compensi aggiuntivi per il personale docente e tecnico amministrativo che contribuisce all'acquisizione di commesse conto terzi ovvero di finanziamenti pubblici o privati».

330. La selezione di cui ai commi 326 e 327 e' svolta con cadenza quinquennale. Le attivita' di supporto alla commissione di cui al comma 318 da parte della competente direzione generale del Ministero dell'istruzione, dell'universita' e della ricerca sono svolte nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente. Per la partecipazione alle riunioni della commissione non sono dovuti compensi, gettoni di presenza o altri emolumenti comunque denominati. Eventuali rimborsi di spese di missione sono posti a carico delle risorse finanziarie disponibili a legislazione vigente del Ministero dell'istruzione, dell'universita' e della ricerca.

331. Per il primo quinquennio di istituzione del Fondo di cui ai commi da 314 a 317 e relativamente agli anni 2018-2022:

- a) il decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di cui al comma 318, e' adottato entro il 30 aprile 2017;
- b) le attivita' di cui ai commi 319 e 320 devono concludersi entro il 30 aprile 2017;
- c) il termine per la presentazione delle domande di cui al comma 321 e' fissato al 31 luglio 2017;
- d) il termine per la pubblicazione dell'elenco di cui al comma 328, primo periodo, e' fissato al 31 dicembre 2017; i termini per il trasferimento del finanziamento annuale di cui al comma 328, secondo periodo, sono fissati al 31 marzo 2018, al 31 marzo 2019, al 31 marzo 2020, al 31 marzo 2021 e al 31 marzo 2022.

332. L'importo annuale del finanziamento di cui ai commi da 314 a 331 e' pari a 1.350.000 euro.

333. L'importo di cui al comma 332:

- a) e' ridotto del 20 per cento per il primo quintile, calcolato in base all'organico su base nazionale, dei dipartimenti che, ai sensi del comma 327, sono risultati assegnatari del finanziamento;
- b) e' ridotto del 10 per cento per il secondo quintile, calcolato in base all'organico su base nazionale, dei dipartimenti che, ai sensi del comma 327, sono risultati assegnatari del finanziamento;
- c) e' mantenuto invariato per il terzo quintile, calcolato in base all'organico su base nazionale, dei dipartimenti che, ai sensi del comma 327, sono risultati assegnatari del finanziamento;
- d) e' aumentato del 10 per cento per il quarto quintile, calcolato in base all'organico su base nazionale, dei dipartimenti che, ai sensi del comma 327, sono risultati assegnatari del finanziamento;
- e) e' aumentato del 20 per cento per il quinto quintile, calcolato in base all'organico su base nazionale, dei dipartimenti che, ai sensi del comma 327, sono risultati assegnatari del finanziamento.

334. Per i dipartimenti appartenenti alle aree disciplinari dal n. 1 al n. 9 del CUN, l'importo di cui al comma 332 e' aumentato di 250.000 euro, utilizzabili esclusivamente per investimenti in infrastrutture per la ricerca.

335. L'importo complessivo del finanziamento quinquennale di cui ai commi da 314 a 317 e di cui al comma 332 e' assoggettato alle seguenti modalita' di utilizzazione:

- a) non piu' del 70 per cento, tenuto conto di quanto previsto all'articolo 18, comma 3, della legge 30 dicembre 2010, n. 240, puo' essere impiegato per le chiamate dei professori e per il reclutamento di ricercatori, a norma degli articoli 18 e 24 della medesima legge n. 240 del 2010, e per il reclutamento del personale tecnico e amministrativo; (11)
- b) nel rispetto del limite percentuale di cui alla lettera a) del presente comma, almeno il 25 per cento deve essere impiegato per le chiamate di professori esterni all'universita' cui appartiene il dipartimento ai sensi dell'articolo 18, comma 4, della legge 30 dicembre 2010, n. 240;
- c) nel rispetto del limite percentuale di cui alla lettera a) del presente comma, almeno il 25 per cento deve essere impiegato per il reclutamento di ricercatori, a norma dell'articolo 24, comma 3, lettera b), della legge 30 dicembre 2010, n. 240; (11)
- d) nel rispetto del limite percentuale di cui alla lettera a) del presente comma, per le chiamate dirette di professori ai sensi dell'articolo 1, comma 9, della legge 4 novembre 2005, n. 230.

336. L'erogazione del finanziamento di cui al comma 332 e' interrotta a seguito del mutamento di denominazione del dipartimento e in conseguenza della sua cessazione.

337. Entro il 31 gennaio dell'ultimo anno di erogazione del finanziamento di cui al comma 332, l'universita', per ogni dipartimento, e' tenuta a presentare alla commissione di cui al comma 318 una relazione contenente il rendiconto concernente l'utilizzazione delle risorse economiche derivanti dal medesimo finanziamento e i risultati ottenuti rispetto ai contenuti individuati nel progetto di cui al comma 323, lettere b) e c). La commissione, entro tre mesi dalla presentazione della relazione, riscontrata la corrispondenza tra l'utilizzazione delle risorse economiche e gli obiettivi del progetto, verificato il rispetto delle modalita' di utilizzazione di cui al comma 335, esprime il proprio motivato giudizio. In caso di giudizio negativo, l'universita' non puo' presentare per lo stesso dipartimento la domanda diretta all'ottenimento, per il quinquennio successivo, del finanziamento di cui ai commi da 314 a 317.

338. Al fine di favorire l'utilizzazione dei finanziamenti di cui ai commi da 314 a 337 del presente articolo, alla legge 30 dicembre 2010, n. 240, sono apportate le seguenti modificazioni:

- a) all'articolo 23, comma 4, sono aggiunte, in fine, le seguenti parole: «, ma consente di computare le eventuali chiamate di coloro che sono stati titolari dei contratti nell'ambito delle risorse vincolate di cui all'articolo 18, comma 4»;
- b) all'articolo 24, comma 3, la lettera b) e' sostituita dalla seguente: «b) contratti triennali, riservati a candidati che hanno usufruito dei contratti di cui alla lettera a), ovvero che hanno conseguito l'abilitazione scientifica nazionale alle funzioni di professore di prima o di seconda fascia di cui all'articolo 16 della presente legge, ovvero che sono in possesso del titolo di specializzazione medica, ovvero che, per almeno tre anni anche non consecutivi, hanno usufruito di assegni di ricerca ai sensi dell'articolo 51, comma 6, della legge 27 dicembre 1997, n. 449, o di assegni di ricerca di cui all'articolo 22 della presente legge, o di borse post-dottorato ai sensi dell'articolo 4 della legge 30 novembre 1989, n. 398, ovvero di analoghi contratti, assegni o borse in atenei stranieri».

339. All'articolo 3, comma 1, del regolamento di cui al decreto del Presidente della Repubblica 1º febbraio 2010, n. 76, e' aggiunta, in fine, la seguente lettera: «i-bis) svolge, con cadenza quinquennale, la valutazione della qualita' della ricerca delle universita' e degli enti di ricerca, sulla base di un apposito decreto del Ministro dell'istruzione, dell'universita' e della ricerca, emanato entro il 31 marzo dell'anno successivo al quinquennio oggetto di valutazione, e diretto a individuare le linee-guida concernenti lo svolgimento della medesima valutazione e le risorse economiche a tal fine necessarie. La valutazione della qualita' della ricerca deve essere conclusa entro il 31 dicembre dell'anno successivo all'emanazione del decreto di cui al precedente periodo».

340. Al fine di consentire la definizione dei progetti avviati nell'ambito dell'ufficio per il processo con la partecipazione dei soggetti di cui all'articolo 50, comma 1-bis, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, alla scadenza del periodo di perfezionamento di cui al predetto comma, e' autorizzato, a domanda, lo svolgimento, da parte dei medesimi soggetti, di un ulteriore periodo di perfezionamento, per una durata non superiore a dodici mesi a decorrere dalla data di entrata in vigore della presente legge, presso gli stessi uffici giudiziari ove sono stati assegnati con decreto del Ministro della giustizia 20 ottobre 2015, pubblicato nella Gazzetta Ufficiale n. 257 del 4 novembre 2015. Durante il periodo autorizzato a norma del presente comma e' riconosciuto il diritto all'attribuzione della borsa di studio per l'importo e con le modalita' di cui all'articolo 9 del citato decreto del Ministro della giustizia 20 ottobre 2015. (11)

341. La domanda di cui al comma 340 e' redatta e trasmessa secondo le modalita' stabilite con provvedimento del direttore generale del personale e della formazione del Ministero della giustizia e fatta pervenire al predetto Ministero, entro quindici giorni dalla data di entrata in vigore della presente legge, corredata di un'attestazione del capo dell'ufficio giudiziario presso il quale si e' svolto il periodo di perfezionamento di cui all'articolo 50, comma 1-bis, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, dalla quale risulti che lo svolgimento da parte del richiedente dell'ulteriore periodo di perfezionamento di cui al comma 340 del presente articolo e' funzionale alle esigenze dell'ufficio.

342. Per i soggetti di cui al comma 340 del presente articolo resta fermo il riconoscimento dei titoli di preferenza e di merito in conformita' a quanto previsto dall'articolo 50, comma 1-quater, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114.

343. Per le finalita' di cui al comma 340 e' autorizzata la spesa di euro 5.807.509 per l'anno 2017, cui si provvede mediante corrispondente riduzione dell'autorizzazione di spesa prevista all'articolo 21-quater, comma 5, del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, limitatamente agli anni 2016 e 2017.

344. Al fine di promuovere forme di imprenditoria in agricoltura, ai coltivatori diretti e agli imprenditori agricoli professionali di cui all'articolo 1 del decreto legislativo 29 marzo 2004, n. 99, con eta' inferiore a quaranta anni, con riferimento alle nuove iscrizioni nella previdenza agricola effettuate tra il 1º gennaio 2017 e il 31 dicembre 2017, e' riconosciuto, ferma restando l'aliquota di computo delle prestazioni pensionistiche, per un periodo massimo di trentasei mesi, l'esonero dal versamento del 100 per cento dell'accredito contributivo presso l'assicurazione generale obbligatoria per l'invalidita', la vecchiaia ed i superstiti. L'esonero di cui al primo periodo, decorsi i primi trentasei mesi, e' riconosciuto per un periodo massimo di dodici mesi nel limite del 66 per cento e per un periodo massimo di ulteriori dodici mesi nel limite del 50 per cento. L'esonero di cui al presente comma spetta ai coltivatori diretti e agli imprenditori agricoli professionali, in presenza delle nuove iscrizioni di cui al primo periodo, nonche' ai coltivatori diretti e agli imprenditori agricoli professionali di eta' inferiore a quaranta anni che nell'anno 2016 hanno effettuato l'iscrizione nella previdenza agricola con aziende ubicate nei territori montani di cui al decreto del Presidente della Repubblica 29 settembre 1973, n. 601, e nelle zone agricole svantaggiate delimitate ai sensi dell'articolo 15 della legge 27 dicembre 1977, n. 984. L'esonero di cui al presente comma non e' cumulabile con altri esoneri o riduzioni delle aliquote di finanziamento previsti dalla normativa vigente. L'INPS provvede, con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente, al monitoraggio del numero di nuove iscrizioni effettuate ai sensi del presente comma e delle conseguenti minori entrate contributive, inviando relazioni mensili al Ministero delle politiche agricole alimentari e forestali, al Ministero del lavoro e delle politiche sociali e al Ministero dell'economia e delle finanze.

345. Le disposizioni di cui al comma 344 del presente articolo si applicano nei limiti previsti dai regolamenti (UE) n. 1407/2013 e n. 1408/2013 della Commissione, del 18 dicembre 2013, relativi all'applicazione degli articoli 107 e 108 del Trattato sul funzionamento dell'Unione europea agli aiuti «de minimis».

346. Al fine di garantire un sostegno al reddito per i lavoratori dipendenti da imprese adibite alla pesca marittima, compresi i soci lavoratori delle cooperative della piccola pesca di cui alla legge 13 marzo 1958, n. 250, nel periodo di sospensione dell'attivita' lavorativa derivante da misure di arresto temporaneo obbligatorio e' riconosciuta per ciascun lavoratore, per l'anno 2017 e nel limite di spesa di 11 milioni di euro per il medesimo anno, un'indennita' giornaliera onnicomprensiva pari a 30 euro. Per l'anno 2017 e nel limite di spesa di 7 milioni di euro per il medesimo anno, a ciascuno dei soggetti di cui al presente comma e' altresi' riconosciuta la medesima indennita' giornaliera onnicomprensiva pari a 30 euro nel periodo di sospensione dell'attivita' lavorativa derivante da misure di arresto temporaneo non obbligatorio, per un periodo non superiore complessivamente a quaranta giorni in corso d'anno. Al relativo onere, pari a 7 milioni di euro per l'anno 2017, si provvede mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 1, comma 199, della legge 23 dicembre 2014, n. 190. Per l'anno 2018, nel limite di spesa di 5 milioni di euro annui, e a decorrere dall'anno 2019, nel limite di spesa di 4,5 milioni di euro annui, a ciascuno dei soggetti di cui al presente comma e' altresi' riconosciuta la medesima indennita' giornaliera onnicomprensiva fino ad un importo massimo di 30 euro nel periodo di sospensione dell'attivita' lavorativa derivante da misure di arresto temporaneo non obbligatorio, per un periodo non superiore complessivamente a quaranta giorni in corso d'anno. (32)

347. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro delle politiche agricole alimentari e forestali e con il Ministro dell'economia e delle finanze, sono disciplinate le modalita' relative al pagamento delle indennita' di cui al comma 346.

348. COMMA ABROGATO DAL D.LGS. 21 DICEMBRE 2021, N. 230.

349. COMMA ABROGATO DAL D.LGS. 21 DICEMBRE 2021, N. 230.

350. Ai fini della predisposizione e dell'attuazione del terzo Piano di azione da adottare in ottemperanza della risoluzione n. 1325 (2000) del Consiglio di sicurezza delle Nazioni Unite (S/RES/1325) sulle donne, la pace e la sicurezza e delle risoluzioni seguenti, incluse le azioni di promozione, monitoraggio e valutazione, e' autorizzata la spesa di 1 milione di euro per ciascuno degli anni 2017, 2018, 2019 e 2020.

351. Al decreto legislativo 15 gennaio 2016, n. 7, sono apportate le seguenti modificazioni:

- a) all'articolo 9, il comma 1 e' sostituito dal seguente: «1. L'importo dovuto a titolo di sanzione pecuniaria civile e' recuperato secondo le disposizioni stabilite dalla parte VII del testo unico delle disposizioni legislative e regolamentari in materia di spese di giustizia, di cui al decreto del Presidente della Repubblica 30 maggio 2002, n. 115»;
- b) all'articolo 10, comma 1, le parole: «devoluto a favore della Cassa delle ammende» sono sostituite dalle seguenti: «versato all'entrata del bilancio dello Stato per essere riassegnato al pertinente capitolo di spesa dello stato di previsione del Ministero dell'interno riguardante il Fondo di rotazione per la solidarieta' alle vittime dei reati di tipo mafioso, delle richieste estorsive, dell'usura e dei reati intenzionali violenti, per le finalita' di cui all'articolo 11 della legge 7 luglio 2016, n. 122».

352. All'articolo 1, comma 367, alinea, della legge 24 dicembre 2007, n. 244, dopo le parole: «30 maggio 2002, n. 115,» sono inserite le seguenti: «nonche' alle sanzioni pecuniarie civili di cui al decreto legislativo 15 gennaio 2016, n. 7,».

353. COMMA ABROGATO DAL D.LGS. 21 DICEMBRE 2021, N. 230.

354. COMMA ABROGATO DAL D.LGS. 30 GIUGNO 2022, N. 105.

355. Con riferimento ai nati a decorrere dal 1º gennaio 2016, per il pagamento di rette relative alla frequenza di asili nido pubblici e privati, nonche' per l'introduzione di forme di supporto presso la propria abitazione in favore dei bambini al di sotto dei tre anni, affetti da gravi patologie croniche, e' attribuito, un buono di importo pari a 1.000 euro su base annua, parametrato a undici mensilita', per gli anni 2017 e 2018, elevato a 1.500 euro su base annua a decorrere dall'anno 2019. A decorrere dall'anno 2020, il buono di cui al primo periodo e' comunque incrementato di 1.500 euro per i nuclei familiari con un valore dell'indicatore della situazione economica equivalente (ISEE), di cui al decreto del Presidente del Consiglio dei ministri 5 dicembre 2013, n. 159, fino a 25.000 euro, calcolato ai sensi dell'articolo 7 del medesimo decreto del Presidente del Consiglio dei ministri n. 159 del 2013, e di 1.000 euro per i nuclei familiari con un ISEE da 25.001 euro fino a 40.000 euro; l'importo del buono spettante a decorrere dall'anno 2022 puo' essere rideterminato, nel rispetto del limite di spesa programmato, con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro per le pari opportunita' e la famiglia, di concerto con il Ministro del lavoro e delle politiche sociali e con il Ministro dell'economia e delle finanze, da adottare entro il 30 settembre 2021 tenuto conto degli esiti del monitoraggio di cui al settimo periodo del presente comma. Con riferimento ai nati a decorrere dal 1° gennaio 2024, per i nuclei familiari con un valore dell'ISEE fino a 40.000 euro, calcolato ai sensi dell'articolo 7 del medesimo decreto del Presidente del Consiglio dei ministri n. 159 del 2013, l'incremento del buono di cui al secondo periodo e' elevato a 2.100 euro. Il buono e' corrisposto dall'INPS al genitore richiedente, previa presentazione di idonea documentazione attestante l'iscrizione e il pagamento della retta a strutture pubbliche o private. Il beneficio di cui ai primi tre periodi del presente comma e' riconosciuto nel limite massimo di 144 milioni di euro per l'anno 2017, 250 milioni di euro per l'anno 2018, 300 milioni di euro per l'anno 2019, 520 milioni di euro per l'anno 2020, 530 milioni di euro per l'anno 2021, 541 milioni di euro per l'anno 2022, 552 milioni di euro per l'anno 2023, 563 milioni di euro per l'anno 2024, 574 milioni di euro per l'anno 2025, 585 milioni di euro per l'anno 2026, 597 milioni di euro per l'anno 2027, 609 milioni di euro per l'anno 2028 e 621 milioni di euro annui a decorrere dall'anno 2029. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro con delega in materia di politiche per la famiglia, di concerto con il Ministro del lavoro e delle politiche sociali e con il Ministro dell'economia e delle finanze, sono stabilite, entro trenta giorni dalla data di entrata in vigore della presente legge, le disposizioni necessarie per l'attuazione del presente comma. L'INPS provvede al monitoraggio dei maggiori oneri derivanti dalle disposizioni di cui al presente comma inviando relazioni mensili alla Presidenza del Consiglio dei ministri, al Ministero del lavoro e delle politiche sociali e al Ministero dell'economia e delle finanze. Nel caso in cui, in sede di attuazione del presente comma, si verifichino o siano in procinto di verificarsi scostamenti, anche in via prospettica, rispetto al limite di spesa programmato, l'INPS non prende in esame ulteriori domande finalizzate ad usufruire del beneficio di cui al presente comma. Il beneficio di cui al presente comma non e' cumulabile con la detrazione prevista dall'articolo 1, comma 335, della legge 23 dicembre 2005, n. 266, e dall'articolo 2, comma 6, della legge 22 dicembre 2008, n. 203; il beneficio di cui al presente comma non e' altresi' fruibile contestualmente con il beneficio di cui ai commi 356 e 357 del presente articolo. (51) (61) (67) ((70))

356. Al fine di sostenere la genitorialita', verificato il buon risultato del periodo sperimentale, il beneficio di cui all'articolo 4, comma 24, lettera b), della legge 28 giugno 2012, n. 92, e' riconosciuto nel limite di spesa di 40 milioni di euro per ciascuno degli anni 2017 e 2018, ferme restando le relative disposizioni attuative.

357. Ai medesimi fini di cui al comma 356 del presente articolo, il beneficio di cui all'articolo 4, comma 24, lettera b), della legge 28 giugno 2012, n. 92, e' riconosciuto, nel limite di spesa di 10 milioni di euro per ciascuno degli anni 2017 e 2018, ferme restando le relative disposizioni attuative, anche alle madri lavoratrici autonome o imprenditrici.

358. Al finanziamento delle iniziative per l'attuazione delle politiche in materia di pari opportunita' e non discriminazione, oltre alle risorse destinate alle predette iniziative gia' stanziate nella parte II (sezione II) della presente legge, per l'anno 2017 possono concorrere ulteriori risorse, fino a complessivi 20 milioni di euro, a valere sulle risorse dei pertinenti programmi operativi cofinanziati dai fondi strutturali e di investimento europei 2014/2020.

359. Al fine di sostenere le attivita' di assistenza e sostegno alle donne vittime di violenza e ai loro figli, di cui all'articolo 5, comma 2, lettera d), del decreto-legge 14 agosto 2013, n. 93, convertito, con modificazioni, dalla legge 15 ottobre 2013, n. 119, sono destinati a favore del Piano d'azione straordinario contro la violenza sessuale e di genere, dei servizi territoriali, dei centri antiviolenza e dei servizi di assistenza alle donne vittime di violenza, di cui agli articoli 5 e 5-bis del medesimo decreto-legge n. 93 del 2013, 5 milioni di euro per ciascuno degli anni 2017, 2018 e 2019, a valere sulle risorse del Fondo per le politiche relative ai diritti e alle pari opportunita'. A tal fine la dotazione del Fondo di cui al periodo precedente e' incrementata di 5 milioni di euro per ciascuno degli anni 2017, 2018 e 2019.

360. Le risorse del Fondo per la cura dei soggetti con disturbo dello spettro autistico, di cui all'articolo 1, comma 401, della legge 28 dicembre 2015, n. 208, non utilizzate per l'anno 2016 confluiscono per l'anno 2017 nel Fondo medesimo.

361. Il Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e' ridotto di 5 milioni di euro nell'anno 2017.

362. In relazione agli interventi per la riparazione, la ricostruzione, l'assistenza alla popolazione e la ripresa economica nei territori interessati dagli eventi sismici del 24 agosto 2016:

- a) e' autorizzata la spesa di 100 milioni di euro per l'anno 2017 e 200 milioni di euro annui dall'anno 2018 all'anno 2047, per la concessione del credito d'imposta maturato in relazione all'accesso ai finanziamenti agevolati, di durata venticinquennale, per la ricostruzione privata di cui all'articolo 5 del decreto-legge 17 ottobre 2016, n. 189; (50) (58)
- b) e' autorizzata la spesa di 200 milioni di euro per l'anno 2017, di 300 milioni di euro per l'anno 2018, di 350 milioni di euro per l'anno 2019 e di 150 milioni di euro per l'anno 2020 per la concessione dei contributi di cui all'articolo 14 del decreto-legge 17 ottobre 2016, n. 189.

363. Le regioni colpite, in coerenza con la programmazione del Commissario per la ricostruzione dei territori interessati dall'evento sismico del 24 agosto 2016 nominato con decreto del Presidente della Repubblica 9 settembre 2016, di cui al comunicato pubblicato nella Gazzetta Ufficiale n. 228 del 29 settembre 2016, possono destinare, nell'ambito dei pertinenti programmi operativi cofinanziati dai fondi strutturali e di investimento europei 2014/2020 e per il conseguimento delle finalita' dagli stessi previste, ulteriori risorse, incluso il cofinanziamento nazionale, per un importo pari a 300 milioni di euro, anche a valere su quelle aggiuntive destinate dall'Unione europea all'Italia ai sensi dell'articolo 92, paragrafo 3, del regolamento (UE) n. 1303/2013 del Parlamento europeo e del Consiglio, del 17 dicembre 2013.

364. Per il pubblico impiego sono complessivamente stanziati, per le finalita' di cui ai commi 365 e 366, 1.920,8 milioni di euro per l'anno 2017 e 2.633 milioni di euro a decorrere dall'anno 2018.

365. Nello stato di previsione del Ministero dell'economia e delle finanze e' istituito un fondo da ripartire con uno o piu' decreti del Presidente del Consiglio dei ministri, su proposta del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze, sentiti il Ministro dell'interno e il Ministro della difesa, da adottare entro novanta giorni dalla data di entrata in vigore della presente legge, con una dotazione di 1.480 milioni di euro per l'anno 2017 e di 1.930 milioni di euro a decorrere dall'anno 2018, per le seguenti finalita':

- a) determinazione, per l'anno 2017 e a decorrere dal 2018, degli oneri aggiuntivi, rispetto a quelli previsti dall'articolo 1, comma 466, della legge 28 dicembre 2015, n. 208, e pari a 300 milioni di euro annui, posti a carico del bilancio dello Stato per la contrattazione collettiva relativa al triennio 2016-2018 in applicazione dell'articolo 48, comma 1, del decreto legislativo 30 marzo 2001, n. 165, e per i miglioramenti economici del personale dipendente dalle amministrazioni statali in regime di diritto pubblico;
- b) definizione, per l'anno 2017 e a decorrere dall'anno 2018, del finanziamento da destinare ad assunzioni di personale a tempo indeterminato, in aggiunta alle facolta' assunzionali previste a legislazione vigente, nell'ambito delle amministrazioni dello Stato, ivi compresi i Corpi di polizia ed il Corpo nazionale dei vigili del fuoco, le agenzie, incluse le agenzie fiscali di cui agli articoli 62, 63 e 64 del decreto legislativo 30 luglio 1999, n. 300, e l'Agenzia italiana per la cooperazione allo sviluppo, gli enti pubblici non economici e gli enti pubblici di cui all'articolo 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, tenuto conto delle specifiche richieste volte a fronteggiare indifferibili esigenze di servizio di particolare rilevanza e urgenza in relazione agli effettivi fabbisogni, nei limiti delle vacanze di organico nonche' nel rispetto dell'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dell'articolo 4 del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125. Le assunzioni sono autorizzate con decreto del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze; (11) (24) (33) (39) (46)
- c) definizione, dall'anno 2017, dell'incremento del finanziamento previsto a legislazione vigente per garantire la piena attuazione di quanto previsto dall'articolo 8, comma 1, lettera a), numeri 1) e 4), della legge 7 agosto 2015, n. 124, e dall'articolo 1, comma 5, della legge 31 dicembre 2012, n. 244, ovvero, per il solo anno 2017, proroga del contributo straordinario di cui all'articolo 1, comma 972, della legge 28 dicembre 2015, n. 208, con la disciplina e le modalita' ivi previste. Al riordino delle carriere del personale non dirigente del Corpo nazionale dei vigili del fuoco e alla valorizzazione delle peculiari condizioni di impiego professionale del personale medesimo nelle attivita' di soccorso pubblico, rese anche in contesti emergenziali, sono altresi' destinati una quota parte delle risorse disponibili nei fondi incentivanti del predetto personale aventi carattere di certezza, continuita' e stabilita', per un importo massimo annuo di 5,3 milioni di euro, i risparmi strutturali di spesa corrente gia' conseguiti, derivanti dall'ottimizzazione e dalla razionalizzazione dei settori di spesa del Corpo nazionale dei vigili del fuoco relativi alle locazioni passive delle sedi di servizio, ai servizi di mensa al personale e ai servizi assicurativi finalizzati alla copertura dei rischi aeronautici, nonche' una quota parte del fondo istituito dall'articolo 1, comma 1328, secondo periodo, della legge 27 dicembre 2006, n. 296. In sede di prima applicazione, le risorse destinate alle finalita' di cui al precedente periodo sono determinate in misura non inferiore a 10 milioni di euro.

366. Per il concorso alle finalita' di cui al comma 364 del presente articolo, nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca, e' iscritto un fondo con una autonoma dotazione di 140 milioni di euro per l'anno 2017 e 400 milioni di euro a decorrere dall'anno 2018, da destinare all'incremento dell'organico dell'autonomia di cui all'articolo 1, comma 201, della legge 13 luglio 2015, n. 107. Al riparto del fondo si provvede con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con il Ministro dell'economia e delle finanze. (6) (11) (32)

366-bis. Allo scopo di garantire la continuita' didattica per gli alunni con disabilita', il fondo di cui al comma 366 e' rifinanziato in misura pari a 62,76 milioni di euro nell'anno 2021, a 321,34 milioni di euro nell'anno 2022, a 699,43 milioni di euro nell'anno 2023, a 916,36 milioni di euro per ciascuno degli anni 2024 e 2025, a 924,03 milioni di euro nell'anno 2026, a 956,28 milioni di euro nell'anno 2027, a 1.003,88 milioni di euro nell'anno 2028 e a 1.031,52 milioni di euro annui a decorrere dall'anno 2029. La dotazione dell'organico dell'autonomia, a valere sulle risorse di cui al primo periodo, e' incrementata di 5.000 posti di sostegno a decorrere dall'anno scolastico 2021/2022, di 11.000 posti di sostegno a decorrere dall'anno scolastico 2022/2023 e di 9.000 posti di sostegno a decorrere dall'anno scolastico 2023/2024. Alla ripartizione delle risorse di cui al presente comma, disponibili a decorrere dall'anno scolastico 2021/2022, si provvede con decreto del Ministro dell'istruzione, di concerto con il Ministro dell'economia e delle finanze. All'incremento derivante dall'attuazione del presente comma non si applicano le disposizioni del comma 373.

367. Con il decreto del Presidente del Consiglio dei ministri di cui al comma 365 del presente articolo si provvede ad aggiornare i criteri di determinazione degli oneri di cui al decreto del Presidente del Consiglio dei ministri 18 aprile 2016, pubblicato nella Gazzetta Ufficiale n. 132 dell'8 giugno 2016, in coerenza con quanto previsto dalla lettera a) del medesimo comma 365.

368. All'articolo 4, comma 4, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, la parola: «2016» e' sostituita dalla seguente: «2017». Sono altresi' prorogate, fino al 31 dicembre 2017, le graduatorie vigenti del personale dei corpi di cui all'articolo 66, comma 9-bis, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e la graduatoria vigente del concorso a 814 posti di vigile del fuoco, bandito con decreto del Ministero dell'interno 6 novembre 2008, pubblicato nella Gazzetta Ufficiale, 4ª serie speciale, n. 90 del 18 novembre 2008, che e' prorogata fino al 31 dicembre 2018.

369. All'articolo 1, comma 466, della legge 28 dicembre 2015, n. 208, dopo le parole: «30 marzo 2001, n. 165,» sono inserite le seguenti: «e per i miglioramenti economici del personale dipendente dalle amministrazioni statali in regime di diritto pubblico,» e sono soppresse le parole da: «, di cui 74 milioni» fino alla fine del comma.

370. Per gli enti di cui al decreto legislativo 30 giugno 1994, n. 509, e al decreto legislativo 10 febbraio 1996, n. 103, che non hanno assolto per gli anni 2011-2014 ai vincoli in materia di personale ai sensi dell'articolo 9, comma 1, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, il riversamento di cui all'articolo 1, comma 417, della legge 27 dicembre 2013, n. 147, per l'anno 2017, e' pari al 16 per cento e soddisfa gli obblighi di cui al predetto articolo 9.

371. La dotazione del Fondo per le misure anti-tratta di cui all'articolo 12 della legge 11 agosto 2003, n. 228, e' incrementata di 5 milioni di euro per l'anno 2017.

372. Nelle more della conclusione dei processi di mobilita' di cui all'articolo 1, comma 425, della legge 23 dicembre 2014, n. 190, e nel limite delle risorse disponibili a legislazione vigente, il Ministero della giustizia, per il triennio 2017-2019, e' autorizzato ad assumere con contratto di lavoro a tempo indeterminato un contingente di personale amministrativo non dirigenziale per un massimo di 1.000 unita' da inquadrare nei ruoli dell'Amministrazione giudiziaria, nei limiti delle dotazioni organiche, mediante procedure concorsuali pubbliche ed eventualmente anche mediante l'utilizzo di graduatorie in corso di validita' alla data di entrata in vigore della presente legge.

373. L'incremento della dotazione dell'organico dell'autonomia di cui al comma 366 avviene in misura corrispondente ad una quota di posti derivante, in applicazione dei vigenti ordinamenti didattici e quadri orari, dall'accorpamento degli spezzoni di orario aggregabili fino a formare una cattedra o un posto interi, anche costituiti tra piu' scuole. La predetta quota di posti viene sottratta in misura numericamente pari dal contingente previsto in organico di fatto all'articolo 1, comma 69, della legge 13 luglio 2015, n. 107.

374. Resta fermo quanto previsto dai regolamenti adottati con decreto del Presidente della Repubblica 20 marzo 2009, n. 81, sulla formazione e costituzione delle classi e sull'utilizzo del personale, e con decreto del Presidente della Repubblica 14 febbraio 2016, n. 19, sulla razionalizzazione ed accorpamento delle classi di concorso, tenuto conto del mantenimento delle economie previste dall'articolo 64 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133.

375. L'articolo 1, comma 131, della legge 13 luglio 2015, n. 107, si interpreta nel senso che i contratti di cui tenere conto per il computo della durata complessiva del servizio gia' maturato sono quelli sottoscritti a decorrere dal 1º settembre 2016.

376. Il fondo di cui all'articolo 1, comma 132, della legge 13 luglio 2015, n. 107, e' rifinanziato nella misura di 2 milioni di euro per ciascuno degli anni dal 2017 al 2019.

377. Al fine di assicurare, anche in relazione alle straordinarie esigenze di prevenzione e contrasto della criminalita' e del terrorismo e alle ulteriori esigenze connesse allo svolgimento del prossimo vertice tra i sette maggiori Paesi industrializzati (G7), la prosecuzione degli interventi di cui all'articolo 24, commi 74 e 75, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, nonche' di quelli previsti dall'articolo 3, comma 2, del decreto-legge 10 dicembre 2013, n. 136, convertito, con modificazioni, dalla legge 6 febbraio 2014, n. 6, e' prorogato fino al 31 dicembre 2017, limitatamente ai servizi di vigilanza di siti e obiettivi sensibili, l'impiego di un contingente pari a 7.050 unita' di personale delle Forze armate. Si applicano le disposizioni di cui all'articolo 7-bis, commi 1, 2 e 3, del decreto-legge 23 maggio 2008, n. 92, convertito, con modificazioni, dalla legge 24 luglio 2008, n. 125. Per l'attuazione del presente comma e' autorizzata la spesa di euro 123.000.000 per l'anno 2017, con specifica destinazione di euro 120.536.797 per il personale di cui al comma 74 e di euro 2.463.203 per il personale di cui al comma 75 dell'articolo 24 del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102. (6)

378. Al fine di sostenere le prospettive di crescita del settore aereo e di ridurre gli oneri a carico dei passeggeri, l'incremento dell'addizionale comunale sui diritti di imbarco stabilita ai sensi dell'articolo 13, comma 23, del decreto-legge 23 dicembre 2013, n. 145, convertito, con modificazioni, dalla legge 21 febbraio 2014, n. 9, e' soppresso a decorrere dal 1º gennaio 2017. Al ristoro della diminuzione di entrate derivante all'INPS dal primo periodo del presente comma provvede il Ministero del lavoro e delle politiche sociali, nel cui stato di previsione e' iscritto l'importo di 184 milioni di euro annui per ciascuno degli anni 2017 e 2018.

379. Al comma 1 dell'articolo 1 del decreto-legge 29 marzo 2016, n. 42, convertito, con modificazioni, dalla legge 26 maggio 2016, n. 89, le parole: «30 novembre 2016» sono sostituite dalle seguenti: «31 agosto 2017» e dopo le parole: «per l'anno 2016» sono aggiunte le seguenti: «e di 128 milioni di euro per l'anno 2017».

380. Al comma 1 dell'articolo 2 del decreto-legge 7 aprile 2014, n. 58, convertito, con modificazioni, dalla legge 5 giugno 2014, n. 87, le parole: «e comunque fino a non oltre il 31 dicembre 2016» sono sostituite dalle seguenti: «e comunque fino a non oltre il 31 agosto 2017».

381. Per l'attuazione degli interventi relativi all'organizzazione e allo svolgimento del vertice tra i sette maggiori Paesi industrializzati (G7), anche per adeguamenti di natura infrastrutturale e per le esigenze di sicurezza, e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo da trasferire alla Presidenza del Consiglio dei ministri. Per le finalita' di cui al primo periodo e' autorizzata la spesa di 45 milioni di euro per l'anno 2017.

382. All'articolo 12 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, sono apportate le seguenti modificazioni:

- a) al comma 15, le parole: «ovvero partecipare alla definizione, realizzazione ed utilizzo dell'infrastruttura nazionale per l'interoperabilita' per il FSE conforme ai criteri stabiliti dai decreti di cui al comma 7, resa disponibile dall'Agenzia per l'Italia digitale» sono sostituite dalle seguenti: «ovvero utilizzare l'infrastruttura nazionale di cui al comma 15-ter, da rendere conforme ai criteri stabiliti dai decreti di cui al comma 7»;
- b) il comma 15-ter e' sostituito dal seguente: «15-ter. Ferme restando le funzioni del Commissario straordinario per l'attuazione dell'Agenda digitale di cui all'articolo 63 del decreto legislativo 26 agosto 2016, n. 179, l'Agenzia per l'Italia digitale, sulla base delle esigenze avanzate dalle regioni e dalle province autonome, nell'ambito dei rispettivi piani, cura, in accordo con il Ministero della salute e il Ministero dell'economia e delle finanze e con le regioni e le province autonome, la progettazione dell'infrastruttura nazionale necessaria a garantire l'interoperabilita' dei FSE, la cui realizzazione e' curata dal Ministero dell'economia e delle finanze attraverso l'utilizzo dell'infrastruttura del Sistema Tessera sanitaria realizzato in attuazione dell'articolo 50 del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, e del decreto del Ministero dell'economia e delle finanze 2 novembre 2011, pubblicato nella Gazzetta Ufficiale n. 264 del 12 novembre 2011, garantendo: 1) l'interoperabilita' dei FSE e dei dossier farmaceutici regionali; 2) l'identificazione dell'assistito, attraverso l'allineamento con l'Anagrafe nazionale degli assistiti (ANA), di cui all'articolo 62-ter del codice di cui al decreto legislativo 7 marzo 2005, n. 82, istituita nell'ambito del Sistema Tessera sanitaria. Nelle more della realizzazione dell'ANA, l'identificazione dell'assistito e' assicurata attraverso l'allineamento con l'elenco degli assistiti gestito dal Sistema Tessera sanitaria, ai sensi dell'articolo 50 del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326; 3) per le regioni e province autonome che, entro il 31 marzo 2017, comunicano al Ministero dell'economia e delle finanze e al Ministero della salute di volersi avvalere dell'infrastruttura nazionale ai sensi del comma 15, l'interconnessione dei soggetti di cui al presente articolo per la trasmissione telematica dei dati di cui ai decreti attuativi del comma 7, ad esclusione dei dati di cui al comma 15-septies, per la successiva alimentazione e consultazione del FSE da parte delle medesime regioni e province autonome, secondo le modalita' da stabilire con decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero della salute; 4) a partire dal 30 aprile 2017, la gestione delle codifiche nazionali e regionali stabilite dai decreti di cui al comma 7, rese disponibili dalle amministrazioni ed enti che le detengono, secondo le modalita' da stabilire con decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero della salute»;
- c) al comma 15-quater, le parole: «e il Ministero della salute» sono sostituite dalle seguenti: «, il Ministero della salute e il Ministero dell'economia e delle finanze» e sono aggiunte, in fine, le seguenti parole: «, congiuntamente con il Tavolo tecnico per la verifica degli adempimenti di cui all'articolo 12 della predetta intesa del 23 marzo 2005»;
- d) dopo il comma 15-quinquies sono aggiunti i seguenti: «15-sexies. Qualora la regione, sulla base della valutazione del Comitato e del Tavolo tecnico di cui al comma 15-quater, non abbia adempiuto nei termini previsti dal medesimo comma 15-quater, il Presidente del Consiglio dei ministri, su proposta del Ministro della salute di concerto con il Ministro dell'economia e delle finanze, sentita l'Agenzia per l'Italia digitale, diffida la regione ad adempiere entro i successivi trenta giorni. Qualora, sulla base delle valutazioni operate dai medesimi Comitato e Tavolo tecnico, la regione non abbia adempiuto, il Presidente della regione, nei successivi trenta giorni in qualita' di commissario ad acta, adotta gli atti necessari all'adempimento e ne da' comunicazione alla Presidenza del Consiglio dei ministri e ai citati Comitato e Tavolo tecnico. 15-septies. Il Sistema Tessera sanitaria realizzato in attuazione dell'articolo 50 del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, entro il 30 aprile 2017, rende disponibile ai FSE e ai dossier farmaceutici regionali, attraverso l'infrastruttura nazionale di cui al comma 15-ter, i dati risultanti negli archivi del medesimo Sistema Tessera sanitaria relativi alle esenzioni dell'assistito, alle prescrizioni e prestazioni erogate di farmaceutica e specialistica a carico del Servizio sanitario nazionale, ai certificati di malattia telematici e alle prestazioni di assistenza protesica, termale e integrativa».

383. Per l'attuazione del comma 15-ter dell'articolo 12 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, come modificato dal comma 382 del presente articolo, e' autorizzata la spesa di 2,5 milioni di euro annui a decorrere dall'anno 2017.

384. L'autorizzazione di spesa di cui all'articolo 12, comma 15-quinquies, del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, e' ridotta di 5 milioni di euro per l'anno 2017, di 4,92 milioni di euro per l'anno 2018 e di 5 milioni di euro annui a decorrere dall'anno 2019.

385. Ferme restando le disposizioni inerenti all'accesso alla quota premiale del Servizio sanitario nazionale di cui all'articolo 15, comma 24, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, nonche' le disposizioni in materia di piani di rientro, di cui all'articolo 2, commi da 77 a 97, della legge 23 dicembre 2009, n. 191, al fine di promuovere e conseguire una maggiore efficienza ed efficacia dei servizi sanitari regionali, in coerenza con gli obiettivi di crescita e di sviluppo del Servizio sanitario nazionale, la quota di premialita' di cui all'articolo 2, comma 68, lettera c), della legge 23 dicembre 2009, n. 191, e' incrementata, a livello sperimentale per l'anno 2017, di una quota pari allo 0,1 per cento del livello del finanziamento del Servizio sanitario nazionale. Sempre a livello sperimentale per l'anno 2017, ogni regione puo' proporre al Comitato paritetico permanente per la verifica dell'erogazione dei Livelli Essenziali di Assistenza, di seguito denominato «Comitato LEA», di cui all'articolo 9 dell'intesa tra lo Stato, le regioni e le province autonome di Trento e di Bolzano del 23 marzo 2005, pubblicata nel supplemento ordinario alla Gazzetta Ufficiale n. 105 del 7 maggio 2005, un programma di miglioramento e riqualificazione di determinate aree del servizio sanitario regionale, anche sulla base delle valutazioni operate dal Comitato stesso in ordine all'erogazione dei Livelli Essenziali di Assistenza (LEA) e tenuto conto delle valutazioni del sistema di garanzia di cui all'articolo 9 del decreto legislativo 18 febbraio 2000, n. 56.

386. I programmi di cui al comma 385, di durata annuale, da presentare entro due mesi dalla data di entrata in vigore della presente legge e da approvare entro i successivi trenta giorni da parte del Comitato LEA, individuano aree prioritarie d'intervento specifiche di ciascun contesto regionale, definendo i relativi indicatori di valutazione. Per le regioni sottoposte a piano di rientro, tali programmi integrano, ove necessario, il programma operativo di prosecuzione del piano di rientro e sono approvati dal Comitato LEA congiuntamente con il Tavolo tecnico per la verifica degli adempimenti di cui all'articolo 12 dell'intesa tra lo Stato, le regioni e le province autonome di Trento e di Bolzano del 23 marzo 2005.

387. I programmi di cui al comma 385 recano altresi':

- a) le modalita' e i tempi per la verifica della realizzazione degli obiettivi indicati;
- b) le forme di monitoraggio degli obiettivi intermedi e finali da effettuare da parte del Comitato LEA e, per le regioni sottoposte a piano di rientro, da parte del Comitato LEA congiuntamente con il Tavolo tecnico per la verifica degli adempimenti.

388. Con accordo da sancire, entro il 31 gennaio 2017, in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, sono disciplinate le modalita' di riparto tra le regioni dell'incremento sperimentale della quota di premialita' per il 2017 di cui al comma 385 e l'accesso alle forme premiali in attuazione dei programmi di cui al medesimo comma. La mancata presentazione del programma ovvero la verifica negativa annuale dell'attuazione del programma medesimo determina, per la regione interessata, la perdita, per il medesimo anno 2017, del diritto di accesso alla quota prevista. Le somme eventualmente rese disponibili in conseguenza dell'applicazione della disposizione del periodo precedente sono integralmente riattribuite alle restanti regioni in maniera proporzionale all'accesso previsto.

389. Il Comitato LEA redige una relazione in ordine all'attivita' sperimentale di cui ai commi da 385 a 388.

390. Al fine di migliorare le performance e di perseguire l'efficienza dei fattori produttivi e dell'allocazione delle risorse delle aziende ospedaliere, delle aziende ospedaliere universitarie, degli Istituti di ricovero e cura a carattere scientifico pubblici o degli altri enti pubblici che erogano prestazioni di ricovero e cura, all'articolo 1, comma 524, lettera a), della legge 28 dicembre 2015, n. 208, le parole: «pari o superiore al 10 per cento dei suddetti ricavi, o, in valore assoluto, pari ad almeno 10 milioni di euro» sono sostituite dalle seguenti: «pari o superiore al 7 per cento dei suddetti ricavi, o, in valore assoluto, pari ad almeno 7 milioni di euro».

391. Le disposizioni di cui ai commi da 524 a 536 dell'articolo 1 della legge 28 dicembre 2015, n. 208, si applicano alle regioni a statuto speciale e alle province autonome di Trento e di Bolzano, che provvedono al finanziamento del servizio sanitario esclusivamente con risorse dei propri bilanci, compatibilmente con le disposizioni dei rispettivi statuti e delle conseguenti norme di attuazione.

392. Per gli anni 2017 e 2018, il livello del finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato, indicato dall'intesa sancita in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano dell'11 febbraio 2016 (Rep. Atti n. 21/CSR), in attuazione dell'articolo 1, comma 680, della legge 28 dicembre 2015, n. 208, e' rideterminato rispettivamente in 113.000 milioni di euro e in 114.000 milioni di euro. Per l'anno 2019 il livello del finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato e' stabilito in 115.000 milioni di euro. Le regioni a statuto speciale e le province autonome di Trento e di Bolzano assicurano gli effetti finanziari previsti dal presente comma, mediante la sottoscrizione di singoli accordi con lo Stato, da stipulare entro il 31 gennaio 2017. Per la regione Trentino-Alto Adige e per le province autonome di Trento e di Bolzano l'applicazione del presente comma avviene nel rispetto dell'accordo sottoscritto tra il Governo e i predetti enti in data 15 ottobre 2014 e recepito con legge 23 dicembre 2014, n. 190, con il concorso agli obiettivi di finanza pubblica previsto dai commi da 406 a 413 dell'articolo 1 della medesima legge.

393. A decorrere dall'anno 2017 una quota del livello del finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato ai sensi del comma 392, pari a 1.000 milioni di euro, e' destinata alle finalita' di cui ai commi 401, 408 e 409.

394. Con i medesimi accordi di cui al comma 392 le regioni a statuto speciale assicurano il contributo a loro carico previsto dall'intesa dell'11 febbraio 2016; decorso il termine del 31 gennaio 2017, all'esito degli accordi sottoscritti, il Ministro dell'economia e delle finanze, di concerto con il Ministro della salute, entro i successivi trenta giorni, con proprio decreto attua quanto previsto per gli anni 2017 e successivi dalla citata intesa dell'11 febbraio 2016, al fine di garantire il conseguimento dell'obiettivo programmatico di finanza pubblica per il settore sanitario.

395. PERIODO SOPPRESSO DAL D.L. 23 OTTOBRE 2018, N. 119, CONVERTITO CON MODIFICAZIONI DALLA L. 17 DICEMBRE 2018, N. 136. Il Comitato e il Tavolo tecnico di cui rispettivamente agli articoli 9 e 12 dell'intesa tra lo Stato, le regioni e le province autonome di Trento e di Bolzano del 23 marzo 2005, con cadenza semestrale, in occasione delle periodiche riunioni di verifica, predispongono, per le regioni commissariate ai sensi dell'articolo 4, comma 2, del decreto-legge 1° ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, una relazione ai Ministri della salute e dell'economia e delle finanze, da trasmettere al Consiglio dei ministri, con particolare riferimento al monitoraggio dell'equilibrio di bilancio e dell'erogazione dei livelli essenziali di assistenza, anche al fine delle determinazioni di cui all'articolo 2, comma 84, della legge 23 dicembre 2009, n. 191. (30)

396. Il comma 570 dell'articolo 1 della legge 23 dicembre 2014, n. 190, e' abrogato.

397. In considerazione di quanto previsto dall'articolo 21, comma 1, del decreto-legge 24 giugno 2016, n. 113, convertito, con modificazioni, dalla legge 7 agosto 2016, n. 160, e di quanto convenuto nell'intesa sancita in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano il 2 luglio 2015 (Rep. Atti n. 113/CSR), fermi restando gli equilibri di finanza pubblica previsti a legislazione vigente, al governo del settore farmaceutico si applicano i commi da 398 a 407 del presente articolo.

398. A decorrere dall'anno 2017, il tetto della spesa farmaceutica ospedaliera di cui all'articolo 5, comma 5, del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, e' calcolato al lordo della spesa per i farmaci di classe A in distribuzione diretta e distribuzione per conto, ed e' rideterminato nella misura del 6,89 per cento. Conseguentemente il tetto della spesa farmaceutica ospedaliera assume la denominazione di «tetto della spesa farmaceutica per acquisti diretti». (38) (50) (61)

399. Ai sensi e per gli effetti di quanto previsto dal comma 398 del presente articolo, il tetto della spesa farmaceutica territoriale, di cui all'articolo 5 del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, e' rideterminato nella misura del 7,96 per cento. Conseguentemente il tetto della spesa farmaceutica territoriale assume la denominazione di «tetto della spesa farmaceutica convenzionata». (38)

400. COMMA ABROGATO DAL D.L. 25 MAGGIO 2021, N. 73, CONVERTITO, CON MODIFICAZIONI DALLA L. 23 LUGLIO 2021, N. 106.

401. A decorrere dal 1° gennaio 2022, nello stato di previsione del Ministero dell'economia e delle finanze e' istituito un Fondo, con una dotazione di 1.000 milioni di euro annui, per il concorso al rimborso alle regioni delle spese sostenute per l'acquisto dei farmaci innovativi. Resta ferma la competenza del Ministero della salute a disciplinare le modalita' operative di erogazione delle risorse stanziate, sulla base dei criteri stabiliti con il decreto adottato ai sensi del comma 405. (42) (50)

401-bis. Il Fondo di cui al comma 401 e' finanziato, per 664 milioni di euro annui, mediante utilizzo delle risorse del comma 393 e, per 336 milioni di euro annui, mediante utilizzo delle risorse destinate alla realizzazione di specifici obiettivi del Piano sanitario nazionale, ai sensi dell'articolo 1, comma 34, della legge 23 dicembre 1996, n. 662.

402. Per gli effetti di quanto previsto al comma 401, con determinazione del direttore generale dell'Agenzia italiana del farmaco (AIFA), previo parere della Commissione consultiva tecnico-scientifica, da adottare entro il 31 marzo 2017, sono stabiliti i criteri per la classificazione dei farmaci innovativi e a innovativita' condizionata e dei farmaci oncologici innovativi. Con la medesima determinazione sono definite le modalita' per la valutazione degli effetti dei predetti farmaci ai fini della permanenza del requisito di innovativita' e le modalita' per la eventuale riduzione del prezzo di rimborso a carico del Servizio sanitario nazionale. Nelle more dell'adozione della determinazione di cui al presente comma e comunque entro e non oltre il 31 marzo 2017, i farmaci innovativi e i farmaci oncologici innovativi validi ai fini della presente procedura sono quelli gia' individuati dall'AIFA.

402-bis. I farmaci, ivi compresi quelli oncologici, per i quali e' stato riconosciuto, da parte dell'Aifa, il possesso del requisito dell'innovativita' condizionata, sono inseriti esclusivamente nei prontuari terapeutici regionali di cui all'articolo 10, commi 2 e 3, del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189, e non accedono alle risorse di cui al Fondo previsto al comma 401 per un periodo massimo di diciotto mesi. Le risorse del Fondo di cui al comma 401 non impiegate per le finalita' ivi indicate confluiscono nella quota di finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato ai sensi del comma 392.

403. Il requisito di innovativita' permane per un periodo massimo di 36 mesi.

404. I farmaci di cui al comma 402 sono soggetti a monitoraggio dei registri AIFA.

405. Le risorse del Fondo di cui al comma 401 sono versate in favore delle regioni in proporzione alla spesa sostenuta dalle regioni medesime per l'acquisto dei medicinali di cui al citato comma 401, secondo le modalita' individuate con apposito decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano.

406. La spesa per l'acquisto dei farmaci innovativi e dei farmaci oncologici innovativi concorre al raggiungimento del tetto della spesa farmaceutica per acquisti diretti di cui al comma 398 per l'ammontare eccedente annualmente l'importo del Fondo di cui al comma 401.

407. All'articolo 15 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dopo il comma 11-ter e' inserito il seguente: «11-quater. L'esistenza di un rapporto di biosimilarita' tra un farmaco biosimilare e il suo biologico di riferimento sussiste solo ove accertato dalla European Medicine Agency (EMA) o dall'Agenzia italiana del farmaco, tenuto conto delle rispettive competenze. Non e' consentita la sostituibilita' automatica tra farmaco biologico di riferimento e un suo biosimilare ne' tra biosimilari. Nelle procedure pubbliche di acquisto per i farmaci biosimilari non possono essere posti in gara nel medesimo lotto principi attivi differenti, anche se aventi le stesse indicazioni terapeutiche. Al fine di razionalizzare la spesa per l'acquisto di farmaci biologici a brevetto scaduto e per i quali siano presenti sul mercato i relativi farmaci biosimilari, si applicano le seguenti disposizioni: a) le procedure pubbliche di acquisto devono svolgersi mediante utilizzo di accordi-quadro con tutti gli operatori economici quando i medicinali sono piu' di tre a base del medesimo principio attivo. A tal fine le centrali regionali d'acquisto predispongono un lotto unico per la costituzione del quale si devono considerare lo specifico principio attivo (ATC di V livello), i medesimi dosaggio e via di somministrazione; b) al fine di garantire un'effettiva razionalizzazione della spesa e nel contempo un'ampia disponibilita' delle terapie, i pazienti devono essere trattati con uno dei primi tre farmaci nella graduatoria dell'accordo-quadro, classificati secondo il criterio del minor prezzo o dell'offerta economicamente piu' vantaggiosa. Il medico e' comunque libero di prescrivere il farmaco, tra quelli inclusi nella procedura di cui alla lettera a), ritenuto idoneo a garantire la continuita' terapeutica ai pazienti; c) in caso di scadenza del brevetto o del certificato di protezione complementare di un farmaco biologico durante il periodo di validita' del contratto di fornitura, l'ente appaltante, entro sessanta giorni dal momento dell'immissione in commercio di uno o piu' farmaci biosimilari contenenti il medesimo principio attivo, apre il confronto concorrenziale tra questi e il farmaco originatore di riferimento nel rispetto di quanto prescritto dalle lettere a) e b); d) l'ente appaltante e' tenuto ad erogare ai centri prescrittori i prodotti aggiudicati con le procedure previste dal decreto legislativo 18 aprile 2016, n. 50; e) eventuali oneri economici aggiuntivi, derivanti dal mancato rispetto delle disposizioni del presente comma, non possono essere posti a carico del Servizio sanitario nazionale».

408. A decorrere dall'anno 2017, nell'ambito del finanziamento del Servizio sanitario nazionale e' prevista una specifica finalizzazione, pari a 100 milioni di euro per l'anno 2017, a 127 milioni di euro per l'anno 2018 e a 186 milioni di euro a decorrere dall'anno 2019, per il concorso al rimborso alle regioni per l'acquisto di vaccini ricompresi nel nuovo piano nazionale vaccini (NPNV) di cui all'intesa sancita in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano il 7 settembre 2016 (Rep. Atti n. 157/CSR). Le somme di cui al presente comma sono ripartite a favore delle regioni sulla base dei criteri individuati con intesa da sancire in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano entro il 31 gennaio 2017.

409. Nel rispetto di quanto previsto dall'articolo 1, comma 541, della legge 28 dicembre 2015, n. 208, a decorrere dall'anno 2017, nell'ambito del finanziamento del Servizio sanitario nazionale e' prevista una specifica finalizzazione, pari a 75 milioni di euro per l'anno 2017 e a 150 milioni di euro a decorrere dall'anno 2018, per il concorso al rimborso alle regioni per gli oneri derivanti dai processi di assunzione e stabilizzazione del personale del Servizio sanitario nazionale da svolgere ai sensi delle disposizioni recate dal primo e secondo periodo del comma 543 del medesimo articolo 1 della legge n. 208 del 2015. Le somme di cui al presente comma sono ripartite a favore delle regioni sulla base dei criteri individuati con intesa da sancire in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano entro il 31 gennaio 2017.

410. Al fine di garantire la continuita' delle attivita' di ricerca, in deroga a quanto disposto dall'articolo 7, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, gli Istituti di ricovero e cura a carattere scientifico e gli Istituti zooprofilattici sperimentali possono continuare ad avvalersi del personale addetto alla ricerca, sia con qualifica di ricercatore, sia con qualifiche afferenti alle professionalita' della ricerca, assunto con contratti flessibili, in servizio presso tali istituti alla data del 31 dicembre 2016.

411. In sede di revisione dei criteri di riparto del Fondo per le non autosufficienze, di cui all'articolo 1, comma 1264, della legge 27 dicembre 2006, n. 296, previsti dall'articolo 1, comma 3, del decreto ministeriale di riparto del Fondo per il 2016 e' compresa la condizione delle persone affette dal morbo di Alzheimer.

412. Ai fini della copertura degli oneri per i rinnovi contrattuali del personale dipendente e convenzionato del Servizio sanitario nazionale, come determinati a seguito dell'aggiornamento dei criteri di cui al comma 367, e' vincolata, a decorrere dalla data di adozione del decreto del Presidente del Consiglio dei ministri di cui al comma 365, una quota del livello del finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato ai sensi del comma 392.

413. Il Ministero dell'economia e delle finanze, nell'ambito del Programma di razionalizzazione degli acquisti della pubblica amministrazione, avvia, tramite la societa' Consip Spa, un'analisi volta ad individuare nuovi strumenti di acquisto centralizzato di beni e correlati servizi, anche mediante modelli organizzativi che prevedano l'acquisizione di beni durevoli e la concessione dell'utilizzo degli stessi da parte delle amministrazioni o dei soggetti pubblici interessati senza che dai suddetti modelli organizzativi derivino discriminazioni o esclusioni per le micro e le piccole imprese.

414. Dalla disposizione di cui al comma 413 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

415. COMMA ABROGATO DAL D.L. 6 NOVEMBRE 2021, N. 152, CONVERTITO CON MODIFICAZIONI DALLA L. 29 DICEMBRE 2021, N. 233.

416. COMMA ABROGATO DAL D.L. 6 NOVEMBRE 2021, N. 152, CONVERTITO CON MODIFICAZIONI DALLA L. 29 DICEMBRE 2021, N. 233.

417. COMMA ABROGATO DAL D.L. 6 NOVEMBRE 2021, N. 152, CONVERTITO CON MODIFICAZIONI DALLA L. 29 DICEMBRE 2021, N. 233.

418. Dalle disposizioni di cui ai commi da 415 a 417 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

419. All'articolo 1 della legge 28 dicembre 2015, n. 208, sono apportate le seguenti modificazioni:

- a) al comma 512, le parole: «provvedono ai propri approvvigionamenti esclusivamente tramite Consip SpA o i soggetti aggregatori» sono sostituite dalle seguenti: «provvedono ai propri approvvigionamenti esclusivamente tramite gli strumenti di acquisto e di negoziazione di Consip Spa o dei soggetti aggregatori»;
- b) dopo il comma 514 e' inserito il seguente: «514-bis. Per i beni e servizi la cui acquisizione riveste particolare rilevanza strategica secondo quanto indicato nel Piano triennale di cui al comma 513, le amministrazioni statali, centrali e periferiche, ad esclusione degli istituti e delle scuole di ogni ordine e grado, delle istituzioni educative e delle istituzioni universitarie, nonche' gli enti nazionali di previdenza ed assistenza sociale pubblici e le agenzie fiscali di cui al decreto legislativo 30 luglio 1999, n. 300, ricorrono a Consip Spa, nell'ambito del Programma di razionalizzazione degli acquisti della pubblica amministrazione del Ministero dell'economia e delle finanze. A tal fine Consip Spa puo' supportare i soggetti di cui al periodo precedente nell'individuazione di specifici interventi di semplificazione, innovazione e riduzione dei costi dei processi amministrativi. Per le attivita' di cui al presente comma e' previsto un incremento delle dotazioni destinate al finanziamento del Programma di razionalizzazione degli acquisti della pubblica amministrazione del Ministero dell'economia e delle finanze pari a euro 3.000.000 per l'anno 2017 e a euro 7.000.000 a decorrere dal 2018»;
- c) al comma 515, dopo le parole: «di cui al comma 513,» sono inserite le seguenti: «compresa quella relativa alle acquisizioni di particolare rilevanza strategica di cui al comma 514-bis,».

420. All'articolo 9 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, dopo il comma 2 e' inserito il seguente: «2-bis. Nell'ambito del Tavolo tecnico dei soggetti aggregatori opera un Comitato guida, disciplinato dal decreto del Presidente del Consiglio dei ministri di cui al comma 2, il quale, oltre ai compiti previsti dal medesimo decreto, fornisce attraverso linee guida indicazioni utili per favorire lo sviluppo delle migliori pratiche con riferimento alle procedure di cui al comma 3 da parte dei soggetti aggregatori di cui ai commi 1 e 2, ivi inclusa la determinazione delle fasce di valori da porre a base d'asta e delle modalita' per non discriminare o escludere le micro e le piccole imprese. I soggetti aggregatori di cui ai commi 1 e 2 trasmettono al Comitato guida, nel caso di non allineamento alle linee guida di cui al periodo precedente, una preventiva comunicazione specificamente motivata sulla quale il Comitato guida puo' esprimere proprie osservazioni».

421. All'articolo 9 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, dopo il comma 3 e' inserito il seguente: «3-bis. Le amministrazioni pubbliche obbligate a ricorrere a Consip Spa o agli altri soggetti aggregatori ai sensi del comma 3 possono procedere, qualora non siano disponibili i relativi contratti di Consip Spa o dei soggetti aggregatori di cui ai commi 1 e 2 e in caso di motivata urgenza, allo svolgimento di autonome procedure di acquisto dirette alla stipula di contratti aventi durata e misura strettamente necessaria. In tale caso l'Autorita' nazionale anticorruzione rilascia il codice identificativo di gara (CIG)».

422. All'articolo 9, comma 9, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, sono aggiunte, in fine, le seguenti parole: «, che tengono conto anche dell'allineamento, da parte dei soggetti aggregatori di cui ai commi 1 e 2, delle indicazioni del Comitato guida fornite ai sensi del comma 2-bis del presente articolo».

423. Con Accordo da sancire in sede di Conferenza permanente tra lo Stato, le regioni e le province autonome di Trento e di Bolzano entro il 28 febbraio 2017 sono definite le attivita' da porre in essere per pervenire alla definizione di linee di indirizzo per l'efficientamento e la definizione di standard con riferimento ai magazzini e alla logistica distributiva, alle tecnologie dell'informazione e della comunicazione nonche' alle politiche e ai processi di gestione delle risorse umane.

424. L'obbligo di approvazione del programma biennale degli acquisti di beni e servizi, di cui all'articolo 21 del decreto legislativo 18 aprile 2016, n. 50, in deroga alla vigente normativa sugli allegati al bilancio degli enti locali, stabilita dal testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e dal decreto legislativo 23 giugno 2011, n. 118, si applica a decorrere dal bilancio di previsione per l'esercizio finanziario 2018.

425. Con decreto del Presidente del Consiglio dei ministri, su proposta dei Ministri competenti, di concerto con il Ministro dell'economia e delle finanze, le riduzioni di spesa apportate con la presente legge, quale concorso dei Ministeri agli obiettivi di finanza pubblica, possono essere rimodulate nell'ambito dei pertinenti stati di previsione della spesa, fermo restando il conseguimento dei risparmi di spesa realizzati in termini di indebitamento netto della pubblica amministrazione.

426. All'articolo 1, comma 624, della legge 28 dicembre 2015, n. 208, sono apportate le seguenti modificazioni:

- a) le parole: «ed euro 10 milioni per ciascuno degli anni 2017 e 2018» sono sostituite dalle seguenti: «, euro 26 milioni per ciascuno degli anni 2017 e 2018 ed euro 16 milioni per l'anno 2019»;
- b) e' aggiunto, in fine, il seguente periodo: «Nelle more del versamento delle predette risorse all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per gli anni 2017, 2018 e 2019, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale, a valere sulle disponibilita' di cui all'articolo 18, comma 2, lettera c), della legge 11 agosto 2014, n. 125, la somma di 26 milioni di euro per ciascuno degli anni 2017 e 2018 e di 16 milioni di euro per l'anno 2019, al netto di quanto effettivamente versato per ciascun anno del triennio 2017-2019».

427. All'articolo 1, comma 623, della legge 28 dicembre 2015, n. 208, le parole: «per ciascuno degli anni dal 2016 al 2018» sono sostituite dalle seguenti: «a decorrere dal 2016».

428. Le maggiori entrate accertate e riscosse dagli uffici all'estero del Ministero degli affari esteri e della cooperazione internazionale, rispetto all'esercizio finanziario 2014, derivanti dall'applicazione della tariffa dei diritti consolari di cui al decreto legislativo 3 febbraio 2011, n. 71, e dall'articolo 41-bis, comma 1, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, pari a 4 milioni di euro a decorrere dal 2017, rimangono acquisite all'entrata e non si applicano le disposizioni di cui all'articolo 1, comma 568, della legge 27 dicembre 2006, n. 296, nonche' all'articolo 2, comma 58, della legge 24 dicembre 2007, n. 244, e all'articolo 41-bis, comma 2, del citato decreto-legge 22 giugno 2012, n. 83. Nelle more del versamento delle predette risorse all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile a decorrere dal 2017, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale, a valere sulle disponibilita' di cui all'articolo 18, comma 2, lettera c), della legge 11 agosto 2014, n. 125, la somma di 4 milioni di euro al netto di quanto effettivamente versato in ciascun anno dal 2017.

429. COMMA ABROGATO DALLA L. 30 DICEMBRE 2024, N. 207.

430. Il finanziamento di cui all'articolo 18, comma 2, lettera c), della legge 11 agosto 2014, n. 125, e' ridotto di 0,8 milioni di euro per l'anno 2017 e di 3 milioni di euro annui a decorrere dall'anno 2018.

431. A decorrere dall'anno 2017 i benefici di cui all'articolo 6 del decreto-legge 30 dicembre 1997, n. 457, convertito, con modificazioni, dalla legge 27 febbraio 1998, n. 30, sono corrisposti nel limite del 48,7 per cento.

432. Ai fini della razionalizzazione della spesa del Ministero dei beni e delle attivita' culturali e del turismo e dell'efficientamento delle modalita' di bigliettazione degli istituti e luoghi della cultura di rilevante interesse nazionale, le Soprintendenze speciali di cui all'articolo 30, comma 2, lettera a), del regolamento di cui al decreto del Presidente del Consiglio dei ministri 29 agosto 2014, n. 171, si adeguano, senza nuovi o maggiori oneri per la finanza pubblica, agli standard internazionali in materia di musei e luoghi della cultura, di cui all'articolo 14 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106. Entro trenta giorni dalla data di entrata in vigore della presente legge sono apportate, con le modalita' di cui all'articolo 1, comma 327, della legge 28 dicembre 2015, n. 208, le necessarie modificazioni al decreto del Ministro dei beni e delle attivita' culturali e del turismo 23 gennaio 2016, pubblicato nella Gazzetta Ufficiale n. 59 dell'11 marzo 2016, nei limiti delle dotazioni organiche del Ministero dei beni e delle attivita' culturali e del turismo, di cui alle tabelle A e B allegate al citato regolamento di cui al decreto del Presidente del Consiglio dei ministri n. 171 del 2014.

433. Nello stato di previsione della spesa del Ministero dell'economia e delle finanze e' istituito un fondo, denominato «Fondo da ripartire per il finanziamento di interventi a favore degli Enti territoriali solo in termini di saldo netto da finanziare», alimentato dalle seguenti risorse:

- a) le risorse in conto residui di cui al comma 13 dell'articolo 11 del decreto-legge 28 giugno 2013, n. 76, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 99, non erogate alla data di entrata in vigore della presente legge;
- b) le risorse in conto residui di cui all'articolo 2 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi modificazioni e rifinanziamenti, ivi comprese le somme di cui al comma 2 dell'articolo 8 del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, non erogate alla data di entrata in vigore della presente legge;
- c) le risorse in conto residui di cui all'articolo 3 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e rifinanziamenti, ivi comprese le quote funzionali all'attuazione dell'articolo 35 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, non erogate alla data di entrata in vigore della presente legge;
- d) le somme disponibili sulla contabilita' speciale di cui all'articolo 45, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, non utilizzate per le finalita' di cui al medesimo articolo nonche' di cui al comma 2 dell'articolo 11 del decreto-legge 24 giugno 2016, n. 113, convertito, con modificazioni, dalla legge 7 agosto 2016, n. 160, alla data del 31 dicembre 2016.

434. Il comma 714 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' sostituito dal seguente: «714. Fermi restando i tempi di pagamento dei creditori, gli enti locali che hanno presentato il piano di riequilibrio finanziario pluriennale o ne hanno conseguito l'approvazione ai sensi dell'articolo 243-bis del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, prima dell'approvazione del rendiconto per l'esercizio 2014, se alla data della presentazione o dell'approvazione del medesimo piano di riequilibrio finanziario pluriennale non avevano ancora provveduto ad effettuare il riaccertamento straordinario dei residui attivi e passivi di cui all'articolo 3, comma 7, del decreto legislativo 23 giugno 2011, n. 118, possono rimodulare o riformulare il predetto piano, entro il 31 maggio 2017, scorporando la quota di disavanzo risultante dalla revisione straordinaria dei residui di cui all'articolo 243-bis, comma 8, lettera e), limitatamente ai residui antecedenti al 1º gennaio 2015, e ripianando tale quota secondo le modalita' previste dal decreto del Ministero dell'economia e delle finanze 2 aprile 2015, pubblicato nella Gazzetta Ufficiale n. 89 del 17 aprile 2015. La restituzione delle anticipazioni di liquidita' erogate agli enti di cui al periodo precedente, ai sensi degli articoli 243-ter e 243-quinquies del citato testo unico di cui al decreto legislativo n. 267 del 2000, e' effettuata in un periodo massimo di trenta anni decorrente dall'anno successivo a quello in cui e' stata erogata l'anticipazione. A decorrere dalla data di rimodulazione o riformulazione del piano, gli enti di cui ai periodi precedenti presentano alla Commissione di cui all'articolo 155 del medesimo testo unico di cui al decreto legislativo n. 267 del 2000 apposita attestazione del rispetto dei tempi di pagamento di cui alla direttiva 2011/7/UE del Parlamento europeo e del Consiglio, del 16 febbraio 2011».

435. Fermi restando i tempi di pagamento dei creditori, gli enti locali che hanno proceduto alla revisione dei residui, per effetto di espressa pronuncia della Corte dei conti, nel corso degli esercizi 2012, 2013 o 2014, antecedentemente al riaccertamento straordinario di cui all'articolo 3, comma 7, del decreto legislativo 23 giugno 2011, n. 118, determinando un piano triennale di copertura del disavanzo riscontrato, ai sensi dell'articolo 193 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, possono riformulare tale piano, entro il 31 marzo 2017, per la parte non ancora attuata, secondo le modalita' e nell'arco temporale previsti dal decreto del Ministero dell'economia e delle finanze 2 aprile 2015, pubblicato nella Gazzetta Ufficiale n. 89 del 17 aprile 2015. A decorrere dalla data di riformulazione del piano, gli enti di cui al periodo precedente presentano alla sezione regionale della Corte dei conti apposita attestazione del rispetto dei tempi di pagamento di cui alla direttiva 2011/7/UE del Parlamento europeo e del Consiglio, del 16 febbraio 2011.

436. Al comma 9 dell'articolo 243-bis del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, sono apportate le seguenti modificazioni:

- a) le lettere b) e c) sono sostituite dalle seguenti: «b) entro il termine di un quinquennio, riduzione almeno del 10 per cento delle spese per acquisti di beni e prestazioni di servizi di cui al macroaggregato 03 della spesa corrente, finanziate attraverso risorse proprie. Ai fini del computo della percentuale di riduzione, dalla base di calcolo sono esclusi gli stanziamenti destinati: 1) alla copertura dei costi di gestione del servizio di smaltimento dei rifiuti solidi urbani; 2) alla copertura dei costi di gestione del servizio di acquedotto; 3) al servizio di trasporto pubblico locale; 4) al servizio di illuminazione pubblica; 5) al finanziamento delle spese relative all'accoglienza, su disposizione della competente autorita' giudiziaria, di minori in strutture protette in regime di convitto e semiconvitto; c) entro il termine di un quinquennio, riduzione almeno del 25 per cento delle spese per trasferimenti di cui al macroaggregato 04 della spesa corrente, finanziate attraverso risorse proprie. Ai fini del computo della percentuale di riduzione, dalla base di calcolo sono escluse le somme relative a trasferimenti destinati ad altri livelli istituzionali, a enti, agenzie o fondazioni lirico-sinfoniche»;
- b) dopo la lettera c) e' inserita la seguente: «c-bis) ferma restando l'obbligatorieta' delle riduzioni indicate nelle lettere b) e c), l'ente locale ha facolta' di procedere a compensazioni, in valore assoluto e mantenendo la piena equivalenza delle somme, tra importi di spesa corrente, ad eccezione della spesa per il personale e ferme restando le esclusioni di cui alle medesime lettere b) e c) del presente comma. Tali compensazioni sono puntualmente evidenziate nel piano di riequilibrio approvato».

437. Le risorse di cui al comma 433 sono versate all'entrata del bilancio dello Stato nell'anno 2017 per essere riassegnate al Fondo di cui al comma 433. Ciascun ente territoriale beneficiario del Fondo, ai sensi dell'articolo 9, comma 5, della legge 24 dicembre 2012, n. 243, consegue un valore positivo del saldo di cui al comma 466 del presente articolo in misura pari al Fondo stesso.

438. Nello stato di previsione della spesa del Ministero dell'economia e delle finanze e' istituito un fondo, denominato «Fondo da ripartire per il finanziamento di interventi a favore degli Enti territoriali», con una dotazione di 969,6 milioni di euro per ciascuno degli anni dal 2017 al 2026, di 935 milioni di euro per ciascuno degli anni dal 2027 al 2046 e di 925 milioni di euro annui a decorrere dall'anno 2047.

439. I beneficiari, le finalita', i criteri e le modalita' di riparto dei fondi di cui ai commi 433 e 438 sono disciplinati con uno o piu' decreti del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, da adottare entro il 31 gennaio 2017, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

440. All'articolo 7, comma 2, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, le parole: «Per gli anni 2015 e 2016» sono sostituite dalle seguenti: «Per gli anni 2015, 2016 e 2017».

441. Per l'anno 2017 gli enti locali possono realizzare le operazioni di rinegoziazione di mutui di cui all'articolo 1, commi 430 e 537, della legge 23 dicembre 2014, n. 190, anche nel corso dell'esercizio provvisorio di cui all'articolo 163 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, fermo restando l'obbligo, a carico dei medesimi enti, di effettuare le relative iscrizioni nel bilancio di previsione.

442. All'articolo 1, comma 430, della legge 23 dicembre 2014, n. 190, le parole: «negli anni 2015 e 2016» sono sostituite dalle seguenti: «negli anni 2015, 2016 e 2017».

443. I commi 433, 437, 438, 439 e il presente comma entrano in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale.

444. Al comma 6 dell'articolo 16 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, il quarto periodo e' sostituito dai seguenti: «Le riduzioni da applicare a ciascun comune a decorrere dall'anno 2013 sono determinate, con decreto del Ministero dell'interno, d'intesa con la Conferenza Stato-citta' ed autonomie locali. In caso di mancata intesa entro quarantacinque giorni dalla data di prima iscrizione all'ordine del giorno della Conferenza Stato-citta' ed autonomie locali della proposta di riparto delle riduzioni di cui al periodo precedente, il decreto del Ministero dell'interno puo', comunque, essere adottato ripartendo le riduzioni in proporzione alla media delle spese sostenute per consumi intermedi nel triennio 2010-2012, desunte dal SIOPE, fermo restando che la riduzione per abitante di ciascun ente non puo' assumere valore superiore al 250 per cento della media costituita dal rapporto fra riduzioni calcolate sulla base dei dati SIOPE 2010-2012 e la popolazione residente di tutti i comuni, relativamente a ciascuna classe demografica di cui all'articolo 156 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267».

445. All'articolo 1, comma 347, della legge 28 dicembre 2015, n. 208, e' aggiunto, in fine, il seguente periodo: «Alle spese relative al personale assunto con contratto a tempo determinato ai fini dell'attuazione del presente comma, fermo restando il rispetto degli obiettivi di finanza pubblica previsti per gli enti territoriali, fino al 31 dicembre 2019 non si applicano i limiti di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e le vigenti disposizioni in materia di contenimento della spesa di personale».

446. All'articolo 1 della legge 24 dicembre 2012, n. 228, dopo il comma 380-octies e' inserito il seguente: «380-novies. Le disposizioni di cui ai commi da 380 a 380-octies che riguardano i criteri di ripartizione del Fondo di solidarieta' comunale, ad eccezione di quelle di cui al comma 380-ter, lettera a), riguardanti il contributo di 30 milioni di euro annui spettante alle unioni di comuni ai sensi dell'articolo 53, comma 10, della legge 23 dicembre 2000, n. 388, nonche' il contributo di 30 milioni di euro annui destinato, ai sensi dell'articolo 20 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, ai comuni istituiti a seguito di fusione, trovano applicazione sino alla determinazione del Fondo stesso relativo all'anno 2016».

447. All'articolo 20, comma 1-bis, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dopo le parole: «commisurato al 40 per cento dei trasferimenti erariali attribuiti per l'anno 2010,» sono inserite le seguenti: «elevato al 50 per cento a decorrere dall'anno 2017,».

448. La dotazione del Fondo di solidarieta' comunale di cui al comma 380-ter dell'articolo 1 della legge 24 dicembre 2012, n. 228, al netto dell'eventuale quota dell'imposta municipale propria (IMU) di spettanza dei comuni connessa alla regolazione dei rapporti finanziari e' stabilita in euro 6.197.184.364,87 per l'anno 2017, in euro 6.208.184.364,87 per ciascuno degli anni 2018 e 2019, in euro 6.213.684.365 per l'anno 2020, in euro 6.616.513.365 per l'anno 2021, in euro 6.949.513.365 per l'anno 2022, in euro 7.157.513.365 per l'anno 2023, in euro 7.476.513.365 per l'anno 2024, in euro 6.760.590.365 per l'anno 2025, in euro 6.872.590.365 per l'anno 2026, in euro 6.928.590.365 per l'anno 2027, in euro 6.984.590.365 per l'anno 2028, in euro 8.260.590.365 per l'anno 2029, in euro 8.214.594.113 per l'anno 2030 e in euro 8.978.517.113 annui a decorrere dall'anno 2031, di cui 2.768.800.000 assicurata attraverso una quota dell'IMU, di spettanza dei comuni, di cui all'articolo 13 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, eventualmente variata della quota derivante dalla regolazione dei rapporti finanziari connessi con la metodologia di riparto tra i comuni interessati del Fondo stesso. (6) (32)

449. Il Fondo di solidarieta' comunale di cui al comma 448 e':

- a) ripartito, quanto a euro 3.767.450.000 sino all'anno 2019 e a euro 3.753.279.000 a decorrere dall'anno 2020, tra i comuni interessati sulla base del gettito effettivo dell'IMU e del tributo per i servizi indivisibili (TASI), relativo all'anno 2015 derivante dall'applicazione dei commi da 10 a 16 e dei commi 53 e 54 dell'articolo 1 della legge 28 dicembre 2015, n. 208;
- b) ripartito, nell'importo massimo di 66 milioni di euro, tra i comuni per i quali il riparto dell'importo di cui alla lettera a) non assicura il ristoro di un importo equivalente al gettito della TASI sull'abitazione principale stimato ad aliquota di base. Tale importo e' ripartito in modo da garantire a ciascuno dei comuni di cui al precedente periodo l'equivalente del gettito della TASI sull'abitazione principale stimato ad aliquota di base; (6)
- c) destinato, per euro 1.885.643.345,70, eventualmente incrementati della quota di cui alla lettera b) non distribuita e della quota dell'imposta municipale propria di spettanza dei comuni connessa alla regolazione dei rapporti finanziari, ai comuni delle regioni a statuto ordinario, di cui il 40 per cento per l'anno 2017 e il 45 per cento per gli anni 2018 e 2019, da distribuire tra i predetti comuni sulla base della differenza tra le capacita' fiscali e i fabbisogni standard approvati dalla Commissione tecnica per i fabbisogni standard entro il 30 settembre dell'anno precedente a quello di riferimento. La quota di cui al periodo precedente e' incrementata del 5 per cento annuo dall'anno 2020, sino a raggiungere il valore del 100 per cento a decorrere dall'anno 2030. Ai fini della determinazione della predetta differenza la Commissione tecnica per i fabbisogni standard, di cui all'articolo 1, comma 29, della legge 28 dicembre 2015, n. 208, propone la metodologia per la neutralizzazione della componente rifiuti, anche attraverso l'esclusione della predetta componente dai fabbisogni e dalle capacita' fiscali standard. Tale metodologia e' recepita nel decreto del Presidente del Consiglio dei ministri di cui al comma 451 del presente articolo. L'ammontare complessivo della capacita' fiscale perequabile dei comuni delle regioni a statuto ordinario e' determinata in misura pari al 50 per cento dell'ammontare complessivo della capacita' fiscale da perequare sino all'anno 2019. A decorrere dall'anno 2020 la predetta quota e' incrementata del 5 per cento annuo, sino a raggiungere il valore del 100 per cento a decorrere dall'anno 2029. La restante quota, sino all'anno 2029, e', invece, distribuita assicurando a ciascun comune un importo pari all'ammontare algebrico della medesima componente del Fondo di solidarieta' comunale dell'anno precedente, eventualmente rettificata, variato in misura corrispondente alla variazione della quota di fondo non ripartita secondo i criteri di cui al primo periodo; (58)
- d) destinato, per euro 464.091.019,18, eventualmente incrementati della quota di cui alla lettera b) non distribuita e della quota dell'IMU di spettanza dei comuni dovuta alla regolazione dei rapporti finanziari, ai comuni delle regioni Sicilia e Sardegna. Tale importo e' ripartito assicurando a ciascun comune una somma pari all'ammontare algebrico del medesimo Fondo di solidarieta' comunale dell'anno precedente, eventualmente rettificato, variata in misura corrispondente alla variazione del Fondo di solidarieta' comunale complessivo.
- d-bis) ripartito, nel limite massimo di 25 milioni di euro annui, tra i comuni che presentano, successivamente all'attuazione del correttivo di cui al comma 450, una variazione negativa della dotazione del Fondo di solidarieta' comunale per effetto dell'applicazione dei criteri perequativi di cui alla lettera c), in misura proporzionale e nel limite massimo della variazione stessa.
- d-ter) destinato, nel limite massimo di euro 5.500.000 annui a decorrere dall'anno 2020, ai comuni fino a 5.000 abitanti che, successivamente all'applicazione dei criteri di cui alle lettere da a) a d-bis), presentino un valore negativo del fondo di solidarieta' comunale. Il contributo di cui al periodo precedente e' attribuito sino a concorrenza del valore negativo del fondo di solidarieta' comunale, al netto della quota di alimentazione del fondo stesso, e, comunque, nel limite massimo di euro 50.000 per ciascun comune. In caso di insufficienza delle risorse il riparto avviene in misura proporzionale al valore negativo del fondo di solidarieta' comunale considerando come valore massimo ammesso a riparto l'importo negativo di euro 100.000. L'eventuale eccedenza delle risorse e' destinata a incremento del correttivo di cui alla lettera d-bis).
- d-quater) destinato, quanto a 100 milioni di euro nel 2020, 200 milioni di euro nel 2021, 300 milioni di euro nel 2022, 380 milioni di euro nel 2023, 560 milioni di euro in ciascuno degli anni 2024 e 2025, 672 milioni di euro nel 2026, 728 milioni di euro nel 2027, 784 milioni di euro nel 2028, 840 milioni di euro nel 2029 e 870 milioni di euro annui a decorrere dal 2030, a specifiche esigenze di correzione nel riparto del Fondo di solidarieta' comunale, da individuare con i decreti del Presidente del Consiglio dei ministri di cui al secondo e al terzo periodo. I comuni beneficiari nonche' i criteri e le modalita' di riparto delle risorse di cui al periodo precedente sono stabiliti con il decreto del Presidente del Consiglio dei ministri di cui al comma 451. Per l'anno 2020 i comuni beneficiari nonche' i criteri e le modalita' di riparto delle risorse di cui al primo periodo sono stabiliti con un apposito decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'interno di concerto con il Ministro dell'economia e delle finanze, da adottare entro il 31 gennaio 2020 previa intesa in sede di Conferenza Statocitta' ed autonomie locali.
- d-quinquies) destinato, quanto a 215.923.000 euro per l'anno 2021, a 254.923.000 euro per l'anno 2022, a 299.923.000 euro per l'anno 2023 e a 345.923.000 euro per l'anno 2024, quale quota di risorse finalizzata al finanziamento e allo sviluppo dei servizi sociali comunali svolti in forma singola o associata dai comuni delle regioni a statuto ordinario. I contributi di cui al periodo precedente sono ripartiti in proporzione del rispettivo coefficiente di riparto del fabbisogno standard calcolato per la funzione "Servizi sociali" e approvato dalla Commissione tecnica per i fabbisogni standard, anche in osservanza del livello essenziale delle prestazioni definito dall'articolo 1, comma 797, alinea, della legge 30 dicembre 2020, n. 178, in modo che venga gradualmente raggiunto, alla luce dell'istruttoria condotta dalla predetta Commissione, l'obiettivo di servizio di un rapporto tra assistenti sociali impiegati nei servizi sociali territoriali e popolazione residente pari a 1 a 6.500. Per le medesime finalita' di cui al primo periodo, il Fondo di solidarieta' comunale e' destinato, per un importo di 44 milioni di euro per l'anno 2022, di 52 milioni di euro per l'anno 2023 e di 60 milioni di euro per l'anno 2024, in favore dei comuni della Regione siciliana e della regione Sardegna, ripartendo il contributo, entro il 31 marzo di ciascun anno di riferimento, con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, tenendo conto dei fabbisogni standard, sulla base di un'istruttoria tecnica condotta dalla Commissione tecnica per i fabbisogni standard, allo scopo integrata con i rappresentanti della Regione siciliana e della regione Sardegna, con il supporto di esperti del settore, senza oneri per la finanza pubblica, e previa intesa in sede di Conferenza Stato-citta' ed autonomie locali. Agli esperti di cui al precedente periodo non spettano gettoni di presenza, compensi, rimborsi di spese o altri emolumenti comunque denominati. Con il medesimo decreto sono disciplinati gli obiettivi di servizio e le modalita' di monitoraggio. Per l'anno 2022, nelle more dell'approvazione dei fabbisogni standard per la funzione "Servizi sociali" dei comuni della regione Sardegna da parte della Commissione tecnica per i fabbisogni standard, allo scopo integrata con i rappresentanti della medesima regione, ai fini del riparto, per i soli comuni della regione Sardegna, non si tiene conto dei fabbisogni standard. Gli obiettivi di servizio e le modalita' di monitoraggio, per definire il livello dei servizi offerti e l'utilizzo delle risorse da destinare al finanziamento e allo sviluppo dei servizi sociali, sono stabiliti entro il 30 giugno 2021 e successivamente entro il 31 marzo dell'anno di riferimento con decreto del Presidente del Consiglio dei ministri, sulla base di un'istruttoria tecnica condotta dalla Commissione tecnica per i fabbisogni standard con il supporto di esperti del settore, senza oneri per la finanza pubblica, e previa intesa in sede di Conferenza Stato-citta' ed autonomie locali. In caso di mancata intesa oltre il quindicesimo giorno dalla presentazione della proposta alla Conferenza Stato-citta' ed autonomie locali, il decreto di cui al periodo precedente puo' essere comunque emanato. PERIODO SOPPRESSO DALLA L. 30 DICEMBRE 2023, N. 213;
- d-sexies) destinato ai comuni delle regioni a statuto ordinario, della Regione siciliana e della regione Sardegna quanto a 120 milioni di euro per l'anno 2022, a 175 milioni di euro per l'anno 2023 e a 230 milioni di euro per l'anno 2024, quale quota di risorse finalizzata a incrementare in percentuale, nel limite delle risorse disponibili per ciascun anno, il numero dei posti nei servizi educativi per l'infanzia di cui all'articolo 2, comma 3, lettera a), del decreto legislativo 13 aprile 2017, n. 65, sino al raggiungimento di un livello minimo che ciascun comune o bacino territoriale e' tenuto a garantire. Il livello minimo da garantire di cui al periodo precedente e' definito quale numero dei posti dei predetti servizi educativi per l'infanzia, equivalenti in termini di costo standard al servizio a tempo pieno dei nidi, in proporzione alla popolazione ricompresa nella fascia di eta' da 3 a 36 mesi, ed e' fissato su base locale nel 33 per cento, inclusivo del servizio privato. In considerazione delle risorse di cui al primo periodo i comuni, in forma singola o associata, garantiscono, secondo una progressione differenziata per fascia demografica tenendo anche conto, ove istituibile, del bacino territoriale di appartenenza, il raggiungimento del livello essenziale della prestazione attraverso obiettivi di servizio annuali. Dall'anno 2022 l'obiettivo di servizio, per fascia demografica del comune o del bacino territoriale di appartenenza, e' fissato con il decreto di cui al sesto periodo, dando priorita' ai bacini territoriali piu' svantaggiati e tenendo conto di una soglia massima del 28,88 per cento, valida sino a quando anche tutti i comuni svantaggiati non abbiano raggiunto un pari livello di prestazioni. L'obiettivo di servizio e' progressivamente incrementato annualmente sino al raggiungimento, nell'anno 2027, del livello minimo garantito del 33 per cento su base locale, anche attraverso il servizio privato. Il contributo di cui al primo periodo e' ripartito con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, il Ministro dell'istruzione, il Ministro per il Sud e la coesione territoriale e il Ministro per le pari opportunita' e la famiglia, previa intesa in sede di Conferenza Stato-citta' ed autonomie locali, su proposta della Commissione tecnica per i fabbisogni standard, tenendo conto, ove disponibili, dei costi standard per la funzione "Asili nido" approvati dalla stessa Commissione. Con il decreto di cui al sesto periodo sono altresi' disciplinati gli obiettivi di potenziamento dei posti di asili nido da conseguire, per ciascuna fascia demografica del bacino territoriale di appartenenza, con le risorse assegnate, e le modalita' di monitoraggio sull'utilizzo delle risorse stesse. PERIODO SOPPRESSO DALLA L. 30 DICEMBRE 2023, N. 213. I comuni possono procedere all'assunzione del personale necessario alla diretta gestione dei servizi educativi per l'infanzia utilizzando le risorse di cui alla presente lettera e nei limiti delle stesse. Si applica l'articolo 57, comma 3-septies, del decreto-legge 14 agosto 2020, n. 104, convertito, con modificazioni, dalla legge 13 ottobre 2020, n. 126;
- d-septies) destinato, quanto a 1.077.000 euro a decorrere dall'anno 2021, alla compensazione del mancato recupero a carico del comune di Sappada, distaccato dalla regione Veneto e aggregato alla regione Friuli Venezia Giulia, nell'ambito della provincia di Udine, ai sensi della legge 5 dicembre 2017, n. 182, delle somme di cui agli allegati 1 e 2 del decreto del Presidente del Consiglio dei ministri 7 marzo 2018, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 83 del 10 aprile 2018;
- d-octies) destinato ai comuni delle regioni a statuto ordinario, della Regione siciliana e della regione Sardegna, quanto a 30 milioni di euro per l'anno 2022, a 50 milioni di euro per l'anno 2023 e a 80 milioni di euro per l'anno 2024, quale quota di risorse finalizzata a incrementare, nel limite delle risorse disponibili per ciascun anno e dei livelli essenziali delle prestazioni (LEP), il numero di studenti disabili frequentanti la scuola dell'infanzia, la scuola primaria e la scuola secondaria di primo grado, privi di autonomia a cui viene fornito il trasporto per raggiungere la sede scolastica. Il contributo di cui al primo periodo e' ripartito con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, il Ministro dell'istruzione, il Ministro per il Sud e la coesione territoriale, il Ministro per le disabilita' e il Ministro per le pari opportunita' e la famiglia, previa intesa in sede di Conferenza Stato-citta' ed autonomie locali, su proposta della Commissione tecnica per i fabbisogni standard, tenendo conto, ove disponibili, dei costi standard relativi alla componente trasporto disabili della funzione "Istruzione pubblica" approvati dalla stessa Commissione. Fino alla definizione dei LEP, con il suddetto decreto sono altresi' disciplinati gli obiettivi di incremento della percentuale di studenti disabili trasportati, da conseguire con le risorse assegnate, e le modalita' di monitoraggio sull'utilizzo delle risorse stesse. PERIODO SOPPRESSO DALLA L. 30 DICEMBRE 2023, N. 213;
- d-novies) destinato, a decorrere dall'anno 2029, per euro 1.100.000.000 ai comuni delle regioni a statuto ordinario, della Regione siciliana e della regione Sardegna per il finanziamento dei livelli essenziali delle prestazioni relativi agli asili nido;
- d-decies) destinato, a decorrere dall'anno 2029, per euro 120.000.000 ai comuni delle regioni a statuto ordinario, della Regione siciliana e della regione Sardegna per il finanziamento dei livelli essenziali delle prestazioni relativi al trasporto degli alunni con disabilita';
- d-undecies) destinato, a decorrere dall'anno 2031, per euro 763.923.000 ai comuni delle regioni a statuto ordinario, della Regione siciliana e della regione Sardegna, in proporzione ai fabbisogni standard approvati dalla Commissione tecnica per i fabbisogni standard entro il 30 settembre dell'anno precedente per la funzione "Servizi sociali";
- d-duodecies) a decorrere dall'anno 2030, le assegnazioni in favore di ciascun comune, come risultanti dalle lettere da a) a d-undecies), sono ridotte in misura pari a euro 75.996.252 per effetto dell'articolo 19, comma 8, lettera f), del decreto-legge 19 settembre 2023, n. 124, convertito, con modificazioni, dalla legge 13 novembre 2023, n. 162.

450. Con riferimento ai comuni delle regioni a statuto ordinario, nel caso in cui l'applicazione dei criteri di riparto di cui alla lettera c) del comma 449 determini una variazione delle risorse di riferimento, tra un anno e l'altro, superiore a + 4 per cento o inferiore a - 4 per cento rispetto all'ammontare delle risorse storiche di riferimento, si puo' applicare un correttivo finalizzato a limitare le predette variazioni. Le risorse di riferimento sono definite dai gettiti dell'IMU e della TASI, entrambi valutati ad aliquota di base, e dalla dotazione netta del Fondo di solidarieta' comunale. Per il calcolo delle risorse storiche di riferimento la dotazione netta del Fondo di solidarieta' comunale e' calcolata considerando pari a zero la percentuale di applicazione della differenza tra capacita' fiscali e fabbisogni standard di cui alla lettera c) del comma 449. Ai fini di cui al primo periodo, nell'ambito del Fondo di solidarieta' comunale, e' costituito un accantonamento alimentato dai comuni che registrano un incremento delle risorse complessive rispetto all'anno precedente superiore all'4 per cento. I predetti enti contribuiscono in modo proporzionale all'accantonamento in misura non superiore all'eccedenza di risorse rispetto alla soglia dell'4 per cento e, comunque, nel limite complessivo delle risorse necessarie per ridurre le variazioni negative dei comuni con una perdita superiore all'4 per cento. Il predetto accantonamento e' ripartito proporzionalmente tra i comuni che registrano una riduzione delle risorse complessive rispetto all'anno precedente superiore all'4 per cento nei limiti delle risorse accantonate. (6)

450-bis. Per il solo anno 2017, la quota di cui alla lettera b) del comma 449 non distribuita, nel limite di 14 milioni di euro, unitamente al contributo di cui al comma 24 dell'articolo 1 della legge 28 dicembre 2015, n. 208, non attribuito ai comuni a titolo di compensazione del minor gettito per l'anno 2016, nel limite di 11 milioni di euro, che sono versati all'entrata del bilancio dello Stato nell'anno 2017 per essere riassegnati, nel medesimo esercizio, al Fondo di solidarieta' comunale, sono accantonati per essere attribuiti a favore dei comuni che presentino contemporaneamente una variazione negativa degli effetti perequativi derivanti dall'aggiornamento della metodologia di determinazione dei fabbisogni standard di cui al decreto del Presidente del Consiglio dei ministri 29 dicembre 2016, pubblicato nella Gazzetta Ufficiale n. 44 del 22 febbraio 2017, una variazione negativa della dotazione netta del Fondo di solidarieta' comunale per l'anno 2017 rispetto alla dotazione netta considerata per il calcolo delle risorse storiche di riferimento di cui al comma 450 e una variazione negativa superiore al 1.3 per cento della dotazione netta del Fondo di solidarieta' comunale per l'anno 2017 rispetto alla dotazione netta del Fondo di solidarieta' comunale per l'anno 2016. Il riparto viene effettuato in proporzione alla distanza dalla percentuale del -1.3 per cento dello scostamento tra la dotazione netta del Fondo di solidarieta' comunale del 2017 e la dotazione netta del Fondo di solidarieta' comunale del 2016 in percentuale delle risorse storiche nette di riferimento cosi' come modificate in base alle disposizioni previste dal comma 450. (6)

451. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, previo parere tecnico della Commissione tecnica per i fabbisogni standard istituita ai sensi dell'articolo 1, comma 29, della legge 28 dicembre 2015, n. 208, di concerto con il Ministro dell'interno, previo accordo da sancire in sede di Conferenza Stato-citta' ed autonomie locali entro il 15 ottobre dell'anno precedente a quello di riferimento e da emanare entro il 31 ottobre dell'anno precedente a quello di riferimento, sono stabiliti i criteri di riparto del Fondo di solidarieta' comunale di cui al comma 449. In caso di mancato accordo, il decreto del Presidente del Consiglio dei ministri di cui al periodo precedente e', comunque, emanato entro il 15 novembre dell'anno precedente a quello di riferimento.

452. Con il decreto del Presidente del Consiglio dei ministri di cui al comma 451, puo' essere previsto un accantonamento sul Fondo di solidarieta' comunale nell'importo massimo di 15 milioni di euro, da destinare per eventuali conguagli a singoli comuni derivanti da rettifiche dei valori utilizzati ai fini del riparto del fondo. Le rettifiche decorrono dall'anno di riferimento del Fondo di solidarieta' comunale cui si riferiscono. Gli accantonamenti di cui al primo periodo non utilizzati sono destinati all'incremento dei contributi straordinari di cui all'articolo 15, comma 3, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio, anche mediante il versamento all'entrata del bilancio dello Stato e la successiva riassegnazione al pertinente capitolo dello stato di previsione del Ministero dell'interno.

453. L'articolo 14, comma 7, del decreto legislativo 23 maggio 2000, n. 164, si interpreta nel senso che il gestore uscente resta obbligato al pagamento del canone di concessione previsto dal contratto. Le risorse derivanti dall'applicazione della presente disposizione concorrono al raggiungimento degli obiettivi di finanza pubblica da parte degli enti locali.

454. COMMA ABROGATO DAL D.L. 30 DICEMBRE 2016, N. 244, CONVERTITO CON MODIFICAZIONI DALLA L. 27 FEBBRAIO 2017, N. 19.

455. Per l'esercizio finanziario 2017, il termine per la deliberazione della nota di aggiornamento del Documento unico di programmazione degli enti locali, di cui all'articolo 170 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, e' differito al 31 dicembre 2016.

456. In deroga a quanto previsto dall'articolo 2, comma 186, lettera e), della legge 23 dicembre 2009, n. 191, i consorzi di cui all'articolo 31 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, possono essere costituiti tra gli enti locali al fine della gestione associata dei servizi sociali assicurando comunque risparmi di spesa.

457. L'articolo 2-bis del decreto-legge 24 giugno 2016, n. 113, convertito, con modificazioni, dalla legge 7 agosto 2016, n. 160, e' sostituito dal seguente: "Art. 2-bis. - (Norme relative alla disciplina del dissesto degli enti locali). - 1. In deroga a quanto previsto dall'articolo 255, comma 10, del decreto legislativo 18 agosto 2000, n. 267, per i comuni e per le province in stato di dissesto finanziario l'amministrazione dei residui attivi e passivi relativi ai fondi a gestione vincolata compete all'organo straordinario della liquidazione. 2. L'amministrazione dei residui attivi e passivi di cui al comma 1 e' gestita separatamente, nell'ambito della gestione straordinaria di liquidazione. Resta ferma la facolta' dell'organo straordinario della liquidazione di definire anche in via transattiva le partite debitorie, sentiti i creditori". (6)

458. All'articolo 5, comma 1, del decreto legislativo 26 novembre 2010, n. 216, sono apportate le seguenti modificazioni:

- a) le parole: «Societa' per gli studi di settore-Sose s.p.a.», ovunque ricorrono, sono sostituite dalle seguenti: «Societa' Soluzioni per il sistema economico - Sose s.p.a.»;
- b) alla lettera a), le parole: «Comuni e Province» sono sostituite dalle seguenti: «Enti locali»;
- c) la lettera c) e' sostituita dalla seguente: «c) ai fini di cui alle lettere a) e b), la Societa' Soluzioni per il sistema economico - Sose s.p.a. puo' predisporre appositi sistemi di rilevazione di informazioni funzionali a raccogliere i dati necessari per il calcolo dei fabbisogni standard degli Enti locali. Ove predisposti e somministrati, gli Enti locali restituiscono per via telematica, entro sessanta giorni dalla pubblicazione, le informazioni richieste. Il mancato invio, nel termine predetto, delle informazioni e' sanzionato con la sospensione, sino all'adempimento dell'obbligo di invio delle informazioni, dei trasferimenti a qualunque titolo erogati all'Ente locale e la pubblicazione dell'ente inadempiente nel sito internet del Ministero dell'interno. Agli stessi fini di cui alle lettere a) e b), anche il certificato di conto consuntivo di cui all'articolo 161 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, contiene i dati necessari per il calcolo del fabbisogno standard»;
- d) alla lettera d), la parola: «questionari» e' sostituita dalle seguenti: «sistemi di rilevazione di informazioni» e le parole: «ai Comuni e alle Province» sono sostituite dalle seguenti: «agli Enti locali»;
- e) alla lettera e), primo periodo, dopo le parole: «Commissione tecnica per i fabbisogni standard» sono inserite le seguenti: «, istituita ai sensi dell'articolo 1, comma 29, della legge 28 dicembre 2015, n. 208,» e, al secondo periodo, dopo le parole: «Commissione tecnica» sono inserite le seguenti: «per i fabbisogni standard»;
- f) la lettera f) e' sostituita dalla seguente: «f) i dati raccolti ed elaborati per le attivita' di cui al presente articolo, ai sensi dell'articolo 60 del codice dell'amministrazione digitale, di cui al decreto legislativo 7 marzo 2005, n. 82, confluiscono nella banca dati delle amministrazioni pubbliche di cui all'articolo 13 della legge 31 dicembre 2009, n. 196, nonche' in quella di cui all'articolo 5, comma 1, lettera g), della legge 5 maggio 2009, n. 42, e sono, altresi', pubblicati nel sito "www.opencivitas.it", il quale consente ai cittadini ed agli Enti locali di accedere ai dati monitorati e alle elaborazioni relative, ai sensi degli articoli 50 e 52 del citato codice di cui al decreto legislativo 7 marzo 2005, n. 82. L'invio delle informazioni di cui alla lettera c) costituisce espressa adozione di una licenza di cui all'articolo 2, comma 1, lettere e) e h), del decreto legislativo 24 gennaio 2006, n. 36».

459. All'articolo 47, comma 9, lettera a), del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, dopo le parole: «relativa ai codici SIOPE indicati nella tabella A allegata al presente decreto.» sono inseriti i seguenti periodi: «A decorrere dall'anno 2018, qualora la spesa relativa ai codici SIOPE di cui alla tabella A sia stata sostenuta da comuni che gestiscono, in quanto capofila, funzioni e servizi in forma associata per conto dei comuni facenti parte della stessa gestione associata, le riduzioni di cui alla presente lettera sono applicate a tutti i comuni compresi nella gestione associata, proporzionalmente alla quota di spesa ad essi riferibile. A tal fine, la regione acquisisce dal comune capofila idonea certificazione della quota di spesa riferibile ai comuni facenti parte della gestione associata e la trasmette, entro il 30 aprile dell'anno precedente a quello di riferimento, al Ministero dell'economia e delle finanze e al Ministero dell'interno, che ne tengono conto in sede di predisposizione del decreto annuale del Presidente del Consiglio dei ministri per la determinazione del Fondo di solidarieta' comunale. In caso di mancata comunicazione da parte della regione entro il predetto termine del 30 aprile, il riparto non tiene conto della ripartizione proporzionale tra i comuni compresi nella gestione associata; restano in tal caso confermate le modalita' di riparto di cui al presente articolo».

460. A decorrere dal 1º gennaio 2018, i proventi dei titoli abilitativi edilizi e delle sanzioni previste dal testo unico di cui al decreto del Presidente della Repubblica 6 giugno 2001, n. 380, sono destinati esclusivamente e senza vincoli temporali alla realizzazione e alla manutenzione ordinaria e straordinaria delle opere di urbanizzazione primaria e secondaria, al risanamento di complessi edilizi compresi nei centri storici e nelle periferie degradate, a interventi di riuso e di rigenerazione, a interventi di demolizione di costruzioni abusive, all'acquisizione e alla realizzazione di aree verdi destinate a uso pubblico, a interventi di tutela e riqualificazione dell'ambiente e del paesaggio, anche ai fini della prevenzione e della mitigazione del rischio idrogeologico e sismico e della tutela e riqualificazione del patrimonio rurale pubblico, nonche' a interventi volti a favorire l'insediamento di attivita' di agricoltura nell'ambito urbano e a spese di progettazione per opere pubbliche. A decorrere dal 1° aprile 2020 le risorse non utilizzate ai sensi del primo periodo possono essere altresi' utilizzate per promuovere la predisposizione di programmi diretti al completamento delle infrastrutture e delle opere di urbanizzazione primaria e secondaria dei piani di zona esistenti, fermo restando l'obbligo dei comuni di porre in essere tutte le iniziative necessarie per ottenere l'adempimento, anche per equivalente, delle obbligazioni assunte nelle apposite convenzioni o atti d'obbligo da parte degli operatori.

461. Il comma 8 dell'articolo 2 della legge 24 dicembre 2007, n. 244, e' abrogato alla data indicata al comma 460 del presente articolo.

462. In attuazione della sentenza della terza sezione del Consiglio di Stato n. 1291 del 12 marzo 2015 e in riferimento al ricorso n. 734 del 2014 pendente innanzi al tribunale amministrativo regionale del Lazio, e' istituito nello stato di previsione del Ministero dell'interno un fondo con una dotazione di 8,52 milioni di euro per l'anno 2017 e di 2,8 milioni di euro per l'anno 2018. Le risorse del predetto fondo sono erogate dal Ministero dell'interno subordinatamente alla rinuncia al contenzioso amministrativo pendente.

462-bis. Le disposizioni di cui all'articolo 1, comma 758, della legge 28 dicembre 2015, n. 208, si applicano anche con riferimento all'esercizio finanziario 2017, tenuto conto degli avanzi di amministrazione vincolati e dei rendiconti relativi all'anno 2016.

462-ter. La sanzione relativa al mancato rispetto dei vincoli del patto di stabilita' interno nell'anno 2012 o negli esercizi precedenti, di cui all'articolo 31, comma 26, lettera e), della legge 12 novembre 2011, n. 183, per violazioni emerse ai sensi dei commi 28, 29 e 31 del citato articolo 31, non trova applicazione, e qualora gia' applicata ne vengono meno gli effetti, nei confronti dei comuni colpiti dagli eventi sismici verificatisi a far data dal 24 agosto 2016, di cui agli allegati 1, 2 e 2-bis al decreto-legge 17 ottobre 2016, n. 189, convertito, con modificazioni, dalla legge 15 dicembre 2016, n. 229, nonche' delle province delle regioni a statuto ordinario per le quali le stesse violazioni sono state accertate successivamente alla data del 31 dicembre 2014.

463. A decorrere dall'anno 2017 cessano di avere applicazione i commi da 709 a 712 e da 719 a 734 dell'articolo 1 della legge 28 dicembre 2015, n. 208. Restano fermi gli adempimenti degli enti territoriali relativi al monitoraggio e alla certificazione del saldo di cui all'articolo 1, comma 710, della legge 28 dicembre 2015, n. 208, nonche' l'applicazione delle sanzioni in caso di mancato conseguimento del saldo 2016, di cui al medesimo comma 710, accertato ai sensi dei commi da 720 a 727 dell'articolo 1 della legge 28 dicembre 2015, n. 208. Sono fatti salvi gli effetti connessi all'applicazione nell'anno 2016 dei patti di solidarieta' di cui ai commi da 728 a 732 dell'articolo 1 della legge 28 dicembre 2015, n. 208.

464. L'ultimo periodo del comma 721 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' soppresso.

465. Ai fini della tutela dell'unita' economica della Repubblica e ai sensi dell'articolo 9 della legge 24 dicembre 2012, n. 243, le regioni e le province autonome di Trento e di Bolzano, le citta' metropolitane, le province e i comuni concorrono alla realizzazione degli obiettivi di finanza pubblica nel rispetto delle disposizioni di cui ai commi da 463 a 484 del presente articolo, che costituiscono principi fondamentali di coordinamento della finanza pubblica, ai sensi degli articoli 117, terzo comma, e 119, secondo comma, della Costituzione. (24)

466. A decorrere dall'anno 2017 gli enti di cui al comma 465 del presente articolo devono conseguire il saldo non negativo, in termini di competenza, tra le entrate finali e le spese finali, ai sensi dell'articolo 9, comma 1, della legge 24 dicembre 2012, n. 243. Ai sensi del comma 1-bis del medesimo articolo 9, le entrate finali sono quelle ascrivibili ai titoli 1, 2, 3, 4 e 5 dello schema di bilancio previsto dal decreto legislativo 23 giugno 2011, n. 118, e le spese finali sono quelle ascrivibili ai titoli 1, 2 e 3 del medesimo schema di bilancio. Per gli anni 2017-2019, nelle entrate e nelle spese finali in termini di competenza e' considerato il fondo pluriennale vincolato, di entrata e di spesa, al netto della quota riveniente dal ricorso all'indebitamento. A decorrere dall'esercizio 2020, tra le entrate e le spese finali e' incluso il fondo pluriennale vincolato di entrata e di spesa, finanziato dalle entrate finali. Non rileva la quota del fondo pluriennale vincolato di entrata che finanzia gli impegni cancellati definitivamente dopo l'approvazione del rendiconto dell'anno precedente. (17) (24)

467. Le risorse accantonate nel fondo pluriennale di spesa dell'esercizio 2015 in applicazione del punto 5.4 del principio contabile applicato concernente la contabilita' finanziaria di cui all'allegato n. 4/2 annesso al decreto legislativo 23 giugno 2011, n. 118, per finanziare le spese contenute nei quadri economici relative a investimenti per lavori pubblici e quelle per procedure di affidamento gia' attivate, se non utilizzate possono essere conservate nel fondo pluriennale vincolato di spesa dell'esercizio 2016 purche' riguardanti opere per le quali l'ente abbia gia' avviato le procedure per la scelta del contraente fatte salve dal decreto legislativo 18 aprile 2016, n. 50 o disponga del progetto esecutivo degli investimenti redatto e validato in conformita' alla vigente normativa, completo del cronoprogramma di spesa e a condizione che il bilancio di previsione 2017-2019 sia approvato entro il 31 gennaio 2017. Tali risorse confluiscono nel risultato di amministrazione se entro l'esercizio 2017 non sono assunti i relativi impegni di spesa.

468. Al fine di garantire l'equilibrio di cui al comma 466 del presente articolo, nella fase di previsione, in attuazione del comma 1 dell'articolo 9 della legge 24 dicembre 2012, n. 243, al bilancio di previsione e' allegato il prospetto dimostrativo del rispetto del saldo di cui al citato comma 466, previsto nell'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, vigente alla data dell'approvazione di tale documento contabile. A tal fine, il prospetto allegato al bilancio di previsione non considera gli stanziamenti del fondo crediti di dubbia esigibilita' e dei fondi spese e rischi futuri concernenti accantonamenti destinati a confluire nel risultato di amministrazione. Il prospetto e' aggiornato dal Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato a seguito di successivi interventi normativi volti a modificare le regole vigenti di riferimento, dandone comunicazione alla Commissione per l'armonizzazione degli enti territoriali. Entro sessanta giorni dall'aggiornamento, il Consiglio approva le necessarie variazioni al bilancio di previsione. PERIODO SOPPRESSO DALLA L. 27 DICEMBRE 2017, N. 205. (24)

468-bis. Le Regioni e le province autonome di Trento e Bolzano possono utilizzare le quote del risultato di amministrazione accantonato risultanti dall'ultimo consuntivo approvato o dall'attuazione dell'articolo 42, comma 10, del decreto legislativo n. 118 del 2011, e le quote del risultato di amministrazione vincolato, iscrivendole nella missione 20 in appositi accantonamenti di bilancio che, nel bilancio gestionale sono distinti dagli accantonamenti finanziati dalle entrate di competenza dell'esercizio. Gli utilizzi degli accantonamenti finanziati dall'avanzo sono disposti con delibere della giunta cui e' allegato il prospetto di cui al comma 468. La giunta e' autorizzata ad effettuare le correlate variazioni, anche in deroga all'articolo 51 del decreto legislativo n. 118 del 2011. (24)

469. Per il monitoraggio degli adempimenti relativi a quanto disposto dai commi da 463 a 484 e per l'acquisizione di elementi informativi utili per la finanza pubblica, gli enti di cui al comma 465 trasmettono al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato le informazioni riguardanti le risultanze del saldo di cui al comma 466, con tempi e modalita' definiti con decreti del predetto Ministero sentite, rispettivamente, la Conferenza Stato-citta' ed autonomie locali e la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. (24)

470. Ai fini della verifica del rispetto dell'obiettivo di saldo, ciascun ente e' tenuto a inviare, utilizzando il sistema web, appositamente previsto nel sito «http://pareggiobilancio.mef.gov.it», entro il termine perentorio del 31 marzo dell'anno successivo a quello di riferimento, al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato una certificazione dei risultati conseguiti, firmata digitalmente, ai sensi dell'articolo 24 del codice dell'amministrazione digitale di cui al decreto legislativo 7 marzo 2005, n. 82, dal rappresentante legale, dal responsabile del servizio finanziario e dall'organo di revisione economico-finanziaria, ove previsto, secondo un prospetto e con le modalita' definiti dai decreti di cui al comma 469 del presente articolo. La trasmissione per via telematica della certificazione ha valore giuridico ai sensi dell'articolo 45, comma 1, del medesimo codice di cui al decreto legislativo n. 82 del 2005. La mancata trasmissione della certificazione entro il termine perentorio del 31 marzo costituisce inadempimento all'obbligo del pareggio di bilancio. Nel caso in cui la certificazione, sebbene in ritardo, sia trasmessa entro il successivo 30 maggio e attesti il conseguimento dell'obiettivo di saldo di cui al comma 466, si applicano, nei dodici mesi successivi al ritardato invio, le sole disposizioni di cui al comma 475, lettera e), limitatamente alle assunzioni di personale a tempo indeterminato. (24)

470-bis. Gli enti locali per i quali, ai sensi dell'articolo 248, comma 1, del decreto legislativo 18 agosto 2000, n. 267, a seguito della dichiarazione di dissesto, sono sospesi i termini per la deliberazione del bilancio, sono tenuti ad inviare la certificazione di cui al comma 470 entro trenta giorni dal termine stabilito per l'approvazione del rendiconto di gestione, previsto dal decreto del Ministro dell'interno di approvazione dell'ipotesi di bilancio di previsione stabilmente riequilibrato di cui all'articolo 261 del medesimo decreto legislativo. La disposizione di cui al periodo precedente si applica anche agli obblighi di certificazione di cui all'articolo 1, comma 720, della legge 28 dicembre 2015, n. 208. (24)

471. Decorsi trenta giorni dal termine stabilito per l'approvazione del rendiconto di gestione, in caso di mancata trasmissione da parte dell'ente locale della certificazione, il presidente dell'organo di revisione economico-finanziaria nel caso di organo collegiale ovvero l'unico revisore nel caso di organo monocratico, in qualita' di commissario ad acta, provvede, pena la decadenza dal ruolo di revisore, ad assicurare l'assolvimento dell'adempimento e a trasmettere la predetta certificazione entro i successivi trenta giorni. Nel caso in cui la certificazione sia trasmessa dal commissario ad acta entro sessanta giorni dal termine stabilito per l'approvazione del rendiconto di gestione e attesti il conseguimento dell'obiettivo di saldo di cui al comma 466, si applicano le sole disposizioni di cui al comma 475, lettere e) e f), tenendo conto della gradualita' prevista al comma 476. Sino alla data di trasmissione da parte del commissario ad acta, le erogazioni di risorse o trasferimenti da parte del Ministero dell'interno relative all'anno successivo a quello di riferimento sono sospese e, a tal fine, il Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato provvede a trasmettere apposita comunicazione al predetto Ministero. (24)

472. Decorsi trenta giorni dal termine stabilito per l'approvazione del rendiconto di gestione, in caso di mancata trasmissione da parte delle regioni e delle province autonome della certificazione si procede al blocco di qualsiasi prelievo dai conti della tesoreria statale sino a quando la certificazione non e' acquisita. (24)

473. I dati contabili rilevanti ai fini del conseguimento del saldo di cui al comma 466, trasmessi con la certificazione dei risultati di cui al comma 470, devono corrispondere alle risultanze del rendiconto di gestione. A tal fine, qualora la certificazione trasmessa entro il termine perentorio di cui al comma 470 sia difforme dalle risultanze del rendiconto di gestione, gli enti sono tenuti ad inviare una nuova certificazione, a rettifica della precedente, entro il termine perentorio di sessanta giorni dall'approvazione del rendiconto e, comunque, non oltre il 30 giugno del medesimo anno per gli enti locali e il 30 settembre per le regioni e le province autonome di Trento e di Bolzano. (24)

473-bis. Per il solo anno 2017, qualora la certificazione trasmessa sia difforme dalle risultanze del rendiconto di gestione, gli enti sono tenuti a inviare una nuova certificazione, a rettifica della precedente, entro il termine perentorio del 30 giugno 2020.

474. Decorsi i termini previsti dal comma 473, sono comunque tenuti ad inviare una nuova certificazione, a rettifica della precedente, solo gli enti che rilevano, rispetto a quanto gia' certificato, un peggioramento del proprio posizionamento rispetto all'obiettivo di saldo di cui al comma 466. (24)

475. Ai sensi dell'articolo 9, comma 4, della legge 24 dicembre 2012, n. 243, in caso di mancato conseguimento del saldo di cui al comma 466 del presente articolo:

- a) l'ente locale e' assoggettato ad una riduzione del fondo sperimentale di riequilibrio o del fondo di solidarieta' comunale in misura pari all'importo corrispondente allo scostamento registrato. Le province della Regione siciliana e della regione Sardegna sono assoggettate alla riduzione dei trasferimenti erariali nella misura indicata al primo periodo. Gli enti locali delle regioni Friuli Venezia Giulia e Valle d'Aosta e delle province autonome di Trento e di Bolzano sono assoggettati ad una riduzione dei trasferimenti correnti erogati dalle medesime regioni o province autonome in misura pari all'importo corrispondente allo scostamento registrato. Le riduzioni di cui ai precedenti periodi assicurano il recupero di cui all'articolo 9, comma 2, della legge 24 dicembre 2012, n. 243, e sono applicate nel triennio successivo a quello di inadempienza in quote costanti. In caso di incapienza, per uno o piu' anni del triennio di riferimento, gli enti locali sono tenuti a versare all'entrata del bilancio dello Stato le somme residue di ciascuna quota annuale, entro l'anno di competenza delle medesime quote, presso la competente sezione di tesoreria provinciale dello Stato, al capo X dell'entrata del bilancio dello Stato, al capitolo 3509, articolo 2. In caso di mancato versamento delle predette somme residue nell'anno successivo, il recupero e' operato con le procedure di cui ai commi 128 e 129 dell'articolo 1 della legge 24 dicembre 2012, n. 228; (17)
- b) nel triennio successivo la regione o la provincia autonoma e' tenuta ad effettuare un versamento all'entrata del bilancio dello Stato, di importo corrispondente a un terzo dello scostamento registrato, che assicura il recupero di cui all'articolo 9, comma 2, della legge 24 dicembre 2012, n. 243. Il versamento e' effettuato entro il 31 maggio di ciascun anno del triennio successivo a quello di inadempienza. In caso di mancato versamento si procede al recupero di detto scostamento a valere sulle giacenze depositate a qualsiasi titolo nei conti aperti presso la tesoreria statale; (17)
- c) nell'anno successivo a quello di inadempienza l'ente non puo' impegnare spese correnti, per le regioni al netto delle spese per la sanita', in misura superiore all'importo dei corrispondenti impegni dell'anno precedente ridotti dell'1 per cento. La sanzione si applica con riferimento agli impegni riguardanti le funzioni esercitate in entrambi gli esercizi. A tal fine, l'importo degli impegni correnti dell'anno precedente e quello dell'anno in cui si applica la sanzione sono determinati al netto di quelli connessi a funzioni non esercitate in entrambi gli esercizi, nonche' al netto degli impegni relativi ai versamenti al bilancio dello Stato effettuati come contributo alla finanza pubblica;
- d) nell'anno successivo a quello di inadempienza l'ente non puo' ricorrere all'indebitamento per gli investimenti. Per le regioni e le province autonome di Trento e di Bolzano, restano esclusi i mutui gia' autorizzati e non ancora contratti. I mutui e i prestiti obbligazionari posti in essere con istituzioni creditizie o finanziarie per il finanziamento degli investimenti o le aperture di linee di credito devono essere corredati di apposita attestazione da cui risulti il rispetto del saldo di cui al comma 466. L'istituto finanziatore o l'intermediario finanziario non puo' procedere al finanziamento o al collocamento del prestito in assenza della predetta attestazione;
- e) nell'anno successivo a quello di inadempienza l'ente non puo' procedere ad assunzioni di personale a qualsiasi titolo, con qualsivoglia tipologia contrattuale, compresi i rapporti di collaborazione coordinata e continuativa e di somministrazione, anche con riferimento ai processi di stabilizzazione in atto. E' fatto altresi' divieto agli enti di stipulare contratti di servizio con soggetti privati che si configurino come elusivi della presente disposizione. Le regioni, le citta' metropolitane e i comuni possono comunque procedere ad assunzioni di personale a tempo determinato, con contratti di durata massima fino al 31 dicembre del medesimo esercizio, necessari a garantire l'esercizio delle funzioni di protezione civile, di polizia locale, di istruzione pubblica e del settore sociale nel rispetto del limite di spesa di cui al primo periodo del comma 28 dell'articolo 9 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122;
- f) nell'anno successivo a quello di inadempienza, il presidente, il sindaco e i componenti della giunta in carica nell'esercizio in cui e' avvenuta la violazione sono tenuti a versare al bilancio dell'ente il 30 per cento delle indennita' di funzione e dei gettoni di presenza spettanti nell'esercizio della violazione. (24)

476. Nel caso in cui il mancato conseguimento del saldo di cui al comma 466 risulti inferiore al 3 per cento degli accertamenti delle entrate finali dell'esercizio del mancato conseguimento del saldo, nell'anno successivo a quello dell'inadempienza la sanzione di cui al comma 475, lettera c), e' applicata imponendo agli impegni di parte corrente, per le regioni al netto della sanita', un limite pari all'importo dei corrispondenti impegni dell'anno precedente; la sanzione di cui al comma 475, lettera e), e' applicata solo per assunzioni di personale a tempo indeterminato; la sanzione di cui al comma 475, lettera f), e' applicata dal presidente, dal sindaco e dai componenti della giunta in carica nell'esercizio in cui e' avvenuta la violazione versando al bilancio dell'ente il 10 per cento delle indennita' di funzione e dei gettoni di presenza spettanti nell'esercizio della violazione. Resta ferma l'applicazione delle restanti sanzioni di cui al comma 475. (24)

477. Agli enti per i quali il mancato conseguimento del saldo di cui al comma 466 sia accertato dalla Corte dei conti successivamente all'anno seguente a quello cui la violazione si riferisce, le sanzioni di cui al comma 475 si applicano nell'anno successivo a quello della comunicazione del mancato conseguimento del saldo, di cui al comma 478. (24)

478. Gli enti di cui al comma 477 sono tenuti a comunicare l'inadempienza entro trenta giorni dall'accertamento della violazione mediante l'invio di una nuova certificazione al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. (24)

479. Ai sensi dell'articolo 9, comma 4, della legge 24 dicembre 2012, n. 243, a decorrere dall'anno 2018, con riferimento ai risultati dell'anno precedente e a condizione del rispetto dei termini perentori di certificazione di cui ai commi 470 e 473:

- a) alle regioni che rispettano il saldo di cui al comma 466 e che conseguono un saldo finale di cassa non negativo fra le entrate e le spese finali, sono assegnate, con decreto del Ministero dell'economia e delle finanze, entro il 30 luglio di ciascun anno, le eventuali risorse incassate dal bilancio dello Stato alla data del 30 giugno ai sensi del comma 475, lettera b), per essere destinate alla realizzazione di investimenti. L'ammontare delle risorse per ciascuna regione e' determinato mediante intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Le regioni che conseguono il saldo finale di cassa non negativo trasmettono al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato le informazioni concernenti il monitoraggio al 31 dicembre del saldo di cui al comma 466 e la certificazione dei relativi risultati, in termini di competenza e in termini di cassa, secondo le modalita' previste dai decreti di cui al comma 469. Ai fini del saldo di cassa rileva l'anticipazione erogata dalla tesoreria statale nel corso dell'esercizio per il finanziamento della sanita' registrata nell'apposita voce delle partite di giro, al netto delle relative regolazioni contabili imputate al medesimo esercizio;
- b) alle citta' metropolitane, alle province e ai comuni, che rispettano il saldo di cui al comma 466 e che conseguono un saldo finale di cassa non negativo fra le entrate finali e le spese finali, sono assegnate, con decreto del Ministero dell'economia e delle finanze, entro il 30 luglio di ciascun anno, le eventuali risorse derivanti dalla riduzione del fondo sperimentale di riequilibrio o del fondo di solidarieta' comunale e dai versamenti e recuperi, effettivamente incassati, di cui al comma 475, lettera a), per essere destinate alla realizzazione di investimenti. L'ammontare delle risorse per ciascuna citta' metropolitana, provincia e comune e' determinato d'intesa con la Conferenza Stato-citta' ed autonomie locali. Le citta' metropolitane, le province e i comuni che conseguono il saldo finale di cassa non negativo trasmettono al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato le informazioni concernenti il monitoraggio al 31 dicembre del saldo di cui al comma 466 e la certificazione dei relativi risultati, in termini di competenza e in termini di cassa, secondo le modalita' previste dai decreti di cui al comma 469;
- c) per le regioni e le citta' metropolitane che rispettano il saldo di cui al comma 466, lasciando spazi finanziari inutilizzati inferiori all'1 per cento degli accertamenti delle entrate finali dell'esercizio nel quale e' rispettato il medesimo saldo, nell'anno successivo la spesa per rapporti di lavoro flessibile di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, puo' essere innalzata del 10 per cento della spesa sostenibile ai sensi del predetto comma 28;
- d) per i comuni che rispettano il saldo di cui al comma 466, lasciando spazi finanziari inutilizzati inferiori all'1 per cento degli accertamenti delle entrate finali dell'esercizio nel quale e' rispettato il medesimo saldo, nell'anno successivo la percentuale stabilita al primo periodo del comma 228 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' innalzata al 90 per cento qualora il rapporto dipendenti-popolazione dell'anno precedente sia inferiore al rapporto medio dipendenti-popolazione per classe demografica, come definito triennalmente con il decreto del Ministro dell'interno di cui all'articolo 263, comma 2, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267. (22) (24)

480. I contratti di servizio e gli altri atti posti in essere dagli enti, che si configurano come elusivi delle regole di cui ai commi da 463 a 484, sono nulli. (22) (24)

481. Qualora le sezioni giurisdizionali regionali della Corte dei conti accertino che il rispetto delle regole di cui ai commi da 463 a 484 e' stato artificiosamente conseguito mediante una non corretta applicazione dei principi contabili di cui al decreto legislativo 23 giugno 2011, n. 118, o altre forme elusive, le stesse irrogano agli amministratori che hanno posto in essere atti elusivi delle predette regole la condanna ad una sanzione pecuniaria fino a un massimo di dieci volte l'indennita' di carica percepita al momento in cui e' stata commessa l'elusione e al responsabile amministrativo, individuato dalla stessa sezione giurisdizionale regionale della Corte dei conti, una sanzione pecuniaria fino a tre mensilita' del trattamento retributivo, al netto degli oneri fiscali e previdenziali. Gli importi di cui al periodo precedente sono acquisiti al bilancio dell'ente. (22) (24)

482. Qualora risultino, anche sulla base dei dati del monitoraggio di cui al comma 469, andamenti di spesa degli enti non coerenti con gli impegni finanziari assunti con l'Unione europea, il Ministro dell'economia e delle finanze, sentite la Conferenza Stato-citta' ed autonomie locali e la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, propone adeguate misure di contenimento della predetta spesa. (22) (24)

483. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205. (22)

484. Alla regione Valle d'Aosta non si applicano le disposizioni in materia di patto di stabilita' interno di cui all'articolo 1, commi 454 e seguenti, della legge 24 dicembre 2012, n. 228. (22)

485. Al fine di favorire gli investimenti, da realizzare attraverso l'utilizzo dei risultati di amministrazione degli esercizi precedenti e il ricorso al debito, per l'anno 2017, sono assegnati agli enti locali spazi finanziari nell'ambito dei patti nazionali, di cui all'articolo 10, comma 4, della legge 24 dicembre 2012, n. 243, nel limite complessivo di 700 milioni di euro, di cui 300 milioni di euro destinati a interventi di edilizia scolastica. Sono assegnati agli enti locali spazi finanziari nell'ambito dei medesimi patti nazionali, nel limite complessivo di 900 milioni di euro annui per ciascuno degli anni 2018 e 2019, di cui 400 milioni di euro annui destinati ad interventi di edilizia scolastica e 100 milioni di euro annui destinati a interventi di impiantistica sportiva, e nel limite complessivo di 700 milioni di euro annui per ciascuno degli anni dal 2020 al 2023. (22) (24)

486. Gli enti locali non possono richiedere spazi finanziari per le finalita' di investimento di cui ai commi da 463 a 508, qualora le operazioni di investimento, realizzate con il ricorso all'indebitamento e all'utilizzo dei risultati di amministrazione degli esercizi precedenti, possano essere effettuate nel rispetto del proprio saldo di cui al comma 1 dell'articolo 9 della legge 24 dicembre 2012, n. 243. (22) (24)

486-bis. I comuni facenti parte di un'unione di comuni, ai sensi dell'articolo 32 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, che hanno delegato le funzioni connesse alla realizzazione di opere pubbliche, possono richiedere spazi finanziari, nell'ambito delle intese regionali e dei patti nazionali, di cui all'articolo 10, commi 3 e 4, della legge 24 dicembre 2012, n. 243, per la quota di contributi trasferita all'unione stessa per investimenti in opere pubbliche riferite alla medesima delega di funzioni. (22) (24)

487. Gli enti locali comunicano gli spazi finanziari destinati ad interventi di edilizia scolastica di cui necessitano, entro il termine perentorio del 20 gennaio di ciascun anno, al Ministero dell'istruzione, dell'universita' e della ricerca secondo le modalita' individuate e pubblicate nel sito internet istituzionale del medesimo Ministero. Le richieste di spazi finanziari sono complete delle informazioni relative:

- a) al fondo di cassa al 31 dicembre dell'anno precedente;
- b) all'avanzo di amministrazione, al netto della quota accantonata del fondo crediti di dubbia esigibilita', risultante dal rendiconto o dal preconsuntivo dell'anno precedente. (22) (24)

487-bis. Gli enti locali comunicano gli spazi finanziari destinati ad interventi di impiantistica sportiva di cui necessitano, entro il termine perentorio del 20 gennaio di ciascun anno, alla Presidenza del Consiglio dei ministri - Ufficio per lo sport secondo le modalita' individuate e pubblicate nel sito internet http://www.sportgoverno.it/. Le richieste di spazi finanziari sono complete delle informazioni relative:

- a) al fondo di cassa al 31 dicembre dell'anno precedente;
- b) all'avanzo di amministrazione, al netto della quota accantonata del fondo crediti di dubbia esigibilita', risultante dal rendiconto o dal preconsuntivo dell'anno precedente. (22) (24)

488. Il Ministero dell'istruzione, dell'universita' e della ricerca individua per ciascun ente locale gli spazi finanziari, tenendo conto del seguente ordine prioritario:

- a) interventi di edilizia scolastica gia' avviati, a valere su risorse acquisite mediante contrazione di mutuo, e per i quali sono stati attribuiti spazi finanziari nell'anno 2017 ai sensi del decreto del Ministero dell'economia e delle finanze n. 77112 del 26 aprile 2017, pubblicato nella Gazzetta Ufficiale n. 114 del 18 maggio 2017 e, negli anni successivi, ai sensi dell'ultimo decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato di cui al comma 492, nonche' interventi finanziati ai sensi dell'articolo 10 del decreto-legge 12 settembre 2013, n. 104, convertito, con modificazioni, dalla legge 8 novembre 2013, n. 128, per la quota di cofinanziamento a carico dell'ente;
- b) interventi di nuova costruzione di edifici scolastici o di adeguamento antisismico degli edifici esistenti per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del codice unico di progetto (CUP) e del cronoprogramma aggiornato della spesa e delle opere, che non abbiano pubblicato il bando alla data della richiesta di spazi finanziari;
- c) interventi di edilizia scolastica per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del CUP e del cronoprogramma aggiornato della spesa e delle opere, che non abbiano pubblicato il bando di gara alla data della richiesta di spazi finanziari;
- c-bis) interventi di nuova costruzione di edifici scolastici o di adeguamento antisismico degli edifici esistenti per i quali gli enti dispongono del progetto definitivo completo del CUP;
- c-ter) altri interventi di edilizia scolastica per i quali gli enti dispongono del progetto definitivo completo del CUP. (22) (24)

488-bis. I comuni facenti parte di un'unione di comuni, ai sensi dell'articolo 32 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, che hanno delegato le funzioni riferite all'edilizia scolastica, possono chiedere spazi finanziari, ai sensi dei commi 487 e 488 del presente articolo, per la quota di contributi trasferiti all'unione stessa per interventi di edilizia scolastica ricadenti nelle priorita' di cui al citato comma 488. (22) (24)

488-ter. La Presidenza del Consiglio dei ministri - Ufficio per lo sport individua per ciascun ente locale gli spazi finanziari, tenendo conto del seguente ordine prioritario:

- a) interventi, su impianti sportivi esistenti, di messa a norma e in sicurezza compreso l'adeguamento antisismico, di abbattimento delle barriere architettoniche, di efficientamento energetico e di ripristino della funzionalita' per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del codice unico di progetto (CUP) e del cronoprogramma aggiornato della spesa e delle opere, che non abbiano pubblicato il bando di gara alla data della richiesta di spazi finanziari;
- b) altri interventi relativi a impianti sportivi per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del CUP e del cronoprogramma aggiornato della spesa e delle opere, che non abbiano pubblicato il bando di gara alla data della richiesta di spazi finanziari;
- c) interventi, su impianti sportivi esistenti, di messa a norma e in sicurezza compreso l'adeguamento antisismico, di abbattimento delle barriere architettoniche, di efficientamento energetico e di ripristino della funzionalita' per i quali gli enti dispongono del progetto definitivo completo del CUP;
- d) altri interventi relativi a impianti sportivi per i quali gli enti dispongono del progetto definitivo completo del CUP. (22) (24)

489. Il Ministero dell'istruzione, dell'universita' e della ricerca e la Presidenza del Consiglio dei ministri - Ufficio per lo sport individuano gli enti locali beneficiari degli spazi finanziari e l'importo degli stessi, sentita la Conferenza Stato-citta' ed autonomie locali, entro il 10 febbraio di ogni anno. Ferme restando le priorita' di cui ai commi 488 e 488-ter, qualora le richieste complessive risultino superiori agli spazi finanziari disponibili, l'individuazione dei medesimi spazi e' effettuata a favore degli enti che presentano la maggiore incidenza del fondo di cassa rispetto all'avanzo di amministrazione. Qualora le richieste complessive risultino inferiori agli spazi disponibili, l'importo eccedente e' destinato alle finalita' degli interventi previsti al comma 492. Entro il 10 febbraio di ogni anno il Ministero dell'istruzione, dell'universita' e della ricerca e la Presidenza del Consiglio dei ministri - Ufficio per lo sport comunicano al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato gli spazi finanziari da attribuire a ciascun ente locale. (22) (24)

490. Gli enti locali comunicano gli spazi finanziari di cui necessitano per gli investimenti, entro il termine perentorio del 20 gennaio di ciascun anno, al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, mediante l'applicativo web appositamente previsto nel sito «http://pareggiobilancio.mef.gov.it». (22) (24)

491. Le richieste di spazi finanziari di cui al comma 490, per la quota non riferita agli interventi di edilizia scolastica e di impiantistica sportiva di cui ai commi da 487 a 489, sono completi delle informazioni relative:

- a) al fondo di cassa al 31 dicembre dell'anno precedente;
- b) all'avanzo di amministrazione, al netto della quota accantonata del Fondo crediti di dubbia esigibilita', risultante dal rendiconto o dal preconsuntivo dell'anno precedente. (22) (24)

492. L'ammontare dello spazio finanziario attribuito a ciascun ente locale e' determinato, entro il 20 febbraio di ciascun anno, con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, tenendo conto del seguente ordine prioritario: 0a) investimenti dei comuni individuati ai sensi dell'articolo 1 del decreto-legge 28 aprile 2009, n. 39, convertito, con modificazioni, dalla legge 24 giugno 2009, n. 77, dell'articolo 1 del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1° agosto 2012, n. 122, e dell'articolo 67-septies del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e delle relative province, nonche' delle province nei cui territori ricadono i comuni di cui agli allegati 1, 2 e 2-bis del decreto-legge 17 ottobre 2016, n. 189, convertito, con modificazioni, dalla legge 15 dicembre 2016, n. 229, finalizzati a fronteggiare gli eccezionali eventi sismici e la ricostruzione, finanziati con avanzo di amministrazione o da operazioni di indebitamento; 0b) investimenti degli enti locali, finanziati con avanzo di amministrazione o da operazioni di indebitamento, finalizzati al ripristino e alla messa in sicurezza del territorio, a seguito di danni derivanti da eccezionali eventi meteorologici per i quali sia stato dichiarato, nell'anno precedente la data della richiesta di spazi finanziari, lo stato di emergenza, ai sensi dell'articolo 5 della legge 24 febbraio 1992, n. 225; 0c) investimenti gia' avviati, a valere su risorse acquisite mediante contrazione di mutuo e per i quali sono stati attribuiti spazi finanziari ai sensi dell'ultimo decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato di cui all'alinea;

- a) investimenti finanziati con avanzo di amministrazione o mediante operazioni di indebitamento: 1) dei comuni istituiti, nel quinquennio precedente all'anno di riferimento, a seguito dei processi di fusione previsti dalla legislazione vigente; per ciascun esercizio del triennio 2017-2019, sono considerati esclusivamente i comuni per i quali i processi di fusione si sono conclusi entro il 1º gennaio dell'esercizio di riferimento; 2) dei comuni con popolazione fino a 5.000 abitanti; 2-bis) dei comuni con popolazione compresa tra 5.001e 15.000 abitanti, per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del cronoprogramma della spesa;
- a-bis) investimenti finanziati con avanzo di amministrazione o mediante operazioni di indebitamento la cui progettazione definitiva e/o esecutiva e' finanziata a valere sulle risorse di cui all'articolo 41-bis del decreto-legge 24 aprile 2017, n. 50, convertito, con modificazioni, dalla legge 21 giugno 2017, n. 96;
- a-ter) spese per investimenti finalizzati all'attuazione del Piano triennale per l'informatica nella pubblica amministrazione, di cui all'articolo 1, comma 513, della legge 28 dicembre 2015, n. 208, relativi allo sviluppo software e alla manutenzione evolutiva, ivi compresi la progettazione, la realizzazione, il collaudo, l'installazione e l'avviamento presso l'ente locale di software sviluppato ad hoc o di software pre-esistente e reingegnerizzato, la personalizzazione di software applicativo gia' in dotazione dell'ente locale o sviluppato per conto di altra unita' organizzativa e riutilizzato, tenendo conto del seguente ordine prioritario: 1. interventi finalizzati all'attuazione delle azioni relative alla razionalizzazione dei data center e all'adozione del cloud, nonche' per la connettivita'; allo sviluppo di base dati di interesse nazionale e alla valorizzazione degli open data nonche' all'adozione delle piattaforme abilitanti; all'adozione del nuovo modello di interoperabilita'; all'implementazione delle misure di sicurezza all'interno delle proprie infrastrutture e all'adesione alla piattaforma digitale nazionale di raccolta dei dati; 2. interventi finalizzati all'attuazione delle restanti azioni contenute all'interno del Piano triennale per l'informatica nella pubblica amministrazione.
- b) LETTERA ABROGATA DAL D.L. 24 APRILE 2017, N. 50, CONVERTITO CON MODIFICAZIONI DALLA L. 21 GIUGNO 2017, N. 96;
- c) investimenti finalizzati all'adeguamento e al miglioramento sismico degli immobili, finanziati con avanzo di amministrazione, per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del cronoprogramma della spesa;
- d) investimenti finalizzati alla prevenzione del rischio idrogeologico e alla messa in sicurezza e alla bonifica di siti inquinati ad alto rischio ambientale, individuati come prioritari per il loro rilevante impatto sanitario, finanziati con avanzo di amministrazione, per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del cronoprogramma della spesa.
- d-bis) progettazione definitiva ed esecutiva di investimenti finalizzati al miglioramento della dotazione infrastrutturale o al recupero degli immobili e delle strutture destinati a servizi per la popolazione, finanziati con avanzo di amministrazione.
- d-ter) investimenti finalizzati al potenziamento e al rifacimento di impianti per la produzione di energia elettrica di fonti rinnovabili diverse dal fotovoltaico, per i quali gli enti dispongono del progetto esecutivo redatto e validato in conformita' alla vigente normativa, completo del cronoprogramma della spesa. (22) (24)

493. Ferme restando le priorita' di cui alle lettere 0a), 0b), 0c), a), a-bis), c), d), d-bis) e d-ter) del comma 492, qualora l'entita' delle richieste pervenute dagli enti locali superi l'ammontare degli spazi disponibili, l'attribuzione e' effettuata a favore degli enti che presentano la maggiore incidenza del fondo di cassa rispetto all'avanzo di amministrazione. (12) (22) (24)

494. In sede di prima applicazione, nell'anno 2017, i termini di cui ai commi 487, 489, 490 e 492 sono, rispettivamente, il 20 febbraio, il 5 marzo, il 20 febbraio e il 15 marzo. (22)

495. Al fine di favorire gli investimenti, da realizzare attraverso l'utilizzo dei risultati di amministrazione degli esercizi precedenti e il ricorso al debito, per gli anni 2017, 2018 e 2019, sono assegnati alle regioni spazi finanziari nell'ambito dei patti nazionali, di cui all'articolo 10, comma 4, della legge 24 dicembre 2012, n. 243, nel limite complessivo di 500 milioni di euro annui. (22)

495-bis. Per l'anno 2017, gli spazi finanziari di cui al comma 495 sono ripartiti tra le Regioni a statuto ordinario sulla base della tabella di seguito riportata. La tabella di seguito riportata puo' essere modificata con decreto del Ministero dell'economia e delle finanze previa proposta formulata dalle Regioni in sede di auto-coordinamento, da recepire con intesa in Conferenza permanente per i rapporti tra lo Stato, le Regioni e le Province autonome di Trento e di Bolzano entro il 31 luglio 2017. Le Regioni utilizzano gli spazi finanziari di cui alla tabella di seguito riportata per effettuare negli anni dal 2017 al 2021 investimenti nuovi o aggiuntivi. A tal fine, entro il 31 luglio di ciascuno dei predetti anni, le medesime Regioni adottano gli atti finalizzati all'impiego delle risorse, assicurando l'esigibilita' degli impegni nel medesimo anno di riferimento per la quota di competenza di ciascuna Regione, come indicata per ciascun anno nella tabella di seguito riportata. Gli investimenti che le singole Regioni sono chiamate a realizzare, secondo quanto stabilito ai periodi precedenti, sono considerati nuovi o aggiuntivi qualora sia rispettata una delle seguenti condizioni:

- a) le Regioni procedono a variare il bilancio di previsione incrementando gli stanziamenti riguardanti gli investimenti diretti e indiretti per la quota di rispettiva competenza, come indicata nella tabella di seguito riportata;
- b) gli investimenti per l'anno di riferimento sono superiori, per un importo pari ai valori indicati per ciascuna regione nella tabella di seguito riportata, rispetto agli impegni per investimenti diretti e indiretti effettuati nell'esercizio precedente a valere su risorse regionali, escluse le risorse del Fondo pluriennale vincolato. Le Regioni certificano l'avvenuta realizzazione degli investimenti di cui alla tabella di seguito riportata entro il 31 marzo dell'anno successivo a quello di riferimento, mediante apposita comunicazione al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. In caso di mancata o parziale realizzazione degli investimenti, si applicano le sanzioni di cui al comma 475. +-------------------------------------------------------------------+ | | | Riparto | | | | | spazi | | |Regioni |Percen-| finanziari | Profilo investimenti | | | tuale | 2017 | | |--------+-------+----------------+---------------------------------| |Abruzzo | 3,16% | 15.812.894,74 | 2017 | 2018 | | | | | | | | | | | 5.534.513,16 | 4.332.733,16 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 4.111.352,63 | 1.676.166,84 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 158.128,95 | | |--------+-------+----------------+----------------+----------------| |Basili- | | | 2017 | 2018 | |cata | 2,50%| 12.492.894,74 | | | | | | | 4.372.513,16 | 3.423.053,16 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 3.248.152,63 | 1.324.246,84 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 124.928,95 | | |--------+-------+----------------+----------------+----------------| |Calabria| 4,46%| 22.302.894,74 | 2017 | 2018 | | | | | | | | | | | 7.806.013,16 | 6.110.993,16 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 5.798.752,63 | 2.364.106,84 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 223.028,95 | | |--------+-------+----------------+----------------+----------------| |Campania| 10,54%| 52.699.210,53 | 2017 | 2018 | | | | | | | | | | | 18.444.723,68 | 14.439.583,68 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 13.701.794,74 | 5.586.116,32 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 526.992,11 | | |--------+-------+----------------+----------------+----------------| |Emilia- | | | 2017 | 2018 | |Romagna | 8,51%| 42.532.894,74 | | | | | | | 14.886.513,16 | 11.654.013,16 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 11.058.552,63 | 4.508.486,84 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 425.328,95 | | |--------+-------+----------------+----------------+----------------| |Lazio | 11,70%| 58.516.578,95 | 2017 | 2018 | | | | | | | | | | | 20.480.802,63 | 16.033.542,63 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 15.214.310,53 | 6.202.757,37 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 585.165,79 | | |--------+-------+----------------+----------------+----------------| |Liguria | 3,10%| 15.503.947,37 | 2017 | 2018 | | | | | | | | | | | 5.426.381,58 | 4.248.081,58 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 4.031.026,32 | 1.643.418,42 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 155.039,47 | | |--------+-------+----------------+----------------+----------------| |Lombar- | | | 2017 | 2018 | |dia | 17,48%| 87.412.631,58 | | | | | | | 30.594.421,05 | 23.951.061,05 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 22.727.284,21 | 9.265.738,95 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 874.126,32 | | |--------+-------+----------------+----------------+----------------| |Marche | 3,48%| 17.411.842,11 | 2017 | 2018 | | | | | | | | | | | 6.094.144,74 | 4.770.844,74 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 4.527.078,95 | 1.845.655,26 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 174.118,42 | | |--------+-------+----------------+----------------+----------------| |Molise | 0,96%| 4.786.052,63 | 2017 | 2018 | | | | | | | | | | | 1.675.118,42 | 1.311.378,42 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 1.244.373,68 | 507.321,58 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 47.860,53 | | |--------+-------+----------------+----------------+----------------| |Piemonte| 8,23%| 41.136.052,63 | 2017 | 2018 | | | | | | | | | | | 14.397.618,42 | 11.271.278,42 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 10.695.373,68 | 4.360.421,58 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 411.360,53 | | |--------+-------+----------------+----------------+----------------| |Puglia | 8,15%| 40.763.421,05 | 2017 | 2018 | | | | | | | | | | | 14.267.197,37 | 11.169.177,37 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 10.598.489,47 | 4.320.922,63 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 407.634,21 | | |--------+-------+----------------+----------------+----------------| |Toscana | 7,82%| 39.086.578,95 | 2017 | 2018 | | | | | | | | | | | 13.680.302,63 | 10.709.722,63 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 10.162.510,53 | 4.143.177,37 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 390.865,79 | | |--------+-------+----------------+----------------+----------------| |Umbria | 1,96%| 9.810.263,16 | 2017 | 2018 | | | | | | | | | | | 3.433.592,11 | 2.688.012,11 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 2.550.668,42 | 1.039.887,89 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 98.102,63 | | |--------+-------+----------------+----------------+----------------| |Veneto | 7,95%| 39.731.842,11 | 2017 | 2018 | | | | | | | | | | | 13.906.144,74 | 10.886.524,74 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 10.330.278,95 | 4.211.575,26 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 397.318,42 | | |--------+-------+----------------+----------------+----------------| |TOTALE |100,00%| 500.000.000,00 | 2017 | 2018 | | | | | | | | | | | 175.000.000,00 | 137.000.000,00 | | | | |----------------+----------------| | | | | 2019 | 2020 | | | | | | | | | | | 130.000.000,00 | 53.000.000,00 | | | | |----------------+----------------| | | | | 2021 | | | | | | | | | | | | 5.000.000,00 | | +-------------------------------------------------------------------+ (22)

495-ter. Per gli anni 2018 e 2019, gli spazi finanziari di cui al comma 495 sono ripartiti tra le regioni a statuto ordinario sulla base, rispettivamente, delle tabelle 1 e 2 di seguito riportate. Gli spazi finanziari di cui alla tabella 1 sono utilizzati dalle regioni per effettuare nuovi investimenti in ciascuno degli anni dal 2018 al 2022, e gli spazi finanziari di cui alla tabella 2 sono utilizzati dalle regioni per effettuare nuovi investimenti per ciascuno degli anni dal 2019 al 2023. A tal fine, entro il 31 ottobre 2018 e il 31 luglio 2019, le medesime regioni adottano gli atti finalizzati all'impiego delle risorse, assicurando almeno l'esigibilita' degli impegni nel medesimo anno di riferimento per la quota di competenza di ciascuna regione, come indicata per ciascun anno nelle tabelle 1 e 2 di seguito riportate. L'utilizzo degli spazi finanziari di cui alla tabella 2 e' disposto dal bilancio di previsione 2019-2021 attraverso l'iscrizione di stanziamenti di spesa riguardanti gli investimenti finanziati dal risultato di amministrazione presunto o dal ricorso al debito, in misura almeno corrispondente agli importi indicati nella tabella 2. Gli stanziamenti riguardanti le spese di investimento iscritti nel bilancio di previsione 2019-2021 relativamente all'esercizio 2019 risultano incrementati rispetto alle previsioni definitive del bilancio di previsione 2018-2020 riguardanti il medesimo esercizio in misura almeno corrispondente agli importi indicati nella tabella 2. Fatto salvo quanto previsto al precedente periodo, gli investimenti che le singole regioni sono chiamate a realizzare, secondo quanto stabilito nei periodi precedenti, sono considerati nuovi se effettuati a seguito di una variazione del bilancio di previsione che incrementa gli stanziamenti riguardanti gli investimenti diretti e indiretti per la quota di rispettiva competenza, come indicata nelle tabelle di seguito riportate, e se verificati attraverso il sistema di monitoraggio opere pubbliche della Banca dati delle amministrazioni pubbliche (BDAP MOP) ai sensi del decreto legislativo 20 dicembre 2011, n. 229. A tal fine le regioni provvedono alla trasmissione delle informazioni riguardanti i propri investimenti diretti effettuati a valere sugli spazi assegnati e assumono le iniziative necessarie affinche' le pubbliche amministrazioni beneficiarie dei propri contributi erogati a valere sugli spazi finanziari effettuino la trasmissione delle informazioni riguardanti gli investimenti realizzati con tali risorse. Le regioni certificano l'avvenuta realizzazione degli investimenti di cui alle tabelle 1 e 2 di seguito riportate entro il 31 marzo dell'anno successivo a quello di riferimento, mediante apposita comunicazione al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. In caso di mancata o parziale realizzazione degli investimenti, si applicano le sanzioni di cui al comma 475. Parte di provvedimento in formato grafico

496. Le regioni non possono richiedere spazi finanziari per le finalita' di investimento di cui al comma 495, qualora le operazioni di investimento, realizzate con il ricorso all'indebitamento e all'utilizzo dei risultati di amministrazione degli esercizi precedenti, possano essere effettuate nel rispetto del proprio saldo di cui al comma 1 dell'articolo 9 della legge 24 dicembre 2012, n. 243. (22)

497. COMMA ABROGATO DAL D.L. 25 LUGLIO 2018, N. 91, CONVERTITO CON MODIFICAZIONI DALLA L. 21 SETTEMBRE 2018, N. 108.

498. COMMA ABROGATO DAL D.L. 25 LUGLIO 2018, N. 91, CONVERTITO CON MODIFICAZIONI DALLA L. 21 SETTEMBRE 2018, N. 108.

499. COMMA ABROGATO DAL D.L. 25 LUGLIO 2018, N. 91, CONVERTITO CON MODIFICAZIONI DALLA L. 21 SETTEMBRE 2018, N. 108.

500. COMMA ABROGATO DAL D.L. 25 LUGLIO 2018, N. 91, CONVERTITO CON MODIFICAZIONI DALLA L. 21 SETTEMBRE 2018, N. 108.

501. In sede di prima applicazione, nell'anno 2017, i termini di cui ai commi 497 e 499 sono, rispettivamente, il 20 febbraio e il 15 marzo.

502. Fermo restando quanto disposto dall'articolo 9 della legge 24 dicembre 2012, n. 243, e in coerenza con il patto di cui alla legge 23 dicembre 2014, n. 190, al fine di favorire gli investimenti, da realizzare attraverso l'utilizzo dei risultati di amministrazione degli esercizi precedenti, per gli anni dal 2017 al 2030, sono assegnati alle province autonome di Trento e di Bolzano, ai sensi e per gli effetti dell'articolo 10 della citata legge n. 243 del 2012, spazi finanziari nell'importo di 70 milioni di euro per ciascuna provincia nell'anno 2017 e 50 milioni di euro annui per ciascuna provincia negli anni dal 2018 al 2030. (24)

503. Il concorso della regione Trentino-Alto Adige e delle province autonome di Trento e di Bolzano, in termini di saldo netto da finanziare a decorrere dall'esercizio 2017 e in termini anche di indebitamento netto a decorrere dal 2018, previsto dall'articolo 79 del testo unico delle leggi costituzionali concernenti lo statuto speciale per il Trentino-Alto Adige, di cui al decreto del Presidente della Repubblica 31 agosto 1972, n. 670, puo' essere assicurato attraverso contributi posti a carico dei medesimi enti da corrispondere anche mediante compensazioni a valere su somme dovute dallo Stato a qualsiasi titolo, con esclusione dei residui passivi perenti e compresi i gettiti arretrati inerenti a devoluzioni di tributi erariali, previa intesa tra ciascun ente e il Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, entro il 30 aprile di ogni anno.

504. Le disposizioni dei commi 502 e 503 del presente articolo sono approvate ai sensi e per gli effetti dell'articolo 104 del testo unico di cui al decreto del Presidente della Repubblica 31 agosto 1972, n. 670.

505. Alla compensazione degli effetti finanziari in termini di fabbisogno e di indebitamento netto derivanti dal comma 502, pari a 50 milioni di euro nel 2017, a 73 milioni di euro nel 2018, a 98 milioni di euro nel 2019, a 103 milioni di euro nel 2020, a 101 milioni di euro nel 2021, a 100 milioni di euro annui dal 2022 al 2030, a 65 milioni di euro nel 2031, a 38 milioni di euro nel 2032 e a 12 milioni di euro nel 2033, si provvede mediante corrispondente riduzione del Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189. (24)

506. Alle regioni e alle province autonome di Trento e di Bolzano che non sanciscono l'intesa regionale disciplinata dal decreto del Presidente del Consiglio dei ministri di cui all'articolo 10, comma 5, della legge 24 dicembre 2012, n. 243, si applicano, nell'esercizio al quale si riferisce la mancata intesa, le sanzioni di cui al comma 475, lettere c) ed e), del presente articolo. (24)

507. L'ente territoriale attesta l'utilizzo degli spazi finanziari concessi in attuazione delle intese e dei patti di solidarieta' previsti dall'articolo 10 della legge 24 dicembre 2012, n. 243, con l'invio della certificazione di verifica del rispetto dell'obiettivo di saldo di cui al comma 470 del presente articolo. L'ente territoriale non puo' beneficiare di spazi finanziari di competenza dell'esercizio finanziario successivo a quello dell'invio della certificazione di cui al periodo precedente qualora gli spazi finanziari concessi siano stati utilizzati per una quota inferiore al 90 per cento. (24)

508. Qualora l'ente territoriale beneficiario di spazi finanziari concessi in attuazione delle intese e dei patti di solidarieta' previsti dal decreto del Presidente del Consiglio dei ministri di cui all'articolo 10, comma 5, della legge 24 dicembre 2012, n. 243, non effettui la trasmissione delle informazioni richieste dal medesimo decreto del Presidente del Consiglio dei ministri, non puo' procedere ad assunzioni di personale a tempo indeterminato, anche con riferimento ai processi di stabilizzazione in atto, fino a quando non abbia adempiuto. (24)

509. In applicazione del punto 1 dell'Accordo in materia di finanza pubblica con il Governo, sottoscritto in data 20 giugno 2016, la Regione siciliana garantisce un saldo positivo non inferiore ad euro 577.512.000 per l'anno 2017 e un saldo non negativo a decorrere dall'anno 2018, calcolato secondo le modalita' di cui al comma 466. In caso di inadempienza, si applicano le sanzioni di cui ai commi 475 e 476. Alla Regione siciliana non si applicano le disposizioni in materia di patto di stabilita' interno in contrasto con le disposizioni del presente comma. (24)

510. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

511. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

512. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

513. La Regione siciliana, ai sensi dell'articolo 31, comma 3, del decreto legislativo 6 maggio 2011, n. 68, nelle more dell'applicazione delle modalita' attraverso le quali lo Stato assicura il conseguimento degli obiettivi costituzionali di perequazione e di solidarieta' per le regioni a statuto speciale ai sensi dell'articolo 27, comma 2, della legge 5 maggio 2009, n. 42, pone in essere le azioni necessarie affinche' gli enti locali del territorio regionale si sottopongano, anche ai sensi dell'articolo 8 della legge regionale 7 maggio 2015, n. 9, alle rilevazioni in materia di determinazione dei costi e dei fabbisogni standard poste in essere dalla SOSE - Soluzioni per il Sistema Economico Spa, nelle modalita' previste dalle norme richiamate a partire dalla prossima rilevazione.

514. In applicazione delle norme di attuazione dello Statuto della Regione siciliana in materia finanziaria, approvate dalla Commissione paritetica in data 3 ottobre 2016, viene assegnato alla Regione siciliana un importo pari a 6,74 decimi per l'anno 2017 e pari a 7,10 decimi a decorrere dall'anno 2018 dell'imposta sul reddito delle persone fisiche (IRPEF) determinata con riferimento al gettito maturato nel territorio regionale, mediante attribuzione diretta da parte della struttura di gestione, individuata dal regolamento di cui al decreto del Ministro delle finanze 22 maggio 1998, n. 183, nei modi e nei tempi da definire con apposito decreto del Ministro dell'economia e delle finanze, adottato previa intesa con la Regione.

515. Il Ministro dell'economia e delle finanze e' autorizzato ad effettuare, con proprio decreto, le conseguenti variazioni di bilancio.

516. A decorrere dall'anno 2018, nel caso in cui il regime di cui all'articolo 17-ter del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, introdotto dall'articolo 1, comma 629, lettera b), della legge 23 dicembre 2014, n. 190, venga prorogato, la Regione siciliana versa, entro il 30 ottobre di ciascun anno e fino alla scadenza della proroga, al capo X, capitolo n. 3465, articolo 1, dello stato di previsione dell'entrata del bilancio dello Stato, l'importo di 285 milioni di euro annui. In mancanza del predetto versamento nei termini previsti dai commi da 509 a 534 del presente articolo, il Ministero dell'economia e delle finanze, anche per il tramite dell'Agenzia delle entrate - Ufficio struttura di gestione, e' autorizzato a trattenere il corrispettivo importo a valere sulle somme a qualsiasi titolo spettanti alla Regione.

517. Sono restituiti alla regione Valle d'Aosta gli accantonamenti effettuati per gli anni dal 2012 al 2015, ai sensi dell'articolo 15, comma 22, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e dell'articolo 1, comma 132, della legge 24 dicembre 2012, n. 228, e non sono applicati nei confronti della stessa regione gli accantonamenti previsti dalla predetta normativa a decorrere dall'anno 2017.

518. In attuazione del punto 7 dell'Accordo firmato il 21 luglio 2015 tra il presidente della regione Valle d'Aosta e il Ministro dell'economia e delle finanze, a definitiva compensazione della perdita di gettito subita, per gli anni dal 2011 al 2014, dalla regione Valle d'Aosta nella determinazione dell'accisa di cui all'articolo 4, comma 1, lettere a) e b), della legge 26 novembre 1981, n. 690, e' attribuito alla medesima regione l'importo complessivo di 448,8 milioni di euro da corrispondere nell'importo di 74,8 milioni di euro per l'anno 2017, di 65,8 milioni di euro per ciascuno degli anni dal 2018 al 2022 e di 45 milioni di euro per l'anno 2023.

519. Il Ministero dell'economia e delle finanze e la regione Friuli Venezia Giulia procedono, mediante intesa da raggiungere entro il 30 giugno 2017, alla verifica della misura degli accantonamenti effettuati nei confronti della regione Friuli Venezia Giulia, ai sensi dell'articolo 1, commi 711, 712 e 729, della legge 27 dicembre 2013, n. 147, per gli anni dal 2012 al 2015, per effetto delle modifiche intervenute rispetto all'anno 2010 in materia di imposizione locale immobiliare. (17)

520. Ai fini della tutela dell'unita' economica della Repubblica e per la salvaguardia degli equilibri di finanza pubblica, con l'intesa di cui al comma 519 sono definite le modalita' alternative di concorso della regione Friuli Venezia Giulia per gli anni dal 2016 al 2020. Nelle more dell'intesa di cui al periodo precedente, in applicazione del principio di equita' sostanziale, con riferimento all'incremento del carico fiscale sostenuto nei comuni del restante territorio nazionale, il Ministero dell'economia e delle finanze e' autorizzato a recuperare il maggior gettito comunale connesso alle modifiche intervenute rispetto all'anno 2010 in materia di imposizione locale immobiliare, provvisoriamente quantificato nell'importo pari a 72 milioni di euro annui salvo conguaglio, mediante corrispondente riduzione delle somme a qualsiasi titolo spettanti alla regione.

521. Il comma 456 dell'articolo 1 della legge 23 dicembre 2014, n. 190, e' sostituito dal seguente: «456. In considerazione degli effetti positivi sul proprio disavanzo, derivante dal trasferimento dei debiti di cui al comma 454, nel titolo primo della spesa del bilancio della regione Piemonte e' costituito un fondo, allocato su un apposito capitolo di spesa del bilancio gestionale, con una dotazione annua di 151 milioni di euro per l'anno 2015, di 222.500.000 euro per l'anno 2016 e di 218.309.385 euro a decorrere dall'anno 2017 e fino all'esercizio 2045, per il concorso agli oneri assunti dalla gestione commissariale».

522. Il comma 521 determina oneri pari a 4.190.615 euro per ciascuno degli anni dal 2017 al 2045.

523. Al comma 458 dell'articolo 1 della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) al primo periodo sono aggiunte, in fine, le seguenti parole: «e risulti pagata l'ultima rata dell'ammortamento delle anticipazioni di liquidita'»;
- b) dopo il primo periodo sono inseriti i seguenti: «Le risorse residue al 31 dicembre 2016 sulla contabilita' speciale della gestione commissariale derivanti dall'applicazione del comma 456 e inerenti al contributo ivi disciplinato, sono trasferite al bilancio della regione Piemonte. A valere sulle relative entrate la regione consegue un valore positivo del saldo di cui all'articolo 9 della legge 24 dicembre 2012, n. 243».

524. Nel caso in cui il pagamento dei debiti certi, liquidi ed esigibili alla data del 31 dicembre 2013 risulti inferiore rispetto alle anticipazioni di liquidita' ricevute a tal fine dalle regioni beneficiarie ai sensi dell'articolo 2 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, nonche' dalla gestione commissariale istituita dall'articolo 1, commi da 452 a 458, della legge 23 dicembre 2014, n. 190, le risorse eccedenti possono essere utilizzate per il pagamento dei debiti certi, liquidi ed esigibili di cui all'articolo 8, comma 1, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125.

525. Ciascuna amministrazione pubblica interessata fornisce formale certificazione al Tavolo tecnico di cui all'articolo 2 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, dell'avvenuto pagamento dei rispettivi debiti di cui al comma 524 del presente articolo e delle relative registrazioni contabili entro il 28 febbraio 2017.

526. Le somme ricevute a titolo di anticipazione di liquidita' per il pagamento dei debiti certi, liquidi ed esigibili alla data del 31 dicembre 2013 e alla data del 31 dicembre 2014, non rendicontate entro il 31 marzo 2017, costituiscono oggetto di estinzione anticipata entro la data del 30 giugno 2017, da parte delle regioni e delle province autonome.

527. Al comma 6 dell'articolo 46 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, al primo e al terzo periodo, la parola: «2019» e' sostituita dalla seguente: «2020». (18)

528. Al comma 680 dell'articolo 1 della legge 28 dicembre 2015, n. 208, al primo periodo, le parole: «2018 e 2019» sono sostituite dalle seguenti: «2018, 2019 e 2020» e, al secondo periodo, dopo le parole: «modalita' di acquisizione delle risorse da parte dello Stato,» sono inserite le seguenti: «inclusa la possibilita' di prevedere versamenti da parte delle regioni interessate,».

529. Al comma 13-duodecies dell'articolo 8 del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, il secondo periodo e' sostituito dal seguente: «Il riparto del contributo fra le regioni e le province autonome e' effettuato sulla base della proposta formulata dalle regioni e dalle province autonome in sede di auto-coordinamento, anche tenendo conto delle elaborazioni fornite dal Ministero dell'economia e delle finanze - Dipartimento delle finanze, da approvare entro il 30 settembre di ciascun anno mediante intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano».

530. Le anticipazioni di tesoreria, concesse, per gli esercizi 2013 e precedenti, alle regioni a statuto ordinario ai sensi dell'articolo 77-quater del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, per assicurare mensilmente il finanziamento della spesa sanitaria e non regolate alla data di entrata in vigore della presente legge a valere sulle somme della compartecipazione all'IVA assegnate alle regioni per i medesimi esercizi, si intendono trasferimenti definitivi alle regioni a titolo di compartecipazione all'IVA. Dette somme sono compensate con la cancellazione di una corrispondente quota dei residui passivi perenti iscritti a tale titolo sul conto del patrimonio al 31 dicembre 2016.

531. Alle sistemazioni contabili derivanti dall'applicazione del comma 530 provvede, per lo Stato, il Ministro dell'economia e delle finanze con proprio decreto. Le relative registrazioni contabili sono riportate nel rendiconto generale dello Stato per l'esercizio 2017.

532. Le sistemazioni contabili derivanti dall'applicazione del comma 530 del presente articolo sono registrate dalle regioni nelle scritture contabili dell'esercizio 2017.

533. All'articolo 14 della legge 31 dicembre 2009, n. 196, dopo il comma 8 sono inseriti i seguenti: «8-bis. Al fine di favorire il monitoraggio del ciclo completo delle entrate e delle spese, le amministrazioni pubbliche ordinano gli incassi e i pagamenti al proprio tesoriere o cassiere esclusivamente attraverso ordinativi informatici emessi secondo lo standard Ordinativo Informatico emanato dall'Agenzia per l'Italia digitale (AGID), per il tramite dell'infrastruttura della banca dati SIOPE gestita dalla Banca d'Italia nell'ambito del servizio di tesoreria statale. Le modalita' con cui enti e tesorieri scambiano gli ordinativi informatici con l'infrastruttura SIOPE sono definite da apposite regole di colloquio definite congiuntamente con l'AGID e disponibili nelle sezioni dedicate al SIOPE del sito internet istituzionale del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. I tesorieri e i cassieri non possono accettare disposizioni di pagamento con modalita' differenti da quelle descritte nel periodo precedente. 8-ter. Con decreti del Ministero dell'economia e delle finanze, sentite la Conferenza unificata e l'AGID, sono stabiliti le modalita' e i tempi per l'attuazione delle disposizioni di cui al comma 8-bis».

534. In virtu' dell'articolo 51, secondo comma, della legge costituzionale 31 gennaio 1963, n. 1, e' attribuita alla regione Friuli-Venezia Giulia, a decorrere dal 1º gennaio 2017, l'imposta sulle formalita' di trascrizione, iscrizione ed annotazione dei veicoli richieste al pubblico registro automobilistico, avente competenza nel territorio regionale, di cui all'articolo 56 del decreto legislativo 15 dicembre 1997, n. 446, e ad essa sono versate le relative entrate. La regione Friuli-Venezia Giulia puo' disciplinare, nei limiti previsti dal decreto legislativo n. 446 del 1997, l'imposta di cui al periodo precedente, ivi compresa la denominazione della medesima. Fino alla data di entrata in vigore della disciplina regionale continua a trovare applicazione la normativa vigente in ciascuna provincia, con attribuzione del gettito direttamente alla regione Friuli-Venezia Giulia.

534-bis. Previo aggiornamento da parte della Conferenza Unificata, segreteria tecnica della Conferenza permanente per il coordinamento della finanza pubblica, del rapporto sulla determinazione della effettiva entita' e della ripartizione delle misure di consolidamento disposte dalle manovre di finanza pubblica fra i diversi livelli di governo fino all'annualita' 2016 e con la proiezione dell'entita' a legislazione vigente per il 2017 - 2019, a decorrere dall'anno 2017, la Commissione tecnica per i fabbisogni standard di cui all'articolo 1, comma 29, della legge 28 dicembre 2015, n. 208, - sulla base delle elaborazioni e ricognizioni effettuate dalla Societa' Soluzioni per il sistema economico - Sose S.p.A, attraverso l'eventuale predisposizione di appositi questionari, in collaborazione con l'ISTAT e avvalendosi della Struttura tecnica di supporto alla Conferenza delle Regioni e delle Province autonome presso il Centro interregionale di Studi e Documentazione (CINSEDO) delle regioni - provvede all'approvazione di metodologie per la determinazioni di fabbisogni standard e capacita' fiscali standard delle Regioni a statuto ordinario, sulla base dei criteri stabiliti dall'articolo 13 del decreto legislativo 6 maggio 2011, n. 68, nelle materie diverse dalla sanita'.

534-ter. A decorrere dall'anno 2018, il concorso alla finanza pubblica di cui all'articolo 46, comma 6, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e di cui all'articolo 1, comma 680, della legge 28 dicembre 2015, n. 208, in caso di mancato raggiungimento dell'intesa in Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, entro il 15 gennaio di ciascun anno, e' ripartito con decreto del Presidente del Consiglio dei ministri, da adottare previa deliberazione del Consiglio dei ministri, tenendo anche conto dei fabbisogni standard come approvati ai sensi del comma 534-bis e delle capacita' fiscali standard elaborate dal Ministero dell'economia e delle finanze - Dipartimento delle finanze avvalendosi della Struttura tecnica di supporto alla Conferenza delle Regioni e delle Province autonome presso il Centro interregionale di Studi e Documentazione (CINSEDO) delle regioni. In caso di mancata approvazione dei fabbisogni standard e delle capacita' fiscali standard, il concorso alla finanza pubblica di cui al periodo precedente e' ripartito tenendo anche conto della popolazione residente e del PIL. Il predetto decreto del Presidente del Consiglio dei ministri individua anche le modalita' di acquisizione delle risorse da parte dello Stato.

534-quater. Nelle more del riordino del sistema della fiscalita' regionale, secondo i principi di cui all'articolo 119 della Costituzione, la dotazione del Fondo di cui all'articolo 16-bis, comma 1, del decreto-legge 6 luglio 2012, n. 95, convertito con modificazioni dalla legge 7 agosto 2012, n. 135, e' rideterminata nell'importo di 4.789.506.000 euro per l'anno 2017 e 4.932.554.000 euro a decorrere dall'anno 2018, anche al fine di sterilizzare i conguagli di cui all'articolo unico, comma 4, del decreto del Presidente del Consiglio dei ministri 26 luglio 2013, pubblicato nella Gazzetta Ufficiale n. 195 del 21 agosto 2013, con riferimento agli anni 2013 e successivi.

534-quinquies. Il decreto del Presidente del Consiglio dei ministri 26 luglio 2013, pubblicato nella Gazzetta Ufficiale n. 195 del 21 agosto 2013 non trova applicazione a decorrere dall'anno 2017.

535. Al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi e relative sanzioni penali e amministrative, di cui al decreto legislativo 26 ottobre 1995, n. 504, sono apportate le seguenti modificazioni:

- a) all'articolo 6, dopo il comma 15 e' aggiunto il seguente: «15-bis. Le autobotti e le bettoline utilizzate per il trasporto di prodotti sottoposti ad accisa in regime sospensivo sono munite di sistemi di tracciamento della posizione e di misurazione delle quantita' scaricate. Con determinazione del Direttore dell'Agenzia delle dogane e dei monopoli sono stabiliti i termini e le modalita' di applicazione della predetta disposizione»;
- b) all'articolo 8, comma 1, primo periodo, sono aggiunte, in fine, le seguenti parole: «presso il proprio deposito. I prodotti sottoposti ad accisa ricevuti in regime sospensivo sono separatamente detenuti e contabilizzati rispetto a quelli assoggettati ad accisa ricevuti nel medesimo deposito»;
- c) all'articolo 12, comma 1, e' aggiunto, in fine, il seguente periodo: «Alle autobotti e alle bettoline utilizzate per il trasporto di prodotti assoggettati ad accisa si applicano le disposizioni dell'articolo 6, comma 15-bis»;
- d) all'articolo 18, comma 1, dopo le parole: «e presso i destinatari registrati» sono inserite le seguenti: «nonche' presso gli altri impianti soggetti a denuncia» e dopo le parole: «del destinatario registrato» sono inserite le seguenti: «ovvero degli altri soggetti obbligati alla denuncia»;
- e) l'articolo 23 e' sostituito dal seguente: «Art. 23 (Depositi fiscali di prodotti energetici). - 1. Il regime del deposito fiscale e' consentito: a) per le raffinerie e per gli altri stabilimenti di produzione dove si ottengono i prodotti energetici di cui all'articolo 21, comma 2, ovvero i prodotti energetici di cui all'articolo 21, comma 3, ove destinati a carburazione e combustione, nonche' i prodotti sottoposti ad accisa ai sensi dell'articolo 21, commi 4 e 5; b) per gli impianti petrolchimici. 2. L'esercizio degli impianti di cui al comma 1 e' subordinato al rilascio della licenza di cui all'articolo 63. 3. La gestione in regime di deposito fiscale puo' essere autorizzata, laddove sussistano effettive necessita' operative e di approvvigionamento dell'impianto, per i depositi commerciali di gas di petrolio liquefatti di capacita' non inferiore a 400 metri cubi e per i depositi commerciali di altri prodotti energetici di capacita' non inferiore a 10.000 metri cubi. 4. La gestione in regime di deposito fiscale puo' essere, altresi', autorizzata per i depositi commerciali di gas di petrolio liquefatti di capacita' inferiore a 400 metri cubi e per i depositi commerciali di altri prodotti energetici di capacita' inferiore a 10.000 metri cubi quando, oltre ai presupposti di cui al comma 3, ricorra almeno una delle seguenti condizioni: a) il deposito effettui forniture di prodotto in esenzione da accisa o ad accisa agevolata o trasferimenti di prodotti energetici in regime sospensivo verso Paesi dell'Unione europea ovvero esportazioni verso Paesi non appartenenti all'Unione europea, in misura complessiva pari ad almeno il 30 per cento del totale delle estrazioni di un biennio; b) il deposito sia propaggine di un deposito fiscale ubicato nelle immediate vicinanze appartenente allo stesso gruppo societario o, se di diversa titolarita', sia stabilmente destinato ad operare al servizio del predetto deposito. 5. L'esercizio dei depositi fiscali autorizzati ai sensi dei commi 3 e 4 e' subordinato al rilascio della licenza di cui all'articolo 63. 6. L'autorizzazione di cui ai commi 3 e 4 e' negata ai soggetti nei cui confronti, nel quinquennio antecedente la richiesta, sia stata pronunciata sentenza irrevocabile di condanna ai sensi dell'articolo 648 del codice di procedura penale, ovvero sentenza definitiva di applicazione della pena su richiesta, ai sensi dell'articolo 444 del codice di procedura penale, per reati di natura tributaria, finanziaria e fallimentare e per i delitti non colposi previsti dai titoli II, V, VII, VIII e XIII del libro secondo del codice penale, per i quali sia prevista la pena della reclusione. La predetta autorizzazione e' altresi' negata ai soggetti nei confronti dei quali siano in corso procedure concorsuali o siano state definite nell'ultimo quinquennio, nonche' ai soggetti che abbiano commesso violazioni gravi e ripetute, per loro natura od entita', alle disposizioni che disciplinano l'accisa, l'imposta sul valore aggiunto e i tributi doganali, in relazione alle quali siano state contestate sanzioni amministrative nell'ultimo quinquennio. 7. L'istruttoria per il rilascio dell'autorizzazione di cui ai commi 3 e 4 e' sospesa fino al passaggio in giudicato della sentenza conclusiva del procedimento penale, qualora nei confronti del soggetto istante sia stato emesso, ai sensi dell'articolo 424 del codice di procedura penale, decreto che dispone il giudizio per uno dei reati indicati nel comma 6. 8. L'autorizzazione di cui ai commi 3 e 4 puo' essere sospesa dall'Autorita' giudiziaria, anche su richiesta dell'Agenzia delle dogane e dei monopoli, nei confronti del depositario autorizzato per il quale sia stato emesso, ai sensi dell'articolo 424 del codice di procedura penale, decreto che dispone il giudizio per reati di natura tributaria, finanziaria e fallimentare. L'autorizzazione di cui al primo periodo e' in ogni caso sospesa dall'Agenzia delle dogane e dei monopoli laddove venga pronunciata nei confronti del depositario autorizzato sentenza di condanna non definitiva, con applicazione della pena della reclusione, per reati di natura tributaria, finanziaria e fallimentare. Il provvedimento di sospensione ha effetto fino alla emissione della sentenza irrevocabile. 9. L'autorizzazione di cui ai commi 3 e 4 e' revocata ai soggetti nei cui confronti e' stata pronunciata sentenza irrevocabile di condanna ai sensi dell'articolo 648 del codice di procedura penale, ovvero sentenza definitiva di applicazione della pena su richiesta, ai sensi dell'articolo 444 del codice di procedura penale, per reati di natura tributaria, finanziaria e fallimentare, per i quali sia prevista la pena della reclusione. 10. La licenza di cui al comma 2 e' negata, sospesa e revocata allorche' ricorrano rispettivamente le condizioni di cui ai commi 6, 8 e 9 e l'istruttoria per il rilascio e' sospesa allorche' ricorrano le condizioni di cui al comma 7. 11. Nel caso di persone giuridiche e di societa', l'autorizzazione e la licenza sono negate, revocate o sospese, ovvero il procedimento per il rilascio delle stesse e' sospeso, allorche' le situazioni di cui ai commi da 6 a 10 ricorrano, alle condizioni ivi previste, con riferimento a persone che ne rivestono funzioni di rappresentanza, di amministrazione o di direzione, nonche' a persone che ne esercitano, anche di fatto, la gestione e il controllo. 12. L'Agenzia delle dogane e dei monopoli verifica la permanenza delle condizioni previste dal comma 4 e, nel caso esse non possano ritenersi sussistenti, l'autorizzazione di cui al medesimo comma viene sospesa fino a quando non ne sia comprovato il ripristino entro il termine di un anno, alla scadenza del quale viene revocata. Contestualmente all'emissione del provvedimento di sospensione di cui al periodo precedente, viene rilasciata, su richiesta dell'esercente il deposito, la licenza di cui all'articolo 25, comma 4. 13. Per il controllo della produzione, della trasformazione, del trasferimento e dell'impiego dei prodotti energetici, l'Agenzia delle dogane e dei monopoli puo' prescrivere l'installazione di strumenti e apparecchiature per la misura e per il campionamento delle materie prime e dei prodotti semilavorati e finiti; puo', altresi', adottare sistemi di verifica e di controllo con l'impiego di tecniche telematiche ed informatiche. 14. Negli impianti di cui ai commi 1, 3 e 4 dotati di un idoneo sistema informatizzato di controllo in tempo reale del processo di gestione della produzione, detenzione e movimentazione dei prodotti, l'Agenzia delle dogane e dei monopoli procede al controllo dell'accertamento e della liquidazione dell'imposta avvalendosi dei dati necessari alla determinazione della quantita' e della qualita' dei prodotti energetici rilevati dal sistema medesimo con accesso in modo autonomo e diretto. 15. Nei recinti dei depositi fiscali non possono essere detenuti prodotti energetici di cui all'articolo 21, comma 2, ad imposta assolta, eccetto quelli strettamente necessari per il funzionamento degli impianti, stabiliti per quantita' e qualita' dal competente ufficio dell'Agenzia delle dogane e dei monopoli. 16. Per i prodotti immessi in consumo che devono essere sottoposti ad operazioni di miscelazione o a rilavorazioni in un impianto di lavorazione o di deposito, gestito in regime di deposito fiscale, si applicano le disposizioni di cui all'articolo 6, comma 13. 17. La presente disposizione non si applica al gas naturale (codici NC 2711 11 00 e 2711 21 00), al carbone (codice NC 2701), alla lignite (codice NC 2702) e al coke (codice NC 2704)».

536. Per i depositi commerciali gestiti in regime di deposito fiscale, di cui all'articolo 23 del testo unico di cui al decreto legislativo 26 ottobre 1995, n. 504, come sostituito dal comma 535, lettera e), del presente articolo, le disposizioni del comma 4 del citato articolo 23, come sostituito dal comma 535, lettera e), del presente articolo, hanno effetto a decorrere dal terzo anno successivo a quello di entrata in vigore della presente legge.

537. All'articolo 3 del regolamento di cui al decreto del Presidente della Repubblica 21 dicembre 1996, n. 696, dopo il comma 3 e' aggiunto il seguente: «3-bis. Lo scontrino fiscale e la ricevuta fiscale contengono l'indicazione del numero di codice fiscale del cessionario o committente, se richiesto dal cliente non oltre il momento di effettuazione dell'operazione».

538. In attuazione di quanto disposto dal comma 537, con successivo provvedimento del Direttore dell'Agenzia delle entrate sono adeguati i decreti che disciplinano il contenuto dello scontrino fiscale e della ricevuta fiscale.

539. La disposizione di cui al comma 537 si applica alle operazioni effettuate a decorrere dal 1º gennaio 2018.

540. A decorrere dal 1° gennaio 2021 le persone fisiche maggiorenni residenti nel territorio dello Stato che effettuano, esclusivamente attraverso strumenti che consentano il pagamento elettronico, acquisti di beni o servizi, fuori dall'esercizio di attivita' di impresa, arte o professione, presso esercenti che trasmettono telematicamente i corrispettivi, ai sensi dell'articolo 2, comma 1, del decreto legislativo 5 agosto 2015, n. 127, possono partecipare all'estrazione a sorte di premi attribuiti nel quadro di una lotteria nazionale. Per partecipare all'estrazione e' necessario che le persone fisiche maggiorenni residenti nel territorio dello Stato procedano all'acquisto con metodi di pagamento elettronico di cui sono titolari, che traggano fondi detenuti su propri rapporti di credito o debito bancari o su rapporti intestati a componenti del proprio nucleo familiare certificato dal proprio stato di famiglia e costituito antecedentemente alla data di estrazione del premio ovvero che operino in forza di una rappresentanza rilasciata antecedentemente alla partecipazione, e che associno all'acquisto medesimo il proprio codice lotteria, individuato dal provvedimento del direttore dell'Agenzia delle dogane e dei monopoli, d'intesa con l'Agenzia delle entrate, adottato ai sensi del comma 544, e che l'esercente trasmetta all'Agenzia delle entrate i dati della singola cessione o prestazione, secondo le modalita' di cui ai commi 3 e 4 dell'articolo 2 del decreto legislativo 5 agosto 2015, n. 127. A decorrere dal 1° marzo 2021, nel caso in cui l'esercente al momento dell'acquisto rifiuti di acquisire il codice lotteria, la persona fisica puo' segnalare tale circostanza nella sezione dedicata del portale Lotteria del sito internet dell'Agenzia delle dogane e dei monopoli. Tali segnalazioni sono utilizzate dall'Agenzia delle entrate e dal Corpo della guardia di finanza nell'ambito delle attivita' di analisi del rischio di evasione. I premi attribuiti non concorrono a formare il reddito del percipiente per l'intero ammontare corrisposto nel periodo d'imposta e non sono assoggettati ad alcun prelievo erariale.

541. La partecipazione all'estrazione a sorte di cui al comma 540 e' consentita anche con riferimento a tutti gli acquisti di beni o servizi, effettuati fuori dell'esercizio di attivita' d'impresa, arte o professione esclusivamente attraverso strumenti che consentano il pagamento elettronico, documentati con fattura, a condizione che i dati di quest'ultima siano trasmessi telematicamente all'Agenzia delle entrate ai sensi dell'articolo 21 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, ovvero ai sensi dell'articolo 1, comma 3, del decreto legislativo 5 agosto 2015, n. 127.

542. Con il provvedimento di cui al comma 544 sono istituiti premi per un ammontare complessivo annuo non superiore a 45 milioni di euro. Con lo stesso provvedimento sono, altresi', stabilite le modalita' attuative del presente comma, prevedendo premi, nell'ambito del predetto ammontare complessivo, anche per gli esercenti che hanno certificato le operazioni di cessione di beni ovvero prestazione di servizi ai sensi dell'articolo 2, comma 1, del decreto legislativo 5 agosto 2015, n. 127. Al fine di garantire le risorse finanziarie necessarie per l'attribuzione dei premi e le spese amministrative e di comunicazione connesse alla gestione della lotteria, il Fondo iscritto nello stato di previsione del Ministero dell'economia e delle finanze ai sensi dell'articolo 18 del decreto-legge 23 ottobre 2018, n. 119, convertito, con modificazioni, dalla legge 17 dicembre 2018, n. 136, e' incrementato di 50 milioni di euro a decorrere dall'anno 2020. I fondi per le spese amministrative e di comunicazione sono attribuiti alle amministrazioni che sostengono i relativi costi.

543. COMMA ABROGATO DAL D.L. 23 OTTOBRE 2018, N. 119, CONVERTITO CON MODIFICAZIONI DALLA L. 17 DICEMBRE 2018, N. 136.

544. Con uno o piu' provvedimenti del direttore dell'Agenzia delle dogane e dei monopoli, d'intesa con l'Agenzia delle entrate, sono disciplinate le modalita' tecniche di tutte le lotterie degli scontrini, sia istantanee sia differite, relative alle operazioni di estrazione, l'entita' e il numero dei premi messi a disposizione, nonche' ogni altra disposizione necessaria per l'avvio e per l'attuazione delle lotterie. Il divieto di pubblicita' per giochi e scommesse, previsto dall'articolo 9, comma 1, del decreto-legge 12 luglio 2018, n. 87, convertito, con modificazioni, dalla legge 9 agosto 2018, n. 96, non si applica alla lotteria di cui al comma 540.

545. Al fine di contrastare l'elusione e l'evasione fiscale, nonche' di assicurare la tutela dei consumatori e garantire l'ordine pubblico, la vendita o qualsiasi altra forma di collocamento di titoli di accesso ad attivita' di spettacolo effettuata da soggetto diverso dai titolari, anche sulla base di apposito contratto o convenzione, dei sistemi per la loro emissione e' punita, salvo che il fatto non costituisca reato, con l'inibizione della condotta e con sanzioni amministrative pecuniarie da 5.000 euro a 180.000 euro, nonche', ove la condotta sia effettuata attraverso le reti di comunicazione elettronica, secondo le modalita' stabilite dal comma 546, con la rimozione dei contenuti, o, nei casi piu' gravi, con l'oscuramento del sito internet attraverso il quale la violazione e' stata posta in essere, fatte salve le azioni risarcitorie. In ogni caso il mancato pagamento di sanzioni amministrative pecuniarie irrogate dall'Autorita' per le garanzie nelle comunicazioni ai sensi del presente comma per importi complessivamente non inferiori a 1 milione di euro, sempreche' la sanzione non sia piu' contestabile in giudizio per decorso dei termini o per intervenuto giudicato dell'eventuale impugnazione, comporta l'oscuramento del sito internet. L'Autorita' per le garanzie nelle comunicazioni, di concerto con l'Autorita' garante della concorrenza e del mercato, effettua i necessari accertamenti e interventi, agendo d'ufficio ovvero su segnalazione degli interessati e comminando, se del caso, le sanzioni amministrative pecuniarie previste dal presente comma. Non e' comunque sanzionata la vendita ad un prezzo uguale o inferiore a quello nominale di titoli di accesso ad attivita' di spettacolo effettuata da una persona fisica in modo occasionale, purche' senza finalita' commerciali.

545-bis. A decorrere dal 1° luglio 2019, ferme restando le specifiche disposizioni in materia di manifestazioni sportive, per le quali continua ad applicarsi la specifica disciplina di settore, i titoli di accesso ad attivita' di spettacolo in impianti con capienza superiore a 5.000 spettatori sono nominativi, previa efficace verifica dell'i dentita', e riportano la chiara indicazione del nome e del cognome del soggetto che fruisce del titolo di accesso, nel rispetto delle disposizioni del codice in materia di protezione dei dati personali, di cui al decreto legislativo 30 giugno 2003, n. 196. L'accesso all'area dello spettacolo e' subordinato al riconoscimento personale, attraverso controlli e meccanismi efficaci di verifica dell'identita' dei partecipanti all'evento, compresi i minorenni. Sono esclusi da tale prescrizione lo spettacolo viaggiante e gli spettacoli di attivita' lirica, sinfonica e cameristica, prosa, jazz, balletto, danza e circo contemporaneo, nonche' le manifestazioni carnevalesche, i corsi mascherati, le rievocazioni storiche, giostre e manifestazioni similari. Con provvedimento del direttore dell'Agenzia delle entrate, adottato previa intesa con il Ministero per i beni e le attivita' culturali e sentita l'Autorita' per le garanzie nelle comunicazioni, entro sessanta giorni dalla data di entrata in vigore della presente disposizione, sono stabilite le regole tecniche attraverso cui i siti internet di rivendita primari, i box office autorizzati o i siti internet ufficiali dell'evento assicurano la rimessa in vendita dei titoli di ingresso nominativi o il cambio di nominativo.

545-ter. Gli organizzatori delle attivita' di spettacolo possono valersi della collaborazione dei propri dipendenti o dei soggetti iscritti nell'elenco di cui all'articolo 1 del decreto del Ministro dell'interno 6 ottobre 2009, pubblicato nella Gazzetta Ufficiale n. 235 del 9 ottobre 2009, per la vigilanza e per il controllo all'accesso, nonche' per la verifica del possesso dei titoli di ingresso in conformita' a quanto previsto dall'articolo 5 del citato decreto del Ministro dell'interno 6 ottobre 2009.

545-quater. I siti internet di rivendita primari, i box office autorizzati o i siti internet ufficiali dell'evento assicurano la possibilita' di rimettere in vendita i titoli di ingresso nominativi e garantiscono adeguata visibilita' e pubblicita' alla rivendita, agendo da intermediari e provvedendo alla modifica dei dati richiesti dal comma 545bis. Il biglietto cosi' rivenduto a persone fisiche deve essere ceduto al prezzo nominale e senza rincari, ferma restando la possibilita' per i siti internet di rivendita primari, per i box office autorizzati o per i siti internet ufficiali dell'evento di addebitare congrui costi relativi unicamente alla gestione della pratica di intermediazione e di modifica dell'intestazione nominale. I siti internet di rivendita primari, i box office autorizzati e i siti internetufficiali dell'evento consentono inoltre la variazione a titolo non oneroso dell'intestazione nominativa del titolo attraverso la modifica delle generalita' del fruitore addebitando unicamente congrui costi relativi alla gestione della pratica di modifica dell'intestazione nominale. La presente disposizione non si applica in materia di manifestazioni sportive.

545-quinquies. Salva l'ipotesi di cessione autorizzata del titolo di ingresso nominativo secondo le modalita' previste dai commi da 545-bis a 545-quater, nel caso di diversita' tra il nominativo dell'acquirente e quello del soggetto che ne fruisce, i titoli di ingresso sono annullati, senza alcun rimborso.

546. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro della giustizia e con il Ministro dei beni e delle attivita' culturali e del turismo, da emanare, sentite l'Autorita' per le garanzie nelle comunicazioni e la Societa' italiana degli autori ed editori, entro trenta giorni dalla data di entrata in vigore della presente legge, sono adottate, nel rispetto della normativa dell'Unione europea, le specificazioni e regole tecniche attuative del comma 545, in particolare al fine di aumentare l'efficienza e la sicurezza informatica delle vendite dei titoli di accesso mediante i sistemi di biglietterie automatizzate, nonche' di assicurare la tutela dei consumatori.

547. Al testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, sono apportate le seguenti modificazioni:

- a) all'articolo 23, comma 1, lettera g), dopo le parole: «non residenti» sono aggiunte le seguenti: «, nonche' quelli di cui all'articolo 55-bis, comma 1, secondo periodo»;
- b) dopo l'articolo 55 e' inserito il seguente: «Art. 55-bis (Imposta sul reddito d'impresa). - 1. Il reddito d'impresa degli imprenditori individuali e delle societa' in nome collettivo e in accomandita semplice in regime di contabilita' ordinaria, determinato ai sensi del presente capo, e' escluso dalla formazione del reddito complessivo e assoggettato a tassazione separata con l'aliquota prevista dall'articolo 77. Dal reddito d'impresa sono ammesse in deduzione le somme prelevate, a carico dell'utile di esercizio e delle riserve di utili, nei limiti del reddito del periodo d'imposta e dei periodi d'imposta precedenti assoggettati a tassazione separata al netto delle perdite residue computabili in diminuzione dei redditi dei periodi d'imposta successivi, a favore dell'imprenditore, dei collaboratori familiari o dei soci. 2. In deroga all'articolo 8, comma 3, le perdite maturate nei periodi d'imposta di applicazione delle disposizioni di cui al comma 1 del presente articolo sono computate in diminuzione del reddito dei periodi d'imposta successivi per l'intero importo che trova capienza in essi. Le perdite non ancora utilizzate al momento di fuoriuscita dal regime di cui al presente articolo sono computabili in diminuzione dai redditi ai sensi dell'articolo 8, comma 3, considerando l'ultimo anno di permanenza nel regime come anno di maturazione delle stesse. Nel caso di societa' in nome collettivo e in accomandita semplice tali perdite sono imputate a ciascun socio proporzionalmente alla sua quota di partecipazione agli utili. 3. Le somme prelevate a carico dell'utile dell'esercizio e delle riserve di utili, nei limiti del reddito dell'esercizio e dei periodi d'imposta precedenti assoggettati a tassazione separata e non ancora prelevati, a favore dell'imprenditore, dei collaboratori familiari o dei soci costituiscono reddito d'impresa e concorrono integralmente a formare il reddito complessivo dell'imprenditore, dei collaboratori familiari o dei soci. 4. Gli imprenditori e le societa' in nome collettivo e in accomandita semplice in regime di contabilita' ordinaria possono optare per l'applicazione delle disposizioni di cui al presente articolo. L'opzione ha durata pari a cinque periodi d'imposta, e' rinnovabile e deve essere esercitata nella dichiarazione dei redditi, con effetto dal periodo d'imposta cui e' riferita la dichiarazione. 5. L'applicazione del presente articolo esclude quella dell'articolo 5 limitatamente all'imputazione e alla tassazione del reddito indipendentemente dalla sua percezione. 6. Le disposizioni del presente articolo non si applicano alle somme prelevate a carico delle riserve formate con utili dei periodi d'imposta precedenti a quello dal quale ha effetto tale articolo; le riserve da cui sono prelevate le somme si considerano formate prioritariamente con utili di tali periodi d'imposta»;
- c) all'articolo 116: 1) la rubrica e' sostituita dalla seguente: «Opzioni per le societa' a ristretta base proprietaria»; 2) dopo il comma 2 e' aggiunto il seguente: «2-bis. In alternativa a quanto disposto dai commi 1 e 2, le societa' ivi previste possono esercitare l'opzione per l'applicazione del regime di cui all'articolo 55-bis. Gli utili di esercizio e le riserve di utili derivanti dalle partecipazioni nelle societa' che esercitano l'opzione di cui all'articolo 55-bis si considerano equiparati alle somme di cui al comma 3 dello stesso articolo». (11)

548. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145. (24)

549. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145. (32)

550. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145. (32)

551. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145. (32)

552. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145. (32)

553. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

554. All'articolo 2, comma 2, del decreto-legge 24 dicembre 2002, n. 282, convertito, con modificazioni, dalla legge 21 febbraio 2003, n. 27, sono apportate le seguenti modificazioni:

- a) al primo periodo, le parole: «1º gennaio 2016» sono sostituite dalle seguenti: «1º gennaio 2017»;
- b) al secondo periodo, le parole: «30 giugno 2016» sono sostituite dalle seguenti: «30 giugno 2017»;
- c) al terzo periodo, le parole: «30 giugno 2016» sono sostituite dalle seguenti: «30 giugno 2017».

555. Sui valori di acquisto delle partecipazioni non negoziate in mercati regolamentati e dei terreni, edificabili o con destinazione agricola, rideterminati con le modalita' e nei termini indicati dal comma 2 dell'articolo 2 del decreto-legge 24 dicembre 2002, n. 282, convertito, con modificazioni, dalla legge 21 febbraio 2003, n. 27, come modificato dal comma 554 del presente articolo, le aliquote delle imposte sostitutive di cui all'articolo 5, comma 2, della legge 28 dicembre 2001, n. 448, sono pari entrambe all'8 per cento e l'aliquota di cui all'articolo 7, comma 2, della medesima legge e' raddoppiata.

556. I soggetti indicati nell'articolo 73, comma 1, lettere a) e b), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, che non adottano i principi contabili internazionali nella redazione del bilancio, possono, anche in deroga all'articolo 2426 del codice civile e ad ogni altra disposizione di legge vigente in materia, rivalutare i beni di impresa e le partecipazioni di cui alla sezione II del capo I della legge 21 novembre 2000, n. 342, ad esclusione degli immobili alla cui produzione o al cui scambio e' diretta l'attivita' di impresa, risultanti dal bilancio dell'esercizio in corso al 31 dicembre 2015.

557. La rivalutazione deve essere eseguita nel bilancio o rendiconto dell'esercizio successivo a quello di cui al comma 556, per il quale il termine di approvazione scade successivamente alla data di entrata in vigore della presente legge, deve riguardare tutti i beni appartenenti alla stessa categoria omogenea e deve essere annotata nel relativo inventario e nella nota integrativa.

558. Il saldo attivo della rivalutazione puo' essere affrancato, in tutto o in parte, con l'applicazione in capo alla societa' di un'imposta sostitutiva delle imposte sui redditi, dell'imposta regionale sulle attivita' produttive e di eventuali addizionali nella misura del 10 per cento da versare con le modalita' indicate al comma 561.

559. Il maggior valore attribuito ai beni in sede di rivalutazione si considera riconosciuto ai fini delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive a decorrere dal terzo esercizio successivo a quello con riferimento al quale la rivalutazione e' stata eseguita, mediante il versamento di un'imposta sostitutiva delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive e di eventuali addizionali nella misura del 16 per cento per i beni ammortizzabili e del 12 per cento per i beni non ammortizzabili.

560. Nel caso di cessione a titolo oneroso, di assegnazione ai soci, di destinazione a finalita' estranee all'esercizio dell'impresa ovvero al consumo personale o familiare dell'imprenditore dei beni rivalutati in data anteriore a quella di inizio del quarto esercizio successivo a quello nel cui bilancio la rivalutazione e' stata eseguita, ai fini della determinazione delle plusvalenze o minusvalenze si ha riguardo al costo del bene prima della rivalutazione.

561. Le imposte sostitutive di cui ai commi 558 e 559 sono versate in un'unica rata entro il termine di versamento del saldo delle imposte sui redditi dovute per il periodo d'imposta con riferimento al quale la rivalutazione e' eseguita. Gli importi da versare possono essere compensati ai sensi del decreto legislativo 9 luglio 1997, n. 241.

562. Si applicano, in quanto compatibili, le disposizioni degli articoli 11, 13, 14 e 15 della legge 21 novembre 2000, n. 342, quelle del regolamento di cui al decreto del Ministro delle finanze 13 aprile 2001, n. 162, nonche' le disposizioni del regolamento di cui al decreto del Ministro dell'economia e delle finanze 19 aprile 2002, n. 86, e dei commi 475, 477 e 478 dell'articolo 1 della legge 30 dicembre 2004, n. 311.

563. Limitatamente ai beni immobili, i maggiori valori iscritti in bilancio ai sensi dell'articolo 14 della legge 21 novembre 2000, n. 342, si considerano riconosciuti con effetto dal periodo d'imposta in corso alla data del 1º dicembre 2018.

564. Le previsioni di cui all'articolo 14, comma 1, della legge 21 novembre 2000, n. 342, si applicano anche ai soggetti che redigono il bilancio in base ai principi contabili internazionali di cui al regolamento (CE) n. 1606/2002 del Parlamento europeo e del Consiglio, del 19 luglio 2002, anche con riferimento alle partecipazioni, in societa' ed enti, costituenti immobilizzazioni finanziarie ai sensi dell'articolo 85, comma 3-bis, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917. Per tali soggetti, per l'importo corrispondente ai maggiori valori oggetto di riallineamento, al netto dell'imposta sostitutiva di cui al comma 559, e' vincolata una riserva in sospensione d'imposta ai fini fiscali che puo' essere affrancata ai sensi del comma 558.

565. Le disposizioni dell'articolo 1, commi da 115 a 120, della legge 28 dicembre 2015, n. 208, si applicano anche alle assegnazioni, trasformazioni e cessioni poste in essere successivamente al 30 settembre 2016 ed entro il 30 settembre 2017. I versamenti rateali dell'imposta sostitutiva di cui al comma 120 del citato articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2017 ed entro il 16 giugno 2018.

566. Le disposizioni dell'articolo 1, comma 121, della legge 28 dicembre 2015, n. 208, si applicano anche alle esclusioni dal patrimonio dell'impresa dei beni ivi indicati, posseduti alla data del 31 ottobre 2016, poste in essere dal 1º gennaio 2017 al 31 maggio 2017. I versamenti rateali dell'imposta sostitutiva di cui al comma 121 del citato articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2017 e il 16 giugno 2018. Per i soggetti che si avvalgono della presente disposizione gli effetti dell'estromissione decorrono dal 1º gennaio 2017.

567. All'articolo 26 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modificazioni:

- a) al comma 2, dopo le parole: «rescissione e simili» sono inserite le seguenti: «o per mancato pagamento in tutto o in parte a causa di procedure concorsuali o di procedure esecutive individuali rimaste infruttuose o a seguito di un accordo di ristrutturazione dei debiti omologato ai sensi dell'articolo 182-bis del regio decreto 16 marzo 1942, n. 267, ovvero di un piano attestato ai sensi dell'articolo 67, terzo comma, lettera d), del medesimo regio decreto n. 267 del 1942, pubblicato nel registro delle imprese»;
- b) al comma 8, le parole: «ai commi 2, 3, 4 e 5» sono sostituite dalle seguenti: «ai commi 2, 3 e 5»;
- c) al comma 12, alinea, le parole: «Ai fini del comma 4, lettera b),» sono sostituite dalle seguenti: «Ai fini del comma 2»;
- d) i commi 4, 6 e 11 sono abrogati e il secondo periodo del comma 5 e' soppresso.

568. Al fine di favorire lo sviluppo dei servizi e delle tecnologie di tipo a banda larga e di garantire una maggiore efficienza nell'uso dello spettro, i diritti d'uso delle frequenze in banda 900 e 1800 Mhz in scadenza al 30 giugno 2018 possono, su domanda dei titolari, essere oggetto di revisione delle condizioni tecniche e di proroga con decorrenza dal 1º luglio 2017 nel rispetto del principio di neutralita' tecnologica.

569. Ai sensi di quanto previsto dal comma 568, i titolari dei diritti d'uso delle frequenze in banda 900 e 1800 Mhz in scadenza al 30 giugno 2018 possono richiedere l'autorizzazione al cambio della tecnologia sull'intera banda attribuita a far data dal 1º luglio 2017 e contestualmente la proroga alle nuove condizioni tecniche al 31 dicembre 2029 della durata dei suddetti diritti d'uso, previa presentazione di un'unica istanza ai sensi dell'articolo 25, comma 6, del codice delle comunicazioni elettroniche, di cui al decreto legislativo 1º agosto 2003, n. 259, da presentare entro il 15 febbraio 2017, corredata di un dettagliato piano tecnico finanziario.

570. La proroga di cui all'articolo 25 del codice delle comunicazioni elettroniche, di cui al decreto legislativo 1º agosto 2003, n. 259, comporta il pagamento anticipato e in un'unica soluzione dei contributi per i diritti d'uso delle frequenze di cui all'articolo 35 del medesimo codice, da effettuare entro e non oltre il 30 settembre 2017. La misura dei suddetti contributi, rapportati alla quantita' di banda e alla durata, e' data dal valore fissato per le suddette frequenze dalle delibere dell'Autorita' per le garanzie nelle comunicazioni 541/08/CONS del 17 settembre 2008 e 282/11/CONS del 18 maggio 2011, maggiorato del 30 per cento.

571. Il contributo di cui al comma 570 e' attualizzato al tasso di rendimento dei buoni del Tesoro poliennali decennali registrato alla data dell'ultima asta dei buoni del tesoro poliennali antecedente alla data di presentazione dell'istanza.

572. In caso di accoglimento dell'istanza di cui al comma 569, il Ministero dello sviluppo economico provvede a rilasciare i nuovi diritti d'uso con decorrenza dal 1º luglio 2017 e con scadenza al 31 dicembre 2029 con recupero degli eventuali importi gia' versati e dovuti per il primo semestre del 2017 per le autorizzazioni al cambio della tecnologia sulle frequenze in banda 900 e 1800 Mhz in scadenza al 30 giugno 2018.

573. In caso di accoglimento dell'istanza di cui al comma 569, fino al 30 giugno 2018 i gestori radiomobili autorizzati al cambio della tecnologia sono, comunque, tenuti al rispetto degli obblighi di cui alle rispettive licenze di global system for mobile communications (GSM) e in considerazione di tale onere i contributi di cui al comma 570 sono decurtati di un importo pari al 30 per cento in misura proporzionale alla percentuale di banda utilizzata sul territorio nazionale con tecnologia GSM fino alla suddetta data.

574. I diritti d'uso delle frequenze per i quali il Ministero dello sviluppo economico non riceve istanze o non concede proroghe sono messi a gara pubblica entro il 30 giugno 2017 e assegnati entro il 31 ottobre 2017, secondo i criteri adottati dall'Autorita' per le garanzie nelle comunicazioni entro e non oltre il 31 marzo 2017, con importo minimo di base d'asta pari ad almeno il valore dei contributi previsto dal comma 570, ulteriormente maggiorato del 10 per cento.

575. I maggiori introiti per il 2017 derivanti dai commi da 568 a 574 sono quantificati in 2.010 milioni di euro. Al fine di garantire la realizzazione integrale dei predetti maggiori introiti, con riferimento ai diritti d'uso delle frequenze per i quali il Ministero dello sviluppo economico non riceve istanze o non concede proroghe, il Ministero dell'economia e delle finanze, sulla base delle informazioni comunicate dal Ministero dello sviluppo economico, provvede entro il 15 aprile 2017 ad accantonare e rendere indisponibili le corrispondenti somme con le modalita' di cui all'articolo 17, comma 12-bis, della legge 31 dicembre 2009, n. 196. Qualora, a seguito degli esiti della gara di cui al comma 574, come comunicati tempestivamente dal Ministero dello sviluppo economico, gli introiti di cui al periodo precedente non dovessero realizzarsi in tutto o in parte, con decreto del Ministro dell'economia e delle finanze si provvede alla riduzione degli stanziamenti accantonati in misura corrispondente per assicurare la copertura delle minori entrate accertate per il 2017. Nel caso in cui gli stanziamenti da ridurre siano di importo tale da recare pregiudizio alla funzionalita' e all'operativita' delle amministrazioni interessate, il Ministro dell'economia e delle finanze provvede, ai sensi dell'articolo 17, comma 13, della citata legge n. 196 del 2009, ad assicurare il conseguimento degli obiettivi di finanza pubblica, assumendo tempestivamente le conseguenti iniziative legislative. Il Ministro dell'economia e delle finanze riferisce senza ritardo alle Camere con apposita relazione in merito alle cause dello scostamento e all'adozione delle misure di cui al presente comma.

576. Per garantire la tutela degli interessi pubblici nelle attivita' di raccolta del gioco, nel rispetto dei principi di cui alla direttiva 2014/23/UE del Parlamento europeo e del Consiglio, del 26 febbraio 2014, sull'aggiudicazione dei contratti di concessione, nonche' dell'articolo 30 del decreto legislativo 18 aprile 2016, n. 50, la gestione di tali attivita' e' affidata a uno o piu' soggetti scelti mediante procedure aperte, competitive e non discriminatorie. Conseguentemente, in vista della scadenza della concessione vigente, la gestione dei giochi numerici a totalizzatore nazionale, dei giochi complementari e opzionali e delle relative forme di partecipazione a distanza, nonche' di ogni ulteriore gioco numerico basato su un unico totalizzatore a livello nazionale, e' affidata in concessione aggiudicata dall'Agenzia delle dogane e dei monopoli, nel rispetto dei principi e delle regole europei e nazionali, a una qualificata impresa con pregresse esperienze nella gestione o raccolta di gioco ovvero in possesso di una capacita' tecnico-infrastrutturale non inferiore a quella richiesta dal capitolato tecnico, con sede legale in uno degli Stati dello Spazio economico europeo, munita di idonei requisiti di affidabilita' tecnica ed economica, scelta mediante procedura di selezione aperta, competitiva e non discriminatoria. La procedura e' indetta alle seguenti condizioni essenziali:

- a) durata della concessione di nove anni, non rinnovabile;
- b) selezione basata sul criterio dell'offerta economicamente piu' vantaggiosa e, quanto alla componente del prezzo, base d'asta, per le offerte al rialzo, di 100 milioni di euro;
- c) versamento del prezzo indicato nell'offerta del concorrente risultato primo in graduatoria, nella misura del 50 per cento all'atto dell'aggiudicazione e della quota residua all'atto dell'effettiva assunzione del servizio del gioco da parte dell'aggiudicatario;
- d) aggio per il concessionario pari al 5 per cento della raccolta con offerta al ribasso;
- e) espressa previsione, negli atti di gara, delle pratiche o dei rapporti negoziali consentiti ai sensi dell'articolo 2, comma 2, del decreto-legge 25 marzo 2010, n. 40, convertito, con modificazioni, dalla legge 22 maggio 2010, n. 73;
- f) facolta' per il concessionario aggiudicatario di utilizzare la rete di telecomunicazioni per prestazioni, dirette o indirette, di servizi diversi dalla raccolta del gioco, previa autorizzazione dell'Agenzia delle dogane e dei monopoli in ragione della loro compatibilita' con la raccolta stessa;
- g) obbligo di aggiornamento tecnologico del sistema della rete e dei terminali di gioco secondo standard qualitativi che garantiscano la massima sicurezza e affidabilita', secondo il piano d'investimento che costituisce parte dell'offerta tecnica;
- h) obbligo per il concessionario di versamento annuale all'erario delle somme comunque eventualmente non investite secondo il piano di cui alla lettera g) e delle somme addebitate in violazione delle previsioni dei bandi di gara ai sensi della lettera e).

577. Al fine di rendere effettiva l'assunzione del servizio del gioco da parte dell'aggiudicatario, con riferimento alla devoluzione della rete allo Stato, prevista dall'articolo 1, comma 90, lettera e), della legge 27 dicembre 2006, n. 296, l'Agenzia delle dogane e dei monopoli puo' disporre il passaggio diretto del diritto d'uso della rete tra il concessionario uscente e l'aggiudicatario, fermo restando che il diritto d'uso ha termine alla scadenza della nuova concessione.

578. Alle fondazioni bancarie di cui al decreto legislativo 17 maggio 1999, n. 153, e' riconosciuto, per l'anno 2017, un contributo, sotto forma di credito d'imposta, pari al 100 per cento dei versamenti volontari effettuati, nell'ambito della propria attivita' istituzionale, in favore dei fondi speciali istituiti presso le regioni ai sensi dell'articolo 15 della legge 11 agosto 1991, n. 266.

579. Il contributo di cui al comma 578 e' assegnato, fino a esaurimento delle risorse disponibili, pari a 10 milioni di euro, secondo l'ordine temporale con cui le fondazioni comunicano all'Associazione di fondazioni e di casse di risparmio Spa (ACRI) l'impegno a effettuare i versamenti di cui al comma 578. Al fine di consentire la fruizione del credito d'imposta, l'ACRI trasmette all'Agenzia delle entrate l'elenco delle fondazioni finanziatrici per le quali sia stata riscontrata la corretta delibera d'impegno in ordine cronologico di presentazione. Il riconoscimento del credito d'imposta e' comunicato dall'Agenzia delle entrate a ogni fondazione finanziatrice e per conoscenza all'ACRI.

580. Il credito d'imposta puo' essere utilizzato esclusivamente in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, a decorrere dal periodo d'imposta nel quale lo stesso e' stato riconosciuto. Il credito d'imposta di cui al presente comma e' cedibile dai soggetti di cui al comma 578, nel rispetto delle disposizioni di cui agli articoli 1260 e seguenti del codice civile e previa adeguata dimostrazione dell'effettivita' del diritto al credito medesimo, a intermediari bancari, finanziari e assicurativi. La cessione del credito d'imposta e' esente dall'imposta di registro. Al credito d'imposta non si applicano i limiti di cui all'articolo 1, comma 53, della legge 24 dicembre 2007, n. 244, e all'articolo 34 della legge 23 dicembre 2000, n. 388.

581. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono definite le disposizioni applicative necessarie, comprese le procedure per la concessione del contributo nel rispetto del limite di spesa stabilito.

582. Al fine di consentire la partecipazione italiana a centri di ricerca europei e internazionali e alle iniziative promosse dai gruppi intergovernatori informali, dalle istituzioni e dagli organismi dell'Unione europea e dalle banche e dai fondi di sviluppo e di investimento europei, comunque denominati, nonche' per assicurare l'adempimento degli oneri connessi alla partecipazione italiana ai predetti soggetti, anche in esecuzione di accordi internazionali approvati e resi esecutivi, e' autorizzata la spesa di 10 milioni di euro per gli anni 2017 e 2018 e di 20 milioni di euro per l'anno 2019.

583. Al fine di ridurre il debito fiscale delle fondazioni lirico-sinfoniche e di favorire le erogazioni liberali assoggettate all'agevolazione fiscale di cui all'articolo 1 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, e' autorizzata la spesa, in favore di tali enti, di 10 milioni di euro per l'anno 2017 e di 15 milioni di euro annui a decorrere dall'anno 2018. Con decreto del Ministro dei beni e delle attivita' culturali e del turismo, da emanare entro centocinquanta giorni dalla data di entrata in vigore della presente legge, sono stabilite le regole tecniche di ripartizione delle risorse di cui al precedente periodo, anche in modo da erogare prioritariamente a ciascun ente una quota pari, o comunque proporzionalmente commisurata, all'ammontare dei rispettivi contributi provenienti da soggetti privati, dalle regioni e dagli enti locali.

584. Al fine di assicurare il pieno ed efficace svolgimento delle attivita' strumentali alle funzioni di tutela e valorizzazione del patrimonio culturale esercitate dal Ministero dei beni e delle attivita' culturali e del turismo, alla societa' ALES - Arte lavoro e servizi Spa non si applicano le norme di contenimento delle spese previste a legislazione vigente a carico dei soggetti inclusi nell'elenco dell'Istituto nazionale di statistica (ISTAT) delle amministrazioni pubbliche, di cui all'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196.

585. Per la realizzazione delle azioni e delle iniziative, nonche' dei progetti connessi e strumentali all'attuazione del Codice dell'amministrazione digitale di cui al decreto legislativo 7 marzo 2005, n. 82, e dell'Agenda digitale italiana, anche in coerenza con gli obiettivi dell'Agenda digitale europea, e' autorizzata la spesa di 11 milioni di euro per l'anno 2017 e di 20 milioni di euro per l'anno 2018. Le risorse di cui al primo periodo sono trasferite al bilancio autonomo della Presidenza del Consiglio dei ministri con autonoma evidenza contabile. Nell'ambito delle funzioni assegnate, il Commissario straordinario per l'attuazione dell'Agenda digitale di cui all'articolo 63 del decreto legislativo 26 agosto 2016, n. 179, provvede all'utilizzo delle risorse di cui al primo periodo del presente comma per il conseguimento degli obiettivi dell'Agenda digitale.

586. Al finanziamento delle iniziative di cui al comma 585 possono concorrere ulteriori risorse per l'anno 2017, fino a complessivi 9 milioni di euro, a valere sulle risorse dei pertinenti programmi operativi cofinanziati dai fondi strutturali e di investimento europei 2014/2020.

587. E' istituito, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale, un fondo da ripartire con una dotazione finanziaria di 20 milioni di euro per l'anno 2017, di 30 milioni di euro per l'anno 2018 e di 50 milioni di euro per ciascuno degli anni 2019 e 2020, per il potenziamento della promozione della cultura e della lingua italiane all'estero. (32) (33)

588. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro degli affari esteri e della cooperazione internazionale, di concerto con il Ministro dell'economia e delle finanze e con il Ministro dei beni e delle attivita' culturali e del turismo, sono individuati gli interventi da finanziare con il fondo di cui al comma 587.

589. A favore degli italiani nel mondo e' autorizzata la spesa di 4 milioni di euro a decorrere dall'anno 2017 per la promozione della lingua e della cultura italiane all'estero, con particolare riferimento al sostegno degli enti gestori di corsi di lingua e cultura italiane all'estero.

590. Al fine di assicurare il sostegno alle famiglie che hanno concluso le procedure di adozione internazionale, il Fondo per le adozioni internazionali, di cui al comma 411 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' incrementato di 5 milioni di euro per l'anno 2017.

591. E' autorizzata la spesa di 10 milioni di euro per l'anno 2017, di 32 milioni di euro per l'anno 2018 e di 42 milioni di euro per ciascuno degli anni dal 2019 al 2022, quale contributo al nuovo contratto di programma - Parte investimenti 2017-2021 tra il Ministero delle infrastrutture e dei trasporti e Rete ferroviaria italiana (RFI) Spa, con destinazione al finanziamento della nuova linea ferroviaria Ferrandina-Matera La Martella.

592. Allo scopo di favorire la promozione della lingua e della cultura italiane nel mondo attraverso la stampa italiana all'estero, per l'anno 2017 e' autorizzata la spesa di:

- a) 300.000 euro, in favore delle agenzie specializzate per i servizi stampa dedicati agli italiani residenti all'estero;
- b) 1 milione di euro, a integrazione della dotazione finanziaria per i contributi diretti in favore della stampa italiana all'estero di cui all'articolo 1-bis del decreto-legge 18 maggio 2012, n. 63, convertito, con modificazioni, dalla legge 16 luglio 2012, n. 103.

593. E' assegnato al Comitato olimpico nazionale italiano (CONI) un contributo annuo di 1 milione di euro per ciascuno degli anni 2017, 2018 e 2019, destinato allo sviluppo dei settori giovanili delle societa' di pallacanestro e al sostegno degli investimenti per l'impiantistica dedicata alla pallacanestro.

594. All'articolo 8 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, il comma 4 e' sostituito dal seguente: «4. Fatti salvi gli investimenti a reddito da effettuare in via indiretta in Abruzzo ai sensi dell'articolo 14, comma 3, del decreto-legge 28 aprile 2009, n. 39, convertito, con modificazioni, dalla legge 24 giugno 2009, n. 77, le restanti risorse sono destinate dai predetti enti previdenziali all'acquisto di immobili, anche di proprieta' di amministrazioni pubbliche, come individuate dall'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196, adibiti o da adibire ad ufficio in locazione passiva alle amministrazioni pubbliche, secondo le indicazioni fornite dall'Agenzia del demanio sulla base del piano di razionalizzazione di cui al comma 3. Con riferimento agli immobili di proprieta' di amministrazioni pubbliche, possono essere compresi nelle procedure di acquisto di cui al presente comma solo gli immobili di proprieta' delle medesime per i quali non siano in corso contratti di locazione a terzi. L'Agenzia del demanio esprime apposito parere di congruita' in merito ai singoli contratti di locazione da porre in essere o da rinnovare da parte degli enti di previdenza pubblici. Eventuali opere e interventi necessari alla rifunzionalizzazione degli immobili sono realizzati a cura e spese dei medesimi enti sulla base di un progetto elaborato dall'Agenzia del demanio. Ai contratti di locazione degli immobili acquistati ai sensi del presente comma non si applicano le riduzioni del canone previste dall'articolo 3 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135. Con decreto di natura non regolamentare del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono stabilite le modalita' di attuazione del presente comma, nel rispetto dei saldi strutturali di finanza pubblica».

595. La societa' Italia Lavoro Spa assume la denominazione di «ANPAL Servizi Spa».

596. L'articolo 2195 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, e' sostituito dal seguente: «Art. 2195 (Contributi a favore di Associazioni combattentistiche). - 1. Al fine di sostenere le finalita' istituzionali e le attivita' di promozione sociale e di tutela degli associati delle Associazioni combattentistiche, sottoposte alla vigilanza del Ministero della difesa, di cui alla legge 31 gennaio 1994, n. 93, e' autorizzata la spesa di 1 milione di euro per ciascuno degli anni 2017, 2018 e 2019».

597. Al fine di ridurre il debito dell'Ente strumentale alla Croce Rossa italiana nei confronti del sistema bancario, inclusa l'anticipazione bancaria, in essere al 28 febbraio 2017, e' autorizzata la spesa massima di 80 milioni di euro per l'anno 2017, da iscrivere in un fondo nello stato di previsione del Ministero dell'economia e delle finanze.

598. All'erogazione della somma di cui al comma 597 si provvede per l'importo risultante da istanza congiunta del presidente e dell'amministratore dell'Ente strumentale alla Croce Rossa italiana, presentata al Ministero dell'economia e delle finanze - Dipartimento del tesoro, corredata di specifica deliberazione del medesimo Ente, approvata dal Ministero della salute ai sensi dell'articolo 7 del decreto legislativo 28 settembre 2012, n. 178, e certificazione della posizione debitoria netta nei confronti del sistema bancario, inclusa l'anticipazione bancaria, asseverata dal collegio dei revisori dei conti.

599. Presso il Ministero dell'economia e delle finanze e' istituito un fondo per l'incremento degli assegni al nucleo familiare in presenza di quattro o piu' figli da corrispondere al cittadino italiano lavoratore in un Paese membro dell'Unione europea, con una dotazione finanziaria di 2 milioni di euro per l'anno 2017 e di 3 milioni di euro per ciascuno degli anni 2018 e 2019. Con decreto del Ministero dell'economia e delle finanze, entro trenta giorni dalla data di entrata in vigore della presente legge, sono definiti i criteri e le modalita' di erogazione dell'agevolazione di cui al presente comma.

600. Il fondo per la concessione di un assegno sostitutivo ai grandi invalidi di guerra o per servizio, di cui all'articolo 2 della legge 27 dicembre 2002, n. 288, e' incrementato di 300.000 euro a decorrere dal 1º gennaio 2017.

601. La dotazione finanziaria del Fondo per l'attuazione del piano nazionale per le citta', di cui all'articolo 12, comma 5, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' incrementata per l'anno 2017 di euro 7 milioni.

602. Con decreto del Presidente del Consiglio dei ministri, da adottare entro il 30 giugno 2017, su proposta del Ministro della salute, di concerto con il Ministro del lavoro e delle politiche sociali, sono individuate le iniziative urgenti di elevata utilita' sociale nel campo dell'edilizia sanitaria, anche con riferimento alle sinergie tra i servizi sanitari regionali e l'INAIL, valutabili da quest'ultimo ente nell'ambito dei propri piani triennali di investimento immobiliare.

603. Per le finalita' di cui al comma 602, l'INAIL, allo scopo di definire le risorse finanziarie necessarie, tiene anche conto dello stato di attuazione degli investimenti attivati per effetto del decreto del Presidente del Consiglio dei ministri 23 dicembre 2015, adottato ai sensi dell'articolo 1, comma 317, della legge 23 dicembre 2014, n. 190.

604. Ai fini delle necessita' di adeguamento della rete viaria interessata dai progetti sportivi delle finali di coppa del mondo di sci del marzo 2020 e dei campionati mondiali di sci alpino del febbraio 2021, e' autorizzata la spesa di 20 milioni di euro per ciascuno degli anni dal 2017 al 2021.

605. I finanziamenti di cui all'articolo 1, comma 43, della legge 27 dicembre 2013, n. 147, disposti per il triennio 2014-2016 dalla delibera del CIPE 1º agosto 2014, n. 34, sono prorogati per il quadriennio 2017-2020. Il CIPE, in sede di riparto delle risorse del Fondo per lo sviluppo e la coesione a valere sulle disponibilita' relative al periodo di programmazione 2014-2020, provvede con propria delibera all'assegnazione delle risorse nel limite massimo di 2 milioni di euro per ciascuno degli anni dal 2017 al 2020.

606. Per la partecipazione italiana ai programmi di ricerca e sviluppo dell'Unione europea e per il rafforzamento della ricerca nel campo della meteorologia e della climatologia, nonche' per la realizzazione delle infrastrutture necessarie a sostenerne il relativo progetto di localizzazione, e' autorizzata una spesa pari a 15 milioni di euro per l'anno 2017, a 20 milioni di euro per l'anno 2018, a 15 milioni di euro per l'anno 2019 e a 2 milioni di euro annui a decorrere dall'anno 2020. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca sono attribuite le risorse necessarie per la realizzazione delle infrastrutture di cui al periodo precedente e sono definiti gli ulteriori interventi previsti dal medesimo periodo.

607. Le somme delle quali sia eventualmente disposta la confisca ai sensi dell'articolo 19 del decreto legislativo 8 giugno 2001, n. 231, nell'ambito di procedimenti penali per reati ambientali o connessi all'attuazione dell'autorizzazione integrata ambientale nei confronti delle societa' del Gruppo ILVA e delle persone giuridiche che, prima del commissariamento di cui al decreto-legge 4 giugno 2013, n. 61, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 89, abbiano esercitato attivita' di gestione, amministrazione o direzione e coordinamento di tali societa', sono destinate al finanziamento di interventi di decontaminazione e di bonifica ambientale degli stabilimenti di interesse strategico nazionale delle medesime societa'. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

608. Ai fini dell'attuazione della direttiva (UE) 2016/681 del Parlamento europeo e del Consiglio, del 27 aprile 2016, sull'uso dei dati del codice di prenotazione (PNR) a fini di prevenzione, accertamento, indagine e azione penale nei confronti dei reati di terrorismo e dei reati gravi, e nelle more del suo recepimento, e' autorizzata la spesa di 5,5 milioni di euro per l'anno 2017 e di 16 milioni di euro per l'anno 2018 per la realizzazione della piattaforma informatica necessaria e di 4,5 milioni di euro a decorrere dall'anno 2019 per la gestione e la manutenzione della stessa. Le risorse di cui al periodo precedente sono assegnate al Ministero dell'interno - Dipartimento della pubblica sicurezza e iscritte nello stato di previsione del medesimo Ministero nella missione «Ordine pubblico e sicurezza», programma «Pianificazione e coordinamento Forze di polizia».

609. All'articolo 1, comma 6-bis, del decreto-legge 4 dicembre 2015, n. 191, convertito, con modificazioni, dalla legge 1º febbraio 2016, n. 13, sono apportate le seguenti modificazioni:

- a) le parole: «maggiorato di uno spread pari al 3 per cento» sono sostituite dalle seguenti: «maggiorato di uno spread pari al 4,1 per cento»;
- b) e' aggiunto, in fine, il seguente periodo: «I finanziamenti statali concessi ai sensi del presente comma e non erogati cessano di avere efficacia a decorrere dalla data di sottoscrizione delle obbligazioni emesse ai sensi dell'articolo 3, comma 1, del decreto-legge 5 gennaio 2015, n. 1, convertito, con modificazioni, dalla legge 4 marzo 2015, n. 20».

610. All'articolo 3, comma 1, del decreto-legge 5 gennaio 2015, n. 1, convertito, con modificazioni, dalla legge 4 marzo 2015, n. 20, dopo le parole: «alla realizzazione del piano delle misure e delle attivita' di tutela ambientale e sanitaria dell'impresa in amministrazione straordinaria» sono inserite le seguenti: «, previa restituzione dei finanziamenti statali di cui all'articolo 1, comma 6-bis, del decreto-legge 4 dicembre 2015, n. 191, convertito, con modificazioni, dalla legge 1º febbraio 2016, n. 13, per la parte eventualmente erogata,».

611. Entro centoventi giorni dalla data di entrata in vigore della presente legge, l'Agenzia nazionale per l'amministrazione e la destinazione dei beni sequestrati e confiscati alla criminalita' organizzata provvede alla predisposizione della strategia nazionale per la valorizzazione dei beni e delle aziende confiscati alla criminalita' organizzata, in collaborazione con la Presidenza del Consiglio dei ministri - Dipartimento per le politiche di coesione, in coerenza con le indicazioni adottate dal Programma nazionale di riforma contenuto nel Documento di economia e finanza per l'anno 2015 e per l'anno 2016. Il documento di strategia nazionale, con allegati le strategie di area e i relativi piani di azione territoriali, e' sottoposto all'approvazione del CIPE, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. In coerenza con la strategia nazionale approvata dal CIPE, i soggetti titolari di programmi cofinanziati da fondi strutturali e di investimento europei 2014/2020 pianificano, con le modalita' di cui al comma 194 dell'articolo 1 della legge 28 dicembre 2015, n. 208, specifiche azioni volte alla valorizzazione dei predetti beni e aziende. Entro il 30 settembre di ciascun anno, l'Agenzia nazionale per l'amministrazione e la destinazione dei beni sequestrati e confiscati alla criminalita' organizzata presenta al CIPE una relazione annuale sull'attuazione della strategia nazionale per la valorizzazione dei beni e delle aziende confiscati alla criminalita' organizzata, nella quale da' evidenza dei risultati conseguiti e dell'utilizzo delle relative risorse assegnate. I fondi di cui al comma 196 del citato articolo 1 della legge n. 208 del 2015 possono essere incrementati con risorse previste dai Programmi operativi nazionali e regionali cofinanziati dalla Commissione europea 2014/2020, dai programmi operativi complementari di cui alla delibera CIPE 28 gennaio 2015, n. 10, nonche' dal Fondo per lo sviluppo e la coesione attraverso i Piani operativi e i Patti per il Sud, previa verifica di coerenza con le priorita' e gli obiettivi riportati nei suddetti strumenti.

612. Al fine di assicurare il sostegno alle aziende sequestrate e confiscate alla criminalita' organizzata l'autorizzazione di spesa di cui al comma 195 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' incrementata di ulteriori 10 milioni di euro per l'anno 2019, incremento che confluisce nelle apposite sezioni dei Fondi di cui al comma 196 del citato articolo 1 della legge n. 208 del 2015, con le modalita' dallo stesso riportate e con la medesima ripartizione delle risorse tra le sezioni.

613. Al fine di realizzare un Piano strategico nazionale della mobilita' sostenibile destinato al rinnovo del parco degli autobus dei servizi di trasporto pubblico locale e regionale, alla promozione e al miglioramento della qualita' dell'aria con tecnologie innovative, in attuazione degli accordi internazionali nonche' degli orientamenti e della normativa dell'Unione europea, il Fondo di cui all'articolo 1, comma 866, della legge 28 dicembre 2015, n. 208, e' incrementato di 200 milioni di euro per l'anno 2019 e di 250 milioni di euro per ciascuno degli anni dal 2020 al 2033. Per la promozione dello sviluppo e della diffusione di autobus ad alimentazione alternativa, il Fondo puo' essere destinato anche al finanziamento delle relative infrastrutture tecnologiche di supporto. Nell'ambito del Piano strategico nazionale e' previsto un programma di interventi finalizzati ad aumentare la competitivita' delle imprese produttrici di beni e di servizi nella filiera dei mezzi di trasporto pubblico su gomma e dei sistemi intelligenti per il trasporto, attraverso il sostegno agli investimenti produttivi finalizzati alla transizione verso forme produttive piu' moderne e sostenibili, con particolare riferimento alla ricerca e allo sviluppo di modalita' di alimentazione alternativa, per il quale e' autorizzata la spesa di 2 milioni di euro per l'anno 2017 e di 50 milioni di euro per ciascuno degli anni 2018 e 2019.

614. A valere sulle risorse di cui al comma 613, ultimo periodo, il Ministero dello sviluppo economico, d'intesa con il Ministero delle infrastrutture e dei trasporti, puo' immediatamente stipulare convenzioni con l'Agenzia nazionale per l'attrazione degli investimenti e lo sviluppo d'impresa-Invitalia e con dipartimenti universitari specializzati nella mobilita' sostenibile per analisi e studi in ordine ai costi e ai benefici degli interventi previsti e ai fabbisogni territoriali, al fine di predisporre il Piano strategico nazionale e il programma di interventi di cui al comma 613, ultimo periodo.

615. Con apposito decreto del Presidente del Consiglio dei ministri, su proposta del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dello sviluppo economico, con il Ministro dell'economia e delle finanze e con il Ministro dell'ambiente e della tutela del territorio e del mare, e' approvato entro il 30 giugno 2017 il Piano strategico nazionale della mobilita' sostenibile. Con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delle infrastrutture e dei trasporti, da emanare entro il 31 gennaio 2018, sono disciplinati gli interventi di cui al comma 613, ultimo periodo, in coerenza con il Piano strategico nazionale. (15)

616. All'articolo 1-quinquies del decreto-legge 29 marzo 2016, n. 42, convertito, con modificazioni, dalla legge 26 maggio 2016, n. 89, il comma 1 e' sostituito dai seguenti: «1. A decorrere dall'anno 2017 e' corrisposto un contributo alle scuole paritarie di cui alla legge 10 marzo 2000, n. 62, che accolgono alunni con disabilita', nel limite di spesa di 23,4 milioni di euro annui. 1-bis. Il contributo di cui al comma 1 e' ripartito secondo modalita' e criteri definiti con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, da adottare entro trenta giorni dalla data di entrata in vigore della presente disposizione, tenendo conto, per ciascuna scuola paritaria, del numero degli alunni con disabilita' accolti e della percentuale di alunni con disabilita' rispetto al numero complessivo degli alunni frequentanti».

617. All'articolo 15, comma 1, lettera e-bis), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, le parole: «400 euro» sono sostituite dalle seguenti: «564 euro per l'anno 2016, a 717 euro per l'anno 2017, a 786 euro per l'anno 2018 e a 800 euro a decorrere dall'anno 2019».

618. All'articolo 1, comma 330, della legge 23 dicembre 2014, n. 190, le parole: «2017/2018» sono sostituite dalle seguenti: «2019/2020».

619. Per l'anno 2017 e' assegnato alle scuole materne paritarie un contributo aggiuntivo di 50 milioni di euro. Il contributo e' ripartito secondo modalita' e criteri definiti con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge. Il contributo e' erogato entro il 31 ottobre dell'anno scolastico di riferimento.

620. All'articolo 1 della legge 13 luglio 2015, n. 107, dopo il comma 148 sono inseriti i seguenti: «148-bis. In deroga a quanto previsto dal comma 148, le erogazioni liberali in denaro destinate agli investimenti effettuate in favore delle scuole paritarie sono effettuate su un conto corrente bancario o postale intestato alle scuole paritarie beneficiarie stesse, con sistemi di pagamento tracciabili. In tal caso le scuole beneficiarie sono tenute a: a) comunicare mensilmente al Ministero dell'istruzione, dell'universita' e della ricerca l'ammontare delle erogazioni liberali ricevute nel mese di riferimento, provvedendo altresi' a dare pubblica comunicazione di tale ammontare, nonche' della destinazione e dell'utilizzo delle erogazioni stesse tramite il proprio sito internet istituzionale, nell'ambito di una pagina dedicata e facilmente individuabile, e sul portale telematico del Ministero dell'istruzione, dell'universita' e della ricerca, nel rispetto delle disposizioni del codice in materia di protezione dei dati personali, di cui al decreto legislativo 30 giugno 2003, n. 196; b) versare, entro trenta giorni dal ricevimento delle erogazioni liberali di cui alla lettera a), il 10 per cento nel fondo di cui al comma 148 stesso per le finalita' di cui al terzo periodo del medesimo comma. 148-ter. All'attuazione del comma 148-bis si provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per il bilancio dello Stato».

621. E' istituito, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale, un fondo con una dotazione finanziaria di 200 milioni di euro per l'anno 2017, per interventi straordinari volti a rilanciare il dialogo e la cooperazione con i Paesi africani d'importanza prioritaria per le rotte migratorie. (32)

622. Alla legge 11 agosto 2014, n. 125, sono apportate le seguenti modificazioni:

- a) all'articolo 8: 1) dopo il comma 1 e' inserito il seguente: «1-bis. Una quota del fondo rotativo di cui al comma 1, stabilita dal Comitato interministeriale di cui all'articolo 15 nel limite di 50 milioni di euro, e' destinata a costituire un fondo di garanzia per i prestiti concessi dalla Cassa depositi e prestiti Spa ai sensi dell'articolo 22, comma 4. Con decreto di natura non regolamentare del Ministro dell'economia e delle finanze sono definiti i criteri e le modalita' di operativita' del predetto fondo di garanzia»; 2) dopo il comma 2 e' aggiunto il seguente: «2-bis. Le risorse dei fondi di cui al presente articolo sono impignorabili»;
- b) all'articolo 27, comma 3, la lettera c) e' sostituita dalla seguente: «c) costituire un fondo di garanzia per prestiti a favore di imprese miste nei Paesi di cui alla lettera a), concessi dalla Cassa depositi e prestiti Spa, da banche dell'Unione europea, da banche di Paesi non appartenenti all'Unione europea se soggette alla vigilanza prudenziale dell'autorita' competente del Paese in cui si effettua l'intervento o da fondi direttamente o indirettamente partecipati o promossi dai predetti soggetti».

623. Per l'acquisto e l'ammodernamento dei mezzi strumentali, anche utilizzando i meccanismi di centralizzazione acquisti attraverso la societa' Consip Spa, in uso alle Forze di polizia e al Corpo nazionale dei vigili del fuoco, anche mediante leasing finanziario, e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo con una dotazione finanziaria di 70 milioni di euro per l'anno 2017 e di 180 milioni di euro annui per il periodo 2018-2030. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze in relazione alle richieste del Ministro dell'interno, del Ministro della difesa e del Ministro della giustizia, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono individuate le amministrazioni cui destinare le predette somme.

624. Il Fondo per interventi strutturali di politica economica, di cui all'articolo 10, comma 5, del decreto-legge 29 novembre 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307, come rifinanziato dall'articolo 15, comma 1, del decreto-legge 22 ottobre 2016, n. 193, e' ridotto di 4.260 milioni di euro per l'anno 2017, di 4.185,5 milioni di euro per l'anno 2018, di 3.270 milioni di euro per l'anno 2019 e di 2.970 milioni di euro annui a decorrere dall'anno 2020.

625. Il Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190, e' incrementato di 63,95 milioni di euro per il 2017, di 91,75 milioni di euro per il 2018, di 105,402 milioni di euro per il 2019, di 114,45 milioni di euro per il 2020, di 108,45 milioni di euro per il 2021, di 99,45 milioni di euro per il 2022, di 90,45 milioni di euro per il 2023, di 78,45 milioni di euro per il 2024, di 65,45 milioni di euro per il 2025 e di 51,45 milioni di euro annui a decorrere dal 2026.

626. Le disposizioni di cui all'articolo 1, comma 979, della legge 28 dicembre 2015, n. 208, trovano applicazione nei termini ivi previsti anche con riferimento ai soggetti che compiono diciotto anni di eta' nell'anno 2017 e nell'anno 2018, i quali possono utilizzare la Carta elettronica di cui al citato comma 979, anche per l'acquisto di musica registrata, nonche' di corsi di musica, di teatro o di lingua straniera. Entro trenta giorni dalla data di entrata in vigore della presente legge sono apportate le necessarie modificazioni al regolamento di attuazione emanato ai sensi dell'ultimo periodo del predetto comma 979, nei limiti degli stanziamenti iscritti in bilancio nella parte II (sezione II) della presente legge. Per l'anno 2017, nel limite complessivo di 15 milioni di euro, secondo i criteri e le modalita' di cui all'articolo 1, comma 984, della legge 28 dicembre 2015, n. 208, agli studenti iscritti ai licei musicali e agli studenti iscritti ai corsi preaccademici, ai corsi del precedente ordinamento e ai corsi di diploma di I e di II livello dei conservatori di musica, degli istituti superiori di studi musicali e delle istituzioni di formazione musicale e coreutica autorizzate a rilasciare titoli di alta formazione artistica, musicale e coreutica ai sensi dell'articolo 11 del regolamento di cui al decreto del Presidente della Repubblica 8 luglio 2005, n. 212, e' concesso un contributo una tantum pari al 65 per cento del prezzo finale, per un massimo di euro 2.500, per l'acquisto di uno strumento musicale nuovo, coerente con il corso di studi. Con provvedimento del direttore dell'Agenzia delle entrate, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, sono definiti le modalita' attuative, comprese le modalita' per usufruire del credito d'imposta, il regime dei controlli nonche' ogni altra disposizione necessaria per il monitoraggio dell'agevolazione e per il rispetto del limite di spesa previsto. (11)

627. Nello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo e' istituito il Fondo nazionale per la rievocazione storica, finalizzato alla promozione di eventi, feste e attivita' nonche' alla valorizzazione dei beni culturali attraverso la rievocazione storica, con una dotazione di 2 milioni di euro per ciascuno degli anni 2017, 2018 e 2019 e di 2 milioni di euro annui a decorrere dall'anno 2020. PERIODO SOPPRESSO DAL D.L. 30 DICEMBRE 2019, N. 162, CONVERTITO CON MODIFICAZIONI DALLA L. 28 FEBBRAIO 2020, N. 8. (13)

628. All'articolo 1, comma 243, primo periodo, della legge 27 dicembre 2013, n. 147, le parole: «500 milioni di euro annui» sono sostituite dalle seguenti: «1 miliardo di euro all'anno».

629. All'articolo 1, comma 249, della legge 27 dicembre 2013, n. 147, dopo la parola: «2016» sono inserite le seguenti: «nonche' fino al limite di 40 milioni di euro per l'anno 2017».

630. Ulteriori risorse, fino all'importo massimo di 280 milioni di euro, oltre a quelle gia' stanziate nella parte II (sezione II) della presente legge per le attivita' di accoglienza, inclusione e integrazione in materia di trattenimento e di accoglienza per stranieri irregolari, possono essere destinate a valere sui programmi operativi cofinanziati dai fondi strutturali e di investimento europei 2014/2020.

631. Al comma 718 dell'articolo 1 della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) alla lettera a), le parole: «1º gennaio 2017» sono sostituite dalle seguenti: «1º gennaio 2018»;
- b) alla lettera b), le parole: «di due punti percentuali dal 1º gennaio 2017 e di un ulteriore punto percentuale dal 1º gennaio 2018» sono sostituite dalle seguenti: «di tre punti percentuali dal 1º gennaio 2018 e di ulteriori 0,9 punti percentuali dal 1º gennaio 2019».

632. Il comma 626 dell'articolo 1 della legge 27 dicembre 2013, n. 147, e' abrogato.

633. Le maggiori entrate per l'anno 2017 derivanti dall'articolo 7 del decreto-legge 22 ottobre 2016, n. 193, sono quantificate nell'importo di 1.600 milioni di euro.

634. Qualora dal monitoraggio effettuato sulla base delle istanze presentate alla data del 31 luglio 2017, ai sensi dell'articolo 5-octies del decreto-legge 28 giugno 1990, n. 167, convertito, con modificazioni, dalla legge 4 agosto 1990, n. 227, introdotto dall'articolo 7, comma 1, del decreto-legge 22 ottobre 2016, n. 193, risulti che il gettito atteso dai conseguenti versamenti non consenta la realizzazione integrale dell'importo di cui al comma 633 del presente articolo, alla compensazione dell'eventuale differenza si provvede mediante l'eventuale maggior gettito, rispetto a quello previsto per l'esercizio 2017, derivante dalla definizione agevolata dei carichi affidati agli agenti della riscossione dall'anno 2000 all'anno 2016, di cui all'articolo 6 del decreto-legge 22 ottobre 2016, n. 193, convertito, con modificazioni, dalla legge 1º dicembre 2016, n. 225 e dalla definizione agevolata delle controversie tributarie, di cui all'articolo 11 del decreto-legge 24 aprile 2017, n. 50, convertito, con modificazioni, dalla legge 21 giugno 2017, n. 96, ovvero la riduzione degli stanziamenti iscritti negli stati di previsione della spesa disposta, su proposta del Ministro dell'economia e delle finanze, con decreto del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri da adottare entro il 31 agosto 2017. Lo schema del decreto di cui al periodo precedente e' trasmesso alle Camere per l'espressione del parere delle Commissioni parlamentari competenti per i profili finanziari, da rendere entro il termine di sette giorni dalla data della trasmissione. Qualora le Commissioni non si esprimano entro il termine di cui al periodo precedente, il decreto puo' essere adottato in via definitiva.

635. Nel caso di scostamenti non compensabili nel corso dell'esercizio con le misure di cui al comma 634, il Ministro dell'economia e delle finanze, qualora riscontri che dalla mancata integrale compensazione delle minori entrate di cui al medesimo comma 634 derivi un pregiudizio al conseguimento degli obiettivi di finanza pubblica, provvede ai sensi dell'articolo 17, comma 13, della legge 31 dicembre 2009, n. 196, ad assumere, entro il 30 settembre 2017, le conseguenti iniziative legislative al fine di assicurare il rispetto dell'articolo 81 della Costituzione.

636. Il Ministro dell'economia e delle finanze riferisce senza ritardo alle Camere con apposita relazione in merito alle cause dello scostamento e all'adozione delle misure di cui al comma 634.

637. Gli importi da iscrivere nei fondi speciali di cui all'articolo 21, comma 1-ter, lettera d), della legge 31 dicembre 2009, n. 196, per il finanziamento dei provvedimenti legislativi che si prevede possano essere approvati nel triennio 2017-2019 restano determinati, per ciascuno degli anni 2017, 2018 e 2019, nelle misure indicate nelle tabelle A e B allegate alla presente legge, rispettivamente per il fondo speciale destinato alle spese correnti e per il fondo speciale destinato alle spese in conto capitale.

638. Le disposizioni della presente legge si applicano alle regioni a statuto speciale e alle province autonome di Trento e di Bolzano compatibilmente con i rispettivi statuti e le relative norme di attuazione, anche con riferimento alla legge costituzionale 18 ottobre 2001, n. 3.

------------ AGGIORNAMENTO (6) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, ha disposto: - (con l'art. 14, comma 1-ter) che le modifiche di cui ai commi 448, 449, lettere b) e d-bis), 450 e 450-bis del presente articolo trovano applicazione con riferimento al Fondo di solidarieta' comunale relativo agli anni 2018 e successivi; - (con l'art. 22-ter, comma 1) che "Il fondo di cui all'articolo 1, comma 366, della legge 11 dicembre 2016, n. 232, e' incrementato di euro 40.700.000 per l'anno 2017, di euro 132.100.000 per l'anno 2018, di euro 131.600.000 per l'anno 2019, di euro 133.800.000 per l'anno 2020, di euro 136.700.000 per l'anno 2021, di euro 140.500.000 per l'anno 2022, di euro 145.800.000 per l'anno 2023, di euro 153.900.000 per l'anno 2024, di euro 166.400.000 per l'anno 2025 e di euro 184.700.000 annui a decorrere dall'anno 2026"; - (con l'art. 36, comma 3) che la modifica di cui al comma 457 del presente articolo si applica ai comuni e alle province che deliberano lo stato di dissesto finanziario successivamente alla data di entrata in vigore del medesimo D.L., nonche' a quelli, gia' in stato di dissesto finanziario, per i quali alla medesima data non e' stata ancora approvata l'ipotesi di bilancio stabilmente riequilibrato; - (con l'art. 46-novies, comma 1) che "Al fine di rafforzare i dispositivi di sicurezza connessi allo svolgimento del vertice tra i sette maggiori Paesi industrializzati (G7), il contingente di personale delle Forze armate di cui all'articolo 1, comma 377, della legge 11 dicembre 2016, n. 232, e' incrementato, dal 1° maggio 2017 al 28 maggio 2017, di 2.900 unita'"; - (con l'art. 53, comma 1) che "Ai sensi e per gli effetti dell'articolo 1, comma 179, lettera d), della legge 11 dicembre 2016, n. 232, le attivita' lavorative di cui all'allegato C si considerano svolte in via continuativa quando nei sei anni precedenti la data di decorrenza dell'indennita' di cui al comma 181 della medesima legge le medesime attivita' lavorative non hanno subito interruzioni per un periodo complessivamente superiore a dodici mesi e a condizione che le citate attivita' lavorative siano state svolte nel settimo anno precedente la predetta decorrenza per un periodo corrispondente a quello complessivo di interruzione"; - (con l'art. 53, comma 2) che "Ai sensi e per gli effetti dell'articolo 1, comma 199, lettera d), della legge 11 dicembre 2016 n. 232, le attivita' lavorative di cui all'allegato E si considerano svolte in via continuativa quando nei sei anni precedenti la data del pensionamento le medesime attivita' lavorative non hanno subito interruzioni per un periodo complessivamente superiore a dodici mesi e a condizione che le citate attivita' lavorative siano state svolte nel settimo anno precedente il pensionamento per un periodo corrispondente a quello complessivo di interruzione"; - (con l'art. 57, comma 2, lettera b)) che "al comma 94, dopo le parole: "I redditi", le parole: "diversi da quelli relativi a partecipazioni qualificate di cui all'articolo 67, comma 1, lettera c), del decreto del Presidente della Repubblica 22 dicembre 1986, n. 917," sono soppresse". --------------- AGGIORNAMENTO (9) Il D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 8, comma 1) che "A seguito dell'attivita' di monitoraggio e verifica relativa alla misura di salvaguardia prevista dall'articolo 1 commi da 214 a 218 della legge 11 dicembre 2016, n. 232 i benefici di cui al citato comma 214 sono riconosciuti nel limite di 16.294 soggetti e nel limite massimo di 112,2 milioni di euro per l'anno 2017, di 167,4 milioni di euro per l'anno 2018, di 179,3 milioni di euro per l'anno 2019, di 152,1 milioni di euro per l'anno 2020, di 121,2 milioni di euro per l'anno 2021, di 86,3 milioni di euro per l'anno 2022, di 53,7 milioni di euro per l'anno 2023, di 27,8 milioni di euro per l'anno 2024, di 7,2 milioni di euro per l'anno 2025, di 3,1 milioni di euro per l'anno 2026, di 1,5 milioni di euro per l'anno 2027, di 0,8 milioni di euro per l'anno 2028, di 0,2 milioni di euro per l'anno 2029 e di 0,1 milioni di euro per l'anno 2030". --------------- AGGIORNAMENTO (11) La L. 27 dicembre 2017, n. 205 ha disposto: - (con l'art. 1, comma 30) che "Le disposizioni dell'articolo 1, comma 9, della legge 11 dicembre 2016, n. 232, si applicano anche agli investimenti in beni materiali strumentali nuovi effettuati entro il 31 dicembre 2018, ovvero entro il 31 dicembre 2019, a condizione che entro la data del 31 dicembre 2018 il relativo ordine risulti accettato dal venditore e sia avvenuto il pagamento di acconti in misura almeno pari al 20 per cento del costo di acquisizione"; - (con l'art. 1, comma 31) che "Per i soggetti che beneficiano della maggiorazione di cui al comma 30, le disposizioni dell'articolo 1, comma 10, della legge 11 dicembre 2016, n. 232, si applicano anche agli investimenti in beni immateriali strumentali effettuati nel periodo di cui al comma 30"; - (con l'art. 1, comma 42) che "Il termine per la concessione dei finanziamenti di cui all'articolo 1, comma 52, della legge 11 dicembre 2016, n. 232, e' prorogato fino alla data dell'avvenuto esaurimento delle risorse disponibili, comunicato con avviso pubblicato nella Gazzetta Ufficiale ai sensi dell'articolo 2, comma 3, del decreto legislativo 31 marzo 1998, n. 123"; - (con l'art. 1, comma 113) che "A decorrere dal 1º gennaio 2018 e con effetto sulle assunzioni decorrenti da tale data sono abrogati i commi 308, 309 e 310 dell'articolo 1 della legge 11 dicembre 2016, n. 232"; - (con l'art. 1, comma 224) che "Per le finalita' del comma 223 del presente articolo, le disposizioni [...] dell'articolo 1, comma 163, della legge 11 dicembre 2016, n. 232, si applicano anche per l'anno 2018"; - (con l'art. 1, comma 613) che "Il fondo di cui all'articolo 1, comma 366, della legge 11 dicembre 2016, n. 232, e' incrementato di 50 milioni di euro per l'anno 2018 e di 150 milioni di euro annui a decorrere dall'anno 2019"; - (con l'art. 1, comma 633) che "Al fine di sostenere ulteriormente l'ingresso dei giovani nel sistema universitario, a decorrere dal finanziamento relativo al quinquennio 2023-2027, le percentuali di cui all'articolo 1, comma 335, lettere a) e c), della legge 11 dicembre 2016, n. 232, sono ridefinite nella misura rispettivamente dell'80 per cento e del 40 per cento"; - (con l'art. 1, comma 643) che "Le disposizioni di cui al terzo periodo del comma 626 dell'articolo 1 della legge 11 dicembre 2016, n. 232, si applicano anche nell'anno 2018, secondo le modalita' ivi previste, nel limite complessivo di spesa di 10 milioni di euro"; - (con l'art. 1, comma 668) che "L'autorizzazione di spesa di cui all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' ridotta di 10 milioni di euro per l'anno 2018 e di 50 milioni di euro annui a decorrere dall'anno 2019"; - (con l'art. 1, comma 1063) che "Le disposizioni di cui all'articolo 1, commi 547 e 548, della legge 11 dicembre 2016, n. 232, si applicano a decorrere dal 1º gennaio 2018"; - (con l'art. 1, comma 1072) che "Il fondo da ripartire di cui all'articolo 1, comma 140, della legge 11 dicembre 2016, n. 232, e' rifinanziato per 800 milioni di euro per l'anno 2018, per 1.615 milioni di euro per l'anno 2019, per 2.180 milioni di euro per ciascuno degli anni dal 2020 al 2023, per 2.480 milioni di euro per l'anno 2024 e per 2.500 milioni di euro per ciascuno degli anni dal 2025 al 2033. Le predette risorse sono ripartite nei settori di spesa relativi a: a) trasporti e viabilita'; b) mobilita' sostenibile e sicurezza stradale; c) infrastrutture, anche relative alla rete idrica e alle opere di collettamento, fognatura e depurazione; d) ricerca; e) difesa del suolo, dissesto idrogeologico, risanamento ambientale e bonifiche; f) edilizia pubblica, compresa quella scolastica e sanitaria; g) attivita' industriali ad alta tecnologia e sostegno alle esportazioni; h) digitalizzazione delle amministrazioni statali; i) prevenzione del rischio sismico; l) investimenti in riqualificazione urbana e sicurezza delle periferie; m) potenziamento infrastrutture e mezzi per l'ordine pubblico, la sicurezza e il soccorso; n) eliminazione delle barriere architettoniche. Restano fermi i criteri di utilizzo del fondo di cui al secondo, terzo e quarto periodo del citato comma 140"; - (con l'art. 1, comma 1079) che "L'autorizzazione di spesa di cui all'articolo 1, comma 140, della legge 11 dicembre 2016, n. 232, relativamente alla quota affluita, con il decreto del Presidente del Consiglio dei ministri 21 luglio 2017, pubblicato nella Gazzetta Ufficiale n. 226 del 27 settembre 2017, allo stato di previsione del Ministero delle infrastrutture e dei trasporti, capitolo 7008, per gli interventi finanziati con il Fondo per la progettazione di fattibilita' delle infrastrutture e degli insediamenti prioritari per lo sviluppo del Paese, e' ridotta di 5.000.000 di euro per ciascuno degli anni 2018 e 2019"; - (con l'art. 1, comma 1121) che "Nelle materie di interesse del Ministero della giustizia, e' disposta la seguente proroga di termini: all'articolo 1, comma 340, della legge 11 dicembre 2016, n. 232, il periodo di dodici mesi e' prorogato sino al 31 dicembre 2018"; - (con l'art. 1, comma 1148, lettera e)) che "In materia di graduatorie e assunzioni presso le pubbliche amministrazioni, sono disposte le seguenti proroghe di termini: [...] e) il termine per procedere alle assunzioni autorizzate con il decreto previsto all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' prorogato al 31 dicembre 2018". ------------ AGGIORNAMENTO (12) Il D.Lgs. 13 dicembre 2017, n. 217 ha disposto (con l'art. 66, comma 7, lettera b)) che al comma 493 del presente articolo, dopo le parole «alle lettere 0a), a-bis),» sono inserite le seguenti: «a-ter),». -------------- AGGIORNAMENTO (13) La Corte Costituzionale, con sentenza 7 marzo - 5 aprile 2018, n. 71 (in G.U. 1ª s.s. 11/04/2018, n. 15), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 85, della legge 11 dicembre 2016, n. 232 (Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019), nella parte in cui non prevede che il decreto del Presidente del Consiglio dei ministri con il quale sono individuate le Regioni ammesse alla ripartizione, sono assegnate le risorse disponibili e sono stabiliti i criteri di selezione dei progetti sia adottato d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le Regioni e le Province autonome di Trento e di Bolzano" e "l'illegittimita' costituzionale dell'art. 1, comma 627, della legge n. 232 del 2016, nella parte in cui non prevede che il decreto del Ministro dei beni e delle attivita' culturali e del turismo con il quale sono determinati i criteri di accesso al Fondo per la rievocazione storica sia adottato d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le Regioni e le Province autonome di Trento e di Bolzano". -------------- AGGIORNAMENTO (14) La Corte Costituzionale, con sentenza 7 marzo - 13 aprile 2018, n. 74 (in G.U. 1ª s.s. 18/04/2018, n. 16), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 140, della legge 11 dicembre 2016, n. 232 (Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019), nella parte in cui non prevede un'intesa con gli enti territoriali in relazione ai decreti del Presidente del Consiglio dei ministri riguardanti settori di spesa rientranti nelle materie di competenza regionale". -------------- AGGIORNAMENTO (15) La Corte Costituzionale, con sentenza 7 marzo - 19 aprile 2018, n. 78 (in G.U. 1ª s.s. 26/04/2018, n. 17), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 615, della legge 11 dicembre 2016, n. 232 (Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019), nella parte in cui non prevede alcuna forma di coinvolgimento decisionale delle Regioni, in relazione all'approvazione con decreto del Presidente del Consiglio dei ministri del Piano strategico nazionale della mobilita' sostenibile e all'emanazione dell'ivi previsto decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delle infrastrutture e dei trasporti". -------------- AGGIORNAMENTO (16) La Corte Costituzionale con sentenza 20 marzo-26 aprile 2018, n. 87 (in G.U. 1ª s.s. 2/5/2018, n. 18) ha dichiarato l'illegittimita' costituzionale del presente articolo commi 269, 270, 272; l'illegittimita' costituzionale del presente articolo commi 271 nella parte in cui prevede che il decreto del Ministro dell'istruzione, dell'universita' e della ricerca che determina i fabbisogni finanziari regionali e' adottato «previo parere della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, che si esprime entro sessanta giorni dalla data di trasmissione, decorso il quale il decreto puo' essere comunque adottato», anziche' «previa intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano» e 275 nella parte in cui prevede che la «Fondazione Articolo 34», entro il 30 aprile di ogni anno, bandisce almeno 400 borse di studio nazionali «sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano», anziche' «d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano». ----------- AGGIORNAMENTO (17) La Corte Costituzionale, con sentenza 7 marzo - 17 maggio 2018, n. 101 (in G.U. 1ª s.s. 23/05/2018, n. 21), ha dichiarato l'illegittimita' costituzionale: - dell'art. 1, comma 466, della presente legge nella parte in cui stabilisce che, a partire dal 2020, ai fini della determinazione dell'equilibrio del bilancio degli enti territoriali, le spese vincolate provenienti dai precedenti esercizi debbano trovare finanziamento nelle sole entrate di competenza e nella parte in cui non prevede che l'inserimento dell'avanzo di amministrazione e del fondo pluriennale vincolato nei bilanci dei medesimi enti territoriali abbia effetti neutrali rispetto alla determinazione dell'equilibrio dell'esercizio di competenza; - dell'art. 1, comma 475, lettere a) e b), della presente legge nella parte in cui prevede che gli enti locali delle Province autonome di Trento e di Bolzano e della Regione Friuli-Venezia Giulia sono tenuti a versare l'importo della sanzione per il mancato conseguimento dell'obiettivo di finanza pubblica al bilancio dello Stato anziche' a quello delle suddette autonomie speciali; - dell'art. 1, comma 519, della presente legge. --------------- AGGIORNAMENTO (18) La Corte Costituzionale, con sentenza 7 marzo - 23 maggio 2018, n. 103 (in G.U. 1ª s.s. 30/05/2018, n. 22), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 527, della legge 11 dicembre 2016, n. 232 (Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019), limitatamente alle parole «al primo e»". --------------- AGGIORNAMENTO (22) L'Avviso di Rettifica in G.U. 15/10/2018, n. 240, nel modificare l'art. 13, comma 1-bis, lettera b) del D.L. 25 luglio 2018, n. 91, convertito con modificazioni dalla L. 21 settembre 2018, n. 108, ha conseguentemente disposto che "Nella legge citata in epigrafe, pubblicata nella sopra indicata Gazzetta Ufficiale, alla pagina 7, alla novella dell'articolo 1 della legge 11 dicembre 2016, n. 232, dove e' scritto: «b) i commi da 479 a 500 sono abrogati.», leggasi: «b) i commi da 497 a 500 sono abrogati.»". --------------- AGGIORNAMENTO (30) Successivamente la Corte Costituzionale, con sentenza 22 ottobre - 4 dicembre 2019, n. 247 (in G.U. 1ª s.s. 11/12/2019, n. 50), ha dichiarato l'illegittimita' costituzionale dell'art. 25-septies del D.L. 23 ottobre 2018, n. 119, convertito, con modificazioni, dalla L. 17 dicembre 2018, n. 136 (che ha modificato il comma 395 del presente articolo). --------------- AGGIORNAMENTO (24) La L. 30 dicembre 2018, n. 145 ha disposto: - (con l'art. 1, comma 60) che "Al fine di favorire processi di trasformazione tecnologica e digitale secondo il modello « Industria 4.0 », le disposizioni dell'articolo 1, comma 9, della legge 11 dicembre 2016, n. 232, si applicano, nelle misure previste al comma 61 del presente articolo, anche agli investimenti in beni materiali strumentali nuovi, destinati a strutture produttive situate nel territorio dello Stato, effettuati entro il 31 dicembre 2019, ovvero entro il 31 dicembre 2020 a condizione che entro la data del 31 dicembre 2019 il relativo ordine risulti accettato dal venditore e sia avvenuto il pagamento di acconti in misura almeno pari al 20 per cento del costo di acquisizione"; - (con l'art. 1, comma 115) che "L'autorizzazione di spesa di cui all'articolo 1, comma 140, della legge 11 dicembre 2016, n. 232, concernente le risorse per il finanziamento del fondo per la progettazione di fattibilita' delle infrastrutture e degli insediamenti prioritari per lo sviluppo del Paese, relative al settore di spesa delle « infrastrutture, anche relative alla rete idrica e alle opere di collettamento, fognatura e depurazione », ed iscritte nello stato di previsione del Ministero delle infrastrutture e dei trasporti, e' ridotta di 30 milioni di euro per l'anno 2019"; - (con l'art. 1, comma 229) che "La disciplina di cui all'articolo 1, comma 10, della legge 11 dicembre 2016, n. 232, si interpreta nel senso che si considerano agevolabili anche i costi sostenuti a titolo di canone per l'accesso, mediante soluzioni di cloudcomputing, a beni immateriali di cui all'allegato B della medesima legge, limitatamente alla quota del canone di competenza del singolo periodo d'imposta di vigenza della disciplina agevolativa"; - (con l'art. 1, comma 298) che "Il fondo di cui all'articolo 1, comma 365, della legge 11 dicembre 2016, n. 232, per le finalita' di cui alla lettera b) del medesimo comma 365, e' rifinanziato per euro 130.725.000 per l'anno 2019, per euro 328.385.000 per l'anno 2020 e per euro 433.913.000 annui a decorrere dall'anno 2021. Le relative assunzioni a tempo indeterminato, in aggiunta alle facolta' di assunzione previste dalla legislazione vigente, sono autorizzate, nell'ambito delle vacanze di organico, a favore delle amministrazioni dello Stato, degli enti pubblici non economici nazionali e delle agenzie individuati con decreto del Ministro per la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze"; - (con l'art. 1, comma 823) che "A decorrere dall'anno 2019, cessano di avere applicazione i commi 465 e 466, da 468 a 482, da 485 a 493, 502 e da 505 a 509 dell'articolo 1 della legge 11 dicembre 2016, n. 232, i commi da 787 a 790 dell'articolo 1 della legge 27 dicembre 2017, n. 205, e l'articolo 6-bis del decreto-legge 20 giugno 2017, n. 91, convertito, con modificazioni, dalla legge 3 agosto 2017, n. 123. Con riferimento al saldo non negativo dell'anno 2018 restano fermi, per gli enti locali, gli obblighi di monitoraggio e di certificazione di cui ai commi da 469 a 474 del citato articolo 1 della legge n. 232 del 2016. Resta ferma l'applicazione delle sanzioni in caso di mancato conseguimento del saldo non negativo dell'anno 2017, accertato ai sensi dei commi 477 e 478 del medesimo articolo 1 della legge n. 232 del 2016"; - (con l'art. 1, comma 824) che "Le disposizioni dei commi da 819 a 823 si applicano anche alle regioni a statuto ordinario a decorrere dall'anno 2021. L'efficacia del presente comma e' subordinata al raggiungimento, entro il 31 gennaio 2019, dell'intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano sulle risorse aggiuntive per il finanziamento degli investimenti e lo sviluppo infrastrutturale del Paese nelle materie di competenza concorrente di cui ai decreti del Presidente del Consiglio dei ministri previsti dai commi 98 e 126. Decorso il predetto termine, in assenza della proposta di riparto delle risorse di cui al periodo precedente alla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano entro il 15 febbraio 2019, le disposizioni del presente comma acquistano comunque efficacia"; - (con l'art. 1, comma 1055) che la presente modifica ha efficacia, in deroga all'articolo 3 della legge 27 luglio 2000, n. 212, a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2017. La L. 27 dicembre 2017, n. 205, come modificata dalla L. 30 dicembre 2018, n. 145, ha disposto (con l'art. 1, comma 1148, lettera e)) che "In materia di graduatorie e assunzioni presso le pubbliche amministrazioni, sono disposte le seguenti proroghe di termini: [...] e) il termine per procedere alle assunzioni autorizzate con il decreto previsto all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' prorogato al 31 dicembre 2019". --------------- AGGIORNAMENTO (25) Il D.L. 28 gennaio 2019, n. 4, convertito con modificazioni dalla L. 28 marzo 2019, n. 26, ha disposto (con l'art. 17, comma 1) che "Per i soggetti che maturano i requisiti di cui all'articolo 1, comma 199, della legge 11 dicembre 2016, n. 232, non trovano applicazione dal 1° gennaio 2019 e fino al 31 dicembre 2026 gli adeguamenti di cui all'articolo 1, comma 200, della medesima legge n. 232 del 2016 e di cui all'articolo 1, comma 149, della legge 27 dicembre 2017, n. 205, e gli stessi soggetti, a decorrere dal 1° gennaio 2019, conseguono il diritto alla decorrenza del trattamento pensionistico trascorsi tre mesi dalla data di maturazione dei requisiti stessi. Conseguentemente, l'autorizzazione di spesa di cui all'articolo 1, comma 203, della legge n. 232 del 2016, e' incrementata di 31 milioni di euro per l'anno 2019, 54,4 milioni di euro per l'anno 2020, 49,5 milioni di euro per l'anno 2021, 55,3 milioni di euro per l'anno 2022, 100 milioni di euro per l'anno 2023, 118,1 milioni di euro per l'anno 2024, 164,5 milioni di euro per l'anno 2025, 203,7 milioni di euro per l'anno 2026, 215,3 milioni di euro per l'anno 2027 e 219,5 milioni di euro annui a decorrere dall'anno 2028". Ha inoltre disposto (con l'art. 18, comma 1) che "l'autorizzazione di spesa di cui al comma 186 del medesimo articolo 1 della citata legge n. 232 del 2016 e' incrementata di 16,2 milioni di euro per l'anno 2019, 131,8 milioni di euro per l'anno 2020, 142,8 milioni di euro per l'anno 2021, 104,1 milioni di euro per l'anno 2022, 51,0 milioni di euro per l'anno 2023 e 2 milioni di euro per l'anno 2024". --------------- AGGIORNAMENTO (33) La L. 27 dicembre 2017, n. 205, come modificata dal D.L. 30 dicembre 2019, n. 162, ha disposto (con l'art. 1, comma 5) che "In materia di graduatorie e assunzioni presso le pubbliche amministrazioni, sono disposte le seguenti proroghe di termini: [...] il termine per procedere alle assunzioni autorizzate con il decreto previsto all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' prorogato al 31 dicembre 2020". -------------- AGGIORNAMENTO (32) La L. 27 dicembre 2019, n. 160 ha disposto: - (con l'art. 1, comma 226) che "Al fine di rafforzare il sostegno agli investimenti innovativi realizzati dalle micro e piccole imprese nel Mezzogiorno, la maggiorazione di cui all'articolo 1, comma 56, della legge 11 dicembre 2016, n. 232, e' elevata al 100 per cento per le micro e piccole imprese che effettuano investimenti nelle regioni Abruzzo, Basilicata, Calabria, Campania, Molise, Puglia, Sardegna e Sicilia, nel limite complessivo di 60 milioni di euro, a valere sulle risorse di cui al primo periodo"; - (con l'art. 1, comma 266) che "Il fondo di cui all'articolo 1, comma 366, della legge 11 dicembre 2016, n. 232, e' rifinanziato in misura pari a 12,06 milioni di euro nell'anno 2020, a 54,28 milioni di euro nell'anno 2021 e a 49,75 milioni di euro a decorrere dall'anno 2022"; - (con l'art. 1, comma 270) che "A sostegno del sistema italiano della formazione superiore e del sistema educativo italiano, il fondo di cui all'articolo 1, comma 587, della legge 11 dicembre 2016, n. 232, e' incrementato per l'importo di 1.000.000 di euro a decorrere dall'anno 2020 per il sostegno delle iniziative previste all'articolo 3, comma 3, del decreto del Presidente del Consiglio dei ministri 6 luglio 2017, di riparto degli stanziamenti del fondo medesimo"; - (con l'art. 1, comma 287, lettera b)) che "A decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2018: [...] b) si applicano le disposizioni di cui all'articolo 1 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e ai commi da 549 a 552 dell'articolo 1 della legge 11 dicembre 2016, n. 232, con l'aliquota percentuale per il calcolo del rendimento nozionale del nuovo capitale proprio fissata all'1,3 per cento"; - (con l'art. 1, comma 473) che "l'autorizzazione di spesa di cui al comma 186 del medesimo articolo 1 della citata legge n. 232 del 2016 e' incrementata di 108 milioni di euro per l'anno 2020, di 218,7 milioni di euro per l'anno 2021, di 184,6 milioni di euro per l'anno 2022, di 124,4 milioni di euro per l'anno 2023, di 57,1 milioni di euro per l'anno 2024 e di 2,2 milioni di euro per l'anno 2025"; - (con l'art. 1, comma 516) che "Al fine di garantire un sostegno al reddito dei lavoratori dipendenti da imprese adibite alla pesca marittima, compresi i soci lavoratori delle cooperative della piccola pesca di cui alla legge 13 marzo 1958, n. 250, nel periodo di sospensione dell'attivita' lavorativa derivante da misure di arresto temporaneo non obbligatorio, le risorse di cui all'articolo 1, comma 346, quarto periodo, della legge 11 dicembre 2016, n. 232, sono incrementate di 2,5 milioni di euro per l'anno 2021"; - (con l'art. 1, comma 848) che "La dotazione del Fondo di solidarieta' comunale di cui al comma 448 dell'articolo 1 della legge 11 dicembre 2016, n. 232, tenuto anche conto di quanto disposto dal comma 8 dell'articolo 47 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e' incrementata di 100 milioni di euro nel 2020, 200 milioni di euro nel 2021, 300 milioni di euro nel 2022, 330 milioni di euro nel 2023 e 560 milioni di euro annui a decorrere dal 2024"; - (con l'art. 1, comma 850) che "A decorrere dall'anno 2020, la dotazione del Fondo di solidarieta' comunale di cui al comma 448 dell'articolo 1 della legge 11 dicembre 2016, n. 232, e' ridotta di 14,171 milioni di euro annui in conseguenza della minore esigenza di ristoro ai comuni delle minori entrate TASI di cui ai commi da 738 a 783"; - (con l'art. 1, comma 878) che "Il fondo istituito dall'articolo 1, comma 621, della legge 11 dicembre 2016, n. 232, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale e' esteso ai Paesi non africani d'importanza prioritaria per i movimenti migratori e rinominato « Fondo per interventi straordinari volti a rilanciare il dialogo e la cooperazione con i Paesi africani e con altri Paesi d'importanza prioritaria per i movimenti migratori ». A tale Fondo e' assegnata una dotazione di 30 milioni di euro per l'anno 2020, 30 milioni di euro per l'anno 2021 e 40 milioni di euro per l'anno 2022". ------------- AGGIORNAMENTO (33) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 14, comma 4-ter) che "La dotazione del fondo per il potenziamento della promozione della cultura e della lingua italiane all'estero, di cui all'articolo 1, comma 587, della legge 11 dicembre 2016, n. 232, e' incrementata di 200.000 euro per l'anno 2020 e di 1 milione di euro per ciascuno degli anni 2021 e 2022, da ripartire tra i Ministeri interessati con le modalita' previste dal comma 588 dell'articolo 1 della medesima legge n. 232 del 2016". --------------- AGGIORNAMENTO (35) Il D.L. 26 ottobre 2019, n. 124, convertito con modificazioni dalla L. 19 dicembre 2019, n. 157, come modificato dal D.L. 19 maggio 2020, n. 34, ha disposto (con l'art. 13-bis, comma 2-bis) che "Per i piani di risparmio a lungo termine che, per almeno i due terzi dell'anno solare di durata del piano, investano almeno il 70% del valore complessivo, direttamente o indirettamente, in strumenti finanziari, anche non negoziati in mercati regolamentati o in sistemi multilaterali di negoziazione, emessi o stipulati con imprese residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o in Stati membri dell'Unione europea o in Stati aderenti all'Accordo sullo Spazio economico europeo con stabile organizzazione nel territorio dello Stato, diverse da quelle inserite negli indici FTSE MIB e FTSE Mid Cap della Borsa italiana o in indici equivalenti di altri mercati regolamentati, in prestiti erogati alle predette imprese nonche' in crediti delle medesime imprese, il vincolo di cui all'articolo 1, comma 103, della legge 11 dicembre 2016, n. 232, e' elevato al 20%". -------------- AGGIORNAMENTO (39) La L. 27 dicembre 2017, n. 205, come modificata dal D.L. 31 dicembre 2020, n. 183, ha disposto (con l'art. 1, comma 1148, lettera e)) che "il termine per procedere alle assunzioni autorizzate con il decreto previsto all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' prorogato al 31 dicembre 2021". -------------- AGGIORNAMENTO (38) La L. 30 dicembre 2020, n. 178 ha disposto: -(con l'art. 1, comma 445) che "Al fine di migliorare la capacita' di produzione e la reperibilita' di ossigeno medicale in Italia e in considerazione della carenza di bombole di ossigeno durante le fasi acute dell'emergenza epidemiologica da COVID-19, il Fondo per il finanziamento degli investimenti e lo sviluppo infrastrutturale del Paese, di cui all'articolo 1, comma 140, della legge 11 dicembre 2016, n. 232, e' incrementato di 5 milioni di euro per l'anno 2021"; - (con l'art. 1, comma 475) che "A decorrere dall'anno 2021, fermo restando il valore complessivo del 14,85 per cento, il limite della spesa farmaceutica convenzionata di cui all'articolo 1, comma 399, della legge 11 dicembre 2016, n. 232, e' rideterminato nella misura del 7 per cento. Conseguentemente, a partire dal medesimo anno, il tetto di spesa della spesa farmaceutica per acquisti diretti di cui all'articolo 1, comma 398, della citata legge n. 232 del 2016 e' rideterminato nella misura del 7,85 per cento, fermo restando il valore percentuale del tetto per acquisti diretti di gas medicinali di cui all'articolo 1, comma 575, della legge 30 dicembre 2018, n. 145"; - (con l'art. 1, comma 477) che "L'attuazione di quanto previsto dal comma 475, con riferimento all'anno 2021, e' subordinata al pagamento da parte delle aziende farmaceutiche degli oneri di ripiano relativi al superamento del tetto degli acquisti diretti della spesa farmaceutica del Servizio sanitario nazionale dell'anno 2018 entro il 28 febbraio 2021, per un importo non inferiore a quello indicato al secondo periodo, come certificato dall'AIFA entro il 10 marzo 2021. Qualora il pagamento sia inferiore a 895 milioni di euro, restano in vigore i valori percentuali dei tetti previsti dalla normativa vigente. Gli eventuali minori pagamenti sono recuperati dall'AIFA su payback 2021 applicando una maggiorazione del 20 per cento. I pagamenti effettuati a titolo di payback 2018, compresi quelli effettuati fino al 31 dicembre 2020, si intendono corrisposti a titolo definitivo e ne consegue l'estinzione di diritto, per cessata materia del contendere, a spese compensate, delle liti pendenti dinanzi al giudice amministrativo". La L. 30 dicembre 2020, n. 178, nel modificare l'art. 68, comma 1 del D.L. 14 agosto 2020, n. 104, convertito con modificazioni dalla L. 13 ottobre 2020, n. 126, ha conseguentemente disposto (con l'art. 1, comma 225) che "Le disposizioni dei commi da 219 a 224 e del comma 226 si applicano in relazione ai piani costituiti dal 1° gennaio 2021 per gli investimenti effettuati entro il 31 dicembre 2021". -------------- AGGIORNAMENTO (42) Il D.L. 25 maggio 2021, n. 73, convertito, con modificazioni dalla L. 23 luglio 2021, n. 106, ha disposto (con l'art. 35-ter, comma 1, lettera c)) che la presente modifica ha effetto dal 1 gennaio 2022. -------------- AGGIORNAMENTO (46) La L. 27 dicembre 2017, n. 205, come modificata dal D.L. 30 dicembre 2021, n. 228, ha disposto (con l'art. 1, comma 1148, lettera e)) che "il termine per procedere alle assunzioni autorizzate con il decreto previsto all'articolo 1, comma 365, lettera b), della legge 11 dicembre 2016, n. 232, e' prorogato al 31 dicembre 2022". -------------- AGGIORNAMENTO (50) La L. 30 dicembre 2021, n. 234 ha disposto: - (con l'art. 1, comma 92) che "Le disposizioni di cui all'articolo 1, comma 179, lettera d), della legge 11 dicembre 2016, n. 232, si applicano ai lavoratori dipendenti che svolgono le professioni indicate nell'allegato 3 annesso alla presente legge. Per gli operai edili, come indicati nel contratto collettivo nazionale di lavoro per i dipendenti delle imprese edili ed affini, per i ceramisti (classificazione Istat 6.3.2.1.2) e per i conduttori di impianti per la formatura di articoli in ceramica e terracotta (classificazione Istat 7.1.3.3) il requisito dell'anzianita' contributiva di cui alla medesima lettera d) e' di almeno 32 anni"; - (con l'art. 1, comma 93) che "L'autorizzazione di spesa di cui al comma 186 dell'articolo 1 della legge 11 dicembre 2016, n. 232, e' incrementata di 144,1 milioni di euro per l'anno 2022, 278,8 milioni di euro per l'anno 2023, 251,2 milioni di euro per l'anno 2024, 187,8 milioni di euro per l'anno 2025, 106,5 milioni di euro per l'anno 2026 e 17,7 milioni di euro per l'anno 2027"; - (con l'art. 1, comma 259) che "Il Fondo di cui all'articolo 1, comma 401, della legge 11 dicembre 2016, n. 232, relativo al concorso al rimborso alle regioni delle spese sostenute per l'acquisto dei farmaci innovativi e' incrementato di 100 milioni di euro per l'anno 2022, di 200 milioni di euro per l'anno 2023 e di 300 milioni di euro a decorrere dall'anno 2024. Gli importi di cui al presente comma integrano il finanziamento di cui al comma 258"; - (con l'art. 1, comma 281) che "Al fine di sostenere il potenziamento delle prestazioni ricomprese nei LEA, anche alla luce delle innovazioni che caratterizzano il settore, il tetto della spesa farmaceutica per acquisti diretti di cui all'articolo 1, comma 398, della legge 11 dicembre 2016, n. 232, e' rideterminato nella misura dell'8 per cento per l'anno 2022, dell'8,15 per cento per l'anno 2023 e dell'8,30 per cento a decorrere dall'anno 2024"; - (con l'art. 1, comma 466) che "Allo scopo di assicurare il proseguimento e l'accelerazione dei processi di ricostruzione privata nei territori interessati dagli eventi sismici del 24 agosto 2016, l'autorizzazione di spesa di cui all'articolo 1, comma 362, lettera a), della legge 11 dicembre 2016, n. 232, e' incrementata di 200 milioni di euro annui a decorrere dall'anno 2022 per venticinque anni e di ulteriori 100 milioni di euro annui a decorrere dall'anno 2024 per venticinque anni". -------------- AGGIORNAMENTO (51) La L. 23 dicembre 2021, n. 238, ha disposto (con l'art. 3, comma 5) che "L'autorizzazione di spesa di cui all'articolo 1, comma 355, della legge 11 dicembre 2016, n. 232, e' incrementata di 8,5 milioni di euro per l'anno 2021 e di 12,8 milioni di euro annui a decorrere dall'anno 2022". -------------- AGGIORNAMENTO (58) La L. 29 dicembre 2022, n. 197 ha disposto: - (con l'art. 1, comma 291) che "L'autorizzazione di spesa di cui al comma 186 dell'articolo 1 della legge 11 dicembre 2016, n. 232, e' incrementata di 64 milioni di euro per l'anno 2023, di 220 milioni di euro per l'anno 2024, di 235 milioni di euro per l'anno 2025, di 175 milioni di euro per l'anno 2026, di 100 milioni di euro per l'anno 2027 e di 8 milioni di euro per l'anno 2028"; - (con l'art. 1, comma 744) che "Al fine di assicurare la prosecuzione dei processi di ricostruzione privata nei territori interessati dagli eventi sismici verificatisi a far data dal 24 agosto 2016, l'autorizzazione di spesa di cui all'articolo 1, comma 362, lettera a), della legge 11 dicembre 2016, n. 232, come incrementata dall'articolo 1, comma 466, della legge 30 dicembre 2021, n. 234, e' ulteriormente incrementata di 200 milioni di euro per l'anno 2047, di 400 milioni di euro per l'anno 2048 e di 500 milioni di euro per l'anno 2049"; - (con l'art. 1, comma 839) che "La lettera c) del comma 449 dell'articolo 1 della legge 11 dicembre 2016, n. 232, si interpreta nel senso che la quota del Fondo di solidarieta' comunale e' ripartita sulla base della differenza tra le capacita' fiscali e i fabbisogni standard approvati entrambi dalla Commissione tecnica per i fabbisogni standard entro il 30 settembre dell'anno precedente a quello di riferimento"; - (con l'art. 1, comma 887) che "L'autorizzazione di spesa di cui all'articolo 1, comma 203, della legge 11 dicembre 2016, n. 232, e' ridotta di 80 milioni di euro per l'anno 2023, di 90 milioni di euro per l'anno 2024 e di 120 milioni di euro annui a decorrere dal 2025". -------------- AGGIORNAMENTO (61) La L. 30 dicembre 2023, n. 213 ha disposto: - (con l'art. 1, comma 19) che "La misura del canone di abbonamento alla televisione per uso privato, di cui all'articolo 1, comma 40, della legge 11 dicembre 2016, n. 232, e' rideterminata in 70 euro per l'anno 2024"; - (con l'art. 1, comma 136) che "Le disposizioni di cui all'articolo 1, commi da 179 a 186, della legge 11 dicembre 2016, n. 232, si applicano fino al 31 dicembre 2024 per i soggetti che si trovano in una delle condizioni di cui alle lettere da a) a d) del menzionato comma 179 al compimento dei 63 anni e 5 mesi. Le disposizioni di cui al secondo e al terzo periodo del comma 165 dell'articolo 1 della legge 27 dicembre 2017, n. 205, si applicano anche con riferimento ai soggetti che si trovano nelle condizioni ivi indicate nell'anno 2024. L'autorizzazione di spesa di cui al comma 186 dell'articolo 1 della legge 11 dicembre 2016, n. 232, e' incrementata di 85 milioni di euro per l'anno 2024, di 168 milioni di euro per l'anno 2025, di 127 milioni di euro per l'anno 2026, di 67 milioni di euro per l'anno 2027 e di 24 milioni di euro per l'anno 2028"; - (con l'art. 1, comma 178) che "Per effetto di quanto disposto dal comma 177, l'autorizzazione di spesa di cui all'articolo 1, comma 355, della legge 11 dicembre 2016, n. 232, e' incrementata di 240 milioni di euro per l'anno 2024, 254 milioni di euro per l'anno 2025, 300 milioni di euro per l'anno 2026, 302 milioni di euro per l'anno 2027, 304 milioni di euro per l'anno 2028 e 306 milioni di euro annui a decorrere dall'anno 2029"; - (con l'art. 1, comma 223) che "In attuazione di quanto previsto dall'articolo 1, comma 282, della legge 30 dicembre 2021, n. 234, il tetto della spesa farmaceutica per acquisti diretti di cui all'articolo 1, comma 398, della legge 11 dicembre 2016, n. 232, e' rideterminato, rispetto a quanto previsto dall'articolo 1, comma 281, della legge 30 dicembre 2021, n. 234, nella misura dell'8,5 per cento a decorrere dall'anno 2024"; - (con l'art. 1, comma 522) che "L'autorizzazione di spesa di cui all'articolo 1, comma 203, della legge 11 dicembre 2016, n. 232, e' ridotta di 10 milioni di euro per l'anno 2024"; --------------- AGGIORNAMENTO (64) Il D.L. 19 ottobre 2024, n. 155 ha disposto (con l'art. 2, comma 1) che "L'autorizzazione di spesa di cui all'articolo 1, comma 186, della legge 11 dicembre 2016, n. 232, e' incrementata di 20 milioni di euro per l'anno 2025, 30 milioni di euro per l'anno 2026, 50 milioni di euro per l'anno 2027 e di 10 milioni di euro per l'anno 2028". -------------- AGGIORNAMENTO (67) La L. 30 dicembre 2024, n. 207 ha disposto: - (con l'art. 1, comma 175) che " Le disposizioni dei commi da 179 a 186 dell'articolo 1 della legge 11 dicembre 2016, n. 232, si applicano fino al 31 dicembre 2025 per i soggetti che si trovano in una delle condizioni di cui alle lettere da a) a d) del citato comma 179 al compimento dell'eta' di 63 anni e 5 mesi. Le disposizioni del secondo e del terzo periodo del comma 165 dell'articolo 1 della legge 27 dicembre 2017, n. 205, si applicano anche con riferimento ai soggetti che si trovano nelle condizioni ivi indicate nell'anno 2025. L'autorizzazione di spesa di cui al comma 186 dell'articolo 1 della legge n. 232 del 2016 e' incrementata di 114 milioni di euro per l'anno 2025, di 240 milioni di euro per l'anno 2026, di 208 milioni di euro per l'anno 2027, di 151 milioni di euro per l'anno 2028, di 90 milioni di euro per l'anno 2029 e di 35 milioni di euro per l'anno 2030"; - (con l'art. 1, comma 185) che "L'autorizzazione di spesa di cui all'articolo 1, comma 203, della legge 11 dicembre 2016, n. 232, e' ridotta di 16 milioni di euro per l'anno 2027, di 31,7 milioni di euro per l'anno 2028, di 50,8 milioni di euro per l'anno 2029, di 36,6 milioni di euro per l'anno 2030, di 19,7 milioni di euro per l'anno 2031, di 9,3 milioni di euro per l'anno 2032, di 8,5 milioni di euro per l'anno 2033, di 11,5 milioni di euro per l'anno 2034, di 14,1 milioni di euro per l'anno 2035, di 21,4 milioni di euro per l'anno 2036, di 19,5 milioni di euro per l'anno 2037, di 30,2 milioni di euro per l'anno 2038, di 38,3 milioni di euro per l'anno 2039, di 52,7 milioni di euro per l'anno 2040, di 59,3 milioni di euro per l'anno 2041, di 74,4 milioni di euro per l'anno 2042, di 87,6 milioni di euro per l'anno 2043, di 88,8 milioni di euro per l'anno 2044 e di 91,3 milioni di euro annui a decorrere dall'anno 2045"; - (con l'art. 1, comma 209) che "Per effetto di quanto disposto dal primo periodo del presente comma l'autorizzazione di spesa di cui al medesimo articolo 1, comma 355, della legge n. 232 del 2016 e' incrementata di 5 milioni di euro annui a decorrere dall'anno 2025"; - (con l'art. 1, comma 211) che "Per effetto di quanto disposto dal comma 210, l'autorizzazione di spesa di cui all'articolo 1, comma 355, della legge 11 dicembre 2016, n. 232, e' incrementata di 97 milioni di euro per l'anno 2025, di 131 milioni di euro per l'anno 2026, di 194 milioni di euro per l'anno 2027, di 197 milioni di euro per l'anno 2028 e di 200 milioni di euro annui a decorrere dall'anno 2029"; - (con l'art. 1, comma 804) che "L'autorizzazione di spesa di cui all'articolo 1, comma 140, della legge 11 dicembre 2016, n. 232, relativamente alla quota affluita, con il decreto del Presidente del Consiglio dei ministri 21 luglio 2017, pubblicato nella Gazzetta Ufficiale n. 226 del 27 settembre 2017, allo stato di previsione del Ministero delle infrastrutture e dei trasporti destinato agli interventi finanziati con il Fondo per la progettazione di fattibilita' delle infrastrutture e degli insediamenti prioritari per lo sviluppo del Paese, e' ridotta di 20 milioni di euro per l'anno 2025, di 30 milioni di euro per l'anno 2026, di 23 milioni di euro per l'anno 2027, di 49,2 milioni di euro per l'anno 2028, di 45 milioni di euro per l'anno 2029, di 60 milioni di euro per l'anno 2030, di 65 milioni di euro per l'anno 2031 e di 80 milioni di euro per l'anno 2032". -------------- AGGIORNAMENTO (70) Il D.L. 30 giugno 2025, n. 95,convertito con modificazioni dalla L. 8 agosto 2025, n. 118, ha disposto: - (con l'art. 5, comma 3) che "L'autorizzazione di spesa di cui all'articolo 1, comma 186, della legge 11 dicembre 2016, n. 232, e' incrementata di 55 milioni di euro per l'anno 2025, di 60 milioni di euro per l'anno 2026, di 85 milioni di euro per l'anno 2027 e di 50 milioni di euro per l'anno 2028"; - (con l'art. 6-bis, comma 1) che "Il comma 355 dell'articolo 1 della legge 11 dicembre 2016, n. 232, nella parte in cui fa riferimento alla frequenza di asili nido pubblici e privati, si interpreta nel senso che le rette sono relative alla frequenza di servizi educativi per l'infanzia di cui all'articolo 2, comma 3, lettere a), b) e c), numeri 1 e 3, del decreto legislativo 13 aprile 2017, n. 65, pubblici e privati in possesso di titolo abilitativo all'esercizio dell'attivita'"; - (con l'art. 18, comma 1) che "Ai commi 90 e 94 dell'articolo 1 della legge 11 dicembre 2016, n. 232, come modificati dall'articolo 33 della legge 16 dicembre 2024, n. 193, le parole: "gli investimenti qualificati" si interpretano come "gli impegni vincolanti a realizzare direttamente o indirettamente investimenti qualificati".

### Sezione II - Approvazione degli stati di previsione

#### Art. 2. - Stato di previsione dell'entrata

1. L'ammontare delle entrate previste per l'anno finanziario 2017, relative a imposte, tasse, contributi di ogni specie e ogni altro provento, accertate, riscosse e versate nelle casse dello Stato, in virtu' di leggi, decreti, regolamenti e di ogni altro titolo, risulta dall'annesso stato di previsione dell'entrata (Tabella n. 1).

#### Art. 3. - Stato di previsione del Ministero dell'economia e delle finanze e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dell'economia e delle finanze, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 2).

2. L'importo massimo di emissione di titoli pubblici, in Italia e all'estero, al netto di quelli da rimborsare e di quelli per regolazioni debitorie, e' stabilito, per l'anno 2017, in ((79.500 milioni di euro)). (2)

3. I limiti di cui all'articolo 6, comma 9, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, concernente gli impegni assumibili dalla SACE Spa - Servizi assicurativi del commercio estero, sono fissati per l'anno finanziario 2017, rispettivamente, in ((2.000 milioni di euro)) per le garanzie di durata fino a ventiquattro mesi e in ((17.000 milioni di euro)) per le garanzie di durata superiore a ventiquattro mesi.

4. La SACE Spa e' altresi' autorizzata, per l'anno finanziario 2017, a rilasciare garanzie e coperture assicurative relativamente alle attivita' di cui all'articolo 11-quinquies, comma 4, del decreto-legge 14 marzo 2005, n. 35, convertito, con modificazioni, dalla legge 14 maggio 2005, n. 80, entro una quota massima del 30 per cento di ciascuno dei limiti indicati al comma 3 del presente articolo.

5. Gli importi dei fondi previsti dagli articoli 26, 27, 28 e 29 della legge 31 dicembre 2009, n. 196, inseriti nel programma «Fondi di riserva e speciali», nell'ambito della missione «Fondi da ripartire» dello stato di previsione del Ministero dell'economia e delle finanze, sono stabiliti, per l'anno finanziario 2017, rispettivamente, in 1.000 milioni di euro, ((1.500 milioni di euro)), 2.000 milioni di euro, ((399,5 milioni di euro)) e ((6.431 milioni di euro)).

6. Per gli effetti di cui all'articolo 26 della legge 31 dicembre 2009, n. 196, sono considerate spese obbligatorie, per l'anno finanziario 2017, quelle descritte nell'elenco n. 1, allegato allo stato di previsione del Ministero dell'economia e delle finanze.

7. Le spese per le quali si puo' esercitare la facolta' prevista dall'articolo 28 della legge 31 dicembre 2009, n. 196, sono indicate, per l'anno finanziario 2017, nell'elenco n. 2, allegato allo stato di previsione del Ministero dell'economia e delle finanze.

8. Ai fini della compensazione sui fondi erogati per la mobilita' sanitaria in attuazione dell'articolo 12, comma 3, lettera b), del decreto legislativo 30 dicembre 1992, n. 502, il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione al programma «Concorso dello Stato al finanziamento della spesa sanitaria», nell'ambito della missione «Relazioni finanziarie con le autonomie territoriali» dello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello Stato dalle regioni e dalle province autonome di Trento e di Bolzano.

9. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione al programma «Protezione sociale per particolari categorie», azione «Promozione e garanzia delle pari opportunita'», nell'ambito della missione «Diritti sociali, politiche sociali e famiglia» dello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017, delle somme affluite all'entrata del bilancio dello Stato, derivanti dai contributi destinati dall'Unione europea alle attivita' poste in essere dalla Commissione per le pari opportunita' fra uomo e donna.

10. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, al trasferimento delle somme occorrenti per l'effettuazione delle elezioni politiche, amministrative e dei membri del Parlamento europeo spettanti all'Italia e per l'attuazione dei referendum, dal programma «Fondi da assegnare», nell'ambito della missione «Fondi da ripartire» dello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017, ai competenti programmi degli stati di previsione del medesimo Ministero dell'economia e delle finanze e dei Ministeri della giustizia, degli affari esteri e della cooperazione internazionale, dell'interno e della difesa per lo stesso anno finanziario, per l'effettuazione di spese relative a competenze spettanti ai componenti i seggi elettorali, a nomine e notifiche dei presidenti di seggio, a compensi per lavoro straordinario, a compensi agli estranei all'amministrazione, a missioni, a premi, a indennita' e competenze varie spettanti alle Forze di polizia, a trasferte e trasporto delle Forze di polizia, a rimborsi per facilitazioni di viaggio agli elettori, a spese di ufficio, a spese telegrafiche e telefoniche, a fornitura di carta e stampa di schede, a manutenzione e acquisto di materiale elettorale, a servizio automobilistico e ad altre esigenze derivanti dall'effettuazione delle predette consultazioni elettorali.

11. Il Ministro dell'economia e delle finanze e' autorizzato a trasferire, con propri decreti, per l'anno 2017, ai capitoli del titolo III (Rimborso di passivita' finanziarie) degli stati di previsione delle amministrazioni interessate le somme iscritte, per competenza e per cassa, nel programma «Rimborsi del debito statale», nell'ambito della missione «Debito pubblico» dello stato di previsione del Ministero dell'economia e delle finanze, in relazione agli oneri connessi alle operazioni di rimborso anticipato o di rinegoziazione dei mutui con onere a totale o parziale carico dello Stato.

12. Nell'elenco n. 5, allegato allo stato di previsione del Ministero dell'economia e delle finanze, sono indicate le spese per le quali si possono effettuare, per l'anno finanziario 2017, prelevamenti dal fondo a disposizione, di cui all'articolo 9, comma 4, della legge 1º dicembre 1986, n. 831, iscritto nel programma «Prevenzione e repressione delle frodi e delle violazioni agli obblighi fiscali», nell'ambito della missione «Politiche economico-finanziarie e di bilancio e tutela della finanza pubblica», nonche' nel programma «Concorso della Guardia di Finanza alla sicurezza pubblica», nell'ambito della missione «Ordine pubblico e sicurezza» del medesimo stato di previsione.

13. Il numero massimo degli ufficiali ausiliari del Corpo della guardia di finanza di cui alla lettera c) del comma 1 dell'articolo 937 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, da mantenere in servizio nell'anno 2017, ai sensi dell'articolo 803 del medesimo codice, e' stabilito in 70 unita'.

14. Le somme iscritte nel bilancio autonomo della Presidenza del Consiglio dei ministri, assegnate dal CIPE con propria delibera alle amministrazioni interessate ai sensi dell'articolo 1, comma 7, della legge 17 maggio 1999, n. 144, per l'anno finanziario 2017, destinate alla costituzione di unita' tecniche di supporto alla programmazione, alla valutazione e al monitoraggio degli investimenti pubblici, sono versate all'entrata del bilancio dello Stato per essere riassegnate, con decreti del Ministro dell'economia e delle finanze, negli stati di previsione delle amministrazioni medesime.

15. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, per l'anno finanziario 2017, alla riassegnazione ad apposito capitolo di spesa dello stato di previsione del Ministero dell'economia e delle finanze, nella misura stabilita con proprio decreto, delle somme versate nell'ambito della voce «Entrate derivanti dal controllo e repressione delle irregolarita' e degli illeciti» dello stato di previsione dell'entrata, dalla societa' Equitalia Giustizia Spa, a titolo di utili relativi alla gestione finanziaria del fondo di cui all'articolo 61, comma 23, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133.

16. Il Ministro dell'economia e delle finanze, con propri decreti, provvede, nell'anno finanziario 2017, all'adeguamento degli stanziamenti dei capitoli destinati al pagamento dei premi e delle vincite dei giochi pronostici, delle scommesse e delle lotterie, in corrispondenza con l'effettivo andamento delle relative riscossioni.

17. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione al programma «Analisi, monitoraggio e controllo della finanza pubblica e politiche di bilancio», nell'ambito della missione «Politiche economico-finanziarie e di bilancio e tutela della finanza pubblica» dello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello Stato relative alla gestione liquidatoria del Fondo gestione istituti contrattuali lavoratori portuali ed alla gestione liquidatoria denominata «Particolari e straordinarie esigenze, anche di ordine pubblico, della citta' di Palermo».

18. Il Ministro dell'economia e delle finanze e' autorizzato ad effettuare, con propri decreti, variazioni compensative, in termini di competenza e di cassa, tra gli stanziamenti dei capitoli 2214 e 2223 dello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017, iscritti nel programma «Oneri per il servizio del debito statale» e tra gli stanziamenti dei capitoli 9502 e 9503 del medesimo stato di previsione, iscritti nel programma «Rimborsi del debito statale», al fine di provvedere alla copertura del fabbisogno di tesoreria derivante dalla contrazione di mutui ovvero da analoghe operazioni finanziarie, qualora tale modalita' di finanziamento risulti piu' conveniente per la finanza pubblica rispetto all'emissione di titoli del debito pubblico.

-------------- AGGIORNAMENTO (2) Il D.L. 23 dicembre 2016, n. 237, convertito con modificazioni dalla L. 17 febbraio 2017, n. 15, ha disposto (con l'art. 27, comma 1) che per l'anno 2017 l'importo massimo di emissione di titoli pubblici, in Italia e all'estero, di cui al comma 2 del presente articolo, e' incrementato di 20 miliardi di euro.

#### Art. 4. - Stato di previsione del Ministero dello sviluppo economico e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dello sviluppo economico, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 3).

2. Le somme impegnate in relazione alle disposizioni di cui all'articolo 1 del decreto-legge 9 ottobre 1993, n. 410, convertito dalla legge 10 dicembre 1993, n. 513, recante interventi urgenti a sostegno dell'occupazione nelle aree di crisi siderurgica, resesi disponibili a seguito di provvedimenti di revoca, sono versate all'entrata del bilancio dello Stato per essere riassegnate, nell'anno finanziario 2017, con decreti del Ministro dell'economia e delle finanze, allo stato di previsione del Ministero dello sviluppo economico, ai fini di cui al medesimo articolo 1 del decreto-legge n. 410 del 1993.

3. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro dello sviluppo economico, per l'anno finanziario 2017, variazioni compensative in termini di residui, di competenza e di cassa tra i capitoli dello stato di previsione del Ministero dello sviluppo economico, anche tra missioni e programmi diversi, ivi compresa la modifica della denominazione dei centri di responsabilita' amministrativa, connesse con l'attuazione del decreto legislativo 18 agosto 2015, n. 145.

#### Art. 5. - Stato di previsione del Ministero del lavoro e delle politiche sociali e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero del lavoro e delle politiche sociali, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 4).

2. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, su proposta del Ministro del lavoro e delle politiche sociali, con propri decreti, per l'anno finanziario 2017, variazioni compensative in termini di residui, di competenza e di cassa tra i capitoli dello stato di previsione del Ministero del lavoro e delle politiche sociali, anche tra missioni e programmi diversi, connesse con l'attuazione dei decreti legislativi 14 settembre 2015, n. 149 e n. 150.

#### Art. 6. - Stato di previsione del Ministero della giustizia e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero della giustizia, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 5).

2. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione, in termini di competenza e di cassa, delle somme versate dal Comitato olimpico nazionale italiano (CONI), dalle regioni, dalle province, dai comuni e da altri enti pubblici e privati all'entrata del bilancio dello Stato, relativamente alle spese per il mantenimento, per l'assistenza e per la rieducazione di detenuti e internati, per gli interventi e gli investimenti finalizzati al miglioramento delle condizioni detentive e delle attivita' trattamentali, nonche' per le attivita' sportive del personale del Corpo di polizia penitenziaria e di detenuti e internati, nel programma «Amministrazione penitenziaria» e nel programma «Giustizia minorile e di comunita'», nell'ambito della missione «Giustizia» dello stato di previsione del Ministero della giustizia per l'anno finanziario 2017.

#### Art. 7. - Stato di previsione del Ministero degli affari esteri e della cooperazione internazionale e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero degli affari esteri e della cooperazione internazionale, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 6).

2. Il Ministero degli affari esteri e della cooperazione internazionale e' autorizzato ad effettuare, previe intese con il Ministero dell'economia e delle finanze, operazioni in valuta estera non convertibile pari alle disponibilita' esistenti nei conti correnti valuta Tesoro costituiti presso le rappresentanze diplomatiche e gli uffici consolari, ai sensi dell'articolo 5 della legge 6 febbraio 1985, n. 15, e successive modificazioni, e che risultino intrasferibili per effetto di norme o disposizioni locali. Il relativo controvalore in euro e' acquisito all'entrata del bilancio dello Stato ed e' contestualmente iscritto, con decreti del Ministro dell'economia e delle finanze, sulla base delle indicazioni del Ministero degli affari esteri e della cooperazione internazionale, nei pertinenti programmi dello stato di previsione del medesimo Ministero per l'anno finanziario 2017, per l'effettuazione di spese connesse alle esigenze di funzionamento, mantenimento e acquisto delle sedi diplomatiche e consolari, degli istituti di cultura e delle scuole italiane all'estero. Il Ministero degli affari esteri e della cooperazione internazionale e' altresi' autorizzato ad effettuare, con le medesime modalita', operazioni in valuta estera pari alle disponibilita' esistenti nei conti correnti valuta Tesoro in valute inconvertibili o intrasferibili individuate, ai fini delle operazioni di cui al presente comma, dal Dipartimento del tesoro del Ministero dell'economia e delle finanze su richiesta della competente Direzione generale del Ministero degli affari esteri e della cooperazione internazionale.

#### Art. 8.

Stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dell'istruzione, dell'universita' e della ricerca, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 7).

#### Art. 9. - Stato di previsione del Ministero dell'interno e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dell'interno, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 8).

2. Le somme versate dal CONI nell'ambito della voce «Entrate derivanti da servizi resi dalle Amministrazioni statali» dello stato di previsione dell'entrata sono riassegnate, con decreti del Ministro dell'economia e delle finanze, al programma «Prevenzione dal rischio e soccorso pubblico», nell'ambito della missione «Soccorso civile» dello stato di previsione del Ministero dell'interno per l'anno finanziario 2017, per essere destinate alle spese relative all'educazione fisica, all'attivita' sportiva e alla costruzione, al completamento e all'adattamento di infrastrutture sportive concernenti il Corpo nazionale dei vigili del fuoco.

3. Nell'elenco n. 1, annesso allo stato di previsione del Ministero dell'interno, sono indicate le spese per le quali si possono effettuare, per l'anno finanziario 2017, prelevamenti dal fondo a disposizione per la Pubblica sicurezza, di cui all'articolo 1 della legge 12 dicembre 1969, n. 1001, iscritto nel programma «Pianificazione e coordinamento Forze di polizia», nell'ambito della missione «Ordine pubblico e sicurezza».

4. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni compensative di bilancio anche tra i titoli della spesa dello stato di previsione del Ministero dell'interno, occorrenti per l'attuazione delle disposizioni recate dall'articolo 61 del decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni, dall'articolo 10, comma 11, della legge 13 maggio 1999, n. 133, e successive modificazioni, e dall'articolo 8, comma 5, della legge 3 maggio 1999, n. 124, relative ai trasferimenti erariali agli enti locali.

5. Il Ministro dell'economia e delle finanze e' autorizzato a trasferire, con propri decreti, su proposta del Ministro dell'interno, agli stati di previsione dei Ministeri interessati per l'anno finanziario 2017, le risorse iscritte nel capitolo 2313, istituito nel programma «Flussi migratori, interventi per lo sviluppo della coesione sociale, garanzia dei diritti, rapporti con le confessioni religiose», nell'ambito della missione «Immigrazione, accoglienza e garanzia dei diritti» dello stato di previsione del Ministero dell'interno, e nel capitolo 2872, istituito nel programma «Pianificazione e coordinamento Forze di polizia», nell'ambito della missione «Ordine pubblico e sicurezza» del medesimo stato di previsione, in attuazione dell'articolo 1, comma 562, della legge 23 dicembre 2005, n. 266, dell'articolo 34 del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, e delle disposizioni di cui all'articolo 2, comma 106, della legge 24 dicembre 2007, n. 244.

6. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, per l'anno finanziario 2017, con propri decreti, nello stato di previsione del Ministero dell'interno, le variazioni compensative di bilancio anche tra i titoli della spesa, occorrenti per l'attuazione delle disposizioni recate dai decreti legislativi 14 marzo 2011, n. 23, e 6 maggio 2011, n. 68, in materia di federalismo fiscale municipale e di autonomia di entrata delle province.

7. Il Ministro dell'economia e delle finanze e' autorizzato a riassegnare, con propri decreti, nello stato di previsione del Ministero dell'interno, per l'anno finanziario 2017, i contributi relativi al rilascio e al rinnovo dei permessi di soggiorno, di cui all'articolo 5, comma 2-ter, del testo unico di cui al decreto legislativo 25 luglio 1998, n. 286, versati all'entrata del bilancio dello Stato e destinati, ai sensi dell'articolo 14-bis del medesimo testo unico, al Fondo rimpatri, finalizzato a finanziare le spese per il rimpatrio degli stranieri verso i Paesi di origine ovvero di provenienza.

8. Al fine di reperire le risorse occorrenti per il finanziamento dei programmi di rimpatrio volontario ed assistito di cittadini di Paesi terzi verso il Paese di origine o di provenienza, ai sensi dell'articolo 14-ter del testo unico di cui al decreto legislativo 25 luglio 1998, n. 286, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro dell'interno, per l'anno finanziario 2017, le occorrenti variazioni compensative di bilancio, nello stato di previsione del Ministero dell'interno, anche tra missioni e programmi diversi.

9. Ferma restando l'adozione dello specifico sistema di erogazione unificata di competenze fisse e accessorie al personale da parte delle amministrazioni dello Stato, al fine di consentire l'erogazione nell'anno successivo delle somme rimaste da pagare alla fine di ciascun esercizio finanziario a titolo di competenze accessorie, per tutti gli appartenenti alle Forze di polizia si applicano le disposizioni di cui al comma 3 dell'articolo 2 del decreto del Ministro dell'economia e delle finanze 1º dicembre 2010, pubblicato nella Gazzetta Ufficiale n. 293 del 16 dicembre 2010.

10. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni compensative di bilancio tra i programmi di spesa dello stato di previsione del Ministero dell'interno «Elaborazione, quantificazione e assegnazione delle risorse finanziarie da attribuire agli enti locali» e «Gestione dell'albo dei segretari comunali e provinciali», in relazione alle minori o maggiori occorrenze connesse alla gestione dell'albo dei segretari provinciali e comunali necessarie ai sensi dell'articolo 7, comma 31-ter, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e dell'articolo 10 del decreto-legge 10 ottobre 2012, n. 174, convertito, con modificazioni, dalla legge 7 dicembre 2012, n. 213.

#### Art. 10. - Stato di previsione del Ministero dell'ambiente e della tutela del territorio e del mare

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dell'ambiente e della tutela del territorio e del mare, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 9).

#### Art. 11. - Stato di previsione del Ministero delle infrastrutture e dei trasporti e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero delle infrastrutture e dei trasporti, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 10).

2. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro delle infrastrutture e dei trasporti, le variazioni di competenza e di cassa nello stato di previsione dell'entrata e in quello del Ministero delle infrastrutture e dei trasporti, per l'anno finanziario 2017, per gli adempimenti previsti dalla legge 6 giugno 1974, n. 298, nonche' dall'articolo 10 del regolamento di cui al decreto del Presidente della Repubblica 28 settembre 1994, n. 634, concernente la disciplina dell'ammissione all'utenza del servizio di informatica del centro elaborazione dati del Dipartimento per i trasporti, la navigazione, gli affari generali ed il personale del Ministero delle infrastrutture e dei trasporti.

3. Il numero massimo degli ufficiali ausiliari del Corpo delle capitanerie di porto da mantenere in servizio come forza media nell'anno 2017, ai sensi dell'articolo 803 del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e' stabilito come segue: 200 ufficiali in ferma prefissata o in rafferma, di cui alla lettera c) del comma 1 dell'articolo 937 del codice di cui al decreto legislativo n. 66 del 2010; 70 ufficiali piloti di complemento, di cui alla lettera b) del comma 1 dell'articolo 937 del codice di cui al decreto legislativo n. 66 del 2010.

4. Il numero massimo degli allievi del Corpo delle capitanerie di porto da mantenere alla frequenza dei corsi presso l'Accademia navale e le Scuole sottufficiali della Marina militare, per l'anno 2017, e' fissato in 136 unita'.

5. Nell'elenco n. 1 annesso allo stato di previsione del Ministero delle infrastrutture e dei trasporti, riguardante il Corpo delle capitanerie di porto, sono descritte le spese per le quali possono effettuarsi, per l'anno finanziario 2017, i prelevamenti dal fondo a disposizione iscritto nel programma «Sicurezza e controllo nei mari, nei porti e sulle coste», nell'ambito della missione «Ordine pubblico e sicurezza» del medesimo stato di previsione.

6. Ai sensi dell'articolo 2 del regolamento per i servizi di cassa e contabilita' delle Capitanerie di porto, di cui al regio decreto 6 febbraio 1933, n. 391, i fondi di qualsiasi provenienza possono essere versati in conto corrente postale dai funzionari delegati.

7. Le disposizioni legislative e regolamentari in vigore presso il Ministero della difesa si applicano, in quanto compatibili, alla gestione dei fondi di pertinenza delle Capitanerie di porto. Alle spese per la manutenzione e l'esercizio dei mezzi nautici, terrestri e aerei e per attrezzature tecniche, materiali e infrastrutture occorrenti per i servizi tecnici e di sicurezza dei porti e delle caserme delle Capitanerie di porto, di cui al programma «Sicurezza e controllo nei mari, nei porti e sulle coste», nell'ambito della missione «Ordine pubblico e sicurezza» dello stato di previsione del Ministero delle infrastrutture e dei trasporti, si applicano, per l'anno finanziario 2017, le disposizioni dell'articolo 61-bis del regio decreto 18 novembre 1923, n. 2440, sulla contabilita' generale dello Stato.

#### Art. 12. - Stato di previsione del Ministero della difesa e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero della difesa, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 11).

2. Il numero massimo degli ufficiali ausiliari da mantenere in servizio come forza media nell'anno 2017, ai sensi dell'articolo 803 del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e' stabilito come segue:

- a) ufficiali ausiliari, di cui alle lettere a) e c) del comma 1 dell'articolo 937 del codice di cui al decreto legislativo n. 66 del 2010: 1) Esercito n. 56; 2) Marina n. 27; 3) Aeronautica n. 63; 4) Carabinieri n. 0;
- b) ufficiali ausiliari piloti di complemento, di cui alla lettera b) del comma 1 dell'articolo 937 del codice di cui al decreto legislativo n. 66 del 2010: 1) Esercito n. 0; 2) Marina n. 22; 3) Aeronautica n. 13;
- c) ufficiali ausiliari delle forze di completamento, di cui alla lettera d) del comma 1 dell'articolo 937 del codice di cui al decreto legislativo n. 66 del 2010: 1) Esercito n. 98; 2) Marina n. 18; 3) Aeronautica n. 25; 4) Carabinieri n. 10.

3. La consistenza organica degli allievi ufficiali delle accademie delle Forze armate, compresa l'Arma dei carabinieri, di cui alla lettera b) del comma 1 dell'articolo 803 del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, e' fissata, per l'anno 2017, come segue: 1) Esercito n. 280; 2) Marina n. 290; 3) Aeronautica n. 245; 4) Carabinieri n. 105.

4. La consistenza organica degli allievi delle scuole sottufficiali delle Forze armate, esclusa l'Arma dei carabinieri, di cui alla lettera b-bis) del comma 1 dell'articolo 803 del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e' stabilita, per l'anno 2017, come segue: 1) Esercito n. 420; 2) Marina n. 306; 3) Aeronautica n. 286.

5. La consistenza organica degli allievi delle scuole militari, di cui alla lettera b-ter) del comma 1 dell'articolo 803 del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e' stabilita, per l'anno 2017, come segue: 1) Esercito n. 480; 2) Marina n. 195; 3) Aeronautica n. 135.

6. Alle spese per accordi internazionali, specificamente afferenti alle infrastrutture multinazionali dell'Alleanza atlantica (NATO), di cui al programma «Servizi e affari generali per le amministrazioni di competenza», nell'ambito della missione «Servizi istituzionali e generali delle amministrazioni pubbliche» ed ai programmi «Approntamento e impiego Carabinieri per la difesa e la sicurezza» e «Pianificazione generale delle Forze Armate e approvvigionamenti militari», nell'ambito della missione «Difesa e sicurezza del territorio» dello stato di previsione del Ministero della difesa, si applicano, per l'anno 2017, le disposizioni contenute nell'articolo 61-bis del regio decreto 18 novembre 1923, n. 2440, sulla contabilita' generale dello Stato.

7. Alle spese per le infrastrutture multinazionali della NATO, sostenute a carico dei programmi «Servizi ed affari generali per le amministrazioni di competenza», «Approntamento e impiego Carabinieri per la difesa e la sicurezza» e «Pianificazione generale delle Forze Armate e approvvigionamenti militari», nell'ambito della missione «Difesa e sicurezza del territorio» dello stato di previsione del Ministero della difesa, per l'anno finanziario 2017, si applicano le direttive che definiscono le procedure di negoziazione ammesse dalla NATO in materia di affidamento dei lavori.

8. Negli elenchi n. 1 e n. 2 allegati allo stato di previsione del Ministero della difesa sono descritte le spese per le quali si possono effettuare, per l'anno finanziario 2017, i prelevamenti dai fondi a disposizione relativi alle tre Forze armate e all'Arma dei carabinieri, ai sensi dell'articolo 613 del codice di cui al decreto legislativo 15 marzo 2010, n. 66.

9. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione ai pertinenti programmi dello stato di previsione del Ministero della difesa, per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello Stato dal CONI, destinate alle attivita' sportive del personale militare e civile della difesa.

10. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione ai pertinenti capitoli del programma «Approntamento e impiego Carabinieri per la difesa e la sicurezza», nell'ambito della missione «Difesa e sicurezza del territorio» dello stato di previsione del Ministero della difesa, per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello Stato dalla Banca d'Italia per i servizi di vigilanza e custodia resi presso le proprie sedi dal personale dell'Arma dei carabinieri.

#### Art. 13. - Stato di previsione del Ministero delle politiche agricole alimentari e forestali e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero delle politiche agricole alimentari e forestali, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 12).

2. Per l'attuazione del decreto legislativo 26 maggio 2004, n. 154, e del decreto legislativo 27 maggio 2005, n. 100, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, nell'ambito della parte corrente e nell'ambito del conto capitale dello stato di previsione del Ministero delle politiche agricole alimentari e forestali, per l'anno finanziario 2017, le variazioni compensative di bilancio, in termini di competenza e di cassa, occorrenti per la modifica della ripartizione delle risorse tra i vari settori d'intervento del Programma nazionale della pesca e dell'acquacoltura.

3. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, al trasferimento delle somme iscritte nel capitolo 2827 del programma «Politiche europee ed internazionali e dello sviluppo rurale», nell'ambito della missione «Agricoltura, politiche agroalimentari e pesca» dello stato di previsione del Ministero delle politiche agricole alimentari e forestali per l'anno finanziario 2017, ai competenti capitoli dello stato di previsione del Ministero delle politiche agricole alimentari e forestali per il medesimo anno, secondo la ripartizione percentuale indicata all'articolo 24, comma 2, della legge 11 febbraio 1992, n. 157.

4. Per l'anno finanziario 2017 il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, nello stato di previsione del Ministero delle politiche agricole alimentari e forestali, le variazioni compensative di bilancio, in termini di competenza e di cassa, occorrenti per l'attuazione di quanto stabilito dagli articoli 12 e 23-quater del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, in ordine alla soppressione e riorganizzazione di enti vigilati dal medesimo Ministero.

5. Il Ministro dell'economia e delle finanze e' autorizzato a ripartire, con propri decreti, per l'anno finanziario 2017, tra i pertinenti programmi dello stato di previsione del Ministero delle politiche agricole alimentari e forestali, le somme iscritte, in termini di residui, di competenza e di cassa, nel capitolo 7810 «Somme da ripartire per assicurare la continuita' degli interventi pubblici nel settore agricolo e forestale» istituito nel programma «Politiche competitive, della qualita' agroalimentare, della pesca, dell'ippica e mezzi tecnici di produzione», nell'ambito della missione «Agricoltura, politiche agroalimentari e pesca» del medesimo stato di previsione, destinato alle finalita' di cui alla legge 23 dicembre 1999, n. 499, recante razionalizzazione degli interventi nel settore agricolo, agroalimentare, agroindustriale e forestale.

6. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione, ai pertinenti programmi dello stato di previsione del Ministero delle politiche agricole alimentari e forestali, per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello Stato da amministrazioni ed enti pubblici in virtu' di accordi di programma, convenzioni ed intese per il raggiungimento di finalita' comuni in materia di telelavoro, ai sensi dell'articolo 4 della legge 16 giugno 1998, n. 191, dell'articolo 3 del regolamento di cui al decreto del Presidente della Repubblica 8 marzo 1999, n. 70, e dell'articolo 15 della legge 7 agosto 1990, n. 241, e successive modificazioni.

#### Art. 14.

Stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo e disposizioni relative

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero dei beni e delle attivita' culturali e del turismo, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 13).

2. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro dei beni e delle attivita' culturali e del turismo, per l'anno finanziario 2017, le variazioni compensative di bilancio, in termini di residui, di competenza e di cassa, tra i capitoli iscritti nel programma «Sostegno, valorizzazione e tutela del settore dello spettacolo dal vivo» e nel programma «Sostegno, valorizzazione e tutela del settore cinema e audiovisivo», nell'ambito della missione «Tutela e valorizzazione dei beni e attivita' culturali e paesaggistici» dello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo relativi al Fondo unico per lo spettacolo.

3. Ai fini di una razionale utilizzazione delle risorse di bilancio, per l'anno finanziario 2017, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, adottati su proposta del Ministro dei beni e delle attivita' culturali e del turismo, comunicati alle competenti Commissioni parlamentari e trasmessi alla Corte dei conti per la registrazione, le occorrenti variazioni compensative di bilancio, in termini di competenza e di cassa, tra i capitoli iscritti nei pertinenti programmi dello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo, relativi agli acquisti ed alle espropriazioni per pubblica utilita', nonche' per l'esercizio del diritto di prelazione da parte dello Stato su immobili di interesse archeologico e monumentale e su cose di arte antica, medievale, moderna e contemporanea e di interesse artistico e storico, nonche' su materiale archivistico pregevole e materiale bibliografico, raccolte bibliografiche, libri, documenti, manoscritti e pubblicazioni periodiche, ivi comprese le spese derivanti dall'esercizio del diritto di prelazione, del diritto di acquisto delle cose denunciate per l'esportazione e dell'espropriazione, a norma di legge, di materiale bibliografico prezioso e raro.

#### Art. 15. - Stato di previsione del Ministero della salute

1. Sono autorizzati l'impegno e il pagamento delle spese del Ministero della salute, per l'anno finanziario 2017, in conformita' all'annesso stato di previsione (Tabella n. 14).

#### Art. 16. - Totale generale della spesa

1. Sono approvati, rispettivamente, in euro 861.047.385.808, in euro 840.467.437.456 e in euro 846.363.079.483 in termini di competenza, nonche' in euro 879.681.277.369, in euro 846.168.154.985 e in euro 850.418.146.132 in termini di cassa, i totali generali della spesa dello Stato per il triennio 2017-2019.

#### Art. 17. - Quadro generale riassuntivo

1. E' approvato, in termini di competenza e di cassa, per il triennio 2017-2019, il quadro generale riassuntivo del bilancio dello Stato, con le tabelle allegate.

#### Art. 18. - Disposizioni diverse

1. In relazione all'accertamento dei residui di entrata e di spesa per i quali non esistono nel bilancio di previsione i corrispondenti capitoli nell'ambito dei programmi interessati, il Ministro dell'economia e delle finanze e' autorizzato ad istituire gli occorrenti capitoli nei pertinenti programmi con propri decreti da comunicare alla Corte dei conti.

2. Il Ministro dell'economia e delle finanze e' autorizzato a trasferire, in termini di competenza e di cassa, con propri decreti, su proposta dei Ministri interessati, per l'anno finanziario 2017, le disponibilita' esistenti su altri programmi degli stati di previsione delle amministrazioni competenti a favore di appositi programmi destinati all'attuazione di interventi cofinanziati dall'Unione europea.

3. In relazione ai provvedimenti di riordino delle amministrazioni pubbliche, il Ministro dell'economia e delle finanze, su proposta dei Ministri competenti, e' autorizzato ad apportare, con propri decreti, da comunicare alle Commissioni parlamentari competenti, per l'anno finanziario 2017, le variazioni compensative di bilancio in termini di residui, di competenza e di cassa, ivi comprese l'istituzione, la modifica e la soppressione di programmi, che si rendano necessarie in relazione all'accorpamento di funzioni o al trasferimento di competenze.

4. Su proposta del Ministro competente, con decreti del Ministro dell'economia e delle finanze, da comunicare alle Commissioni parlamentari competenti, negli stati di previsione della spesa che nell'esercizio finanziario 2017 e in quello in corso siano stati interessati dai processi di ristrutturazione di cui al comma 3, nonche' da quelli previsti da altre normative vigenti, possono essere effettuate variazioni compensative, in termini di residui, di competenza e di cassa, limitatamente alle autorizzazioni di spesa aventi natura di fabbisogno, nonche' tra capitoli di programmi dello stesso stato di previsione limitatamente alle spese di funzionamento per oneri relativi a movimenti di personale e per quelli strettamente connessi con l'operativita' delle amministrazioni.

5. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni di bilancio connesse con l'attuazione dei contratti collettivi nazionali di lavoro del personale dipendente dalle amministrazioni dello Stato, stipulati ai sensi dell'articolo 40 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, nonche' degli accordi sindacali e dei provvedimenti di concertazione, adottati ai sensi dell'articolo 2 del decreto legislativo 12 maggio 1995, n. 195, e successive modificazioni, per quanto concerne il trattamento economico fondamentale e accessorio del personale interessato.

6. Le risorse finanziarie relative ai fondi destinati all'incentivazione del personale civile dello Stato, delle Forze armate, del Corpo nazionale dei vigili del fuoco e dei Corpi di polizia, nonche' quelle per la corresponsione del trattamento economico accessorio del personale dirigenziale, non utilizzate alla chiusura dell'esercizio, sono conservate nel conto dei residui per essere utilizzate nell'esercizio successivo. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni di bilancio occorrenti per l'utilizzazione dei predetti fondi conservati.

7. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione, negli stati di previsione delle amministrazioni statali interessate, per l'anno finanziario 2017, delle somme rimborsate dalla Commissione europea per spese sostenute dalle amministrazioni medesime a carico dei pertinenti programmi dei rispettivi stati di previsione, affluite al fondo di rotazione di cui all'articolo 5 della legge 16 aprile 1987, n. 183, e successivamente versate all'entrata del bilancio dello Stato.

8. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni di bilancio negli stati di previsione delle amministrazioni interessate, occorrenti per l'attuazione dei decreti del Presidente del Consiglio dei ministri emanati ai sensi dell'articolo 7 della legge 15 marzo 1997, n. 59, e successive modificazioni, e dei decreti legislativi concernenti il conferimento di funzioni e compiti amministrativi dello Stato alle regioni e agli enti locali, in attuazione del capo I della medesima legge n. 59 del 1997, e successive modificazioni.

9. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, nei pertinenti programmi degli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, le variazioni di bilancio occorrenti per l'applicazione del decreto legislativo 18 febbraio 2000, n. 56, concernente disposizioni in materia di federalismo fiscale.

10. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione negli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, delle somme versate all'entrata a titolo di contribuzione alle spese di gestione degli asili nido istituiti presso le amministrazioni statali ai sensi dell'articolo 70, comma 5, della legge 28 dicembre 2001, n. 448, nonche' di quelle versate a titolo di contribuzione alle spese di gestione di servizi ed iniziative finalizzati al benessere del personale.

11. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, nell'ambito degli stati di previsione di ciascun Ministero, per l'anno finanziario 2017, le variazioni compensative di bilancio tra i capitoli interessati al pagamento delle competenze fisse e accessorie mediante ordini collettivi di pagamento con il sistema denominato «cedolino unico», ai sensi dell'articolo 2, comma 197, della legge 23 dicembre 2009, n. 191.

12. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, negli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, le variazioni di bilancio compensative occorrenti per l'attuazione dell'articolo 14, comma 2, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122.

13. In attuazione dell'articolo 30, comma 4, della legge 31 dicembre 2009, n. 196, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni compensative, in termini di competenza e di cassa, tra gli stanziamenti dei capitoli degli stati di previsione dei Ministeri, delle spese per interessi passivi e per rimborso di passivita' finanziarie relative ad operazioni di mutui il cui onere di ammortamento e' posto a carico dello Stato.

14. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, negli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, le variazioni di bilancio compensative occorrenti in relazione alle riduzioni dei trasferimenti agli enti territoriali, disposte ai sensi dell'articolo 16, comma 2, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni.

15. Il Ministro dell'economia e delle finanze e' autorizzato a riassegnare, per l'anno finanziario 2017, con propri decreti, negli stati di previsione delle amministrazioni competenti per materia, che subentrano, ai sensi della normativa vigente, nella gestione delle residue attivita' liquidatorie degli organismi ed enti vigilati dallo Stato, sottoposti a liquidazione coatta amministrativa in base all'articolo 12, comma 40, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, le somme residuali al 31 dicembre 2016 versate all'entrata del bilancio dello Stato dai commissari liquidatori cessati dall'incarico.

16. Le somme stanziate sul capitolo 1896 dello stato di previsione del Ministero dell'economia e delle finanze, destinate al CONI per il finanziamento dello sport, e sul capitolo 2295 dello stato di previsione del Ministero delle politiche agricole alimentari e forestali, destinate agli interventi gia' di competenza della soppressa Agenzia per lo sviluppo del settore ippico, per il finanziamento del monte premi delle corse, in caso di mancata adozione del decreto previsto dall'articolo 1, comma 281, della legge 30 dicembre 2004, n. 311, e successive modificazioni, o, comunque, nelle more dell'emanazione dello stesso, costituiscono determinazione della quota parte delle entrate erariali ed extraerariali derivanti da giochi pubblici con vincita in denaro affidati in concessione allo Stato ai sensi del comma 282 del medesimo articolo 1 della legge n. 311 del 2004.

17. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni di bilancio negli stati di previsione delle amministrazioni interessate, occorrenti per l'attuazione dell'articolo 10 del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, relativo al trasferimento delle risorse umane, strumentali e finanziarie del Dipartimento per lo sviluppo e la coesione economica del Ministero dello sviluppo economico alla Presidenza del Consiglio dei ministri e all'Agenzia per la coesione territoriale.

18. Le risorse finanziarie iscritte nei fondi connessi alla sistemazione di partite contabilizzate in conto sospeso nonche' da destinare alle regioni, alle province autonome e agli altri enti territoriali, istituiti negli stati di previsione dei Ministeri interessati, in relazione all'eliminazione dei residui passivi di bilancio e alla cancellazione dei residui passivi perenti, a seguito dell'attivita' di ricognizione svolta in attuazione dell'articolo 49, comma 2, lettere c) e d), del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, sono ripartite con decreti del Ministro competente.

19. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alle variazioni compensative per il triennio 2017-2019 tra i programmi degli stati di previsione dei Ministeri interessati e il capitolo 3465, articolo 2, dello stato di previsione dell'entrata, in relazione al contributo alla finanza pubblica previsto dal comma 6 dell'articolo 46 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e successive modificazioni, da attribuire con decreto del Presidente del Consiglio dei ministri a carico delle regioni e delle province autonome di Trento e di Bolzano.

20. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le variazioni di bilancio occorrenti per la ripartizione, tra le diverse finalita' di spesa, delle risorse finanziarie iscritte negli stati di previsione del Ministero dello sviluppo economico e del Ministero dell'ambiente e della tutela del territorio e del mare in attuazione dell'articolo 19, commi 2 e 3, del decreto legislativo 13 marzo 2013, n. 30.

21. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, negli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, le variazioni di bilancio occorrenti per la riduzione degli stanziamenti dei capitoli relativi alle spese correnti per l'acquisto di beni e servizi in applicazione di quanto disposto dall'articolo 2, comma 222-quater, della legge 23 dicembre 2009, n. 191, e successive modificazioni.

22. Le assegnazioni disposte con decreto del Presidente del Consiglio dei ministri per corrispondere a eccezionali indilazionabili esigenze di servizio, per l'anno finanziario 2017, tengono conto anche delle risorse finanziarie gia' iscritte sui pertinenti capitoli degli stati di previsione dei Ministeri interessati al fine di assicurare la tempestiva corresponsione delle somme dovute al personale e ammontanti al 50 per cento delle risorse complessivamente autorizzate per le medesime finalita' nell'anno 2016. L'utilizzazione delle risorse e' subordinata alla registrazione del citato decreto del Presidente del Consiglio dei ministri da parte dei competenti organi di controllo.

23. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta dei Ministri competenti, per l'anno finanziario 2017, le variazioni compensative, anche tra programmi diversi del medesimo stato di previsione, in termini di residui, di competenza e di cassa, che si rendano necessarie nel caso di sentenze definitive anche relative ad esecuzione forzata nei confronti delle amministrazioni dello Stato.

24. In relazione al pagamento delle competenze accessorie mediante ordini collettivi di pagamento con il sistema denominato «cedolino unico», ai sensi dell'articolo 2, comma 197, della legge 23 dicembre 2009, n. 191, il Ministro dell'economia e delle finanze, su proposta del Ministro dell'interno, e' autorizzato a ripartire, con propri decreti, fra gli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, i fondi iscritti nello stato di previsione del Ministero dell'interno, nell'ambito della missione «Ordine pubblico e sicurezza», programma «Servizio permanente dell'Arma dei Carabinieri per la tutela dell'ordine e la sicurezza pubblica» e programma «Pianificazione e coordinamento Forze di polizia», concernenti il trattamento accessorio del personale delle Forze di polizia e del personale alle dipendenze della Direzione investigativa antimafia.

25. In relazione al pagamento delle competenze fisse e accessorie mediante ordini collettivi di pagamento con il sistema denominato «cedolino unico», ai sensi dell'articolo 2, comma 197, della legge 23 dicembre 2009, n. 191, il Ministro dell'economia e delle finanze e' autorizzato a riassegnare nello stato di previsione del Ministero della difesa, per l'anno finanziario 2017, le somme versate in entrata concernenti le competenze fisse e accessorie del personale dell'Arma dei carabinieri in forza extraorganica presso le altre amministrazioni.

26. Su proposta del Ministro dell'interno, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, per l'anno finanziario 2017, le variazioni compensative negli stati di previsione delle amministrazioni interessate, tra le spese per la manutenzione dei beni acquistati nell'ambito delle dotazioni tecniche e logistiche per le esigenze delle sezioni di polizia giudiziaria, iscritte nell'ambito della missione «Ordine pubblico e sicurezza», programma «Contrasto al crimine, tutela dell'ordine e della sicurezza pubblica».

27. Ai fini dell'attuazione del programma di interventi previsto dall'articolo 5, comma 2, del decreto legislativo 4 luglio 2014, n. 102, finanziato ai sensi del comma 12 del medesimo articolo, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro dello sviluppo economico, per l'anno finanziario 2017, variazioni compensative, in termini di residui, di competenza e di cassa, tra i capitoli dello stato di previsione del Ministero dello sviluppo economico relativi all'attuazione del citato programma di interventi e i correlati capitoli degli stati di previsione del Ministero dell'economia e delle finanze e del Ministero delle infrastrutture e dei trasporti.

28. In relazione alla razionalizzazione delle funzioni di polizia e all'assorbimento del Corpo forestale dello Stato nell'Arma dei carabinieri di cui al decreto legislativo 19 agosto 2016, n. 177, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, per l'anno finanziario 2017, le opportune variazioni compensative di bilancio tra gli stati di previsione delle amministrazioni interessate.

29. Il Ministro dell'economia e delle finanze e' autorizzato a provvedere, con propri decreti, alla riassegnazione negli stati di previsione delle amministrazioni interessate, per l'anno finanziario 2017, delle somme versate all'entrata del bilancio dello stato dall'Unione europea, dalle pubbliche amministrazioni e da enti pubblici e privati, a titolo di contribuzione alle spese di promozione della conciliazione dei tempi di vita e di lavoro nelle amministrazioni pubbliche di cui all'articolo 14 della legge 7 agosto 2015, n. 124.

30. Il Ministro dell'economia e delle finanze e' autorizzato a ripartire, tra gli stati di previsione dei Ministeri interessati, le risorse del capitolo «Fondo ((...)) per la sistemazione contabile delle partite iscritte al conto sospeso», iscritto nello stato di previsione del Ministero dell'economia e delle finanze per l'anno finanziario 2017 ((, ovvero, al fine di accelerare l'estinzione delle suddette partite, ad assegnare direttamente le medesime risorse, anche in conto residui, all'istituto gestore della tesoreria dello Stato, il quale provvede alla relativa sistemazione fornendo al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato e alla competente Amministrazione ogni elemento informativo utile delle operazioni effettuate di individuazione e regolazione di ciascuna partita, secondo lo schema trasmesso dal Dipartimento della Ragioneria generale dello Stato)). Le risorse del suddetto fondo non utilizzate nel corso dello stesso esercizio sono conservate in bilancio al termine dell'anno 2017 per essere utilizzate nell'esercizio successivo.

#### Art. 19. - Entrata in vigore

1. La presente legge, salvo quanto diversamente previsto, entra in vigore il 1º gennaio 2017.

